'use strict';
/**
 * @ngdoc overview
 * @name Track
 * @description
 * # Initializes main application and routing
 *
 * Main module of the application.
 */

angular.module('Track', ['ionic', 'ngCordova', 'ngResource', 'nutritionix.nutrition-label', 'nix.track-api-client', 'nix.diet-graph-directive', 'nix.fda-round-filter', 'nix.textcomplete', 'angular-carousel', 'angular.filter', 'monospaced.qrcode', 'chart.js', 'ngPostMessage', 'ngFileUpload', 'ion-autocomplete']).run(["$ionicPlatform", "$cordovaNetwork", "ConfigurationService", "UserService", "nixTrackApiClient", "$http", "$state", "$cordovaSQLite", "PushNotificationService", "SQLiteService", function ($ionicPlatform, $cordovaNetwork, ConfigurationService, UserService, nixTrackApiClient, $http, $state, $cordovaSQLite, PushNotificationService, SQLiteService) {
  $ionicPlatform.ready(function () {
    window.Sentry.init({
      dsn: 'https://84e7ad3ef0d24d73895d708080289fb3@sentry.io/1212947',
      release: 'com.nutritionix.nixtrack-1.4.8' + (ConfigurationService.environment === 'local' ? '-dev' : '')
    });

    if (!window.db) {
      window.db = window.sqlitePlugin.openDatabase({
        name: 'track_db',
        location: 1
      }); // smooth transition to new logic, uncomment when versions lower than 1.4.0 become obsolete (minimal % of users)

      $cordovaSQLite.execute(window.db, "SELECT name FROM sqlite_master WHERE type='table' AND name='localdata'").then(function (res) {
        var result = SQLiteService.getAll(res);

        if (result.length) {
          $cordovaSQLite.execute(window.db, "SELECT * FROM localdata").then(function (res) {
            var result = SQLiteService.getAll(res);
            var filtered = result.filter(function (row) {
              return row.dataName === 'currentUser';
            });

            if (!!filtered && filtered.length) {
              var oldUserObj = JSON.parse(filtered[0].value);
              SQLiteService.query(window.db, 'DROP TABLE IF EXISTS localdata');
              $cordovaSQLite.execute(window.db, 'CREATE TABLE IF NOT EXISTS localdata (id INTEGER PRIMARY KEY, dataName TEXT UNIQUE, value TEXT)');
              UserService.setJwt(oldUserObj['x-user-jwt']);
              UserService.setUser(oldUserObj.user);
            }

            UserService.getUser().then(function (user) {
              PushNotificationService.scheduleNotifications(user.weekday_reminders_enabled, user.weekend_reminders_enabled);
            })["catch"](function (err) {
              console.log('[run 1] Error getting user data:', err);
            });
            UserService.getJwt().then(function (jwt) {
              console.log('[run 1] jwt: ', jwt ? jwt.length : 'no JWT stored');
              nixTrackApiClient.setUserJwt(jwt);
              $http.defaults.headers.common['x-user-jwt'] = jwt || '';
              console.log('[run 1] setting user jwt in default headers.');
              setTimeout(function () {
                $state.go('app.foodlog');
              }, 100);
            })["catch"](function (err) {
              console.log('[run 1] Error getting jwt:', err);
            });
          });
        } else {
          $cordovaSQLite.execute(window.db, 'CREATE TABLE IF NOT EXISTS localdata (id INTEGER PRIMARY KEY, dataName TEXT UNIQUE, value TEXT)');
        }
      });
    } // end of transition code
    // new logic, uncomment when versions lower than 1.4.0 become obsolete (minimal % of users)
    // $cordovaSQLite
    //   .execute(window.db, 'CREATE TABLE IF NOT EXISTS localdata (id INTEGER PRIMARY KEY, dataName TEXT UNIQUE, value TEXT)');
    // $cordovaSQLite
    //   .execute(window.db, 'CREATE TABLE IF NOT EXISTS localdatatest (id INTEGER PRIMARY KEY, dataName TEXT UNIQUE, value TEXT)');
    // }


    UserService.getUser().then(function (user) {
      PushNotificationService.scheduleNotifications(user.weekday_reminders_enabled, user.weekend_reminders_enabled);
    })["catch"](function (err) {
      console.log('[run 1] Error getting user data:', err);
    });
    UserService.getJwt().then(function (jwt) {
      console.log('[run 1] jwt: ', jwt ? jwt.length : 'no JWT stored');
      nixTrackApiClient.setUserJwt(jwt);
      $http.defaults.headers.common['x-user-jwt'] = jwt || '';
      console.log('[run 1] setting user jwt in default headers.');
    })["catch"](function (err) {
      console.log('[run 1] Error getting jwt:', err);
    });
  });
}]).run(["$ionicPlatform", "$rootScope", "$state", "$cordovaDevice", "$cordovaSQLite", "$cordovaSplashscreen", "$cordovaNetwork", "$http", "$interval", "$timeout", "AnalyticsService", "ApiService", "CacheFactory", "UserService", "SQLiteService", "ExternalURLService", "ForceTouchService", "PushNotificationService", "nixTrackApiClient", "NixService", "HealthKitWeightService", "HealthKitExerciseService", "WidgetService", function ($ionicPlatform, $rootScope, $state, $cordovaDevice, $cordovaSQLite, $cordovaSplashscreen, $cordovaNetwork, $http, $interval, $timeout, AnalyticsService, ApiService, CacheFactory, UserService, SQLiteService, ExternalURLService, ForceTouchService, PushNotificationService, nixTrackApiClient, NixService, HealthKitWeightService, HealthKitExerciseService, WidgetService) {
  if (!$rootScope.userTotals) {
    $rootScope.userTotals = {};
  }

  var latestDeeplinkTimestamp;
  $rootScope.showStateChangeOverlay = false;

  window.alert = function () {
    console.log('alert is manually suppressed.');
  };

  ApiService.getCachedFoodLog().then(function (cachedLog) {
    $rootScope.foodlog = cachedLog;
  })["catch"](function (err) {
    $rootScope.foodlog = [];
    console.log('[App] Error getting cached foodLog', err);
  });
  $ionicPlatform.ready(function () {
    window.universalLinks.subscribe('LaunchUrl', function (eventData) {
      console.log('Did launch application from the link: ' + eventData.url);

      if (eventData.url) {
        //avoid running handler with empty data
        if (!latestDeeplinkTimestamp) {
          // avoid calling handler with the same data twice on iOS
          latestDeeplinkTimestamp = eventData.timestamp;
        } else if (latestDeeplinkTimestamp == eventData.timestamp) {
          return;
        }

        var url = eventData || eventData.url;
        ExternalURLService.handleUrl(url);
      }
    });
    document.addEventListener('deviceready', function () {
      if (!!cordova.plugins.notification.local.launchDetails) {
        $state.go('app.foodlog');
        cordova.plugins.notification.local.launchDetails = undefined;
      }
    }, false);

    if (window.device.platform == 'Android') {
      $rootScope.$on('$stateChangeStart', function (event, toState, toParams, fromState, fromParams, error) {
        $rootScope.showStateChangeOverlay = true;
      });
      $rootScope.$on('$stateChangeSuccess', function (event, toState, toParams, fromState, fromParams, error) {
        $timeout(function () {
          $rootScope.showStateChangeOverlay = false;
        }, 200);
      });
      $rootScope.$on('$stateNotFound', function (event, toState, toParams, fromState, fromParams, error) {
        $timeout(function () {
          $rootScope.showStateChangeOverlay = false;
        }, 200);
      });
      $rootScope.$on('$stateChangeError', function (event, toState, toParams, fromState, fromParams, error) {
        $timeout(function () {
          $rootScope.showStateChangeOverlay = false;
        }, 200);
      });
    }

    $rootScope.checkOnlineTimer;
    $cordovaSplashscreen.hide();
    ForceTouchService.configure(); // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
    // for form inputs)

    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
      cordova.plugins.Keyboard.disableScroll(true);
    }

    if (window.StatusBar) {
      // org.apache.cordova.statusbar required
      StatusBar.styleDefault();
    } // AnalyticsService.init();


    if ($cordovaSQLite) {
      if (!window.barcode_history_db) {
        window.barcode_history_db = window.sqlitePlugin.openDatabase({
          name: 'barcode_scanner_history.db',
          location: 1
        });
      }

      if (!window.db) {
        window.db = window.sqlitePlugin.openDatabase({
          name: 'track_db',
          location: 1
        });
      }

      $cordovaSQLite.execute(window.db, 'CREATE TABLE IF NOT EXISTS queries (id INTEGER PRIMARY KEY, query TEXT, updated_at DATETIME DEFAULT CURRENT_TIMESTAMP)');
      $cordovaSQLite.execute(window.db, 'CREATE TABLE IF NOT EXISTS history (id INTEGER PRIMARY KEY, response TEXT, updated_at DATETIME DEFAULT CURRENT_TIMESTAMP)');
      $cordovaSQLite.execute(window.db, 'CREATE TABLE IF NOT EXISTS localdata (id INTEGER PRIMARY KEY, dataName TEXT UNIQUE, value TEXT)');
      $cordovaSQLite.execute(window.db, 'CREATE TABLE IF NOT EXISTS iap_receipts (id INTEGER PRIMARY KEY, receipt TEXT, signature TEXT)');
      SQLiteService.query(window.barcode_history_db, 'DELETE FROM history'); // Clear barcode scans history
    }

    if ($cordovaNetwork.isOnline()) {
      if ($cordovaNetwork.getNetwork() === 'wifi') {
        $rootScope.noInternet = false;
        NixService.getRestaurantsWithCalc();
      } else {
        ApiService.checkConnection().then(function () {
          $rootScope.noInternet = false;
          NixService.getRestaurantsWithCalc();
        })["catch"](function () {
          $rootScope.noInternet = true;
          $rootScope.$broadcast('$cordovaNetwork:offline');
        });
      }
    } else {
      $rootScope.noInternet = true;
    }

    $rootScope.$on('$cordovaNetwork:online', function () {
      if ($cordovaNetwork.getNetwork() === 'wifi') {
        $rootScope.noInternet = false;
        NixService.getRestaurantsWithCalc();
      } else {
        ApiService.checkConnection().then(function () {
          $rootScope.noInternet = false;
          NixService.getRestaurantsWithCalc();
        })["catch"](function () {
          $rootScope.noInternet = true;
          $rootScope.$broadcast('$cordovaNetwork:offline');
          $timeout(function () {
            window.navigator.notification.alert('Please check your internet connection and ensure in your device settings that this app has permission to use mobile data.', null, '', 'OK');
            $rootScope.$broadcast('$cordovaNetwork:offline');
          }, 500);
        });
      }
    });
    $rootScope.$on('$cordovaNetwork:offline', function () {
      $rootScope.noInternet = true;
      if (angular.isDefined($rootScope.checkOnlineTimer)) return;
      $rootScope.checkOnlineTimer = $interval(function () {
        ApiService.checkConnection().then(function (response) {
          $rootScope.noInternet = false;
          $rootScope.$broadcast('$cordovaNetwork:online');
          $interval.cancel($rootScope.checkOnlineTimer);
          $rootScope.checkOnlineTimer = undefined;
        });
      }, 10000);
    });
    var hkToggle = JSON.parse(window.localStorage.getItem('healthkit'));

    if (hkToggle) {
      $rootScope.hk = hkToggle;
    } else {
      $rootScope.hk = {
        'weight': 'off',
        'exercise': 'off',
        'nutrition': 'off'
      };
    }

    if ($rootScope.hk.weight === 'pull') {
      HealthKitWeightService.pullWeightsFromHK();
    }

    if ($rootScope.hk.exercise === 'pull') {
      HealthKitExerciseService.pullExerciseFromHK();
    }

    var sqlReceiptID;
    SQLiteService.query(window.db, 'SELECT * FROM iap_receipts').then(function (result) {
      //receipt exists so they bought a subscription
      if (result.rows.length >= 1) {
        var res = SQLiteService.getAll(result);
        var latestEntry = res[res.length - 1];
        sqlReceiptID = latestEntry.id;
        var receipt = latestEntry.receipt;
        var signature = latestEntry.signature;
        var platform = 'ios';

        if ($cordovaDevice.getPlatform() === 'Android') {
          platform = 'android';
        }

        return ApiService.validatePurchase(receipt, signature, platform);
      }
    }).then(function (resp) {
      if (resp) {
        //receipt is expired, so delete it
        if (resp.data.premium_user === false) {
          SQLiteService.query(window.db, 'DELETE FROM iap_receipts')["catch"](function (err) {
            console.log('there was an error deleting the expired receipt', angular.toJson(err));
          });
        } else {
          var latest_receipt = resp.data.latest_receipt;
          SQLiteService.query(window.db, 'UPDATE iap_receipts SET receipt=? where id=?', [latest_receipt, sqlReceiptID])["catch"](function (err) {
            console.log('there was error upating latest receipt', angular.toJson(err));
          });
        }
      }
    })["catch"](function (err) {
      console.log(angular.toJson(err));
    });
    document.addEventListener('resume', function () {
      document.addEventListener('deviceready', function () {
        if (!!cordova.plugins.notification.local.launchDetails) {
          $state.go('app.foodlog');
          cordova.plugins.notification.local.launchDetails = undefined;
        }
      }, false);
      ApiService.checkConnection().then(function (response) {
        $rootScope.noInternet = false;
        $rootScope.$broadcast('$cordovaNetwork:online');
      })["catch"](function (error) {
        $rootScope.noInternet = true;

        if ($cordovaNetwork.isOnline()) {
          $timeout(function () {
            window.navigator.notification.alert('Please check your internet connection and ensure in your device settings that this app has permission to use mobile data.', null, '', 'OK');
            $rootScope.$broadcast('$cordovaNetwork:offline');
          }, 500);
        }
      });

      if ($cordovaNetwork.isOnline()) {
        $rootScope.noInternet = false;
        checkForWidgetActivation();
      } else {
        $rootScope.noInternet = true;
        if (angular.isDefined($rootScope.checkOnlineTimer)) return;
        $rootScope.checkOnlineTimer = $interval(function () {
          ApiService.checkConnection().then(function (response) {
            $rootScope.noInternet = false;
            $rootScope.$broadcast('$cordovaNetwork:online');
            $interval.cancel($rootScope.checkOnlineTimer);
            $rootScope.checkOnlineTimer = undefined;
          })["catch"](function (error) {
            $rootScope.$broadcast('$cordovaNetwork:offline');
          });
        }, 10000);
      }

      var hkToggle = JSON.parse(window.localStorage.getItem('healthkit'));

      if (hkToggle) {
        $rootScope.hk = hkToggle;
      } else {
        $rootScope.hk = {
          'weight': 'off',
          'exercise': 'off',
          'nutrition': 'off'
        };
      }

      if ($rootScope.hk.weight === 'pull') {
        HealthKitWeightService.pullWeightsFromHK();
      }

      if ($rootScope.hk.exercise === 'pull') {
        HealthKitExerciseService.pullExerciseFromHK();
      }
    }, false);
    $rootScope.updatePendingLength = 0;
    checkForWidgetActivation();

    function checkForWidgetActivation() {
      if ($cordovaDevice.getPlatform() !== 'Android') {
        return;
      }

      window.nutritionixWidget.getAction(function (action) {
        // Putting switch for future widget features like quick log, or load specific view.
        switch (action) {
          case 1:
            var today = moment().format('YYYY-MM-DD'),
                yesterday = moment().subtract(1, 'day').format('YYYY-MM-DD');
            ApiService.getUserTotals(0, yesterday, today).then(function (result) {
              if (!!result && !!result[moment().format('ddd, MM/DD/YY')]) {
                if (result[moment().format('ddd, MM/DD/YY')].daily_kcal_limit !== undefined && result[moment().format('ddd, MM/DD/YY')].daily_kcal_limit !== null) {
                  WidgetService.setCaloriesLimit(result[moment().format('ddd, MM/DD/YY')].daily_kcal_limit);
                } else {
                  UserService.getUser().then(function (result) {
                    if (result && result.daily_kcal) {
                      WidgetService.setCaloriesLimit(result.daily_kcal);
                    }
                  });
                }

                WidgetService.setConsumedCalories(result[moment().format('ddd, MM/DD/YY')].total_cal);
                WidgetService.setBurnedCalories(result[moment().format('ddd, MM/DD/YY')].total_cal_burned);
              }
            });
            break;

          default:
            return;
        }
      });
    }

    var reviewCheck = {};

    if (!!window.localStorage.getItem('reviewCheck')) {
      reviewCheck = JSON.parse(window.localStorage.getItem('reviewCheck'));
      reviewCheck.lastRunDate = reviewCheck.lastRunDate || moment().format('DD-MM-YYYY');
      reviewCheck.runCounter = reviewCheck.runCounter || 0;
    } else {
      reviewCheck = {
        runCounter: 0,
        lastRunDate: moment().format('DD-MM-YYYY')
      };
    }

    if (!moment(reviewCheck.lastRunDate, 'DD-MM-YYYY').startOf('day').isSame(moment().startOf('day'))) {
      reviewCheck.runCounter++;
      reviewCheck.lastRunDate = moment().format('DD-MM-YYYY');
    }

    window.localStorage.setItem('reviewCheck', angular.toJson(reviewCheck));
  });
  $rootScope.$on('$stateChangeError', function (event, toState, toParams, fromState, fromParams, error) {
    console.log('Error changing state from', angular.toJson(fromState));
    console.log('to ', angular.toJson(toState));
    console.log('Error data:', angular.toJson(error));

    if (error == 'unauthorized' || error.statusText == 'Unauthorized') {
      event.preventDefault();
      $state.go('login', {}, {
        reload: true
      });
    }
  });
  /* Set HTTP Headers */

  $http.defaults.headers.common['x-3scale-bypass'] = 'c49e69471a7b51beb2bb0e452ef53867385f7a5a';
  $http.defaults.headers.common['Content-Type'] = 'application/json';
  $rootScope.$on('user login', login);
  $rootScope.$on('user logout', logout);

  $rootScope.hideKeyboard = function () {
    cordova.plugins.Keyboard.close();
  };

  function login(e, trackResponse) {
    console.log('[login] user logged in');
    nixTrackApiClient.setUserJwt(function () {
      return (trackResponse.data || {})['x-user-jwt'] || null;
    });
    console.log('[login] setting user JWT. jwt string length=' + nixTrackApiClient.getUserJwt().length);
    $http.defaults.headers.common['x-user-jwt'] = nixTrackApiClient.getUserJwt();

    if (!window.db) {
      console.log('[login] db not opened. opening db and setting user');
      window.db = window.sqlitePlugin.openDatabase({
        name: 'track_db',
        location: 1
      }, UserService.setUser(trackResponse.data));
      return;
    }

    UserService.setJwt(trackResponse.data['x-user-jwt']);
    UserService.setUser(trackResponse.data.user);
  }

  function logout() {
    console.log('[logout] clearing user data');
    SQLiteService.query(window.db, 'DELETE FROM localdata');
    SQLiteService.query(window.db, 'DROP TABLE IF EXISTS localdata');
    UserService.removeUser();
    UserService.removeJwt();
    $rootScope.foodlog = [];
    $rootScope.selected_day = {
      'date': moment().format('ddd, MM/DD/YY'),
      'log': {}
    };
    $rootScope.itemsInBuilder = [];
    $http.defaults.headers.common['x-user-jwt'] = '';
    nixTrackApiClient.setUserJwt('');
    window.localStorage.removeItem('userGroceyAgentInfo');
    window.localStorage.removeItem('groceryAgentPreferences');
    window.localStorage.clear(); // PushNotificationService.mergeTagsToUser('', false)
    //   .then(function () {
    //     console.log('unlinking user to PN service');
    //     window.sessionStorage.setItem('PW_register', false);
    //   });

    window.sessionStorage.removeItem('sessionStart');
  }
}]).config(["$httpProvider", "$stateProvider", "$urlRouterProvider", "$ionicConfigProvider", function ($httpProvider, $stateProvider, $urlRouterProvider, $ionicConfigProvider) {
  // register $http interceptors, if any. e.g.
  // $httpProvider.interceptors.push('interceptor-name');
  $httpProvider.interceptors.push(["$q", "SQLiteService", "$rootScope", "$cordovaNetwork", function ($q, SQLiteService, $rootScope, $cordovaNetwork) {
    return {
      'request': function request(config) {
        if ($rootScope.noInternet && config.url.indexOf('https:') !== -1 && config.url !== "https://trackapi.nutritionix.com/") {
          return Promise.reject('no internet');
        }

        if (config.headers['x-user-jwt'] !== null) {
          return config;
        } else {
          return SQLiteService.query(window.db, 'SELECT value FROM localdata WHERE dataName = ?', ['jwt']).then(function (result) {
            var jwt = SQLiteService.getById(result);

            if (!!jwt) {
              config.headers['x-user-jwt'] = jwt;
              return config;
            }
          })["catch"](function (err) {
            console.log('error changing header', err);
          });
        }
      },
      'responseError': function responseError(error) {
        return Promise.reject(error);
      }
    };
  }]); // Application routing
  //disable swiping to go backwards to show view history.

  $ionicConfigProvider.views.swipeBackEnabled(false);
  $ionicConfigProvider.tabs.position('bottom');
  $ionicConfigProvider.views.transition('none');
  $stateProvider.state('app', {
    url: '/app',
    "abstract": true,
    templateUrl: 'templates/main.html',
    controller: 'MainController'
  }).state('app.foodlog', {
    url: '/foodlog',
    cache: false,
    params: {
      change_day: '',
      startWalkthroughAfterLog: false,
      askForReview: false
    },
    resolve: {
      userObj: ["UserService", "$q", "$state", "$ionicPlatform", function (UserService, $q, $state, $ionicPlatform) {
        var deferred = $q.defer();
        $ionicPlatform.ready(function () {
          UserService.getUser().then(function (user) {
            if (!window.sessionStorage.getItem('sessionStart')) {
              window.sessionStorage.setItem('sessionStart', true);
            }

            deferred.resolve(user);
          })["catch"](function (err) {
            console.log('[run 2 / app.foodlog] There was an error getting user data:', err);
            deferred.reject('unauthorized');
          });
        });
        return deferred.promise;
      }]
    },
    views: {
      'viewContent': {
        templateUrl: 'templates/views/foodlog.html',
        controller: 'FoodlogController'
      }
    }
  }).state('app.betaFeatures', {
    url: '/beta',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/betaFeatures.html',
        controller: 'betaFeaturesController'
      }
    }
  }).state('app.users', {
    url: '/users',
    cache: false,
    resolve: {
      users: ["$ionicPlatform", "ApiService", "UserService", function ($ionicPlatform, ApiService, UserService) {
        $ionicPlatform.ready(function () {
          var userObj = UserService.getUser().then(function (result) {
            return result;
          })["catch"](function (err) {
            console.log('Error getting user from local DB:', err);
          });
          return ApiService.getUsers(userObj['x-user-jwt']);
        });
      }]
    },
    views: {
      'viewContent': {
        templateUrl: 'templates/views/users.html',
        controller: 'UsersController'
      }
    }
  }).state('login', {
    url: '/login',
    cache: false,
    templateUrl: 'templates/views/auth/login.html',
    controller: 'LoginController'
  }).state('manualLogin', {
    url: '/manualLogin',
    cache: false,
    templateUrl: 'templates/views/auth/manualLogin.html',
    controller: 'ManualLoginController'
  }).state('signup', {
    url: '/signup',
    cache: false,
    templateUrl: 'templates/views/auth/signupViaEmail.html',
    controller: 'SignupController'
  }).state('app.settings', {
    url: '/settings',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/settings.html',
        controller: 'SettingsController'
      }
    }
  }).state('app.connectedApps', {
    url: '/connected',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/connectedApps.html',
        controller: 'connectedAppsController'
      }
    }
  }).state('app.manageAppSync', {
    url: '/manageAppSync',
    cache: false,
    params: {
      managedApp: ''
    },
    views: {
      'viewContent': {
        templateUrl: 'templates/views/manageAppSync.html',
        controller: 'manageAppSyncController'
      }
    }
  }).state('app.pushNotifications', {
    url: '/reminders',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/notifications.html',
        controller: 'pushNotificationsController'
      }
    }
  }).state('app.groceryAgentPreferences', {
    url: '/grocery-agent-preferences',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/groceryAgentPreferences.html',
        controller: 'GroceryAgentPreferencesController'
      }
    }
  }).state('app.developerSettings', {
    url: '/developer-settings',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/developerSettings.html',
        controller: 'developerSettingsController'
      }
    }
  }).state('app.profile', {
    url: '/profile',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/profile.html',
        controller: 'ProfileController as vm'
      }
    }
  }).state('app.resetPassword', {
    url: '/reset-password/:key',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/resetPassword.html',
        controller: 'ResetPasswordController as vm'
      }
    }
  }).state('app.food', {
    url: '/food/:food_id',
    cache: false,
    params: {
      'readOnly': false
    },
    resolve: {
      food: ["ApiService", function (ApiService) {
        return ApiService.getCurrentFood().then(function (response) {
          return response;
        });
      }]
    },
    views: {
      'viewContent': {
        templateUrl: 'templates/views/food.html',
        controller: 'FoodController'
      }
    }
  }).state('app.total', {
    url: '/total',
    cache: false,
    resolve: {
      dayTotal: ["ApiService", function (ApiService) {
        return ApiService.getCurrentDayTotal();
      }]
    },
    params: {
      mealTypeFilter: null,
      readOnly: false,
      clientId: '',
      date: null,
      dayValue: null
    },
    views: {
      'viewContent': {
        templateUrl: 'templates/views/total.html',
        controller: 'TotalController'
      }
    }
  }).state('instruction', {
    url: '/instruction',
    cache: false,
    templateUrl: 'templates/views/instruction.html',
    controller: 'InstructionController'
  }).state('completeRegistration', {
    url: '/complete_registration?link_hash&email&firstname&lastname&facebook&country_code',
    cache: false,
    templateUrl: 'templates/views/auth/signup2.html',
    controller: 'registrationController'
  }).state('app.preferences', {
    url: '/preferences',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/preferences.html',
        controller: 'PreferencesController as vm'
      }
    }
  }).state('app.shareLog', {
    url: '/shareLog',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/share.html',
        controller: 'shareController'
      }
    }
  }).state('app.help', {
    url: '/help',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/help.html',
        controller: 'HelpController as vm'
      }
    }
  }).state('app.stats', {
    url: '/stats',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/stats.html',
        controller: 'StatsController as vm'
      }
    }
  }).state('app.calculateDailyCalories', {
    url: '/calculate_daily_calories',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/calculateDailyCalories.html',
        controller: 'CalculateDailyCaloriesController as vm'
      }
    }
  }).state('app.addfoodsmart', {
    url: '/addfood/smart',
    cache: true,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/addFoodSmart.html',
        controller: 'addFoodSmartController as vm'
      }
    }
  }).state('app.restaurants', {
    url: '/addfood/restaurant',
    cache: true,
    resolve: {
      restaurants: ["NixService", "CacheFactory", function (NixService, CacheFactory) {
        return CacheFactory.getRestaurants()["catch"](function () {
          return NixService.getRestaurants();
        });
      }]
    },
    views: {
      'viewContent': {
        templateUrl: 'templates/views/restaurants.html',
        controller: 'restaurantsController'
      }
    }
  }).state('app.restaurantfoods', {
    url: '/addfood/restaurant/:brand_name/:brand_id',
    cache: true,
    params: {
      restaurantLogoUrl: ''
    },
    resolve: {
      foods: ["$stateParams", "NixService", function ($stateParams, NixService) {
        return NixService.getRestaurantFoods('', $stateParams.brand_id);
      }],
      calculatorUrl: ["$stateParams", "CacheFactory", function ($stateParams, CacheFactory) {
        return CacheFactory.getRestaurantsWithCalc().then(function (res) {
          var result;

          for (var i = 0; i < res.length; i++) {
            if ($stateParams.brand_id === res[i].brand_id && !!res[i].mobile_calculator_url) {
              result = res[i].mobile_calculator_url;
              break;
            }
          }

          return result;
        })["catch"](function (err) {
          return null;
        });
      }]
    },
    views: {
      'viewContent': {
        templateUrl: 'templates/views/restaurantFoods.html',
        controller: 'restaurantFoodsController'
      }
    }
  }).state('app.restaurantcalculator', {
    url: '/addfood/restaurant/:brand_name/:brand_id/restaurantcalculator',
    cache: false,
    params: {
      calculatorUrl: undefined
    },
    views: {
      'viewContent': {
        templateUrl: 'templates/views/restaurantCalculator.html',
        controller: 'RestaurantCalculatorController'
      }
    }
  }).state('app.grocery', {
    url: '/addfood/grocery',
    cache: true,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/grocery.html',
        controller: 'groceryController'
      }
    },
    resolve: {
      groceries: ["$rootScope", "NixService", "CacheFactory", function ($rootScope, NixService, CacheFactory) {
        return CacheFactory.getDefaultGroceryFoods().then(function (cachedFoods) {
          console.log('cachedFoods', cachedFoods);

          if (cachedFoods) {
            return cachedFoods;
          } else if (!$rootScope.noInternet) {
            return NixService.getGroceryFoods('app').then(function (groceries) {
              CacheFactory.setDefaultGroceryFoods(groceries);
              return groceries;
            });
          } else {
            return {
              data: {
                hits: []
              }
            };
          }
        });
      }]
    }
  }).state('app.reviewFoods', {
    url: '/reviewFoods?type&name&servings&recipeBrand&mealConsumed&mealType',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/reviewFoods.html',
        controller: 'reviewFoodsController'
      }
    }
  }).state('app.history', {
    url: '/history',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/history.html',
        controller: 'historyController'
      }
    },
    resolve: {
      history: ["ApiService", "CacheFactory", function (ApiService, CacheFactory) {
        return CacheFactory.getFoodHistory().then(function (response) {
          return response;
        })["catch"](function (err) {
          console.log('there was an error. Most likely there was no history', angular.toJson(err));
          return ApiService.getFoodHistory().then(function (response) {
            CacheFactory.setFoodHistory(response);
            return response;
          });
        });
      }]
    }
  }).state('app.UploadPhotoUser', {
    url: '/upload-photo-user',
    resolve: {
      userObj: ["UserService", function (UserService) {
        return UserService.getUser();
      }]
    },
    params: {
      barcode: null,
      redirectState: null
    },
    views: {
      'viewContent': {
        templateUrl: 'templates/views/uploadPhotoUser.html',
        controller: 'UploadPhotoUserController'
      }
    }
  }).state('app.UploadPhotoAgent', {
    url: '/upload-photo-agent',
    resolve: {
      userObj: ["UserService", function (UserService) {
        return UserService.getUser();
      }]
    },
    views: {
      'viewContent': {
        templateUrl: 'templates/views/uploadPhotoAgent.html',
        controller: 'UploadPhotoAgentController'
      }
    }
  }).state('app.myRecipes2', {
    url: '/recipes2',
    cache: false,
    params: {
      showSavedRecipeMessage: false
    },
    views: {
      'viewContent': {
        templateUrl: 'templates/views/myRecipes2.html',
        controller: 'myRecipes2Controller'
      }
    }
  }).state('app.editRecipe2', {
    url: '/recipes2/edit?id',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/editRecipe2.html',
        controller: 'editRecipe2Controller as vm'
      }
    }
  }).state('app.recipes', {
    url: '/recipes',
    cache: false,
    params: {
      selectedFilter: '',
      // 'recipes', 'custom'
      showSavedRecipeMessage: false
    },
    views: {
      'viewContent': {
        templateUrl: 'templates/views/myrecipes.html',
        controller: 'myRecipesController'
      }
    }
  }).state('app.editRecipe', {
    url: '/recipes/edit?id',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/editRecipe.html',
        controller: 'editRecipeController'
      }
    }
  }).state('app.newRecipe', {
    url: '/recipes/new',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/newRecipe.html',
        controller: 'newRecipeController'
      }
    }
  }).state('app.createFood', {
    url: '/recipes/create',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/createFood.html',
        controller: 'createFoodController'
      }
    }
  }).state('app.customFoods', {
    url: '/custom-foods',
    cache: false,
    params: {
      showSavedFoodMessage: false
    },
    views: {
      'viewContent': {
        templateUrl: 'templates/views/customFoods.html',
        controller: 'customFoodsController'
      }
    }
  }).state('app.customFood', {
    url: '/recipes/create/custom',
    cache: false,
    params: {
      logAfterSubmit: false,
      customFoodId: '',
      mealType: null
    },
    views: {
      'viewContent': {
        templateUrl: 'templates/views/customFood.html',
        controller: 'customFoodController'
      }
    }
  }).state('app.dailygoals', {
    url: '/dailygoals',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/dailygoals.html',
        controller: 'dailyGoalsController'
      }
    }
  }).state('app.myCoach', {
    url: '/my-coach',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/myCoach.html',
        controller: 'myCoachController'
      }
    }
  }).state('app.coachPortal', {
    url: '/coach-portal',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/coachPortal.html',
        controller: 'coachPortalController'
      }
    }
  }).state('app.viewClient', {
    url: '/coach-portal/view-client/?clientId',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/viewClient.html',
        controller: 'viewClientController'
      }
    },
    params: {
      client: {}
    }
  }).state('app.viewClientDayLog', {
    url: '/coach-portal/view-client/?clientId/day-log',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/viewClientDayLog.html',
        controller: 'viewClientDayLogController'
      }
    },
    params: {
      date: '',
      client: {},
      foodLog: [],
      totals: {}
    }
  }).state('app.subscribe', {
    url: '/subscribe',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/subscribe.html',
        controller: 'subscribeController'
      }
    },
    resolve: {
      userObj: ["UserService", function (UserService) {
        return UserService.getUser().then(function (result) {
          return result;
        })["catch"](function (err) {
          console.log('Error getting active user from local DB:', err);
        });
      }]
    }
  }).state('app.productRecommendations', {
    url: '/product-recommendations',
    cache: false,
    views: {
      'viewContent': {
        templateUrl: 'templates/views/productRecommendations.html',
        controller: 'productRecommendationsController'
      }
    }
  }); // redirects to default route for undefined routes

  $urlRouterProvider.otherwise(function ($injector) {
    var $state = $injector.get('$state');
    $state.go('app.foodlog');
  });
}]) // makes sure that white list is behaving nice
.config(["$compileProvider", function ($compileProvider) {
  $compileProvider.imgSrcSanitizationWhitelist(/^\s*(local|http|https|app|ftp|file|blob|content|cdvfile|ionic):|data:image\//);
}]); // function DeepLinkHandler(url) {
//   if (url === false) {
//     return;
//   }
//   setTimeout( function() {
//     var event = new CustomEvent('LaunchUrl', {detail: {'url': url}});
//     window.dispatchEvent(event);
//   }, 0);
// }
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:addFoodSmartController
 * @description
 * # addFoodSmartController
 */

angular.module('Track').controller('addFoodSmartController', ["$rootScope", "$scope", "$cordovaKeyboard", "$state", "$location", "$ionicBackdrop", "$timeout", "$cordovaDatePicker", "$ionicPlatform", "$ionicPopup", "$cordovaNetwork", "$cordovaInAppBrowser", "$q", "AnalyticsService", "ApiService", "UserService", "NixService", "CacheFactory", "HelperService", "VoiceRecognitionService", "WalkthroughService", function ($rootScope, $scope, $cordovaKeyboard, $state, $location, $ionicBackdrop, $timeout, $cordovaDatePicker, $ionicPlatform, $ionicPopup, $cordovaNetwork, $cordovaInAppBrowser, $q, AnalyticsService, ApiService, UserService, NixService, CacheFactory, HelperService, VoiceRecognitionService, WalkthroughService) {
  var vm = this;
  vm.busy = false;
  UserService.getUser().then(function (result) {
    vm.isGroceryAgent = result.grocery_agent;
    vm.currentUserId = result.id;
  })["catch"](function (err) {
    console.log('Error getting user from local DB:', err);
  });
  vm.query = '';
  vm.placeholderText = [' e.g. Turkey club sandwich and 12oz coke', ' e.g. 600 cal chicken caesar salad', ' e.g. 5 eggs and 1 glass milk', ' e.g. 2 glasses of wine', ' e.g. 15 almonds', ' e.g. 100 cal greek yogurt', ' e.g. yesterday for dinner i ate a grilled cheese (this will log to 7pm yesterday)', ' e.g. for breakfast i had 2 eggs, a slice of bacon, and toast (this will log to 8am this morning)'];
  $scope.$watch('vm.query', function (newVal, oldVal) {
    if (!newVal.length) {
      vm.isVoiceRecognitionUsed = false;
    }
  });
  $ionicPlatform.ready(function () {
    AnalyticsService.setUserId(vm.currentUserId);
    $scope.recordingMessage = '';
    var options = {
      language: 'en-US',
      showPopup: true,
      showPartial: true
    };

    vm.startRecognition = function () {
      if ($scope.recordingMessage === 'Finish') {
        VoiceRecognitionService.stopVoiceRecognition();
        $scope.recordingMessage = 'Finished';
        $timeout(function () {
          $scope.recordingMessage = '';
        }, 1000);
      } else {
        $scope.recordingMessage = window.ionic.Platform.isAndroid() ? 'Recording' : 'Finish';
        VoiceRecognitionService.startVoiceRecognition(options).then(function (result) {
          if (window.ionic.Platform.isAndroid()) {
            $scope.recordingMessage = 'Finished';
            $timeout(function () {
              $scope.recordingMessage = '';
            }, 1000);
          }

          vm.query = result;
          vm.isVoiceRecognitionUsed = true;
        }, function (err) {
          console.log(err);

          if (err == 'Cancelled') {
            $scope.recordingMessage = 'Cancelled';
            $scope.showDisclaimer();
          } else if (window.ionic.Platform.isAndroid()) {
            if (err === 'Not available') {
              $scope.recognErr = err;
              $ionicPopup.show({
                template: "<p>You're almost there! To use this feature, download and setup Google Voice Search, and then restart the app. To get Google Voice Search from the Play Market now, click \"Download\".</p>",
                title: 'Voice recognition error',
                scope: $scope,
                buttons: [{
                  text: 'Download',
                  type: 'button-positive',
                  onTap: $scope.goToGooglePlayMarket
                }, {
                  text: 'Cancel'
                }]
              });
            } else {
              $scope.recordingMessage = 'Error';
            }
          }

          $timeout(function () {
            $scope.recordingMessage = '';
          }, 1000);
        }, function (result) {
          vm.query = result;
          vm.isVoiceRecognitionUsed = true;
        });
      }
    };

    $scope.$on('$ionicView.enter', function (event, data) {
      AnalyticsService.trackView('Natural Language Interface');

      if (WalkthroughService.eventsList.firstEnterInTrackTab) {
        WalkthroughService.runWalkthrough(5);
        WalkthroughService.setEventFlag('firstEnterInTrackTab', false);
      }
    });
  });
  $scope.$on('$ionicView.beforeLeave', function () {
    VoiceRecognitionService.stopVoiceRecognition();
  });
  $scope.state = $state.current.name;

  vm.randPlaceholderText = function () {
    vm.exampleText = _.sample(vm.placeholderText);
  }();

  vm.submitFood = function () {
    if (!vm.query) return emptyQuery();
    AnalyticsService.trackEvent('foodlog_natural', vm.query);
    return $state.go('app.foodlog').then(function () {
      var foodObject = {
        query: vm.query
      };
      ApiService.addFood(foodObject).then(function (errs) {
        _.forEach(errs, function (err) {
          if (err.status == 404) {
            errorMessage(err);
          }

          if (err.status === 0) {
            console.log('The request has timed out. Your food(s): ' + err.config.data.query + 'will attempt to log again later.');
          }
        });

        if (errs) {
          console.log('errs', angular.toJson(errs));
        }
      }).then(function () {
        return $rootScope.$broadcast('refresh foodlog', {
          scrollToTop: true
        });
      });
    });
  };

  vm.goToFoodLog = function () {
    $state.go('app.foodlog');
  };

  vm.getNutrients = function () {
    if ($rootScope.noInternet) {
      return navigator.notification.alert('This feature is not available in offline mode', null, '', 'OK');
    }

    var cachedResults;
    if (!vm.query) return emptyQuery();

    if (vm.isVoiceRecognitionUsed) {
      AnalyticsService.trackEvent('voice_logging', vm.query);
    }

    var foodObject = {
      query: vm.query
    };
    ApiService.getFoodNutrients(foodObject).then(function (results) {
      cachedResults = results;
      return CacheFactory.getMealBuilderFoods();
    }).then(function (mealBuilder) {
      $rootScope.itemsInBuilder = mealBuilder;
      return cachedResults.data.foods.forEach(function (food) {
        food = HelperService.addGramsToAltMeasures(food);
        food._hiddenQuery = vm.query;
        return $rootScope.itemsInBuilder.push(food);
      });
    }).then(function () {
      //the the user requested measure/defaul measure to alt_measures so it is part of drop down in review foods
      _.forEach($rootScope.itemsInBuilder, function (foodObj) {
        if (foodObj.alt_measures) {
          var temp = {
            'serving_weight': foodObj.serving_weight_grams,
            'seq': null,
            'measure': foodObj.serving_unit,
            'qty': foodObj.serving_qty
          };
          foodObj.alt_measures.unshift(temp);
        }
      });

      CacheFactory.setMealBuilderFoods($rootScope.itemsInBuilder);
      AnalyticsService.trackEvent('natural_addFoodSmart', vm.query);
      return $state.go('app.reviewFoods');
    })["catch"](function (err) {
      console.log('there was an err', angular.toJson(err));
      errorMessage(err);
    });
  };

  $scope.goToGooglePlayMarket = function () {
    $cordovaInAppBrowser.open('market://details?id=com.google.android.googlequicksearchbox', '_system');
  };

  $scope.hideDisclaimer = function () {
    window.localStorage.setItem('hideVoiceRecognitionDisclaimer', !!vm.doNotShowDisclaimer + '');
    vm.isDisclaimerVisible = false;
  };

  $scope.showDisclaimer = function () {
    if (!window.ionic.Platform.isAndroid()) {
      vm.isDisclaimerVisible = false;
      return false;
    }

    var isDisclaimerDisabled = eval(window.localStorage.getItem('hideVoiceRecognitionDisclaimer'));

    if (isDisclaimerDisabled) {
      vm.isDisclaimerVisible = false;
    } else {
      vm.isDisclaimerVisible = true;
    }
  };

  function emptyQuery() {
    $ionicPopup.alert({
      title: 'Please enter some foods to continue',
      buttons: [{
        text: 'Ok',
        type: 'button-balanced'
      }]
    });
  }

  function errorMessage(err) {
    $ionicPopup.alert({
      title: err.data.message + ' for:',
      template: err.config.data.query,
      buttons: [{
        text: 'Ok',
        type: 'button-balanced'
      }]
    });
  }
}]);
'use strict';

addFoodTabsController.$inject = ["$scope"];
angular.module('Track').controller('addFoodTabsController', addFoodTabsController);

function addFoodTabsController($scope) {
  if ($scope.state === 'app.addfoodsmart') {
    $scope.smartClass = 'active';
  }

  if ($scope.state === 'app.restaurants' || $scope.state === 'app.restaurantfoods') {
    $scope.restaurantClass = 'active';
  }

  if ($scope.state === 'app.grocery') {
    $scope.groceryClass = 'active';
  }

  if ($scope.state === 'app.history') {
    $scope.historyClass = 'active';
  }
}
'use strict';

barcodeScannerController.$inject = ["$cordovaDevice", "$ionicPopup", "$log", "$q", "$rootScope", "$scope", "$state", "ApiService", "AnalyticsService", "BarcodeScannerService", "ConfigurationService", "ExternalURLService", "NixService", "UserService", "HelperService"];
angular.module('Track').controller('barcodeScannerController', barcodeScannerController);

function barcodeScannerController($cordovaDevice, $ionicPopup, $log, $q, $rootScope, $scope, $state, ApiService, AnalyticsService, BarcodeScannerService, ConfigurationService, ExternalURLService, NixService, UserService, HelperService) {
  /*------------------------------------------------------------
   *  The barcode scanner has the following conditional logic:
    *  1. it always works for Grocery Agents on any platform: Android/iOS.
   *  2. it does not work for Regular Users on Android (due to the fact that taking a picture
   takes tooo much time on some devices).
   *  2.1 --- > 26.04.17 update - enabled for Regular Users on Android due to Matt request.
   *  3. for Grocery Agents there is a setting (Menu->Preferences->Grocery Agent Preferences->Volunteer to submit new photos)
   to always submit new photos in case the food is outdated. If that is not set, then the chance to prompt to volunteer is 1/5.
   *  4. for Regular Users it is always a 1/5 chance to get prompted to volunteer.
   *  5. if the food is "older" then 24 months from last update - the prompt to submit new photos comes up.
   *  6. if the food is not found by barcode, Regular Users get a simple popup
   (No match was found), Grocery Agents are redirected to User Photo Upload.
    *  The chance and time from last update are regulated by ConfigurationService:
   for the chance - ConfigurationService.grocery_photo_upload.user_volunteering_multiplicator
   time - ConfigurationService.grocery_photo_upload.food_update_time.quantity and
   ConfigurationService.grocery_photo_upload.food_update_time.unit
   *------------------------------------------------------------*/
  var getFoodViaBarcode = function getFoodViaBarcode(barcode, mtype) {
    // preset data for barcode scanning conditional logic
    var preSetData = {
      userIsGroceyAgent: !!($rootScope.userGroceyAgentInfo && $rootScope.userGroceyAgentInfo.grocery_agent),
      thisIsAndroid: 'Android' === $cordovaDevice.getPlatform()
    };
    var force_photo_upload = window.localStorage.getItem('force_photo_upload');
    window.localStorage.removeItem('force_photo_upload');
    ApiService.getFoodViaBarcode(barcode).then(function (food) {
      food[0].upc = barcode;

      if (!food[0].alt_measures && !!food[0].serving_weight_grams) {
        food[0] = HelperService.addGramsToAltMeasures(food[0]);
      } else if (!!food[0].alt_measures && !!food[0].serving_weight_grams) {
        var temp = {
          'serving_weight': food[0].serving_weight_grams,
          'seq': null,
          'measure': food[0].serving_unit,
          'qty': food[0].serving_qty
        };
        food[0].alt_measures.unshift(temp);
        food[0] = HelperService.addGramsToAltMeasures(food[0]);
      } // if barcode scanned from 'report' popup - don't add food to the basket.


      if (!force_photo_upload) {
        $rootScope.$broadcast('mealBuilder: addFood', {
          foodArray: food
        });
      } // check if enough time passed to ask user/agent to update food


      var foodNeedsUpdate;

      if (food[0] && food[0].updated_at) {
        foodNeedsUpdate = moment(food[0].updated_at).add(ConfigurationService.grocery_photo_upload.food_update_time.quantity, ConfigurationService.grocery_photo_upload.food_update_time.unit).isBefore(moment());
      }

      if (force_photo_upload) {
        foodNeedsUpdate = true;
      }

      if (!foodNeedsUpdate) {
        return $q.reject();
      } else {
        return food;
      }
    }).then(function (data) {
      // skip check if force upload selected launched.
      if (force_photo_upload) {
        return data;
      } // if this is an agent with a set preference to volunteer


      if (preSetData.userIsGroceyAgent && !!($rootScope.groceryAgentPreferences && $rootScope.groceryAgentPreferences.volunteer)) {
        return data;
      } // or if this is a user and the 1/6 chance fired
      else if (0 === Math.floor(Math.random() * ConfigurationService.grocery_photo_upload.user_volunteering_multiplicator)) {
          return data;
        } else {
          return $q.reject();
        }
    }).then(function (food) {
      if (force_photo_upload) {
        return true;
      } // ask user to submit photos


      return UserService.getUser().then(function (user) {
        var currentUser = user;
        return $ionicPopup.confirm({
          title: 'We could use some help',
          subTitle: 'Hey ' + currentUser.first_name + '! ' + food[0].brand_name + ' ' + (food[0].item_name || food[0].food_name || '') + ' exists in our database, ' + 'but we could use some help submitting photos of this product\'s nutrition label ' + 'so we can make sure our data is still up - to - date. ' + 'Would you mind taking two photos of this product for us?',
          cancelText: 'No thank you!',
          cancelType: '',
          okText: 'Sure, happy to help!',
          okType: 'button-balanced'
        });
      })["catch"](function (err) {
        console.log('Error getting user from local DB:', err);
      });
    }).then(function (userHasVolutered) {
      if (userHasVolutered) {
        $state.go('app.UploadPhotoUser', {
          barcode: barcode,
          redirectState: 'app.reviewFoods'
        });
      } else {
        var params = {};

        if (mtype) {
          params.mealType = mtype;
        }

        $state.go('app.reviewFoods', params, {
          reload: true
        });
      }
    })["catch"](function (err) {
      if (err && err.statusText) {
        if (preSetData.userIsGroceyAgent) {
          $state.go('app.UploadPhotoUser', {
            barcode: barcode,
            redirectState: 'app.reviewFoods'
          });
        } else {
          $state.go('app.UploadPhotoUser', {
            barcode: barcode
          });
        }
      } else {
        var params = {};

        if (mtype) {
          params.mealType = mtype;
        }

        $state.go('app.reviewFoods', params, {
          reload: true
        });
      }
    });
  };

  $scope.scanBarcode = function (mtype) {
    BarcodeScannerService.scanBarcode().then(function (barcode) {
      if (!barcode) return;

      if (barcode.length > 14) {
        if (barcode.includes('nutritionix.com/q1')) {
          ExternalURLService.externalLinkV1(barcode);
        } else if (barcode.includes('nutritionix.com/q2')) {
          ExternalURLService.externalLinkV2(barcode);
        } else if (barcode.includes('nutritionix.com/q3')) {
          ExternalURLService.externalLinkV3(barcode);
        }
      } else {
        getFoodViaBarcode(barcode, mtype);
      }

      AnalyticsService.trackEvent('foodlog_barcode', barcode);
    })["catch"](function (error) {
      $log.error(error);
    });
  };

  if (!$rootScope.scanBarcodeActionHandler) {
    $rootScope.$on('scanBarcodeAction', function () {
      $scope.scanBarcode();
    });
  }
}
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:betaFeaturesController
 * @description
 * # betaFeaturesController
 */

angular.module('Track').controller('betaFeaturesController', ["$scope", "$state", "UserService", function ($scope, $state, UserService) {
  UserService.getUser().then(function (result) {
    $scope.user = result.data;
  });

  $scope.goBack = function () {
    $state.go('app.foodlog');
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:CalculateDailyCaloriesController
 * @description
 * # CalculateDailyCalories
 */

angular.module('Track').controller('CalculateDailyCaloriesController', ["$rootScope", "nixTrackCalculator", "ApiService", "UserService", "$cordovaDevice", "$timeout", "$scope", "$state", "$ionicHistory", "$ionicPopup", "AnalyticsService", function ($rootScope, nixTrackCalculator, ApiService, UserService, $cordovaDevice, $timeout, $scope, $state, $ionicHistory, $ionicPopup, AnalyticsService) {
  var vm = this;
  vm.showMessage = false;
  var sysMap = {
    0: 'imperial',
    1: 'metric'
  };
  $scope.$on('$ionicView.beforeEnter', function (event, data) {
    UserService.getUser().then(function (user) {
      var userPreferences = user;
      vm.unitSystem = sysMap[userPreferences.measure_system] || sysMap['0'];
      vm.gender = userPreferences.gender || 'female';
      vm.weight = {
        kg: userPreferences.weight_kg,
        lb: _.round(userPreferences.weight_kg * 2.20462, 2)
      };
      vm.weightView = {
        kg: _.round(userPreferences.weight_kg, 1),
        lb: _.round(userPreferences.weight_kg * 2.20462, 1)
      };
      vm.initialData = {
        birth_year: userPreferences.birth_year,
        daily_kcal: userPreferences.daily_kcal,
        exercise_level: userPreferences.exercise_level,
        gender: userPreferences.gender,
        height_cm: userPreferences.height_cm,
        weight_kg: userPreferences.weight_kg,
        measure_system: userPreferences.measure_system
      };
      vm.cmToinches = userPreferences.height_cm * 0.393701;
      vm.height = {
        cm: userPreferences.height_cm,
        ft: _.floor(vm.cmToinches / 12),
        inch: _.round(vm.cmToinches % 12, 2)
      };
      vm.heightView = {
        cm: _.round(userPreferences.height_cm),
        ft: _.floor(vm.cmToinches / 12),
        inch: _.round(vm.cmToinches % 12, 0)
      };
      vm.age = new Date().getFullYear() - userPreferences.birth_year;

      if (vm.age > 100) {
        vm.age = 30;
      }

      vm.myCalorieLimit = userPreferences.daily_kcal;
    });
  });
  $scope.$watch('vm.weightView', function (newValue, oldValue) {
    if (!newValue || !oldValue) {
      return;
    }

    if (newValue.kg === oldValue.kg) {
      vm.weight.lb = vm.weightView.lb;
    } else {
      vm.weight.kg = vm.weightView.kg;
    }

    vm.calculateWeights();
  }, true);
  $scope.$watch('vm.heightView', function (newValue, oldValue) {
    if (!newValue) {
      return;
    }

    Object.assign(vm.height, newValue);
    vm.calculateHeights();
  }, true);
  $scope.$on('$ionicView.enter', function (event, data) {
    AnalyticsService.trackView('Calculate Daily Calories');
    $scope.iosFloatingButtonAdjustment = 0;

    if ($cordovaDevice.getPlatform() == 'iOS') {
      window.addEventListener('native.keyboardshow', keyboardShowHandler);
      window.addEventListener('native.keyboardhide', keyboardHideHandler);
    }

    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(false);
    }
  });
  $scope.$on('$ionicView.beforeLeave', function (event, data) {
    if ($cordovaDevice.getPlatform() == 'iOS') {
      window.removeEventListener('native.keyboardshow', keyboardShowHandler);
      window.removeEventListener('native.keyboardhide', keyboardHideHandler);
    }

    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
    }
  });

  function keyboardShowHandler(e) {
    $scope.iosFloatingButtonAdjustment = e.keyboardHeight;
    $scope.$apply();
  }

  function keyboardHideHandler(e) {
    $scope.iosFloatingButtonAdjustment = 0;
    $scope.$apply();
  }

  vm.goBack = function () {
    //in the case of a deep link
    if ($ionicHistory.backView() === undefined) {
      $state.go('app.foodlog');
    } else {
      $ionicHistory.goBack();
    }
  };

  vm.getRecommendedCalories = function () {
    if (vm.gender && vm.weight.kg > 0 && vm.height.cm > 0 && vm.age > 0) {
      return nixTrackCalculator.calculateRecommendedCalories(vm.gender, vm.weight.kg, vm.height.cm, vm.age);
    }
  };

  vm.changeUnitSystem = function () {
    vm.calculateWeights(vm.unitSystem === 'metric' ? 'imperial' : 'metric');
    vm.calculateHeights(vm.unitSystem === 'metric' ? 'imperial' : 'metric');
  };

  vm.calculateWeights = function (unitSystem) {
    if (!vm.weight && !vm.weightView) {
      return;
    }

    if ((unitSystem || vm.unitSystem) === 'metric') {
      vm.weight.lb = _.round(vm.weight.kg * 2.20462, 2);
      vm.weightView.lb = _.round(vm.weight.lb, 1);
    } else {
      vm.weight.kg = _.round(vm.weight.lb * 0.453592, 2);
      vm.weightView.kg = _.round(vm.weight.kg, 1);
    }
  };

  vm.calculateHeights = function (unitSystem) {
    if ((unitSystem || vm.unitSystem) === 'metric') {
      vm.height.inch = _.round(vm.height.cm * 0.393701, 2);

      if (vm.height.inch > 12) {
        vm.height.ft = _.floor(vm.height.inch / 12);
        vm.height.inch -= vm.height.ft * 12;
      } else {
        vm.height.ft = 0;
      }

      vm.heightView.ft = vm.height.ft;
      vm.heightView.inch = _.round(vm.height.inch);
    } else {
      vm.height.cm = _.round((vm.height.ft || 0) * 30.48 + (vm.height.inch || 0) * 2.54, 2);
      vm.heightView.cm = _.round(vm.height.cm);
    }
  };

  vm.savePreferences = function (kcal) {
    if ($rootScope.noInternet) {
      $ionicPopup.alert({
        title: 'Not available in offline mode.',
        buttons: [{
          text: 'Ok',
          type: 'button-balanced'
        }]
      });
      return;
    }

    vm.preferencesNotSaved = false;

    if (vm.unitSystem === 'imperial') {
      vm.calculateHeights('imperial');
      vm.calculateWeights('imperial');
    }

    if (!kcal || kcal === 0 || kcal === '') {
      vm.preferencesNotSaved = true;
      vm.showErrorMessage = true;
      return;
    } else {
      vm.showErrorMessage = false;
      kcal = _.round(kcal, 0);
    }

    var userPref = {
      daily_kcal: kcal,
      gender: vm.gender,
      exercise_level: 0,
      measure_system: vm.unitSystem === 'imperial' ? 0 : 1
    };

    if (vm.weight.kg && vm.weight.kg !== 0 && vm.initialData.weight_kg !== vm.weight.kg) {
      userPref.weight_kg = parseFloat(vm.weight.kg);
    }

    if (vm.age && vm.age !== 0) {
      userPref.birth_year = new Date().getFullYear() - vm.age;
    }

    if (vm.height.cm && vm.height.cm !== 0) {
      userPref.height_cm = vm.height.cm;
    }

    if (vm.initialData && vm.initialData.daily_kcal && vm.initialData.daily_kcal !== userPref.daily_kcal) {
      AnalyticsService.trackEvent('changedCalorieLimit', 'From ' + vm.initialData.daily_kcal + ' to ' + userPref.daily_kcal);
    }

    UserService.updateUser(userPref).then(function (result) {
      vm.updateCalorieMessage = 'Updated';
      vm.showMessage = true;
      $timeout(function () {
        vm.showMessage = false;
        $scope.$apply();
      }, 3000);
      $rootScope.$broadcast('userPreferences:updated');
      $state.go('app.foodlog');
    })["catch"](function (err) {
      vm.updateCalorieMessage = err.data;
      vm.showMessage = true;
      $timeout(function () {
        vm.showMessage = false;
        $scope.$apply();
      }, 3000);
      throw err;
    });
  };

  vm.isDataChanged = function () {
    if (!vm.initialData) {
      return false;
    }

    if (vm.initialData.birth_year !== new Date().getFullYear() - vm.age || vm.initialData.daily_kcal !== vm.myCalorieLimit || vm.initialData.exercise_level !== 0 || vm.initialData.gender !== vm.gender || vm.initialData.height_cm !== vm.height.cm || vm.initialData.weight_kg !== parseFloat(vm.weight.kg) || vm.initialData.measure_system !== (vm.unitSystem === 'imperial' ? 0 : 1)) {
      return true;
    }

    return false;
  };

  vm.showDisclaimer = function () {
    $ionicPopup.alert({
      title: 'Many different variables affect a person’s energy needs, including age, height, weight, and sex.',
      buttons: [{
        text: 'Close',
        type: 'button-balanced'
      }]
    });
  };

  vm.hideKeyboard = function () {
    cordova.plugins.Keyboard.close();
  };

  vm.goToCalcFAQ = function () {
    cordova.InAppBrowser.open('https://help.nutritionix.com/articles/6153-setting-understanding-your-daily-calorie-limit', '_blank', 'location=no');
    return false;
  };

  vm.openDisclaimerLink = function (url) {
    cordova.InAppBrowser.open(url, '_blank', 'location=no');
    return false;
  };

  vm.openDisclaimerPDF = function (url) {
    cordova.InAppBrowser.open(url, '_system', 'location=no');
    return false;
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:coachPortalController
 * @description
 * # coachPortalController
 */

angular.module('Track').controller('coachPortalController', ["$scope", "$rootScope", "$state", "$ionicHistory", "$ionicPopup", "CoachService", "UserService", function ($scope, $rootScope, $state, $ionicHistory, $ionicPopup, CoachService, UserService) {
  $scope.clientsList = [];
  $scope.data = {};
  UserService.getUser().then(function (result) {
    $scope.user = result;
  });
  CoachService.getClients().then(function (res) {
    if (!res || !res.data || !res.data.patients) {
      return;
    }

    _.forEach(res.data.patients, function (user, id) {
      $scope.clientsList.push(user);
    });
  });

  $scope.copyCodeToClipboard = function () {
    var textArea = document.createElement('textarea'); // Place in top-left corner of screen regardless of scroll position.

    textArea.style.position = 'fixed';
    textArea.style.top = 0;
    textArea.style.left = 0; // Ensure it has a small width and height. Setting to 1px / 1em
    // doesn't work as this gives a negative w/h on some browsers.

    textArea.style.width = '2em';
    textArea.style.height = '2em'; // We don't need padding, reducing the size if it does flash render.

    textArea.style.padding = 0; // Clean up any borders.

    textArea.style.border = 'none';
    textArea.style.outline = 'none';
    textArea.style.boxShadow = 'none'; // Avoid flash of white box if rendered for any reason.

    textArea.style.background = 'transparent';
    textArea.value = $scope.user.coach.code.replace(/(.{3})/, '$1-');
    document.body.appendChild(textArea);
    textArea.setSelectionRange(0, textArea.value.length);

    try {
      var successful = document.execCommand('copy');

      if (!!successful) {
        $ionicPopup.alert({
          title: 'Coach ID copied to the clipboard.',
          buttons: [{
            text: 'Ok',
            type: 'button-balanced'
          }]
        });
      }
    } catch (err) {
      console.log('Oops, unable to copy');
    }

    document.body.removeChild(textArea);
  };

  $scope.shareCode = function () {
    var message = "With Nutritionix Track, you can share your food log directly with a coach. To make me your coach, use this coach ID: ".concat($scope.user.coach.code.replace(/(.{3})/, '$1-'), "\n\nNew to Nutritionix Track?\nDownload the app here:\nwww.nutritionix.com/app");
    window.plugins.socialsharing.available(function (isAvailable) {
      var options = {
        message: message,
        // not supported on some apps (Facebook, Instagram)
        // subject: '',
        // url: '',
        chooserTitle: 'Pick an app' // Android only, you can override the default share sheet title

      };

      var onSuccess = function onSuccess(result) {
        console.log('Share completed? ' + result.completed); // On Android apps mostly return false even while it's true

        console.log('Shared to app: ' + result.app); // On Android result.app is currently empty. On iOS it's empty when sharing is cancelled (result.completed=false)
      };

      var onError = function onError(msg) {
        console.log('Sharing failed with message: ' + msg);
      };

      window.plugins.socialsharing.shareWithOptions(options, onSuccess, onError);
    });
  };

  $scope.stopBeingCoach = function () {
    CoachService.stopBeingCoach().then(function () {
      $rootScope.isCoach = false;
      UserService.updateUser({
        coach: null
      });
      $state.go('app.myCoach');
    })["catch"](function (err) {
      console.log('there was an error', angular.toJson(err));
      throw err;
    });
  };

  $scope.viewClient = function (client) {
    $state.go('app.viewClient', {
      client: client,
      clientId: client.id
    });
  };

  $scope.clearSearch = function () {
    $scope.data.search = '';
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:connectAppController
 * @description
 * # connectAppController
 */

angular.module('Track').controller('connectedAppsController', ["$rootScope", "$scope", "$state", "$ionicHistory", "$cordovaDevice", "$cordovaSQLite", "AnalyticsService", "ApiService", function ($rootScope, $scope, $state, $ionicHistory, $cordovaDevice, $cordovaSQLite, AnalyticsService, ApiService) {
  $scope.$on('$ionicView.enter', function (event, data) {
    AnalyticsService.trackView('Connected Apps');
  });
  $scope.platform = $cordovaDevice.getPlatform();

  if ($scope.platform !== 'Android') {
    var attrs_to_check = ['HKQuantityTypeIdentifierDietaryEnergyConsumed', 'HKQuantityTypeIdentifierDietaryCaffeine', 'HKQuantityTypeIdentifierDietaryCalcium', 'HKQuantityTypeIdentifierDietaryCarbohydrates', 'HKQuantityTypeIdentifierDietaryCholesterol', 'HKQuantityTypeIdentifierDietaryCopper', 'HKQuantityTypeIdentifierDietaryFatMonounsaturated', 'HKQuantityTypeIdentifierDietaryFatPolyunsaturated', 'HKQuantityTypeIdentifierDietaryFatSaturated', 'HKQuantityTypeIdentifierDietaryFatTotal', 'HKQuantityTypeIdentifierDietaryFiber', 'HKQuantityTypeIdentifierDietaryIron', 'HKQuantityTypeIdentifierDietaryMagnesium', 'HKQuantityTypeIdentifierDietaryManganese', 'HKQuantityTypeIdentifierDietaryNiacin', 'HKQuantityTypeIdentifierDietaryPantothenicAcid', 'HKQuantityTypeIdentifierDietaryPhosphorus', 'HKQuantityTypeIdentifierDietaryPotassium', 'HKQuantityTypeIdentifierDietaryProtein', 'HKQuantityTypeIdentifierDietaryRiboflavin', 'HKQuantityTypeIdentifierDietarySodium', 'HKQuantityTypeIdentifierDietarySugar', 'HKQuantityTypeIdentifierDietaryThiamin', 'HKQuantityTypeIdentifierDietaryVitaminB6', 'HKQuantityTypeIdentifierDietaryVitaminA', 'HKQuantityTypeIdentifierDietaryVitaminC', 'HKQuantityTypeIdentifierDietaryVitaminD', 'HKQuantityTypeIdentifierDietaryVitaminE', 'HKQuantityTypeIdentifierDietaryZinc', 'HKQuantityTypeIdentifierBodyMass', 'HKQuantityTypeIdentifierActiveEnergyBurned'];
    var turnOffWeightHKSync = true;
    var turnOffExcerciseHKSync = true;
    var turnOffNutritionHKSync = true; // go through all attributes and turn off appropriate options if not authorized.

    attrs_to_check.map(function (attr, index) {
      window.plugins.healthkit.checkAuthStatus({
        'type': attr
      }, function (res) {
        if (res === 'authorized') {
          if (attr === 'HKQuantityTypeIdentifierBodyMass') {
            turnOffWeightHKSync = false;
          } else if (attr === 'HKQuantityTypeIdentifierActiveEnergyBurned') {
            turnOffExcerciseHKSync = false;
          } else {
            turnOffNutritionHKSync = false;
          }
        } //check if it's last attribute in the list and check for options that sould be disabled.


        if (index === attrs_to_check.length - 1) {
          if (turnOffNutritionHKSync) {
            $rootScope.hk.nutrition = 'off';
            $cordovaSQLite.execute(window.db, 'DROP TABLE hkdata');
            AnalyticsService.trackEvent('HealthKit nutrition sync', 'disable');
          }

          if (turnOffExcerciseHKSync) {
            $rootScope.hk.exercise = 'off';
            $cordovaSQLite.execute(window.db, 'DROP TABLE hkdata_exercise');
            AnalyticsService.trackEvent('HealthKit exercise sync', 'disable');
          }

          if (turnOffWeightHKSync) {
            $rootScope.hk.weight = 'off';
            $cordovaSQLite.execute(window.db, 'DROP TABLE hkdata_weight');
            AnalyticsService.trackEvent('HealthKit weight sync', 'disable');
          }

          window.localStorage.setItem('healthkit', angular.toJson($rootScope.hk));
        }
      }, function (err) {
        return console.log(err);
      });
    });
  }

  $scope.goBack = function () {
    //in the case of a deep link
    if ($ionicHistory.backView() === undefined) {
      $state.go('app.foodlog');
    } else {
      $ionicHistory.goBack();
    }
  };

  $scope.goToManageAppSync = function (managedApp) {
    $state.go('app.manageAppSync', {
      'managedApp': managedApp
    });
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:CreateFoodController
 * @description
 * # CreateFoodController
 */

angular.module('Track').controller('createFoodController', ["$scope", "$state", function ($scope, $state) {
  $scope.goBack = function () {
    $state.go('app.recipes');
  };

  $scope.goToRecipe = function () {
    $state.go('app.newRecipe');
  };

  $scope.goToCustomFood = function () {
    $state.go('app.customFood');
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:CustomFoodController
 * @description
 * # CustomFoodController
 */

angular.module('Track').controller('customFoodController', ["$scope", "$rootScope", "$state", "$stateParams", "$timeout", "$ionicPopup", "CustomFoodService", "HelperService", "CacheFactory", function ($scope, $rootScope, $state, $stateParams, $timeout, $ionicPopup, CustomFoodService, HelperService, CacheFactory) {
  $scope.logAfterSubmit = $stateParams.logAfterSubmit || false;
  $scope.mealType = $stateParams.mealType || null;
  $scope.isProcessingFood = false;
  var customFoodId = $stateParams.customFoodId || null;

  if (customFoodId) {
    $scope.editingFood = true;
  } else {
    $scope.editingFood = false;
  }

  $scope.customFood = {
    food_name: '',
    nf_vitamin_a_dv: null,
    nf_vitamin_c_dv: null,
    nf_vitamin_d_dv: null,
    nf_calcium_dv: null,
    nf_iron_dv: null,
    nf_calories: null,
    nf_cholesterol: null,
    nf_dietary_fiber: null,
    nf_p: null,
    nf_potassium: null,
    nf_protein: null,
    nf_saturated_fat: null,
    nf_sodium: null,
    nf_sugars: null,
    nf_total_carbohydrate: null,
    nf_total_fat: null,
    serving_qty: 1,
    serving_unit: 'Serving',
    source: 9,
    source_key: null
  };

  if (customFoodId) {
    $scope.loadingFood = true;
    CustomFoodService.getFoodById(customFoodId).then(function (result) {
      $scope.customFood = angular.copy(_.pick(result.data, ['food_name', 'full_nutrients', 'photo', 'serving_qty', 'serving_unit', 'serving_weight_grams', 'source', 'source_key']));

      _.extend($scope.customFood, window.nutritionixApiDataUtilities.convertFullNutrientsToNfAttributes($scope.customFood.full_nutrients));

      $scope.loadingFood = false;
    });
  }

  $scope.goBack = function () {
    $state.go('app.customFoods');
  };

  $scope.logCustom = function () {
    if ($scope.isProcessingFood) {
      return false;
    }

    $scope.invalidForm = false;

    if (!$scope.customFood.food_name || $scope.customFood.nf_calories === null || $scope.customFood.nf_calories === undefined || $scope.customFood.nf_calories < 0 || !$scope.customFood.serving_qty || !$scope.customFood.serving_unit) {
      $scope.invalidForm = true;
      return $timeout(function () {
        $scope.invalidForm = false;
      }, 500);
    }

    $scope.logAfterSubmit = true;
    $scope.submitCustomFood();
  };

  $scope.logFood = function () {
    var foodToLog = _.omit($scope.customFood, function (normalizedCustomFood, e) {
      return '_dv' === e.substr(-3);
    });

    foodToLog.full_nutrients = window.nutritionixApiDataUtilities.buildFullNutrientsArray(foodToLog);
    var nf = window.nutritionixApiDataUtilities.convertFullNutrientsToNfAttributes(foodToLog.full_nutrients);

    _.extend(foodToLog, nf);

    foodToLog = window.nutritionixApiDataUtilities.convertV1ItemToTrackFood(foodToLog);
    CacheFactory.getMealBuilderFoods().then(function (mb) {
      $rootScope.itemsInBuilder = mb;
      return $rootScope.itemsInBuilder.push(foodToLog);
    }).then(function () {
      var params = {};

      if ($scope.mealType !== null && $scope.mealType !== undefined) {
        if (!$rootScope.selected_day) {
          params = {
            mealConsumed: moment().format('ddd, MM/DD/YY')
          };
        } else {
          params = {
            mealConsumed: $rootScope.selected_day.date
          };
        }

        params.mealType = $scope.mealType;
      }

      CacheFactory.setMealBuilderFoods($rootScope.itemsInBuilder);
      $state.go('app.reviewFoods', params);
    });
  };

  $scope.submitCustomFood = function () {
    submit();
  };

  function resubmitCustomFood(newName) {
    $scope.customFood.food_name = newName;
    submit();
  }

  function submit() {
    if ($scope.isProcessingFood) {
      return false;
    }

    $scope.invalidForm = false;

    if (!$scope.customFood.food_name || $scope.customFood.nf_calories === null || $scope.customFood.nf_calories === undefined || $scope.customFood.nf_calories < 0 || !$scope.customFood.serving_qty || !$scope.customFood.serving_unit) {
      $scope.invalidForm = true;
      return $timeout(function () {
        $scope.invalidForm = false;
      }, 500);
    }

    $scope.isProcessingFood = true;

    var normalizedCustomFood = _.omitBy($scope.customFood, function (normalizedCustomFood, e) {
      return '_dv' === e.substr(-3);
    });

    normalizedCustomFood.full_nutrients = window.nutritionixApiDataUtilities.buildFullNutrientsArray($scope.customFood);

    if ($scope.editingFood) {
      normalizedCustomFood.id = customFoodId;
      CustomFoodService.updateFood(normalizedCustomFood).then(function (results) {
        $scope.isProcessingFood = false;

        if ($scope.logAfterSubmit) {
          $scope.logFood();
        } else {
          $state.go('app.customFoods', {
            showSavedFoodMessage: true
          });
        }
      })["catch"](function (err) {
        console.log('error updating food', err);
      });
    } else {
      CustomFoodService.addFood(normalizedCustomFood).then(function (results) {
        $scope.isProcessingFood = false;

        if ($scope.logAfterSubmit) {
          $scope.logFood();
        } else {
          $state.go('app.customFoods', {
            showSavedFoodMessage: true
          });
        }
      })["catch"](function (err) {
        console.log('error creating food', err);

        if (err.status === 409) {
          errorPromptUser(err);
        } else {
          throw err;
        }
      });
    }
  }

  function errorPromptUser(err) {
    $scope.invalidForm = true;
    $scope.isProcessingFood = false;
    $timeout(function () {
      $scope.invalidForm = false;
    }, 500);
    $scope.newrecipe = {};
    $ionicPopup.show({
      template: '<input type="text" ng-model="newrecipe.name" focus-me="true">',
      title: 'Custom Food with that name already exists',
      subTitle: 'Please Enter New Custom Food Name',
      scope: $scope,
      buttons: [{
        text: 'Cancel'
      }, {
        text: 'Save',
        type: 'button-positive',
        onTap: function onTap(e) {
          resubmitCustomFood($scope.newrecipe.name);
        }
      }]
    });
  }
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:CustomFoodsController
 * @description
 * # CustomFoodsController
 */

angular.module('Track').controller('customFoodsController', ["$scope", "$rootScope", "$state", "$stateParams", "$ionicPopup", "$timeout", "CustomFoodService", "HelperService", "CacheFactory", function ($scope, $rootScope, $state, $stateParams, $ionicPopup, $timeout, CustomFoodService, HelperService, CacheFactory) {
  $scope.customFoods = [];
  CustomFoodService.getCustomFoods().then(function (resp) {
    $scope.customFoods = resp.data.custom_foods;
  })["catch"](function (err) {
    console.log('[customFoodsController] error getting custom foods:', err);
  });
  $scope.showSavedFoodMessage = $stateParams.showSavedFoodMessage || false;

  if ($stateParams.showSavedFoodMessage) {
    $timeout(function () {
      $scope.showSavedFoodMessage = false;
    }, 2500);
  }

  $scope.goToCreateFood = function () {
    $state.go('app.customFood');
  };

  $scope.editFood = function (food) {
    $state.go('app.customFood', {
      customFoodId: food.id
    });
  };

  $scope.deleteFood = function (index, food_id) {
    CustomFoodService.deleteFood(food_id);

    var customIndex = _.findIndex($scope.customFoods, function (food) {
      return food.id == food_id;
    });

    $scope.customFoods.splice(customIndex, 1);
  };

  $scope.logFood = function (foodId) {
    CustomFoodService.getFoodById(foodId).then(function (resp) {
      var serving_qty = resp.data.serving_qty;

      var foodToLog = _.cloneDeep(resp.data);

      delete foodToLog.id; // need to do this for top level

      var nf = window.nutritionixApiDataUtilities.convertFullNutrientsToNfAttributes(foodToLog.full_nutrients);
      var accepted = ['nf_calories', 'nf_total_fat', 'nf_saturated_fat', 'nf_cholesterol', 'nf_sodium', 'nf_total_carbohydrate', 'nf_dietary_fiber', 'nf_sugars', 'nf_protein', 'nf_potassium', 'nf_p'];

      var keep = _.pick(nf, accepted);

      _.extend(foodToLog, keep); //remove public id because the log endpoint not accepting this property.


      delete foodToLog.public_id;
      CacheFactory.getMealBuilderFoods().then(function (mb) {
        $rootScope.itemsInBuilder = mb;
        return $rootScope.itemsInBuilder.push(foodToLog);
      }).then(function () {
        CacheFactory.setMealBuilderFoods($rootScope.itemsInBuilder);
        $state.go('app.reviewFoods');
      });
    });
  };
}]);
'use strict';

angular.module('Track').controller('dailyGoalsController', ["$rootScope", "$scope", "$state", "$timeout", "$ionicPopup", "AnalyticsService", "ApiService", "UserService", function ($rootScope, $scope, $state, $timeout, $ionicPopup, AnalyticsService, ApiService, UserService) {
  var previousData = {
    daily_kcal: null,
    daily_carbs_pct: null,
    daily_protein_pct: null,
    daily_fat_pct: null
  };
  $scope.$on('$ionicView.beforeEnter', function (event, data) {
    UserService.getUser().then(function (result) {
      $scope.currentUser = result;
      previousData.daily_kcal = $scope.currentUser.daily_kcal;
      previousData.daily_carbs_pct = $scope.currentUser.daily_carbs_pct;
      previousData.daily_protein_pct = $scope.currentUser.daily_protein_pct;
      previousData.daily_fat_pct = $scope.currentUser.daily_fat_pct;
    });
  });

  $scope.saveGoals = function () {
    if ($rootScope.noInternet) {
      $ionicPopup.alert({
        title: 'Not available in offline mode.',
        buttons: [{
          text: 'Ok',
          type: 'button-balanced'
        }]
      });
      return;
    }

    var userPref = {};
    $scope.saveError = null;
    $scope.shakeButton = false;
    var isGoalsChanged = false;
    var isCaloriesChanged = false;

    if (!!$scope.currentUser && !!$scope.currentUser.daily_kcal) {
      userPref.daily_kcal = $scope.currentUser.daily_kcal;
      isCaloriesChanged = userPref.daily_kcal !== previousData.daily_kcal;
    }

    if ($scope.currentUser.daily_carbs_pct !== null && $scope.currentUser.daily_carbs_pct !== undefined) {
      userPref.daily_carbs_pct = $scope.currentUser.daily_carbs_pct;
      isGoalsChanged = isGoalsChanged || userPref.daily_carbs_pct !== previousData.daily_carbs_pct;
    } else {
      userPref.daily_carbs_pct = null;
    }

    if ($scope.currentUser.daily_protein_pct !== null && $scope.currentUser.daily_protein_pct !== undefined) {
      userPref.daily_protein_pct = $scope.currentUser.daily_protein_pct;
      isGoalsChanged = isGoalsChanged || userPref.daily_protein_pct !== previousData.daily_protein_pct;
    } else {
      userPref.daily_protein_pct = null;
    }

    if ($scope.currentUser.daily_fat_pct !== null && $scope.currentUser.daily_fat_pct !== undefined) {
      userPref.daily_fat_pct = $scope.currentUser.daily_fat_pct;
      isGoalsChanged = isGoalsChanged || userPref.daily_fat_pct !== previousData.daily_fat_pct;
    } else {
      userPref.daily_fat_pct = null;
    }

    if (($scope.currentUser.daily_carbs_pct || 0) + ($scope.currentUser.daily_protein_pct || 0) + ($scope.currentUser.daily_fat_pct || 0) > 100) {
      $scope.saveError = 'The total percentage cannot be more than 100%';
      $scope.shakeButton = true;
      $timeout(function () {
        $scope.shakeButton = false;
        $scope.saveError = null;
      }, 3000);
      return;
    }

    if (isGoalsChanged) {
      AnalyticsService.trackEvent('changedDailyGoals', 'protein:' + userPref.daily_protein_pct + '% carbs:' + userPref.daily_carbs_pct + '% fat:' + userPref.daily_fat_pct + '%');
    }

    if (isCaloriesChanged) {
      AnalyticsService.trackEvent('changedCalorieLimit', 'From ' + previousData.daily_kcal + ' to ' + userPref.daily_kcal);
    }

    UserService.updateUser(userPref).then(function () {
      $rootScope.$broadcast('userPreferences:updated');
      $state.go('app.foodlog');
    })["catch"](function (err) {
      console.log('There was error saving daily goals.', err);
    });
  };

  $scope.showGoalsFaq = function () {
    cordova.InAppBrowser.open('https://help.nutritionix.com/articles/11429-q-what-are-macro-goals-and-how-do-i-use-them-in-track', '_blank', "location=no");
  };

  $scope.goBack = function () {
    $state.go('app.foodlog');
  };
}]);
'use strict';

angular.module('Track').controller('developerSettingsController', ["$rootScope", "$scope", "$ionicHistory", function ($rootScope, $scope, $ionicHistory) {
  $scope.goBack = function () {
    return $ionicHistory.goBack();
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:EditRecipe2Controller
 * @description
 * # EditRecipe2Controller
 */

angular.module('Track').controller('editRecipe2Controller', ["$scope", "$state", "$rootScope", "$stateParams", "$filter", "$timeout", "$ionicPopup", "$q", "$http", "$cordovaDevice", "Recipe2Service", "nixTrackUtils", "CacheFactory", "AnalyticsService", "ApiService", "HelperService", "SQLiteService", "$ionicScrollDelegate", function ($scope, $state, $rootScope, $stateParams, $filter, $timeout, $ionicPopup, $q, $http, $cordovaDevice, Recipe2Service, nixTrackUtils, CacheFactory, AnalyticsService, ApiService, HelperService, SQLiteService, $ionicScrollDelegate) {
  var vm = this;
  var id = $stateParams.id;
  $scope.recipe = {
    'name': '',
    'source': 4,
    'serving_weight_grams': 0,
    'ingredients': [],
    'serving_unit': 'Serving',
    'serving_qty': 1
  };
  $scope.uploadPhoto = {
    file: null,
    isUploading: false,
    isChanged: false,
    isUploaded: false,
    noCustomPhoto: !$scope.recipe.photo || !$scope.recipe.photo.thumb || $scope.recipe.photo.thumb.indexOf('nix-apple-grey') !== -1 ? true : false
  };
  $scope.initialIngredientsQty = 0;
  $scope.errorMessages = {
    name: '',
    serving_unit: '',
    serving_qty: '',
    ingredients: ''
  };
  $scope.ingredientsView = [];
  $scope.changedIngredient = false;
  SQLiteService.query(window.db, 'SELECT value FROM localdata WHERE dataName = ?', ['photoUploadUserAgreement']).then(function (result) {
    $scope.agreedToUsePhoto = SQLiteService.getById(result);

    if ($scope.agreedToUsePhoto && $scope.agreedToUsePhoto) {
      $scope.isPhotoPopupShown = true;
    } else {
      $scope.isPhotoPopupShown = false;
    }
  })["catch"](function (err) {
    console.log(err);
  });

  $scope.showPhotoPopup = function () {
    var permissions = cordova.plugins.permissions;
    $q.when().then(function () {
      var deferred = $q.defer();

      if (window.ionic.Platform.isAndroid()) {
        permissions.checkPermission(permissions.WRITE_EXTERNAL_STORAGE, function (result) {
          if (!result.hasPermission) {
            permissions.requestPermission(permissions.WRITE_EXTERNAL_STORAGE, function (result) {
              if (result.hasPermission) {
                deferred.resolve(result.hasPermission);
              } else {
                deferred.reject(result.hasPermission);
              }
            });
          } else {
            deferred.resolve(true);
          }
        });
      } else {
        deferred.resolve(true);
      }

      return deferred.promise;
    }).then(function () {
      var deferred = $q.defer();

      if (window.ionic.Platform.isAndroid()) {
        permissions.checkPermission(permissions.CAMERA, function (result) {
          if (!result.hasPermission) {
            permissions.requestPermission(permissions.CAMERA, function (result) {
              if (result.hasPermission) {
                deferred.resolve(result.hasPermission);
              } else {
                deferred.reject(result.hasPermission);
              }
            });
          } else {
            deferred.resolve(true);
          }
        });
      } else {
        deferred.resolve(true);
      }

      return deferred.promise;
    }).then(function () {
      return $ionicPopup.show({
        title: 'Info box',
        template: '<div class="text-center" style="font-size:12px;">All meal photos uploaded become public and viewable on Nutritionix.com. No other personal information is shared with the photo. By uploading a photo, you are agreeing to make it public.</div>',
        buttons: [{
          text: 'I understand',
          type: 'button-balanced',
          onTap: function onTap() {
            SQLiteService.query(window.db, 'INSERT INTO localdata (dataName, value) VALUES (?1, ?2) ON CONFLICT(dataName) DO UPDATE SET dataName=?1, value=?2', ['photoUploadUserAgreement', 'true']);
            $scope.isPhotoPopupShown = true;
            $timeout(function () {
              angular.element('div[ngf-select="fileChanged($files)"]').click();
            }, 1000);
          }
        }]
      });
    });
  };

  $scope.fileChanged = function (files) {
    $scope.uploadPhoto.file = files[0];
    $scope.uploadPhoto.isChanged = true;
    $scope.uploadPhoto.noCustomPhoto = false;
    $scope.showPhoto = true;
    var formData = new FormData();
    formData.append('file', $scope.uploadPhoto.file);
    $scope.uploadPhoto.isUploading = true;
    return $http.post('https://trackapi.nutritionix.com/v2/upload/image/foods/' + moment().format('YYYY-MM-DD'), formData, {
      headers: {
        'Content-Type': undefined
      }
    }).then(function (resp) {
      $scope.showPhoto = true;
      $scope.uploadPhoto.isUploading = false;
      $scope.customPhotoUrl = resp.data;
      return $scope.customPhotoUrl;
    })["catch"](function (e) {
      $scope.uploadPhoto.isUploading = false;
      console.log('there was an error uploading photo', e);
    });
  };

  $scope.clearCustomPhoto = function () {
    $scope.uploadPhoto = {
      file: null,
      isUploading: false,
      isChanged: false,
      isUploaded: false,
      noCustomPhoto: !$scope.recipe.photo || !$scope.recipe.photo.thumb || $scope.recipe.photo.thumb.indexOf('nix-apple-grey') !== -1 ? true : false
    };
  };

  function generateIngredientsView(ingredients) {
    for (var i = 0; i < ingredients.length; i++) {
      if (!ingredients[i].metadata || !ingredients[i].metadata.original_input) {
        if (!ingredients[i].metadata) {
          ingredients[i].metadata = {};
        }

        ingredients[i].metadata.original_input = ingredients[i].serving_qty + ' ' + ingredients[i].serving_unit + ' ' + ingredients[i].food_name;
      }

      if (!$scope.ingredientsView[i]) {
        $scope.ingredientsView[i] = {};
      }

      $scope.ingredientsView[i].thumb = !!ingredients[i].photo ? ingredients[i].photo.thumb : null;
      $scope.ingredientsView[i].original_input = ingredients[i].metadata.original_input;
      $scope.ingredientsView[i].totalCalories = $filter('nutrient')(ingredients[i].full_nutrients, 208, 'value');
    }
  }

  if (!!id) {
    $scope.editingRecipe = true;
    $scope.showPreloader = true;
    Recipe2Service.getRecipeById(id).then(function (resp) {
      _.forEach(resp.data.ingredients, function (foodObj) {
        if (foodObj.alt_measures) {
          var temp = {
            'serving_weight': foodObj.serving_weight_grams,
            'seq': null,
            'measure': foodObj.serving_unit,
            'qty': foodObj.serving_qty
          };
          foodObj.alt_measures.unshift(temp);
        }

        if (!foodObj.metadata || !foodObj.metadata.original_input) {
          if (!foodObj.metadata) {
            foodObj.metadata = {};
          }

          foodObj.metadata.original_input = foodObj.serving_qty + ' ' + foodObj.serving_unit + ' ' + foodObj.food_name;
        }
      });

      $scope.recipe = resp.data;
      $scope.initialIngredientsQty = $scope.recipe.ingredients.length;
      $scope.uploadPhoto.noCustomPhoto = !$scope.recipe.photo || !$scope.recipe.photo.thumb || $scope.recipe.photo.thumb.indexOf('nix-apple-grey') !== -1 ? true : false;
      generateIngredientsView($scope.recipe.ingredients);
      $scope.clonedRecipe = _.cloneDeep($scope.recipe);
      $scope.changedQuantity();
      $scope.showPreloader = false;
    });
  } else {
    $scope.editingRecipe = false;
  }

  $scope.$on('$ionicView.enter', function (event, data) {
    $scope.iosFloatingButtonAdjustment = 0;

    if ($cordovaDevice.getPlatform() == 'iOS') {
      window.addEventListener('native.keyboardshow', keyboardShowHandler);
      window.addEventListener('native.keyboardhide', keyboardHideHandler);
    }
  });
  $scope.$on('$ionicView.beforeLeave', function (event, data) {
    if ($cordovaDevice.getPlatform() == 'iOS') {
      window.removeEventListener('native.keyboardshow', keyboardShowHandler);
      window.removeEventListener('native.keyboardhide', keyboardHideHandler);
    }
  });

  function keyboardShowHandler(e) {
    $scope.iosFloatingButtonAdjustment = e.keyboardHeight;
    $scope.$apply();
  }

  function keyboardHideHandler(e) {
    $scope.iosFloatingButtonAdjustment = 0;
    $scope.$apply();
  }

  $scope.changedQuantity = function () {
    $scope.isMultiServing = $scope.recipe.serving_qty > 1;
  };

  $scope.calculateTotalTime = function () {
    var result = (parseInt($scope.recipe.cook_time_min) || 0) + (parseInt($scope.recipe.prep_time_min) || 0);
    return result || 0;
  };

  $scope.calculateTotalCalories = function () {
    var result = 0;

    _.each($scope.recipe.ingredients, function (food) {
      result = result + ($filter('nutrient')(food.full_nutrients, 208, 'value') || food.nf_calories);
    });

    result = result / ($scope.recipe.serving_qty || 1);
    return result || 0;
  };

  $scope.removeIngredient = function (index) {
    $scope.recipe.ingredients.splice(index, 1);
    $scope.ingredientsView.splice(index, 1);
  };

  $scope.validateForm = function () {
    $scope.errorMessages = {
      name: '',
      serving_unit: '',
      serving_qty: '',
      ingredients: ''
    };

    if (!$scope.recipe.name) {
      $scope.errorMessages.name = 'Recipe Name is required';
      $scope.invalidForm = true;
    }

    if (!$scope.recipe.serving_unit) {
      $scope.errorMessages.serving_unit = 'Serving unit is required';
      $scope.invalidForm = true;
    }

    if (!$scope.recipe.serving_qty) {
      $scope.errorMessages.serving_qty = 'Serving quantity is required';
      $scope.invalidForm = true;
    }

    if (!$scope.recipe.ingredients.length) {
      $scope.errorMessages.ingredients = 'Recipe must have at least one ingredient';
      $scope.invalidForm = true;
    }
  };

  $scope.submitRecipe = function (logAfterUpdate) {
    $scope.validateForm();

    if ($scope.invalidForm) {
      $timeout(function () {
        $scope.invalidForm = false;
      }, 3000);
      $timeout(function () {
        $ionicScrollDelegate.scrollTop();
      }, 1000);
      return;
    }

    if ($scope.uploadPhoto.isUploading) {
      return console.log('uploading photo');
    }

    if ($scope.customPhotoUrl) {
      $scope.recipe.photo = {
        highres: $scope.customPhotoUrl.full,
        thumb: $scope.customPhotoUrl.thumb,
        is_user_uploaded: true
      };
    }

    if ($scope.editingRecipe) {
      var recipeToUpdate = _.cloneDeep($scope.recipe);

      delete recipeToUpdate.public_id;
      delete recipeToUpdate.created_at;
      delete recipeToUpdate.updated_at;
      delete recipeToUpdate.full_nutrients;
      delete recipeToUpdate.serving_weight_grams;
      Recipe2Service.updateRecipe(recipeToUpdate).then(function (res) {
        if (logAfterUpdate) {
          return res;
        } else {
          return $state.go('app.myRecipes2', {
            showSavedRecipeMessage: true
          });
        }
      })["catch"](function (err) {
        console.log(err);
      });
    } else {
      Recipe2Service.addRecipe($scope.recipe).then(function (res) {
        AnalyticsService.trackEvent('Recipe created', 'Created from the recipes interface');

        if (logAfterUpdate) {
          return res;
        } else {
          return $state.go('app.myRecipes2', {
            showSavedRecipeMessage: true
          });
        }
      })["catch"](function (err) {
        if (!!err && !!err.data && !!err.data.message && err.data.message == 'resource already exists') {
          errorMessage(err);
          return console.log('resource already exists');
        }

        console.log(err);
      });
    }
  };

  $scope.showIngredientsPopup = function () {
    $ionicPopup.show({
      template: '<textarea class="input-bg-color" multiline-placeholder style="text-indent:0!important; padding:5px;" rows="7" ng-model="vm.query" placeholder="For best results, please limit one ingredient per line.\\n\\nE.g.\\n2 cups baby spinach\\n1 tbsp olive oil\\n.25 cups onions, chopped" focus-me="true"> </textarea>',
      title: 'Add Ingredients',
      scope: $scope,
      cssClass: 'custom-popup',
      buttons: [{
        text: 'Add',
        type: 'button-positive',
        onTap: function onTap(e) {
          ApiService.getFoodNutrients({
            query: vm.query,
            line_delimited: true,
            use_raw_foods: true
          }).then(function (res) {
            _.forEach(res.data.foods, function (foodObj) {
              if (foodObj.alt_measures) {
                var temp = {
                  'serving_weight': foodObj.serving_weight_grams,
                  'seq': null,
                  'measure': foodObj.serving_unit,
                  'qty': foodObj.serving_qty
                };
                foodObj.alt_measures.unshift(temp);
              }

              if (!foodObj.metadata.original_input) {
                foodObj.metadata.original_input = foodObj.serving_qty + ' ' + foodObj.serving_unit + ' ' + foodObj.food_name;
              }
            });

            $scope.recipe.ingredients = $scope.recipe.ingredients.concat(res.data.foods);
            vm.query = '';
            generateIngredientsView($scope.recipe.ingredients);

            if (!!res.data.errors && res.data.errors.length) {
              errorMessage1(res, 'add');
            }
          })["catch"](function (err) {
            ApiService.getFoodNutrients({
              query: vm.query,
              line_delimited: false,
              use_raw_foods: true
            }).then(function (res) {
              _.forEach(res.data.foods, function (foodObj) {
                if (foodObj.alt_measures) {
                  var temp = {
                    'serving_weight': foodObj.serving_weight_grams,
                    'seq': null,
                    'measure': foodObj.serving_unit,
                    'qty': foodObj.serving_qty
                  };
                  foodObj.alt_measures.unshift(temp);
                }

                if (!foodObj.metadata.original_input) {
                  foodObj.metadata.original_input = foodObj.serving_qty + ' ' + foodObj.serving_unit + ' ' + foodObj.food_name;
                }
              });

              $scope.recipe.ingredients = $scope.recipe.ingredients.concat(res.data.foods);
              vm.query = '';
              generateIngredientsView($scope.recipe.ingredients);

              if (!!res.data.errors && res.data.errors.length) {
                errorMessage1(res, 'add');
              }
            })["catch"](function (err) {
              errorMessage1(err, 'add');
              console.log('error getting nutrients', err);
            });
            console.log('error getting nutrients', err);
          });
        }
      }, {
        text: 'Cancel',
        onTap: function onTap(e) {
          vm.query = '';
          $scope.errorInProgress = false;
        }
      }]
    });
  };

  $scope.copyRecipe = function () {
    delete $scope.clonedRecipe.created_at;
    delete $scope.clonedRecipe.updated_at;
    delete $scope.clonedRecipe.id;
    $scope.clonedRecipe.newRecipeName = $scope.clonedRecipe.name;
    $ionicPopup.show({
      'title': 'Copy Recipe',
      scope: $scope,
      'template': 'Enter new unique name for the new recipe <br/><input type="text" ng-model="clonedRecipe.newRecipeName" />',
      buttons: [{
        'text': 'Cancel',
        'type': 'button-default'
      }, {
        'text': 'Sumbit',
        'type': 'button-positive',
        onTap: function onTap(e) {
          if ($scope.clonedRecipe.newRecipeName === $scope.clonedRecipe.name) {
            e.preventDefault();
            errorMessage();
          } else {
            $scope.clonedRecipe.name = $scope.clonedRecipe.newRecipeName;
            return Recipe2Service.addRecipe($scope.clonedRecipe).then(function (res) {
              $scope.clonedRecipe = res.data;
              $state.go('app.editRecipe2', {
                id: res.data.id
              }, {
                reload: true
              });
              AnalyticsService.trackEvent('Recipe copied', 'Copied from the edit recipe interface');
            })["catch"](function (err) {
              if (!!err && !!err.data && !!err.data.message && err.data.message == 'resource already exists') {
                errorMessage(err);
                return console.log('resource already exists');
              } else {
                throw err;
              }
            });
          }
        }
      }]
    });
  };

  vm.changeIngredient = function (index) {
    if (vm.goingBack || $scope.ingredientsView[index].original_input === $scope.recipe.ingredients[index].metadata.original_input) {
      return;
    }

    var query = $scope.ingredientsView[index].original_input;
    ApiService.getFoodNutrients({
      query: query,
      line_delimited: true,
      use_raw_foods: true
    }).then(function (res) {
      $scope.recipe.ingredients[index] = res.data.foods[0];

      if (!$scope.recipe.ingredients[index].metadata.original_input) {
        $scope.recipe.ingredients[index].metadata.original_input = query;
      }

      $scope.changedIngredient = true;
      generateIngredientsView($scope.recipe.ingredients);
    })["catch"](function (err) {
      errorMessage1(err, 'edit', index);
      console.log('error getting nutrients', err);
    });
  };

  $scope.logRecipe = function () {
    $scope.validateForm();

    if ($scope.invalidForm) {
      $timeout(function () {
        $scope.invalidForm = false;
      }, 3000);
      return;
    }

    $scope.submitRecipe(true);

    var recipeToLog = _.cloneDeep($scope.recipe); // need to do this for top level as well as each ingredient


    var nf = window.nutritionixApiDataUtilities.convertFullNutrientsToNfAttributes(recipeToLog.full_nutrients);
    var accepted = ['nf_calories', 'nf_total_fat', 'nf_saturated_fat', 'nf_cholesterol', 'nf_sodium', 'nf_total_carbohydrate', 'nf_dietary_fiber', 'nf_sugars', 'nf_protein', 'nf_potassium', 'nf_p'];

    var keep = _.pick(nf, accepted);

    _.extend(recipeToLog, keep);

    _.forEach(recipeToLog.ingredients, function (ingredient) {
      var ing_nf = window.nutritionixApiDataUtilities.convertFullNutrientsToNfAttributes(ingredient.full_nutrients);

      var ing_keep = _.pick(ing_nf, accepted);

      _.extend(ingredient, ing_keep);
    });

    if (!!$scope.recipe.photo && !!$scope.recipe.photo.highres) {
      var customPhoto = {
        full: $scope.recipe.photo.highres || null,
        thumb: $scope.recipe.photo.thumb
      };
      window.localStorage.setItem('reviewBasketCustomPhoto', angular.toJson(customPhoto));
    } //only want to log 1 serving


    var scaled_recipe = HelperService.multiply(recipeToLog, 1 / $scope.recipe.serving_qty, 1);
    $rootScope.$broadcast('mealBuilder: addFood', {
      foodArray: scaled_recipe.ingredients
    });
    AnalyticsService.trackEvent('Added recipe to the basket', ' ');
    $state.go('app.reviewFoods', {
      type: 'singleFood',
      name: scaled_recipe.name,
      recipeBrand: scaled_recipe.brand_name || null,
      servings: $scope.recipe.serving_qty
    });
  };

  $scope.goBack = function (mode) {
    vm.goingBack = true;

    if (mode == 'discard') {
      return $state.go('app.myRecipes2');
    }

    var editedInput = angular.element('input[ng-model="ingredient.original_input"]:focus');

    if (editedInput.length) {
      return $ionicPopup.show({
        title: 'Attention',
        subTitle: 'You are currently editing an ingredient.',
        template: '<div class="text-center">Do you want to continue edit?</div>',
        buttons: [{
          text: 'Yes',
          type: 'button-balanced',
          onTap: function onTap(e) {
            return $timeout(function () {
              vm.goingBack = false;
              editedInput.focus();
            }, 200);
          }
        }, {
          text: 'No',
          type: 'button-default',
          onTap: function onTap(e) {
            $scope.goBack();
          }
        }]
      });
    }

    if (!vm.recipeDirectionsForm.$pristine || !vm.recipeForm.$pristine || $scope.recipe.ingredients.length != $scope.initialIngredientsQty || $scope.changedIngredient) {
      return $ionicPopup.show({
        title: 'Attention',
        subTitle: 'You have unsaved changes',
        template: '<div class="text-center">Do you want to save changes?</div>',
        buttons: [{
          text: 'Save',
          type: 'button-balanced',
          onTap: function onTap(e) {
            $scope.submitRecipe();
          }
        }, {
          text: 'Discard',
          type: 'button-assertive',
          onTap: function onTap(e) {
            $state.go('app.myRecipes2');
          }
        }]
      });
    }

    $state.go('app.myRecipes2');
  };

  function errorMessage1(err, action, index) {
    if ($scope.errorInProgress) {
      return;
    }

    $scope.errorInProgress = true;
    $scope.invalidForm = true;
    $timeout(function () {
      $scope.invalidForm = false;
    }, 500);
    var wrongQuery = '';
    var errorMessageText = '';

    if (err.data.message && err.data.message.length) {
      errorMessageText = err.data.message + ' for:';
    } else {
      errorMessageText = 'Could not find foods for:';
    }

    if (!!err.data && !!err.data.errors && err.data.errors.length) {
      for (var i = 0; i < err.data.errors.length; i++) {
        if (i > 0) {
          wrongQuery = wrongQuery + '<br/>';
        }

        wrongQuery = wrongQuery + err.data.errors[i].original_text;
      }
    } else if (!vm.query || !vm.query.length) {
      errorMessageText = 'No food found.';
    } else {
      wrongQuery = vm.query;
    }

    if (vm.goingBack) {
      return;
    }

    $ionicPopup.show({
      title: errorMessageText,
      template: '<div>' + wrongQuery + '</div>',
      buttons: [{
        text: 'Edit',
        type: 'button-balanced',
        onTap: function onTap(e) {
          if (action == 'add') {
            //save wrong text as query and open popup.
            vm.query = wrongQuery.replace(/<br\/>/g, '\n');
            $scope.showIngredientsPopup();
            $scope.errorInProgress = false;
          } else if (action == 'edit') {
            //focus back on the edited element
            var editedInput = angular.element('input[ng-model="ingredient.original_input"]')[index];
            $timeout(function () {
              editedInput.focus();
            }, 200);
            $timeout(function () {
              $scope.errorInProgress = false;
            }, 500);
          }
        }
      }, {
        text: 'Dismiss',
        type: 'button-default',
        onTap: function onTap(e) {
          if (action == 'add') {
            vm.query = '';
          } else if (action == 'edit') {
            $scope.ingredientsView[index].original_input = $scope.recipe.ingredients[index].metadata.original_input;
          }

          $scope.errorInProgress = false;
        }
      }]
    });
  }

  function errorMessage(err) {
    var errorMessageText = 'Recipe with this name already exists';
    $ionicPopup.show({
      title: errorMessageText,
      template: '<div class="text-center">Would you like to change the name or replace the existing recipe?</div>',
      buttons: [{
        text: 'Change',
        type: 'button-balanced',
        onTap: function onTap(e) {
          $timeout(function () {
            if (window.jQuery('input[ng-model="clonedRecipe.newRecipeName"]').length) {
              window.jQuery('input[ng-model="clonedRecipe.newRecipeName"]').focus();
            } else {
              window.jQuery('input[ng-model="recipe.name"]').focus();
            }
          }, 500);
        }
      }, {
        text: 'Replace',
        type: 'button-default',
        onTap: function onTap(e) {
          promptToOverwriteRecipe(err.data.existing_resource_id);
        }
      }]
    });
  }

  function promptToOverwriteRecipe(existingRecipeId) {
    $ionicPopup.show({
      title: 'Are you sure?',
      template: '<div class="text-center">This will replace the existing recipe</div>',
      buttons: [{
        text: 'Yes',
        type: 'button-balanced',
        onTap: function onTap(e) {
          $scope.editingRecipe = true;
          $scope.recipe.id = existingRecipeId;
          $scope.submitRecipe(false);
        }
      }, {
        text: 'Cancel',
        type: 'button-default',
        onTap: function onTap(e) {
          console.log('Cancelled');
        }
      }]
    });
  }
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:EditRecipeController
 * @description
 * # EditRecipeController
 */

angular.module('Track').controller('editRecipeController', ["$scope", "$state", "$rootScope", "$stateParams", "$ionicPopup", "RecipeService", "nixTrackUtils", "CacheFactory", "ApiService", "HelperService", function ($scope, $state, $rootScope, $stateParams, $ionicPopup, RecipeService, nixTrackUtils, CacheFactory, ApiService, HelperService) {
  var id = $stateParams.id;
  $scope.editingName = false;
  $scope.recipe = {};
  $scope.top_level = {};
  $scope.instruction = {};
  var instruct_copy = '';
  RecipeService.getRecipeById(id).then(function (resp) {
    _.forEach(resp.data.ingredients, function (foodObj) {
      if (foodObj.alt_measures) {
        var temp = {
          'serving_weight': foodObj.serving_weight_grams,
          'seq': null,
          'measure': foodObj.serving_unit,
          'qty': foodObj.serving_qty
        };
        foodObj.alt_measures.unshift(temp);
      }
    });

    $scope.recipe = resp.data;
    $scope.top_level.serving_qty = $scope.recipe.serving_qty;
    $scope.initial_food_name = $scope.recipe.food_name;
    $scope.instruction.text = $scope.recipe.directions;
    instruct_copy = $scope.recipe.directions;
  });
  $scope.$on('$ionicView.enter', function () {
    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(false);
    }
  });
  $scope.$on('$ionicView.leave', function () {
    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
    }
  });

  $scope.goBack = function () {
    $state.go('app.recipes');
  };

  $scope.selectText = function (index) {
    var el = document.getElementById(index);
    el.selectionStart = 0;
    el.selectionEnd = 9999;
  };

  $scope.changeQty = function (newFoodObj, oldFood) {
    var index = _.indexOf($scope.recipe.ingredients, newFoodObj);

    if (!newFoodObj.serving_qty || newFoodObj.serving_qty === '' || newFoodObj.serving_qty === 0) {
      $scope.recipe.ingredients[index] = oldFood;
      return;
    } else {
      var cloneOldFood = _.cloneDeep(oldFood);

      var multiplier = nixTrackUtils.calculateFoodMultiplier(cloneOldFood, newFoodObj.serving_qty);
      var newFood = nixTrackUtils.multiplyFoodNutrients(cloneOldFood, multiplier, true);
      RecipeService.updateRecipeIngredient($scope.recipe.id, [newFood]).then(function (response) {
        $scope.recipe = response.data;
      });
    }
  };

  $scope.removeIngredient = function (index, ingredient) {
    RecipeService.deleteRecipeIngredient($scope.recipe.id, ingredient.id).then(function (response) {
      _.forEach(response.data.ingredients, function (foodObj) {
        if (foodObj.alt_measures) {
          var temp = {
            'serving_weight': foodObj.serving_weight_grams,
            'seq': null,
            'measure': foodObj.serving_unit,
            'qty': foodObj.serving_qty
          };
          foodObj.alt_measures.unshift(temp);
        }
      });

      $scope.recipe = response.data;
    });
  };

  $scope.changeServingQty = function () {
    if (!$scope.top_level.serving_qty || $scope.top_level.serving_qty === '' || $scope.top_level.serving_qty === 0) {
      $scope.top_level.serving_qty = $scope.recipe.serving_qty;
      return;
    } else {
      RecipeService.updateRecipeServingQty($scope.recipe.id, $scope.top_level.serving_qty).then(function (response) {
        $scope.recipes = response.data;
      });
    }
  };

  $scope.changeMeasure = function (newFoodObj, oldFoodObj, serving_unit) {
    var new_alt_measure = _.find(newFoodObj.alt_measures, {
      'measure': serving_unit
    });

    var old_alt_measure = _.find(oldFoodObj.alt_measures, {
      'measure': oldFoodObj.serving_unit
    });

    var multiplier = new_alt_measure.serving_weight / new_alt_measure.qty / (old_alt_measure.serving_weight / old_alt_measure.qty);
    var newFood = nixTrackUtils.multiplyFoodNutrients(oldFoodObj, multiplier, false);
    newFood.serving_unit = serving_unit;
    newFood.serving_qty = oldFoodObj.serving_qty;
    newFood.id = oldFoodObj.id;
    RecipeService.updateRecipeIngredient($scope.recipe.id, [newFood]).then(function (response) {
      $scope.recipe = response.data;
    });
  };

  $scope.logRecipe = function () {
    var recipeToLog = _.cloneDeep($scope.recipe); // need to do this for top level as well as each ingredient


    var nf = window.nutritionixApiDataUtilities.convertFullNutrientsToNfAttributes(recipeToLog.full_nutrients);
    var accepted = ['nf_calories', 'nf_total_fat', 'nf_saturated_fat', 'nf_cholesterol', 'nf_sodium', 'nf_total_carbohydrate', 'nf_dietary_fiber', 'nf_sugars', 'nf_protein', 'nf_potassium', 'nf_p'];

    var keep = _.pick(nf, accepted);

    _.extend(recipeToLog, keep);

    _.forEach(recipeToLog.ingredients, function (ingredient) {
      var ing_nf = window.nutritionixApiDataUtilities.convertFullNutrientsToNfAttributes(ingredient.full_nutrients);

      var ing_keep = _.pick(ing_nf, accepted);

      _.extend(ingredient, ing_keep);
    }); //only want to log 1 serving


    var scaled_recipe = HelperService.multiply(recipeToLog, 1 / $scope.top_level.serving_qty, 1);
    $rootScope.$broadcast('mealBuilder: addFood', {
      foodArray: scaled_recipe.ingredients
    });
    $state.go('app.reviewFoods', {
      type: 'singleFood',
      name: scaled_recipe.food_name,
      recipeBrand: scaled_recipe.brand_name || null,
      servings: $scope.top_level.serving_qty
    });
  };

  $scope.addRecipeIngredient = function () {
    $scope.data = {
      addedRecipeIngredient: '',
      placeholder: ' 2 slices white bread'
    };
    $ionicPopup.show({
      template: '<textarea rows=5 ng-model="data.addedRecipeIngredient" placeholder={{data.placeholder}}> </textarea>',
      title: 'Enter Recipe Ingredients',
      scope: $scope,
      buttons: [{
        text: 'Cancel'
      }, {
        text: 'Save',
        type: 'button-positive',
        onTap: function onTap(e) {
          RecipeService.addRecipeIngredient(id, $scope.data.addedRecipeIngredient).then(function (resp) {
            _.forEach(resp.data.ingredients, function (foodObj) {
              if (foodObj.alt_measures) {
                var temp = {
                  'serving_weight': foodObj.serving_weight_grams,
                  'seq': null,
                  'measure': foodObj.serving_unit,
                  'qty': foodObj.serving_qty
                };
                foodObj.alt_measures.unshift(temp);
              }
            });

            $scope.recipe = resp.data;
          })["catch"](function (e) {
            errorMessage(e);
          });
        }
      }]
    });
  };

  $scope.editFoodName = function () {
    $scope.editingName = true;
  };

  $scope.saveFoodName = function () {
    $scope.editingName = false;

    if ($scope.recipe.food_name !== $scope.initial_food_name) {
      $scope.initial_food_name = $scope.recipe.food_name;
      return RecipeService.updateRecipe($scope.recipe);
    }
  };

  $scope.showIngredientInfo = function (ingredient) {
    return ApiService.setCurrentFood(ingredient).then(function () {
      return $state.go('app.food', {
        food_id: ingredient.id,
        readOnly: true
      });
    });
  };

  $scope.saveRecipe = function () {
    if (!$scope.instruction.text || $scope.instruction.text === instruct_copy) {
      return $state.go('app.recipes');
    }

    RecipeService.addRecipeInstructions(id, $scope.instruction.text).then(function (response) {
      $state.go('app.recipes');
    });
  };

  function errorMessage(err) {
    $ionicPopup.alert({
      title: err.data.message + ' for:',
      template: err.config.data.query,
      buttons: [{
        text: 'Ok',
        type: 'button-balanced'
      }]
    });
  }
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:FoodController
 * @description
 * # FoodController
 */

angular.module('Track').controller('FoodController', ["$rootScope", "$scope", "$state", "$stateParams", "$ionicHistory", "$timeout", "$http", "$cordovaNetwork", "$ionicPopup", "$q", "food", "AnalyticsService", "ApiService", "HelperService", "nixTrackUtils", "UserService", "SQLiteService", "$filter", function ($rootScope, $scope, $state, $stateParams, $ionicHistory, $timeout, $http, $cordovaNetwork, $ionicPopup, $q, food, AnalyticsService, ApiService, HelperService, nixTrackUtils, UserService, SQLiteService, $filter) {
  $scope.$on('$ionicView.beforeEnter', function () {
    $scope.readOnly = $stateParams.readOnly || false;
    $scope.food = _.cloneDeep(food);
    $scope.initialFood = {
      consumed_at: $scope.food.consumed_at || null,
      serving_qty: $scope.food.serving_qty || null,
      serving_unit: $scope.food.serving_unit || null,
      note: $scope.food.note || null,
      photo: $scope.food.photo || null
    };
    $rootScope.showSpinner = false;
    $scope.showCheck = false;
    $scope.qrText = 'nutritionix.com/q3?ufl=' + $scope.food.id + '&s=' + $scope.food.share_key;

    if ($scope.food.serving_qty === null || $scope.food.serving_qty === undefined) {
      $scope.food.serving_qty = 1;
    }

    if (!$scope.food.serving_unit) $scope.food.serving_unit = null;
    $scope.showNotes = !!$scope.food.note ? true : false;
    $scope.updateForm = {
      quantity: $scope.food.serving_qty,
      measure: $scope.food.serving_unit
    };

    if (!!$scope.food && !$scope.food.nf_calories && !!_.find($scope.food.full_nutrients, {
      attr_id: 208
    })) {
      $scope.food.nf_calories = _.find($scope.food.full_nutrients, {
        attr_id: 208
      }).value;
    }

    $scope.uploadPhoto = {
      file: null,
      isUploading: false,
      isChanged: false,
      isUploaded: false,
      noCustomPhoto: !food.photo || !food.photo.thumb || food.photo.thumb.indexOf('nix-apple-grey') !== -1 ? true : false
    };
    $scope.showPhoto = !!$scope.food && !!$scope.food.photo && $scope.food.photo.is_user_uploaded ? true : false;
    updateLabelData($scope.food); // SQLiteService.query(window.db, 'DELETE FROM localdata WHERE dataName = ?', ['photoUploadUserAgreement']);

    SQLiteService.query(window.db, 'SELECT value FROM localdata WHERE dataName = ?', ['photoUploadUserAgreement']).then(function (result) {
      $scope.agreedToUsePhoto = SQLiteService.getById(result);

      if ($scope.agreedToUsePhoto && $scope.agreedToUsePhoto) {
        $scope.isPhotoPopupShown = true;
      } else {
        $scope.isPhotoPopupShown = false;
      }
    })["catch"](function (err) {
      console.log(err);
    });
  });

  $scope.showPhotoPopup = function () {
    var permissions = cordova.plugins.permissions;
    $q.when().then(function () {
      var deferred = $q.defer();

      if (window.ionic.Platform.isAndroid()) {
        permissions.checkPermission(permissions.WRITE_EXTERNAL_STORAGE, function (result) {
          if (!result.hasPermission) {
            permissions.requestPermission(permissions.WRITE_EXTERNAL_STORAGE, function (result) {
              if (result.hasPermission) {
                deferred.resolve(result.hasPermission);
              } else {
                deferred.reject(result.hasPermission);
              }
            });
          } else {
            deferred.resolve(true);
          }
        });
      } else {
        deferred.resolve(true);
      }

      return deferred.promise;
    }).then(function () {
      var deferred = $q.defer();

      if (window.ionic.Platform.isAndroid()) {
        permissions.checkPermission(permissions.CAMERA, function (result) {
          if (!result.hasPermission) {
            permissions.requestPermission(permissions.CAMERA, function (result) {
              if (result.hasPermission) {
                deferred.resolve(result.hasPermission);
              } else {
                deferred.reject(result.hasPermission);
              }
            });
          } else {
            deferred.resolve(true);
          }
        });
      } else {
        deferred.resolve(true);
      }

      return deferred.promise;
    }).then(function () {
      return $ionicPopup.show({
        title: 'Info box',
        template: '<div class="text-center" style="font-size:12px;">All meal photos uploaded become public and viewable on Nutritionix.com. No other personal information is shared with the photo. By uploading a photo, you are agreeing to make it public.</div>',
        buttons: [{
          text: 'I understand',
          type: 'button-balanced',
          onTap: function onTap() {
            SQLiteService.query(window.db, 'INSERT INTO localdata (dataName, value) VALUES (?1, ?2) ON CONFLICT(dataName) DO UPDATE SET dataName=?1, value=?2', ['photoUploadUserAgreement', 'true']);
            $scope.isPhotoPopupShown = true;
            $timeout(function () {
              angular.element('div[ngf-select="fileChanged($files)"]').click();
            }, 1000);
          }
        }]
      });
    });
  };

  $scope.isDataChanged = function () {
    if ($scope.readOnly) {
      return false;
    }

    if (!_.isEqual($scope.initialFood.photo, $scope.food.photo) || $scope.initialFood.serving_qty !== $scope.food.serving_qty || $scope.initialFood.serving_unit !== $scope.food.serving_unit || $scope.initialFood.consumed_at !== $scope.food.consumed_at || $scope.initialFood.note !== $scope.food.note) {
      return true;
    } else {
      return false;
    }
  };

  $scope.$on('$ionicView.enter', function () {
    AnalyticsService.trackView('Edit Food Page');

    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(false);
    }
  });
  $scope.$on('$ionicView.leave', function () {
    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
    }
  });
  $scope.$watch('food', function (n, o) {
    if (o.note !== n.note) {
      $scope.isNoteChanged = true; // $scope.updateFood();
    }

    if (o.consumed_at && n.consumed_at && o.consumed_at !== n.consumed_at) {
      $scope.food.consumed_at = moment(n.consumed_at);
      $scope.food.meal_type = n.meal_type; // $scope.updateFood();
    }
  }, true); //instantiate one for use in the $watch fn.

  var cleanInputWrapper = new CleanInputWrapper();

  function CleanInputWrapper() {
    var cachedOldQty;
    return function cleanInput(newQty, oldQty) {
      //fraction parsing
      var rxAttempt = /^([0-9]+)\/([1-9]+[0-9]*)$/.exec(newQty);

      if (rxAttempt) {
        newQty = +(rxAttempt[1] / rxAttempt[2]).toFixed(3);
      }

      var newQtyAsNumber = parseFloat(newQty);
      var oldQtyAsNumber = parseFloat(oldQty);
      oldQty = isNaN(oldQtyAsNumber) || oldQtyAsNumber === 0 ? 1 : oldQtyAsNumber;
      newQty = isNaN(newQtyAsNumber) || newQtyAsNumber === 0 ? 1 : newQtyAsNumber;

      if (!cachedOldQty) {
        cachedOldQty = oldQty;
      }

      var tmp = cachedOldQty;
      cachedOldQty = newQty;
      return [newQty, tmp];
    };
  }

  function multiply(newQty, oldQty) {
    var coeff = newQty / oldQty;
    return HelperService.multiply($scope.food, coeff, newQty);
  }

  $scope.updateFood = function () {
    AnalyticsService.trackEvent('updatedFood', $scope.food.food_name);

    var food_omitted = _.omit($scope.food, ['share_key', '$$hashKey']);

    $rootScope.showSpinner = true;
    return ApiService.updateFood(food_omitted).then(function () {
      return $timeout(function () {
        $rootScope.showSpinner = false;
      }, 800);
    }).then(function () {
      $scope.showCheck = true;
      $timeout(function () {
        $scope.showCheck = false;
      }, 1500);
    }).then(function () {
      $rootScope.$broadcast('refresh foodlog');
      return $state.go('app.foodlog');
    });
  };

  $scope.updateCachedFoodOnQtyChange = function () {
    cordova.plugins.Keyboard.close();
    var argsArray = cleanInputWrapper.apply(null, Array.prototype.slice.call(arguments));

    if (argsArray[0] === argsArray[1]) {
      return;
    }

    var newFoodObj = multiply.apply(null, argsArray);
    $scope.food = newFoodObj;
    updateLabelData($scope.food); // return $scope.updateFood()
    //         .then(function() {
    //           $rootScope.$broadcast('refresh foodlog');
    //         });
  };

  $scope.$watch('updateForm.quantity', _.debounce($scope.updateCachedFoodOnQtyChange, 50));
  $scope.$watch('updateForm.measure', function (new_unit) {
    if (!new_unit || new_unit === $scope.food.serving_unit) {
      return;
    }

    var new_alt_measure = _.find($scope.food.alt_measures, {
      'measure': new_unit
    });

    var old_alt_measure = _.find($scope.food.alt_measures, {
      'measure': $scope.food.serving_unit
    });

    var multiplier = new_alt_measure.serving_weight / new_alt_measure.qty / (old_alt_measure.serving_weight / old_alt_measure.qty);
    var newFood = nixTrackUtils.multiplyFoodNutrients($scope.food, multiplier, false);
    newFood.id = $scope.food.id;
    newFood.serving_unit = new_unit;
    newFood.serving_qty = $scope.updateForm.quantity;
    $scope.food = _.defaults(newFood, $scope.food);
    updateLabelData($scope.food);

    if ($scope.updateForm.quantity !== 1) {
      $scope.updateForm.quantity = 1;
    } // else {
    //   return updateFood();
    // }

  });

  $scope.deleteFood = function () {
    var foodArray = [{
      id: $scope.food.id
    }];

    if ($rootScope.noInternet) {
      navigator.notification.alert('We cannot delete this item in offline mode', null, '', 'OK');
      return;
    }

    AnalyticsService.trackEvent('deletedFood', $scope.food.food_name);
    $ionicPopup.show({
      title: 'Delete Food',
      subTitle: 'Are you sure you want to delete this food?',
      buttons: [{
        text: 'Cancel'
      }, {
        text: 'Yes',
        type: 'button-balanced',
        onTap: function onTap() {
          $state.go('app.foodlog').then(function () {
            return ApiService.deleteFood(foodArray).then(function () {
              return $rootScope.$broadcast('refresh foodlog');
            });
          });
        }
      }]
    });
  };

  $scope.copyFood = function () {
    var newFood = JSON.parse(angular.toJson($scope.food));
    newFood.consumed_at = moment();
    $rootScope.$broadcast('mealBuilder: addFood', {
      foodArray: [newFood]
    });
    $state.go('app.reviewFoods', {
      mealType: $scope.food.meal_type
    }, {
      reload: true
    });
  };

  $scope.ifLongTitle = function (foodName) {
    if (foodName.length > 20) {
      return 'long-food-name';
    }

    return '';
  };

  $scope.goBack = function () {
    angular.element('input').blur();
    angular.element('textarea').blur();

    if ($scope.uploadPhoto.isUploading) {
      $scope.confirmationPopup = $ionicPopup.show({
        title: 'Upload in progress',
        template: 'Upload is still in progress, please try again in a moment',
        buttons: [{
          text: 'Ok'
        }]
      });
    } else if (!$scope.uploadPhoto.isUploaded && $scope.uploadPhoto.isChanged) {
      $scope.confirmationPopup = $ionicPopup.show({
        title: 'Photo is not saved',
        template: '<div class="text-center">Tap "Ok" to discard photo changes and return to the food log. Tap "Cancel" to continue editing.</div>',
        buttons: [{
          text: 'Ok',
          type: 'button-positive',
          onTap: function onTap() {
            $scope.clearCustomPhoto();
            $ionicHistory.goBack();
          }
        }, {
          text: 'Cancel'
        }]
      });
    } else if ($scope.isDataChanged()) {
      return $ionicPopup.show({
        title: 'Attention',
        subTitle: 'You have unsaved changes',
        template: '<div class="text-center">Do you want to save changes?</div>',
        buttons: [{
          text: 'Save',
          type: 'button-balanced',
          onTap: function onTap(e) {
            $scope.updateFood();
          }
        }, {
          text: 'Discard',
          type: 'button-assertive',
          onTap: function onTap(e) {
            $ionicHistory.goBack();
          }
        }]
      });
    } else {
      $ionicHistory.goBack();
    }
  };

  $scope.fileChanged = function (files) {
    $scope.uploadPhoto.file = files[0];
    $scope.uploadPhoto.isChanged = true;
    $scope.uploadPhoto.noCustomPhoto = false;
    $scope.showPhoto = true;
  };

  $scope.submitPhoto = function () {
    $scope.uploadPhoto.isUploading = true;
    var formData = new FormData();
    formData.append('file', $scope.uploadPhoto.file);
    $http.post('https://trackapi.nutritionix.com/v2/upload/image/foods/' + moment().format('YYYY-MM-DD'), formData, {
      headers: {
        'Content-Type': undefined
      }
    }).then(function (resp) {
      var photoEventName = $scope.food.photo.is_user_uploaded ? 'Changed photo' : 'Custom photo added';
      AnalyticsService.trackEvent(photoEventName, ' ');
      $scope.food.photo = {
        highres: resp.data.full,
        thumb: resp.data.thumb,
        is_user_uploaded: true
      };
      $scope.uploadPhoto.isUploaded = true;
      $scope.uploadPhoto.isUploading = false;
      $scope.clearCustomPhoto(); // $scope.updateFood();
    })["catch"](function (e) {
      $scope.uploadPhoto.isUploading = false;
      $ionicPopup.show({
        title: 'Oops, something went wrong',
        subTitle: 'Image upload failed',
        scope: $scope,
        buttons: [{
          text: 'Try again',
          type: 'button-positive',
          onTap: function onTap() {
            $scope.submitPhoto();
          }
        }, {
          text: 'Cancel'
        }]
      });
      console.log('there was an error uploading photo', e);
    });
  };

  $scope.clearCustomPhoto = function () {
    $scope.uploadPhoto = {
      file: null,
      isUploading: false,
      isChanged: false,
      isUploaded: false,
      noCustomPhoto: !food.photo || !food.photo.thumb || food.photo.thumb.indexOf('nix-apple-grey') !== -1 ? true : false
    };
  };

  $scope.socialSharing = function () {
    window.plugins.socialsharing.available(function (isAvailable) {
      var options = {
        message: 'Log ' + $scope.food.food_name.replace(/\w\S*/g, function (txt) {
          return txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase();
        }) + ' on the Nutritionix Track app by tapping this link from your mobile phone: ',
        // not supported on some apps (Facebook, Instagram)
        subject: $scope.food.food_name.replace(/\w\S*/g, function (txt) {
          return txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase();
        }) + ' on the Nutritionix Track App',
        url: 'https://nutritionix.app.link/q3?ufl=' + $scope.food.id + '&s=' + $scope.food.share_key,
        chooserTitle: 'Pick an app' // Android only, you can override the default share sheet title

      };

      var onSuccess = function onSuccess(result) {
        console.log('Share completed? ' + result.completed); // On Android apps mostly return false even while it's true

        console.log('Shared to app: ' + result.app); // On Android result.app is currently empty. On iOS it's empty when sharing is cancelled (result.completed=false)
      };

      var onError = function onError(msg) {
        console.log('Sharing failed with message: ' + msg);
      };

      window.plugins.socialsharing.shareWithOptions(options, onSuccess, onError);
    });
  };

  function updateLabelData(food) {
    var total = {
      item_name: 'Total',
      brand_name: 'Nutritionix',
      full_nutrients: [],
      metric_qty: 0,
      calories: 0,
      total_fat: 0,
      nf_saturated_fat: 0,
      nf_cholesterol: 0,
      nf_sodium: 0,
      nf_total_carbohydrate: 0,
      nf_dietary_fiber: 0,
      nf_sugars: 0,
      nf_protein: 0,
      nf_p: 0,
      nf_potassium: 0,
      nf_vitamin_a_dv: 0,
      nf_vitamin_c_dv: 0,
      nf_calcium_dv: 0,
      nf_iron_dv: 0,
      vitamin_d: 0,
      caffeine: 0
    };
    var foodExtendedNf = window.nutritionixApiDataUtilities.convertFullNutrientsToNfAttributes($scope.food.full_nutrients);
    total.metric_qty = foodExtendedNf.serving_weight_grams;
    total.calories = foodExtendedNf.nf_calories;
    total.total_fat = foodExtendedNf.nf_total_fat;
    total.nf_saturated_fat = foodExtendedNf.nf_saturated_fat;
    total.nf_cholesterol = foodExtendedNf.nf_cholesterol;
    total.nf_sodium = foodExtendedNf.nf_sodium;
    total.nf_total_carbohydrate = foodExtendedNf.nf_total_carbohydrate;
    total.nf_dietary_fiber = foodExtendedNf.nf_dietary_fiber;
    total.nf_sugars = foodExtendedNf.nf_sugars;
    total.nf_protein = foodExtendedNf.nf_protein;
    total.nf_p = foodExtendedNf.nf_p;
    total.nf_potassium = foodExtendedNf.nf_potassium;
    total.nf_vitamin_a_dv = foodExtendedNf.nf_vitamin_a_dv || 0, total.nf_vitamin_c_dv = foodExtendedNf.nf_vitamin_c_dv || 0, total.nf_calcium_dv = foodExtendedNf.nf_calcium_dv || 0, total.nf_iron_dv = foodExtendedNf.nf_iron_dv || 0, total.caffeine = $filter('nutrient')(food.full_nutrients, 262, 'value') || 0;
    total.vitamin_d = $filter('nutrient')(food.full_nutrients, 324, 'value') || 0;

    if (total.nf_total_carbohydrate === 0 || total.nf_total_carbohydrate - total.nf_dietary_fiber <= 0) {
      $scope.net_carbs = 0;
    } else {
      $scope.net_carbs = total.nf_total_carbohydrate - total.nf_dietary_fiber;
    }

    total.serving_qty = 1;
    total.serving_unit = 'Serving';
    total.showItemName = false;
    total.showServingUnitQuantity = false;
    total.showServingUnitQuantityTextbox = false;
    $scope.labelData = {
      adjustUserDailyValues: true,
      allowFDARounding: false,
      applyMathRounding: true,
      brandName: 'Nutritionix',
      decimalPlacesForQuantityTextbox: 2,
      itemName: 'cheeseburger',
      scrollLongItemNamePixel: 38,
      showAmountPerServing: false,
      showCalcium: true,
      showCalories: true,
      showCholesterol: true,
      showFatCalories: true,
      showFibers: true,
      showIngredients: false,
      showIron: true,
      showMonoFat: false,
      showPolyFat: false,
      showProteins: true,
      showSatFat: true,
      showServingSize: true,
      showServingUnitQuantity: true,
      showServingsPerContainer: false,
      showSodium: true,
      showSugars: true,
      showTotalCarb: true,
      showTotalFat: true,
      showTransFat: false,
      showVitaminA: true,
      showVitaminC: true,
      'valueServingUnitQuantity': total.serving_qty,
      'valueServingSizeUnit': total.serving_unit,
      'valueCalories': total.calories,
      'valueFatCalories': total.total_fat * 9,
      'valueTotalFat': total.total_fat,
      'valueSatFat': total.nf_saturated_fat,
      'valueCholesterol': total.nf_cholesterol,
      'valueSodium': total.nf_sodium,
      'valueTotalCarb': total.nf_total_carbohydrate,
      'valueFibers': total.nf_dietary_fiber,
      'valueSugars': total.nf_sugars,
      'valueProteins': total.nf_protein,
      'valueVitaminA': total.nf_vitamin_a_dv,
      'valueVitaminC': total.nf_vitamin_c_dv,
      'valueCalcium': total.nf_calcium_dv,
      'valueIron': total.nf_iron_dv
    };
    UserService.getUser().then(function (user) {
      $scope.labelData.calorieIntake = user.daily_kcal;
    })["catch"](function (err) {
      console.log('Error getting user from local DB:', err);
    });
    $scope.labelData.vitamin_d = total.vitamin_d;
    $scope.labelData.nf_p = total.nf_p;
    $scope.labelData.nf_potassium = total.nf_potassium;
    $scope.labelData.caffeine = total.caffeine;
  }
}]);
'use strict';
/*jshint multistr: true */

/**
 * @ngdoc function
 * @name Track.controller:FoodlogController
 * @description
 * # FoodlogController
 */

angular.module('Track').controller('FoodlogController', ["$rootScope", "$scope", "$ionicPlatform", "$state", "$stateParams", "$window", "$ionicBackdrop", "$timeout", "$cordovaBarcodeScanner", "$cordovaEmailComposer", "$ionicPopup", "$ionicHistory", "$ionicScrollDelegate", "$ionicListDelegate", "$filter", "$log", "$cordovaNetwork", "$cordovaDevice", "AnalyticsService", "ApiService", "RecipeService", "HelperService", "UserService", "QueueService", "NixService", "SQLiteService", "CacheFactory", "userObj", "GroceryAgentService", "PushNotificationService", "HealthKitService", "HealthKitWeightService", "HealthKitExerciseService", "WidgetService", "WalkthroughService", function ($rootScope, $scope, $ionicPlatform, $state, $stateParams, $window, $ionicBackdrop, $timeout, $cordovaBarcodeScanner, $cordovaEmailComposer, $ionicPopup, $ionicHistory, $ionicScrollDelegate, $ionicListDelegate, $filter, $log, $cordovaNetwork, $cordovaDevice, AnalyticsService, ApiService, RecipeService, HelperService, UserService, QueueService, NixService, SQLiteService, CacheFactory, userObj, GroceryAgentService, PushNotificationService, HealthKitService, HealthKitWeightService, HealthKitExerciseService, WidgetService, WalkthroughService) {
  (function init() {
    $scope.user = userObj;
    var device_info = $cordovaDevice.getDevice();

    if (!$rootScope.noInternet) {
      UserService.getUser().then(function (resp) {
        if (!!resp) {
          $scope.user.daily_kcal = resp.daily_kcal;
          $scope.user.weight_system = resp.unit_system;

          if (!resp.weight_kg || !resp.height_cm || !resp.gender || !resp.birth_year) {
            $scope.uncompletedProfile = true;
          } else {
            $scope.uncompletedProfile = false;
          }

          if (!!resp && !!resp.coach && !!resp.coach.is_active) {
            $rootScope.isCoach = true;
          } else {
            $rootScope.isCoach = false;
          }

          WidgetService.setCaloriesLimit(resp.daily_kcal);
        }
      });
    } // this var is used with the header directive


    $scope.logging = {};
    $scope.foodLogOffset = 0;
    $scope.logDatesInterval = {
      begin: moment().subtract(7 + $scope.foodLogOffset, 'days').format('YYYY-MM-DD'),
      end: moment().add(1 - $scope.foodLogOffset, 'day').format('YYYY-MM-DD')
    }; // init selected day to todays date

    if (!$rootScope.selected_day) {
      $rootScope.selected_day = {
        'date': moment().format('ddd, MM/DD/YY'),
        'log': {},
        'meta': {}
      }; //get cached logs if there is no internet connection.

      if ($rootScope.noInternet) {
        ApiService.getCachedWeightLog().then(function (result) {
          $rootScope.weightLog = result;

          if ($rootScope.hk.weight === 'push') {
            HealthKitWeightService.syncWeight($scope.user.weight_system);
          }
        });
        ApiService.getCachedExerciseLog().then(function (result) {
          $rootScope.exerciseLog = result;

          if ($rootScope.hk.exercise === 'push') {
            HealthKitExerciseService.syncExercise();
          }
        });
        ApiService.getCachedUserTotals().then(function (result) {
          $rootScope.userTotals = result;
          $rootScope.selected_day.meta = $rootScope.userTotals[$rootScope.selected_day.date];

          if ($rootScope.selected_day.meta.daily_kcal_limit === null || $rootScope.selected_day.meta.daily_kcal_limit === undefined) {
            $rootScope.selected_day.meta.daily_kcal_limit = $scope.user.daily_kcal;
          }
        });

        if (!$rootScope.foodlog[$rootScope.selected_day.date]) {
          $rootScope.selected_day.date = _.keys($rootScope.foodlog)[0];
        }

        $rootScope.selected_day.log = formatLogSelectedDate($rootScope.foodlog[$rootScope.selected_day.date]);
      }
    }

    $ionicPlatform.ready(function () {
      if (!$rootScope.noInternet) {
        ApiService.getFoodHistory()["catch"](function (err) {
          console.log('error initializing history', angular.toJson(err));
        });
        NixService.getRestaurants()["catch"](function (err) {
          console.log('error initializing restaurant', angular.toJson(err));
        });
        var PnRegistrationStatus = window.sessionStorage.getItem('PW_register'); // dont want to register everytime we go to the food log.
        // so check session storage to see if user is already registered. If not, register.
        // session storage will clear once session is over.
        // if ($scope.user.push_enabled && $scope.user.weekday_reminders_enabled && (!PnRegistrationStatus || PnRegistrationStatus=='false')) {
        // console.log('begin PN init');
        // PushNotificationService.initPushwoosh()
        // .then(function() {
        //   PushNotificationService.mergeTagsToUser($scope.user.id, 1);
        // });
        // }
      }
    });
    CacheFactory.getMealBuilderFoods().then(function (mealBuilder) {
      $rootScope.itemsInBuilder = mealBuilder;
    });
  })();

  $scope.isNewLogLoading = false;
  $scope.cut = 34;

  if ($window.screen.width >= 375) {
    $scope.cut = 42;
  }

  $ionicPlatform.ready(function () {
    $scope.$on('$cordovaNetwork:offline', function () {
      if (WalkthroughService.eventsList.firstOfflineMode) {
        WalkthroughService.runWalkthrough(6);
        WalkthroughService.setEventFlag('firstOfflineMode', false);
      }

      $timeout(function () {
        QueueService.getAllFromQ().then(function (response) {
          return response ? $rootScope.updatePendingLength = response.length : $rootScope.updatePendingLength = 0;
        });
      }, 500);
    });
    $scope.$on('$cordovaNetwork:online', function () {
      if (angular.isDefined($scope.clearQueueTimeout)) {
        return;
      }

      $scope.clearQueueTimeout = $timeout(clearTheQueue, 1000);
    });

    function clearTheQueue() {
      QueueService.clearQ().then(function (res) {
        $scope.$emit('refresh foodlog', {
          scrollToTop: true
        });
      })["catch"](function (err) {
        console.log('[foodlogController] clearTheQueue error:', angular.toJson(err));
      });
    }
  });
  $scope.$on('$ionicView.loaded', function (event, data) {
    GroceryAgentService.initGroceyAgentInfo().then(function (userGroceyAgentInfo) {
      $rootScope.userGroceyAgentInfo = userGroceyAgentInfo;
      return userGroceyAgentInfo;
    }).then(function (userGroceyAgentInfo) {
      if (!!userGroceyAgentInfo.grocery_agent) {
        GroceryAgentService.initGroceyAgentPreferences().then(function (groceryAgentPreferences) {
          $rootScope.groceryAgentPreferences = groceryAgentPreferences;
        });
      }
    })["catch"](function (error) {
      $log.error(error);
    });

    if (WalkthroughService.eventsList.firstLogin) {
      WalkthroughService.runWalkthrough(0);
      WalkthroughService.setEventFlag('firstLogin', false);
    }

    if ($stateParams.startWalkthroughAfterLog && WalkthroughService.eventsList.firstFoodAddedToFoodLog) {
      WalkthroughService.runWalkthrough(1);
      $stateParams.startWalkthroughAfterLog = false;
      WalkthroughService.setEventFlag('firstFoodAddedToFoodLog', false);
    }
  });
  $scope.$on('$ionicView.enter', function () {
    AnalyticsService.setUserId($scope.user.id);
    AnalyticsService.trackView('Dashboard');

    if ($stateParams.change_day) {
      $scope.changeDayToDate($stateParams.change_day);
      $ionicHistory.currentView().stateParams.change_day = null;
    } else {
      $scope.calculateFoodLogOffset($rootScope.selected_day.date);
      $scope.$broadcast('refresh foodlog');
    }

    if ($stateParams.askForReview) {
      var reviewCheck = JSON.parse(window.localStorage.getItem('reviewCheck'));

      if (window.LaunchReview.isRatingSupported()) {
        window.LaunchReview.rating(function (result) {
          if (result == 'shown') {
            reviewCheck.rateClicked = 1;
          }

          if (result == 'dismissed') {
            reviewCheck.rateClicked = !!reviewCheck.scheduleDate && !!reviewCheck.popupShown ? 1 : 0;
            reviewCheck.scheduleDate = moment().add(1, 'month').format('DD-MM-YYYY');
          }

          window.localStorage.setItem('reviewCheck', angular.toJson(reviewCheck));
        });
      } else {
        $ionicPopup.show({
          template: '<div class="text-center">★ Please rate the Track app now ★</div>',
          title: 'Enjoying Nutritionix Track?',
          scope: $scope,
          cssClass: 'review-popup',
          buttons: [{
            text: 'Not now',
            onTap: function onTap(e) {
              var reviewCheck = JSON.parse(window.localStorage.getItem('reviewCheck'));
              reviewCheck.rateClicked = !!reviewCheck.scheduleDate && !!reviewCheck.popupShown ? 1 : 0;
              reviewCheck.scheduleDate = moment().add(1, 'month').format('DD-MM-YYYY');
              window.localStorage.setItem('reviewCheck', angular.toJson(reviewCheck));
            }
          }, {
            text: 'Rate',
            type: 'button-positive',
            onTap: function onTap(e) {
              var reviewCheck = JSON.parse(window.localStorage.getItem('reviewCheck'));
              reviewCheck.rateClicked = 1;
              window.localStorage.setItem('reviewCheck', angular.toJson(reviewCheck));
              window.LaunchReview.launch();
            }
          }]
        });
      }

      reviewCheck.popupShown = 1;
      window.localStorage.setItem('reviewCheck', angular.toJson(reviewCheck));
      $ionicHistory.currentView().stateParams.askForReview = null;
    }

    $scope.$watch('isNewLogLoading', function (oldVal, newVal) {
      if (newVal) {
        setTimeout(function () {
          $scope.isNewLogLoading = false;
        }, 3000);
      }
    });
  });

  var onResume = function onResume() {
    if (!window.sessionStorage.getItem('sessionStart')) {
      return;
    }

    $scope.isNewLogLoading = false;
    $scope.$emit('refresh foodlog', 'onResume');
    $scope.$emit('refresh history');
  };

  if (!$rootScope.resumeEventHandler) {
    $rootScope.resumeEventHandler = $ionicPlatform.on('resume', onResume);
  }

  if (!$rootScope.userPreferencesHandler) {
    $rootScope.userPreferencesHandler = $rootScope.$on('userPreferences:updated', function () {
      UserService.getUser().then(function (result) {
        $scope.user = result;
      })["catch"](function (err) {
        console.log('Error getting active user from local DB:', err);
      });
    });
  }

  $ionicBackdrop.release();

  $scope.getCurrentDayName = function () {
    var currentDayName = moment().format('ddd, MM/DD/YY') === moment($rootScope.selected_day.date, 'ddd, MM/DD/YY').format('ddd, MM/DD/YY') ? 'Today' : moment($rootScope.selected_day.date, 'ddd, MM/DD/YY').format('dddd');
    return currentDayName;
  };

  $scope.progressWidth = function () {
    var result;

    if (!$rootScope.exerciseLog || !$rootScope.selected_day.log.totalCalories || !$rootScope.exerciseLog[$rootScope.selected_day.date] || $rootScope.selected_day.log.totalCalories - $rootScope.exerciseLog[$rootScope.selected_day.date].totalCaloriesBurned < 0) {
      result = 0;
      return result;
    } else {
      if (!$rootScope.selected_day.meta) {
        $rootScope.selected_day.meta = {
          daily_kcal_limit: $scope.user.daily_kcal
        };
      }

      result = (($rootScope.selected_day.log.totalCalories - $rootScope.exerciseLog[$rootScope.selected_day.date].totalCaloriesBurned) / ($rootScope.selected_day.meta.daily_kcal_limit || $scope.user.daily_kcal)).toFixed(2) * 100;
    }

    result = result > 100 ? 100 : result;
    return result;
  };

  $scope.barColor = function (totalCalories) {
    if (!$rootScope.selected_day || !$rootScope.selected_day.meta) {
      return;
    }

    if (totalCalories < $rootScope.selected_day.meta.daily_kcal_limit && totalCalories > $rootScope.selected_day.meta.daily_kcal_limit * 0.9) {
      return '#f0b840';
    } else if (totalCalories > $rootScope.selected_day.meta.daily_kcal_limit) {
      return '#ef4e3a';
    } else {
      return '#28a54c';
    }
  };

  function formatLogSelectedDate(days_log) {
    var output = {};
    output.totalCalories = days_log && days_log.totalCalories ? days_log.totalCalories : 0;
    output.totalCarbohydrate = days_log && days_log.totalCarbohydrate ? days_log.totalCarbohydrate : 0;
    output.totalFat = days_log && days_log.totalFat ? days_log.totalFat : 0;
    output.totalProtein = days_log && days_log.totalProtein ? days_log.totalProtein : 0;
    output.totalSodium = days_log && days_log.totalSodium ? days_log.totalSodium : 0;
    output.breakfast = [];
    output.am_snack = [];
    output.lunch = [];
    output.pm_snack = [];
    output.dinner = [];
    output.late_snack = [];

    if (!!days_log) {
      output.breakfast = _.filter(days_log.foods, function (food) {
        return food.meal_type == 1;
      });
      output.am_snack = _.filter(days_log.foods, function (food) {
        return food.meal_type == 2;
      });
      output.lunch = _.filter(days_log.foods, function (food) {
        return food.meal_type == 3;
      });
      output.pm_snack = _.filter(days_log.foods, function (food) {
        return food.meal_type == 4;
      });
      output.dinner = _.filter(days_log.foods, function (food) {
        return food.meal_type == 5;
      });
      output.late_snack = _.filter(days_log.foods, function (food) {
        return food.meal_type == 6;
      });
      output.breakfast_calories = _.reduce(output.breakfast, function (sum, food) {
        return sum + food.nf_calories;
      }, 0);
      output.am_snack_calories = _.reduce(output.am_snack, function (sum, food) {
        return sum + food.nf_calories;
      }, 0);
      output.lunch_calories = _.reduce(output.lunch, function (sum, food) {
        return sum + food.nf_calories;
      }, 0);
      output.pm_snack_calories = _.reduce(output.pm_snack, function (sum, food) {
        return sum + food.nf_calories;
      }, 0);
      output.dinner_calories = _.reduce(output.dinner, function (sum, food) {
        return sum + food.nf_calories;
      }, 0);
      output.late_snack_calories = _.reduce(output.late_snack, function (sum, food) {
        return sum + food.nf_calories;
      }, 0);
    }

    return output;
  }

  $scope.$on('refresh foodlog', refreshFoodLog);

  function refreshFoodLog(e, val) {
    if ($rootScope.noInternet) {
      return;
    }

    ApiService.checkConnection().then(function () {
      UserService.getUser().then(function (resp) {
        $scope.user = _.cloneDeep(resp);
      });
      ApiService.getUserTotals($scope.foodLogOffset, $scope.logDatesInterval.begin, $scope.logDatesInterval.end, $scope.user.timezone || null).then(function (result) {
        $rootScope.selected_day.meta = $rootScope.userTotals[$rootScope.selected_day.date];

        if (!!$rootScope.selected_day && $rootScope.selected_day.meta && ($rootScope.selected_day.meta.daily_kcal_limit === null || $rootScope.selected_day.meta.daily_kcal_limit === undefined)) {
          $rootScope.selected_day.meta.daily_kcal_limit = $scope.user.daily_kcal;
        }
      })["catch"](function (err) {
        console.log('[FoodlogController] There was error getting user totals:', err);
      });
      ApiService.getUserFoodLog($scope.user.id, $scope.foodLogOffset, $scope.logDatesInterval.begin, $scope.logDatesInterval.end).then(function () {
        $rootScope.selected_day.log = formatLogSelectedDate($rootScope.foodlog[$rootScope.selected_day.date]);

        if ($rootScope.foodlog[moment().format('ddd, MM/DD/YY')]) {
          WidgetService.setConsumedCalories($rootScope.foodlog[moment().format('ddd, MM/DD/YY')].totalCalories);
        }

        $scope.isNewLogLoading = false;
        $rootScope.$broadcast('scroll.refreshComplete');

        if ($rootScope.hk.nutrition === 'push') {
          HealthKitService.sync();
        }

        if (val && val.scrollToTop) $ionicScrollDelegate.anchorScroll();
      })["catch"](function (err) {
        console.log('Error getting food log from API:', err);
        ApiService.getCachedFoodLog().then(function (result) {
          $rootScope.foodlog = result;
          $rootScope.selected_day.log = formatLogSelectedDate($rootScope.foodlog[$rootScope.selected_day.date]);
        });
      });
      ApiService.getUserExerciseLog($scope.foodLogOffset, $scope.logDatesInterval.begin, $scope.logDatesInterval.end).then(function (result) {
        if (!!$rootScope.exerciseLog && !!$rootScope.exerciseLog[moment().format('ddd, MM/DD/YY')] && !!$rootScope.exerciseLog[moment().format('ddd, MM/DD/YY')].totalCaloriesBurned) {
          WidgetService.setBurnedCalories(Math.round($rootScope.exerciseLog[moment().format('ddd, MM/DD/YY')].totalCaloriesBurned));
        }

        $scope.isNewLogLoading = false;
        $rootScope.$broadcast('scroll.refreshComplete');
        if (val && val.scrollToTop) $ionicScrollDelegate.anchorScroll();

        if ($rootScope.hk.exercise === 'push') {
          HealthKitExerciseService.syncExercise();
        }
      })["catch"](function (err) {
        console.log('Error getting exercise log from API:', err);
        ApiService.getCachedExerciseLog().then(function (result) {
          $rootScope.exerciseLog = result;
        });
      });
      ApiService.getUserWeighIns($scope.foodLogOffset, $scope.logDatesInterval.begin, $scope.logDatesInterval.end).then(function (result) {
        $scope.isNewLogLoading = false;
        $rootScope.$broadcast('scroll.refreshComplete');
        if (val && val.scrollToTop) $ionicScrollDelegate.anchorScroll();

        if ($rootScope.hk.weight === 'push') {
          HealthKitWeightService.syncWeight($scope.user.weight_system);
        }
      })["catch"](function (err) {
        console.log('Error getting weight log from API:', err);
        ApiService.getCachedWeightLog().then(function (result) {
          $rootScope.weightLog = result;
        });
      });
      ApiService.getUserWaterLog($scope.foodLogOffset, $scope.logDatesInterval.begin, $scope.logDatesInterval.end).then(function (result) {
        $scope.isNewLogLoading = false;
        $rootScope.$broadcast('scroll.refreshComplete');
        if (val && val.scrollToTop) $ionicScrollDelegate.anchorScroll();
      })["catch"](function (err) {
        console.log('Error getting weight log from API:', err);
        ApiService.getCachedWaterLog().then(function (result) {
          $rootScope.waterLog = result;
        });
      });
    })["catch"](function (err) {
      console.log('connection error', err);
      $rootScope.$broadcast('scroll.refreshComplete');
    });
  }

  if (!$rootScope.refreshHistoryEventHandler) {
    $scope.refreshHistoryEventHandler = $rootScope.$on('refresh history', function () {
      if (!$rootScope.noInternet) {
        ApiService.getFoodHistory()["catch"](function (err) {
          console.log('error initializing history', angular.toJson(err));
        });
      }
    });
  }

  $scope.doRefresh = function () {
    if ($rootScope.noInternet) {
      return $rootScope.$broadcast('scroll.refreshComplete');
    }

    return $scope.$emit('refresh foodlog');
  };

  $scope.goToFood = function (food) {
    return ApiService.setCurrentFood(food).then(function () {
      return $state.go('app.food', {
        food_id: food.id
      });
    });
  };

  $scope.swipeDeleteFood = function (food) {
    AnalyticsService.trackEvent('swipe-left', 'swipe-left-delete');
    $scope.deleteFood(food);
  };

  $scope.swipeDeleteFoodBulk = function (foods, mealTypeName) {
    AnalyticsService.trackEvent('swipe-left', 'swipe-left-delete');
    $scope.deleteFoodBulk(foods, mealTypeName);
  };

  $scope.deleteFood = function (food) {
    if ($rootScope.noInternet) {
      navigator.notification.alert('We cannot delete this item in offline mode', null, '', 'OK');
      return;
    }

    AnalyticsService.trackEvent('deletedFood', food.food_name);
    var foodArray = [{
      id: food.id
    }];
    return ApiService.deleteFood(foodArray).then(function (errs) {
      errs.forEach(function (err) {
        console.log(err);
      });
    }).then(function () {
      return $scope.$broadcast('refresh foodlog', 'delete');
    });
  };

  $scope.deleteFoodBulk = function (foods, mealTypeName) {
    if ($rootScope.noInternet) {
      navigator.notification.alert('We cannot delete this item in offline mode', null, '', 'OK');
      return;
    }

    var confirmDeletionPopup = $ionicPopup.confirm({
      title: 'Delete foods',
      template: 'Are you sure you want to delete all of your ' + mealTypeName + ' items?',
      buttons: [{
        text: 'Yes',
        type: 'button-positive',
        onTap: function onTap(e) {
          return true;
        }
      }, {
        text: 'No',
        type: 'button-default',
        onTap: function onTap(e) {
          return false;
        }
      }]
    });
    confirmDeletionPopup.then(function (res) {
      if (res) {
        var foodArray = [];
        foods.forEach(function (food) {
          foodArray.push({
            id: food.id
          });
        });
        return ApiService.deleteFood(foodArray).then(function (errs) {
          errs.forEach(function (err) {
            console.log(err);
          });
        }).then(function () {
          $ionicListDelegate.closeOptionButtons();
          return $scope.$broadcast('refresh foodlog', 'delete');
        });
      } else {
        return $ionicListDelegate.closeOptionButtons();
      }
    });
  };

  $scope.swipeCopyFood = function (food) {
    AnalyticsService.trackEvent('swipe-left', 'swipe-left-copy');
    $scope.copyFood(food);
  };

  $scope.swipeCopyFoodBulk = function (foods) {
    AnalyticsService.trackEvent('swipe-left', 'swipe-left-copy');
    $scope.copyFoodBulk(foods);
  };

  $scope.copyFood = function (food) {
    if ($rootScope.noInternet) {
      navigator.notification.alert('We cannot copy this item in offline mode', null, '', 'OK');
      return;
    }

    var newFood = JSON.parse(angular.toJson(food));
    newFood.consumed_at = moment();
    $rootScope.$broadcast('mealBuilder: addFood', {
      foodArray: [newFood]
    });
    $state.go('app.reviewFoods', {
      mealType: food.meal_type
    }, {
      reload: true
    });
  };

  $scope.copyFoodBulk = function (foods) {
    if ($rootScope.noInternet) {
      navigator.notification.alert('We cannot copy this item in offline mode', null, '', 'OK');
      return;
    }

    foods.forEach(function (food) {
      food.meal_type = null;
      food.consumed_at = moment();
    });
    var newFood = JSON.parse(angular.toJson(foods));
    $rootScope.$broadcast('mealBuilder: addFood', {
      foodArray: newFood
    });
    $state.go('app.reviewFoods', {
      reload: true
    });
  };

  $scope.goToTotal = function (dayValue, mealType) {
    var params = {
      mealTypeFilter: mealType || null
    };
    ApiService.setCurrentDayTotal(dayValue);
    $state.go('app.total', params);
  };

  $scope.isNewLogLoading = false;

  $scope.changeOnDays = function (dayDiff) {
    var newDay = moment($rootScope.selected_day.date, 'ddd, MM/DD/YY').add(dayDiff, 'days').format('ddd, MM/DD/YY');

    if ($rootScope.foodlog[newDay]) {
      $rootScope.selected_day.date = newDay;
      $rootScope.selected_day.log = formatLogSelectedDate($rootScope.foodlog[$rootScope.selected_day.date]);
      $rootScope.selected_day.meta = $rootScope.userTotals[$rootScope.selected_day.date];

      if ($rootScope.selected_day.meta.daily_kcal_limit === null || $rootScope.selected_day.meta.daily_kcal_limit === undefined) {
        $rootScope.selected_day.meta.daily_kcal_limit = $scope.user.daily_kcal;
      }

      if (!!$rootScope.exerciseLog[moment().format('ddd, MM/DD/YY')] && !!$rootScope.foodlog[moment().format('ddd, MM/DD/YY')] && !!$rootScope.exerciseLog[moment().format('ddd, MM/DD/YY')].totalCaloriesBurned && !!$rootScope.foodlog[moment().format('ddd, MM/DD/YY')].totalCalories) {
        WidgetService.setConsumedCalories($rootScope.foodlog[moment().format('ddd, MM/DD/YY')].totalCalories);
        WidgetService.setBurnedCalories(Math.round($rootScope.exerciseLog[moment().format('ddd, MM/DD/YY')].totalCaloriesBurned));
      }
    } else {
      if (!$scope.isNewLogLoading && !$rootScope.noInternet) {
        $rootScope.selected_day.date = newDay;
        $scope.calculateFoodLogOffset(newDay);
        $scope.isNewLogLoading = true;
        $scope.$emit('refresh foodlog');
      } else {
        return false;
      }
    }
  };

  $scope.changeDayToDate = function (newDate) {
    if ($rootScope.noInternet) return false;
    $scope.calculateFoodLogOffset(newDate);

    if ($rootScope.selected_day.date === moment(newDate, 'MM/DD/YY').format('ddd, MM/DD/YY')) {
      return $scope.$emit('refresh foodlog');
    }

    $rootScope.selected_day.date = moment(newDate, 'MM/DD/YY').format('ddd, MM/DD/YY');
    $scope.isNewLogLoading = true;
    $scope.$emit('refresh foodlog');
  };

  $scope.calculateFoodLogOffset = function (newDate) {
    var differenceInDays = moment().startOf('day').diff(moment(newDate, 'ddd, MM/DD/YY').startOf('day'), 'days');
    $scope.foodLogOffset = _.floor(differenceInDays / 7, 0) * 7;
    $scope.logDatesInterval = {
      begin: moment().subtract(7 + $scope.foodLogOffset, 'days').format('YYYY-MM-DD'),
      end: moment().add(1 - $scope.foodLogOffset, 'day').format('YYYY-MM-DD')
    };
  };

  $scope.guessSnackType = function () {
    var currentMealType = HelperService.calculateMealTypeByTime(moment().hour());

    if (currentMealType % 2 !== 0) {
      currentMealType += 1;
    }

    return currentMealType;
  };

  $scope.toggleSuggestedFoods = function (meal_type) {
    $scope.logging.meal_type = meal_type;
    $rootScope.basketLog = true;
    $timeout(function () {
      angular.element('#autocompleteSearch').focus();
    }, 0);
  }; // editExercise/ index can be None; if it is, then it is just logging


  $scope.logExercise = function (index, editExercise) {
    var editText = '';
    var shouldEdit = null;

    if (editExercise) {
      editText = editExercise.duration_min + ' min ' + editExercise.name;
      shouldEdit = editExercise;
    }

    $scope.ex_data = {
      addedExercise: editText
    };
    var recent = [];

    _.forEach($rootScope.exerciseLog, function (day) {
      if (day.exercises.length > 0) {
        recent.push.apply(recent, day.exercises);
      }
    });

    $scope.recentExercises = [];
    var deviceModel = window.ionic.Platform.device().model;
    var recentExercisesLimit = deviceModel === 'iPhone5,1' || deviceModel === 'iPhone5,2' || deviceModel === 'iPhone5,3' || deviceModel === 'iPhone5,4' || deviceModel === 'iPhone6,1' || deviceModel === 'iPhone6,2' ? 2 : 3;
    var cachedRecent = CacheFactory.getRecentExercises().splice(-1 * recentExercisesLimit, recentExercisesLimit);

    _.forEach(cachedRecent, function (exercise) {
      $scope.recentExercises.push(exercise.name);
    });

    $scope.recentExercises = _.reverse($scope.recentExercises);
    $scope.recentExercises = _.compact($scope.recentExercises);

    $scope.trackExercise = function (exercise) {
      var user_data = {
        'birth_year': $scope.user.birth_year || null,
        'height_cm': $scope.user.height_cm || null,
        'weight_kg': $scope.user.weight_kg || null,
        'gender': $scope.user.gender || null
      };
      AnalyticsService.trackEvent('loggedExercise', exercise);
      ApiService.addExercise(exercise, shouldEdit, user_data).then(function (resp) {
        if (!resp.data.exercises.length) {
          errorMessageExercise();
        } //resolve exercise log with newly added/updated exercises


        _.forEach(resp.data.exercises, function (exercise) {
          var exDate = moment(exercise.timestamp.toString(), 'YYYY-MM-DDTHH:mm:ssZZ').format('ddd, MM/DD/YY');

          if (!!$rootScope.exerciseLog[exDate] && !!$rootScope.exerciseLog[exDate].exercises) {
            if (shouldEdit) {
              // replace the existing exercise with new one
              var old_cal = $rootScope.exerciseLog[exDate].exercises[index].nf_calories;
              $rootScope.exerciseLog[exDate].totalCaloriesBurned -= old_cal;
              $rootScope.exerciseLog[exDate].exercises.splice(index, 1, exercise);
              $rootScope.exerciseLog[exDate].totalCaloriesBurned;
              $rootScope.exerciseLog[exDate].totalCaloriesBurned += exercise.nf_calories;
            } else {
              $rootScope.exerciseLog[exDate].exercises.unshift(exercise);
              $rootScope.exerciseLog[exDate].totalCaloriesBurned += exercise.nf_calories;
            }

            if (exercise.name !== 'HealthKit Exercise Total') {
              CacheFactory.addRecentExercise(exercise);
            }
          }
        });

        if ($rootScope.hk.exercise === 'push') {
          HealthKitExerciseService.syncExercise();
        }

        if (!!$rootScope.exerciseLog[moment().format('ddd, MM/DD/YY')] && !!$rootScope.exerciseLog[moment().format('ddd, MM/DD/YY')].totalCaloriesBurned) {
          WidgetService.setBurnedCalories(Math.round($rootScope.exerciseLog[moment().format('ddd, MM/DD/YY')].totalCaloriesBurned));
        }
      })["catch"](function (e) {
        errorMessageExercise();
      });
    };

    var buttons = [{
      text: 'Save',
      type: 'button-positive',
      onTap: function onTap(e) {
        if (!$scope.ex_data.addedExercise) {
          errorMessageExercise();
        } else {
          $scope.trackExercise($scope.ex_data.addedExercise);
        }
      }
    }, {
      text: 'Cancel'
    }];

    if (shouldEdit) {
      buttons = [{
        text: '<i class="fa fa-trash"></i>',
        type: 'button-assertive',
        onTap: function onTap(e) {
          $scope.deleteExercise(index, editExercise);
        }
      }, {
        text: 'Cancel'
      }, {
        text: 'Save',
        type: 'button-positive',
        onTap: function onTap(e) {
          if (!$scope.ex_data.addedExercise) {
            errorMessageExercise();
          } else {
            $scope.trackExercise($scope.ex_data.addedExercise);
          }
        }
      }];
    }

    var popupView = $ionicPopup.show({
      template: '<textarea class="input-bg-color" multiline-placeholder style="text-indent:0!important; padding:5px;" rows=5 ng-model="ex_data.addedExercise" placeholder="Type or speak an exercise:\\n• 45 min spinning class\\n• ran 3 miles\\n• walked 30 mins\\n• 350cal" focus-me="true"> </textarea> \
        Recent Exercises:<ul class="list-recent-exercise"><li ng-repeat="ex in recentExercises" ng-click="trackExercise(ex); closePopup()"><i class="fa fa-plus" aria-hidden="true"></i> {{ex}} </li></ul>',
      title: shouldEdit ? 'Edit Exercise' : 'Log Exercises',
      scope: $scope,
      cssClass: (shouldEdit ? 'edit-exercise-popup ' : '') + 'custom-popup exercise-modal',
      buttons: buttons
    });

    $scope.closePopup = function () {
      popupView.close();
    };
  }; //editWeighIn/ index can be None; used for edit if not None


  $scope.logWeighIn = function (index, editWeight) {
    $scope.weight_data = {
      unit: $scope.user.measure_system ? 'kg' : 'lbs'
    };

    $scope.recalculateWeightData = function (newUnitSystem) {
      if (newUnitSystem === 'kg') {
        $scope.weight_data.addedWeight = Math.round($scope.weight_data.addedWeight / 2.20462 * 10) / 10;
      } else {
        $scope.weight_data.addedWeight = Math.round($scope.weight_data.addedWeight * 2.20462 * 10) / 10;
      }
    };

    $scope.goToPreferences = function () {
      if (!!weighInPopup) {
        weighInPopup.close();
      }

      $state.go('app.preferences');
    };

    if (editWeight) {
      $scope.weight_data.addedWeight = _.round($scope.user.measure_system ? editWeight.kg : editWeight.kg * 2.20462, 1);
    } else {
      $scope.weight_data.addedWeight = _.round($scope.user.measure_system ? $scope.user.weight_kg : $scope.user.weight_kg * 2.20462, 1);
    }

    var popupView = {
      template: "<input class=\"input-bg-color text-center\" ng-model=\"weight_data.addedWeight\" type=\"number\" focus-me=\"true\">\n                    <div style=\"display:flex;justify-content:space-around;align-items:center;\">\n                      Units:\n                      <label style=\"display:flex;\" class=\"padding\">\n                        <input style=\"width:30px;\" ng-model=\"weight_data.unit\" type=\"radio\" value=\"kg\" ng-change=\"recalculateWeightData('kg')\"/>\n                        kg\n                      </label>\n                      <label style=\"display:flex;\" class=\"padding\">\n                        <input style=\"width:30px;\" ng-model=\"weight_data.unit\" type=\"radio\" value=\"lbs\" ng-change=\"recalculateWeightData('lbs')\"/>\n                        lbs\n                      </label>\n                    </div>\n                    <div style=\"font-size:10px;text-align:center;line-height:1.2;font-style:italic;\">\n                      You can also manage your unit settings in <a ng-click=\"goToPreferences()\">Preferences</a>.\n                    </div>",
      title: editWeight ? 'Edit Weight' : 'Record Weight',
      scope: $scope,
      cssClass: 'custom-popup',
      buttons: [{
        text: 'Save',
        type: 'button-positive',
        onTap: function onTap(e) {
          if (!$scope.weight_data.addedWeight) {
            errorMessageWeight();
          } else {
            // if unit system is dofferent from what defined in the preferences -> update the preferences
            if ($scope.user.measure_system === 1 && $scope.weight_data.unit === 'lbs') {
              $scope.user.measure_system = 0;
              ApiService.updatePreferences({
                measure_system: $scope.user.measure_system
              });
            } else if ($scope.user.measure_system === 0 && $scope.weight_data.unit === 'kg') {
              $scope.user.measure_system = 1;
              ApiService.updatePreferences({
                measure_system: $scope.user.measure_system
              });
            } //if unit is lbs, need to convert it to kg


            var weight_to_api = -1;

            if ($scope.weight_data.unit === 'lbs') {
              weight_to_api = $scope.weight_data.addedWeight / 2.20462;
            } else {
              weight_to_api = $scope.weight_data.addedWeight;
            }

            AnalyticsService.trackEvent('loggedWeight', $scope.weight_data.addedWeight);
            ApiService.addWeighIn(weight_to_api, editWeight).then(function (resp) {
              refreshFoodLog(); // Legacy logic part since weight logging goes trough QueueService
              // if (!resp || !resp.data){
              //   return;
              // }
              // var weight = resp.data.weights[0];
              // var weightDate = moment(weight.timestamp.toString(), 'YYYY-MM-DDTHH:mm:ssZZ').format('ddd, MM/DD/YY');
              //   console.log('resp',resp);
              //   console.log('$rootScope.weightLog',$rootScope.weightLog);
              // if ($rootScope.weightLog[weightDate]) {
              //   if(editWeight) {
              //     $rootScope.weightLog[weightDate].weights.splice(index, 1, weight);
              //   }
              //   else {
              //     $rootScope.weightLog[weightDate].weights.unshift(weight);
              //   }
              // }
              // if ($rootScope.hk.weight === 'push') {
              //   HealthKitWeightService.syncWeight($scope.user.weight_system);
              // }
            });
          }
        }
      }, {
        text: 'Cancel'
      }]
    };
    var weighInPopup = $ionicPopup.show(popupView);
  };

  $scope.logWater = function () {
    $scope.waterData = {
      'consumed': $scope.user.measure_system ? $rootScope.waterLog[$rootScope.selected_day.date] : _.round($rootScope.waterLog[$rootScope.selected_day.date] * 33.814, 0),
      'date': $rootScope.selected_day.date
    };
    var popupView = {
      template: "\n          <div style=\"white-space:nowrap; font-size:10px;font-weight:700;\">Common Measures (tap to add instantly):</div>\n          <div ng-if=\"user.measure_system\" class='row' style=\"padding:5px 0;margin:0 -5px; width:auto;\">\n            <div class=\"col-25\" style=\"padding:0 5px;\">\n              <button class=\"button button-default add-water-button\" ng-click=\"addWater(0.25, waterData.date, waterPopup)\">0.25 L</button>\n            </div>\n            <div class=\"col-25\" style=\"padding:0 5px;\">\n              <button class=\"button button-default add-water-button\" ng-click=\"addWater(0.33, waterData.date, waterPopup)\">0.33 L</button>\n            </div>\n            <div class=\"col-25\" style=\"padding:0 5px;\">\n              <button class=\"button button-default add-water-button\" ng-click=\"addWater(0.5, waterData.date, waterPopup)\">0.5 L</button>\n            </div>\n            <div class=\"col-25\" style=\"padding:0 5px;\">\n              <button class=\"button button-default add-water-button\" ng-click=\"addWater(1, waterData.date, waterPopup)\">1 L</button>\n            </div>\n          </div>\n          <div ng-if=\"!user.measure_system\" class='row' style=\"padding:5px 0;margin:0 -5px; width:auto;\">\n            <div class=\"col-25\" style=\"padding:0 5px;\">\n              <button class=\"button button-default add-water-button\" ng-click=\"addWater(8, waterData.date, waterPopup)\">8 oz</button>\n            </div>\n            <div class=\"col-25\" style=\"padding:0 5px;\">\n              <button class=\"button button-default add-water-button\" ng-click=\"addWater(16, waterData.date, waterPopup)\">16 oz</button>\n            </div>\n            <div class=\"col-25\" style=\"padding:0 5px;\">\n              <button class=\"button button-default add-water-button\" ng-click=\"addWater(24, waterData.date, waterPopup)\">24 oz</button>\n            </div>\n            <div class=\"col-25\" style=\"padding:0 5px;\">\n              <button class=\"button button-default add-water-button\" ng-click=\"addWater(32, waterData.date, waterPopup)\">32 oz</button>\n            </div>\n          </div>\n\n          <div style=\"white-space:nowrap; font-size:10px;font-weight:700;\">Custom Measure:</div>\n          <div class=\"row\" style=\"padding:5px 0;\">\n            <div class=\"col-30\">\n              <input class=\"input-bg-color text-center\" ng-model=\"waterData.intake\" type=\"number\">\n            </div>\n            <div class=\"col-10\" style=\"padding-left:5px;display:flex;align-items:center;\">\n              {{user.measure_system ? 'L' : 'oz'}}\n            </div>\n            <div class=\"col-60\" style=\"padding-left:10px; display:flex;align-items:center;\">\n              <input ng-click=\"addWater(waterData.intake, waterData.date, waterPopup)\" class=\"button button-positive\" type=\"button\" value=\"Add\" style=\"min-height:34px; line-height:32px;\"/>\n            </div>\n          </div>\n\n          <hr/>\n\n          <div style=\"white-space:nowrap; font-size:14px; font-weight:700;\">Total water consumed today:</div>\n          <div class=\"row\" style=\"padding:5px 0;\">\n            <div class=\"col-30\">\n              <input class=\"input-bg-color text-center\" ng-model=\"waterData.consumed\" type=\"number\">\n            </div>\n            <div class=\"col-10\" style=\"padding-left:5px;display:flex;align-items:center;\">\n              {{user.measure_system ? 'L' : 'oz'}}\n            </div>\n            <div class=\"col-60\" style=\"padding-left:10px; display:flex;align-items:center;\">\n              <input ng-click=\"updateWater(waterData.consumed, waterData.date, waterPopup)\" class=\"button button-positive\" type=\"button\" value=\"Update\" style=\"min-height:34px; line-height:32px;\"/>\n            </div>\n          </div>\n        ",
      title: '<i class="icon ion-waterdrop positive"></i> Log Water',
      scope: $scope,
      cssClass: 'custom-popup',
      buttons: [{
        text: 'Cancel'
      }]
    };
    $scope.waterPopup = $ionicPopup.show(popupView);
  };

  $scope.addWater = function (waterIntake, date, popup) {
    var waterApiIntake = $scope.user.measure_system ? waterIntake : waterIntake / 33.814;
    ApiService.addWater(waterApiIntake, date).then(function (res) {
      var unit = $scope.user.measure_system ? 'L' : 'oz';
      AnalyticsService.trackEvent('addedWater', waterIntake + ' ' + unit);

      if (popup) {
        popup.close();
      }

      refreshFoodLog();
    })["catch"](function (err) {
      console.log('Error adding water intake:', err);
    });
  };

  $scope.updateWater = function (waterIntake, date, popup) {
    var waterApiData = $scope.user.measure_system ? waterIntake : waterIntake / 33.814;
    ApiService.updateWater(waterApiData, date).then(function (res) {
      AnalyticsService.trackEvent('updatedWater', ' ');

      if (popup) {
        popup.close();
      }

      refreshFoodLog();
    })["catch"](function (err) {
      console.log('Error updating water intake:', err);
    });
  };

  $scope.swipeDeleteWater = function (date) {
    AnalyticsService.trackEvent('swipe-left', 'swipe-left-delete');
    $scope.deleteWater(date);
  };

  $scope.deleteWater = function (date) {
    ApiService.deleteWater(date).then(function (res) {
      AnalyticsService.trackEvent('deletedWater', ' ');
      refreshFoodLog();
    })["catch"](function (err) {
      console.log('Error deleting water intake:', err);
    });
  };

  $scope.swipeDeleteExercise = function (index, exercise) {
    AnalyticsService.trackEvent('swipe-left', 'swipe-left-delete');
    $scope.deleteExercise(index, exercise);
  };

  $scope.deleteExercise = function (index, exercise) {
    ApiService.deleteExercise(exercise.id).then(function () {
      var exDate = moment(exercise.timestamp.toString(), 'YYYY-MM-DDTHH:mm:ssZZ').format('ddd, MM/DD/YY');

      if (!!$rootScope.exerciseLog[exDate] && !!$rootScope.exerciseLog[exDate].exercises[index]) {
        var old_cal = $rootScope.exerciseLog[exDate].exercises[index].nf_calories;
        $rootScope.exerciseLog[exDate].totalCaloriesBurned -= old_cal;
        $rootScope.exerciseLog[exDate].exercises.splice(index, 1);
      }

      if ($rootScope.hk.exercise === 'push') {
        HealthKitExerciseService.syncExercise();
      }

      if (!!$rootScope.exerciseLog[moment().format('ddd, MM/DD/YY')] && $rootScope.exerciseLog[moment().format('ddd, MM/DD/YY')].totalCaloriesBurned !== null && $rootScope.exerciseLog[moment().format('ddd, MM/DD/YY')].totalCaloriesBurned !== undefined) {
        WidgetService.setBurnedCalories(Math.round($rootScope.exerciseLog[moment().format('ddd, MM/DD/YY')].totalCaloriesBurned));
      }
    });
  };

  $scope.swipeDeleteWeighIn = function (index, exercise) {
    AnalyticsService.trackEvent('swipe-left', 'swipe-left-delete');
    $scope.deleteWeighIn(index, exercise);
  };

  $scope.deleteWeighIn = function (index, weight) {
    ApiService.deleteWeighIn(weight.id).then(function () {
      var weightDate = moment(weight.timestamp.toString(), 'YYYY-MM-DDTHH:mm:ssZZ').format('ddd, MM/DD/YY');

      if ($rootScope.weightLog[weightDate]) {
        $rootScope.weightLog[weightDate].weights.splice(index, 1);
      }

      if ($rootScope.hk.weight === 'push') {
        HealthKitWeightService.syncWeight($scope.user.weight_system);
      }
    });
  };

  function errorMessageExercise() {
    $ionicPopup.alert({
      title: 'Could not determine any exercises to log.',
      buttons: [{
        text: 'Ok',
        type: 'button-balanced'
      }]
    });
  }

  function errorMessageWeight() {
    $ionicPopup.alert({
      title: 'Please enter a weight to log.',
      buttons: [{
        text: 'Ok',
        type: 'buttoned-balanced'
      }]
    });
  }
}]);
'use strict';

angular.module('Track').controller('footerController', ["$rootScope", "$scope", "$state", "$ionicViewSwitcher", "$ionicSideMenuDelegate", "$ionicHistory", function ($rootScope, $scope, $state, $ionicViewSwitcher, $ionicSideMenuDelegate, $ionicHistory) {
  $rootScope.showFooter = true; // list of states that will show footer

  $scope.statesWithFooter = ['app.addfoodsmart', 'app.foodlog', 'app.grocery', 'app.help', 'app.history', 'app.preferences', 'app.restaurants', 'app.restaurantfoods', 'app.restaurantcalculator', 'app.stats', 'app.recipes', 'app.productRecommendations', 'app.subscribe'];
  $rootScope.$on('$stateChangeStart', function (event, toState, toParams, fromState, fromParams) {
    $rootScope.showFooter = _.find($scope.statesWithFooter, function (state) {
      if (state === toState.name) {
        return true;
      }

      return false;
    });
  });
  $scope.isAndroid = window.ionic.Platform.isAndroid();
  $scope.$watch(function () {
    return $ionicSideMenuDelegate.isOpenLeft();
  }, function (isOpen) {
    if (isOpen) {
      $rootScope.showFooter = false;
    } else {
      $rootScope.showFooter = _.find($scope.statesWithFooter, function (state) {
        var currentView = $ionicHistory.currentView();

        if (currentView && state === currentView.stateName) {
          return true;
        }

        return false;
      });
    }
  });
}]);
'use strict';

angular.module('Track').controller('GroceryAgentPreferencesController', ["$rootScope", "$scope", "$ionicHistory", "ConfigurationService", "GroceryAgentService", function ($rootScope, $scope, $ionicHistory, ConfigurationService, GroceryAgentService) {
  $scope.refreshFoodPhotoTime = ConfigurationService.grocery_photo_upload.food_update_time;
  $scope.groceryAgentPreferences = $rootScope.groceryAgentPreferences;
  $scope.$watch('groceryAgentPreferences', function (newVal, oldVal) {
    $rootScope.groceryAgentPreferences = $scope.groceryAgentPreferences;
    GroceryAgentService.setGroceryAgentPreferences($scope.groceryAgentPreferences);
  }, true);

  $scope.goBack = function () {
    return $ionicHistory.goBack();
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:groceryController
 * @description
 * # groceryController
 */

angular.module('Track').controller('groceryController', ["$rootScope", "$scope", "$cordovaKeyboard", "$state", "$ionicBackdrop", "$ionicHistory", "$ionicViewSwitcher", "$timeout", "$cordovaDatePicker", "$ionicPlatform", "$cordovaNetwork", "$ionicScrollDelegate", "AnalyticsService", "ApiService", "NixService", "groceries", "$ionicLoading", function ($rootScope, $scope, $cordovaKeyboard, $state, $ionicBackdrop, $ionicHistory, $ionicViewSwitcher, $timeout, $cordovaDatePicker, $ionicPlatform, $cordovaNetwork, $ionicScrollDelegate, AnalyticsService, ApiService, NixService, groceries, $ionicLoading) {
  $scope.checkHintWasPresented = function () {
    if (!$scope.data.grocerySearch) {
      var currentTop = $ionicScrollDelegate.$getByHandle('groceryScroll').getScrollPosition().top;

      var maxScrollableDistanceFromTop = $ionicScrollDelegate.$getByHandle('groceryScroll').getScrollView().__maxScrollTop;

      if (currentTop >= maxScrollableDistanceFromTop) {
        $ionicLoading.show({
          template: 'Please enter a search query to filter results.',
          duration: 1000
        });
      }
    }
  };

  $scope.$on('$ionicView.enter', function (event, data) {
    AnalyticsService.trackView('Grocery tab');
  });
  $scope.data = {
    grocerySearch: ''
  };
  $scope.hideClearItem = true;
  $scope.state = $state.current.name;
  $scope.start = 0;
  $scope.end = 20;

  if (groceries && groceries.data) {
    if (groceries.data.hits) {
      $scope.groceries = _.map(groceries.data.hits, 'fields');
    }

    if (groceries.data.total) {
      $scope.maxHits = groceries.data.total;
    }
  }

  $scope.$watch('data.grocerySearch', function (newValue, oldValue) {
    $scope.start = 0;
    $scope.end = 20;

    if (!newValue || !oldValue || newValue.length < 3) {
      $scope.hideClearItem = true;
      return;
    }

    $scope.hideClearItem = false;
    $scope.newValue = newValue;
    NixService.getGroceryFoods(newValue).then(function (response) {
      $scope.groceries = _.map(response.data.hits, 'fields');
      $scope.maxHits = response.data.total;
    });
  });

  $scope.clearSearch = function () {
    $scope.data.grocerySearch = '';
    $timeout(function () {
      angular.element('#grocerySearch').focus();
    }, 500);
  };

  $scope.goToReviewFoods = function () {
    $ionicViewSwitcher.nextDirection('forward');
    $state.go('app.reviewFoods');
  };

  $scope.goBack = function () {
    $ionicViewSwitcher.nextDirection('back');
    $state.go('app.foodlog');
  };

  $scope.addFood = function (food) {
    $scope.mealBuilderClass = 'has-footer';
    $rootScope.$broadcast('mealBuilder: addFood', {
      foodArray: [food]
    });
  };

  $scope.loadMoreFoods = function () {
    $scope.start += 20;
    $scope.end += 20;
    NixService.getGroceryFoods($scope.newValue, $scope.start, $scope.end).then(function (response) {
      $scope.maxHits = response.data.total;
      $scope.groceries = $scope.groceries.concat(_.map(response.hits, 'fields'));
      $scope.$broadcast('scroll.infiniteScrollComplete');
    });
  };
}]);
'use strict';

angular.module('Track').controller('headerController', ["$scope", "$rootScope", "$state", "$ionicHistory", "$ionicScrollDelegate", "$ionicSideMenuDelegate", "$ionicViewSwitcher", "$filter", "$window", "$timeout", "$ionicPopup", "AnalyticsService", "ApiService", "CustomFoodService", "CacheFactory", "NixService", "Recipe2Service", "HelperService", function ($scope, $rootScope, $state, $ionicHistory, $ionicScrollDelegate, $ionicSideMenuDelegate, $ionicViewSwitcher, $filter, $window, $timeout, $ionicPopup, AnalyticsService, ApiService, CustomFoodService, CacheFactory, NixService, Recipe2Service, HelperService) {
  var currentStateName = $ionicHistory.currentStateName();
  $scope.showBack = currentStateName !== 'app.foodlog';
  $scope.showCloseAutocomplete = false;
  $scope.currentPlatform = window.ionic.Platform.platform();
  $ionicSideMenuDelegate.canDragContent(false);
  $rootScope.cartNumber = $rootScope.itemsInBuilder ? $rootScope.itemsInBuilder.length : 0;
  $rootScope.showAutocomplete = false;
  $scope.hourNow = '';
  $scope.boostFreeform = false;
  $scope.showFullBranded = false;
  $scope.autocompleteView = {
    commonLimit: 3,
    brandedLimit: 5,
    additionToLimit: 0
  };
  $scope.data = {
    search: '',
    suggested: [],
    instant: {
      self: [],
      common: [],
      branded: []
    }
  };
  $scope.showHint = false;
  $scope.loading = null;
  $scope.$watch($rootScope.cartNumber, function () {
    $rootScope.cartNumber = $rootScope.itemsInBuilder ? $rootScope.itemsInBuilder.length : 0;
  });

  $scope.universalHeaderLeftButton = function () {
    if ($scope.showCloseAutocomplete) {
      $scope.hideDropdown();
    } else {
      if ($scope.showBack) {
        $scope.goBack();
      } else {
        $ionicSideMenuDelegate.toggleLeft();
      }
    }
  };

  $scope.switchFilter = function (filter) {
    $scope.autocompleteView.additionToLimit = 0;
    $scope.selectedFilter = filter;

    switch (filter) {
      case 'Common':
        $scope.autocompleteView.commonLimit = 10;
        $scope.autocompleteView.brandedLimit = 0;
        break;

      case 'Branded':
        $scope.autocompleteView.commonLimit = 0;
        $scope.autocompleteView.brandedLimit = 10;
        $scope.showFullBranded = false;
        break;

      case 'users_foods':
        $scope.autocompleteView.commonLimit = 0;
        $scope.autocompleteView.brandedLimit = 0;
        break;

      default:
        $scope.autocompleteView.commonLimit = 3;
        $scope.autocompleteView.brandedLimit = 5;
    }

    $ionicScrollDelegate.scrollTop();
  };

  $scope.goBack = function () {
    if ($rootScope.itemsInBuilder.length === 0 && $rootScope.tempSearchQuery && $rootScope.tempSearchQuery.length) {
      $scope.data.search = $rootScope.tempSearchQuery;
      angular.element('#autocompleteSearch').focus().val($scope.data.search).triggerHandler('change');
      delete $rootScope.tempSearchQuery;
      return $scope.search();
    } //Dont go back and forth between add food views when using back button


    var addFoodViews = ['app.addfoodsmart', 'app.grocery', 'app.restaurants', 'app.history', 'app.reviewFoods'];

    if ($rootScope.itemsInBuilder.length === 0 && $ionicHistory.currentView().stateName === 'app.reviewFoods' || $ionicHistory.backView() && _.includes(addFoodViews, currentStateName) && _.includes(addFoodViews, $ionicHistory.backView().stateName)) {
      $ionicViewSwitcher.nextDirection('back');
      $state.go('app.foodlog');
    } else {
      $ionicHistory.goBack();
    }
  };

  var trackViewAutocomplete = function trackViewAutocomplete() {};

  $scope.$watch(function () {
    return $ionicSideMenuDelegate.isOpenLeft();
  }, function (isOpen) {
    if (isOpen) {
      AnalyticsService.trackView('Menu');
    }
  });

  trackViewAutocomplete = function trackViewAutocomplete() {
    AnalyticsService.trackView('Autocomplete');
  };

  $scope.goToSmart = function () {
    $rootScope.showAutocomplete = false;
    $state.go('app.addfoodsmart');
  };

  $scope.goToCustomFood = function () {
    $rootScope.showAutocomplete = false;
    var mealType = null;

    if ($scope.logging && $scope.logging.meal_type) {
      mealType = $scope.logging.meal_type;
    }

    $state.go('app.customFood', {
      logAfterSubmit: true,
      mealType: mealType
    });
  };

  $scope.goToReviewFoods = function () {
    $rootScope.showAutocomplete = false;
    $ionicViewSwitcher.nextDirection('forward');
    $state.go('app.reviewFoods');
  };

  $scope.hideKeyboard = function () {
    window.cordova.plugins.Keyboard.close();
  };

  function calculateMealTimeByType(meal_type) {
    var mtypeDict = {
      1: 'Breakfast',
      2: 'AM Snack',
      3: 'Lunch',
      4: 'PM Snack',
      5: 'Dinner',
      6: 'Late Snack'
    };
    var type_str = meal_type.toString();
    return mtypeDict[type_str];
  }

  $scope.showDropdown = function () {
    $scope.data.userFoods = [];
    delete $rootScope.tempSearchQuery;
    $scope.data.customFoods = CustomFoodService.getCachedFoods();

    if (!$scope.data.customFoods || !$scope.data.customFoods.length) {
      CustomFoodService.getCustomFoods().then(function (res) {
        $scope.data.customFoods = res.data.custom_foods;
        $scope.data.userFoods = $scope.data.userFoods.concat($scope.data.customFoods);
      });
    } else {
      $scope.data.userFoods = $scope.data.userFoods.concat($scope.data.customFoods);
    }

    $scope.data.recipes = Recipe2Service.getCachedRecipes();

    if (!$scope.data.recipes || !$scope.data.recipes.length) {
      Recipe2Service.getMyRecipes().then(function (res) {
        $scope.data.recipes = res.data.recipes;
        $scope.data.userFoods = $scope.data.userFoods.concat($scope.data.recipes);
      });
    } else {
      $scope.data.userFoods = $scope.data.userFoods.concat($scope.data.recipes);
    }

    $scope.showCloseAutocomplete = true;
    var mtype = -1; //comes from foodlog scope and reviewfoods scope

    if ($scope.logging && $scope.logging.meal_type) {
      mtype = $scope.logging.meal_type;
    }

    trackViewAutocomplete();
    $rootScope.showAutocomplete = true;
    $scope.loading = true;

    if ($scope.data.suggested.length || $scope.data.instant.self.length || $scope.data.instant.common.length || $rootScope.noInternet) {
      $scope.loading = false;
      return;
    }

    ApiService.getSuggestedFoods(mtype).then(function (results) {
      $scope.data.suggested = results.data.foods;
      $scope.data.suggested = _.remove($scope.data.suggested, function (el) {
        return el.food_name;
      });

      if (!$scope.data.suggested.length) {
        $scope.showHint = true;
      }

      if ($scope.logging && $scope.logging.meal_type) {
        $scope.mealPrefix = 'for';
        $scope.hourNow = calculateMealTimeByType($scope.logging.meal_type);
      } else {
        $scope.mealPrefix = 'around';
        var min = moment().get('minute');

        if (min >= 30) {
          $scope.hourNow = moment().add(1, 'hour').format('hA');
        } else {
          $scope.hourNow = moment().format('hA');
        }
      }

      $scope.loading = false;
    });
  };

  $scope.hideDropdown = function () {
    angular.element('#autocompleteSearch').blur();
    $rootScope.showAutocomplete = false;
    $rootScope.basketLog = false;
    $scope.boostFreeform = false;
    $scope.showHint = false;
    $scope.showFullBranded = false;
    $scope.showCloseAutocomplete = false;
    $scope.data.search = '';
    $scope.data.suggested = [];
    $scope.data.instant = {
      self: [],
      common: [],
      branded: []
    };

    if ($scope.logging && $scope.logging.meal_type && currentStateName !== 'app.reviewFoods') {
      $scope.logging.meal_type = null;
    }

    $scope.autocompleteView.commonLimit = 3;
    $scope.autocompleteView.brandedLimit = 5;
    $scope.autocompleteView.additionToLimit = 0;
    $scope.selectedFilter = '';
    $ionicScrollDelegate.scrollTop();
  };

  $scope.search = function () {
    $scope.showFullBranded = false;
    $scope.data.suggested = [];

    if ($scope.data.search) {
      if (!$filter('filter')($scope.data.instant.common, $scope.data.search, false, 'food_name').length || $scope.data.search.includes('and') || $scope.data.search.includes(' of ') || !isNaN($scope.data.search.charAt(0)) && $scope.data.search.charAt(0)) {
        $scope.boostFreeform = true;
      } else {
        $scope.boostFreeform = false;
      }

      ApiService.getAutocompleteFoods($scope.data.search).then(function (results) {
        $scope.showHint = false; // bug where serving_qty in db is null in self foods. filter out these results first

        var selfResults = _.filter(results.data.self, function (res) {
          return res.serving_qty;
        });

        $scope.data.instant.self = selfResults;

        var uniqCommon = _.uniqBy(results.data.common, function (food) {
          return food.tag_id;
        });

        if (uniqCommon.length <= 3) {
          $scope.data.instant.common = results.data.common;
        } else {
          $scope.data.instant.common = uniqCommon;
        }

        $scope.data.instant.branded = results.data.branded;

        if (!$filter('filter')($scope.data.instant.common, $scope.data.search, false, 'food_name').length || $scope.data.search.includes('and') || $scope.data.search.includes(' of ') || !isNaN($scope.data.search.charAt(0)) && $scope.data.search.charAt(0)) {
          $scope.boostFreeform = true;
        } else {
          $scope.boostFreeform = false;
        } // Clean suggested one more time after the searched foods are loaded.


        $scope.data.suggested = [];
        $timeout(function () {
          $ionicScrollDelegate.resize();
        }, 100);
      });
    }
  };

  $scope.showMoreBranded = function () {
    $scope.showFullBranded = true;
    $timeout(function () {
      $ionicScrollDelegate.resize();
    }, 100);
  }; // helper function to add calories. if in reviewfoods view,
  // state.go will not reload and total calories will not update.
  // this is workaround for that


  function addCalories(calories) {
    if ($scope.totalCalories || $scope.totalCalories === 0) {
      $scope.totalCalories += calories;
    }
  }

  $scope.addSuggestedFood = function (item) {
    if (!item.food_name) {
      return;
    }

    $rootScope.cartNumber++;
    delete item.id;
    delete item.popularity;
    delete item.note;
    item.meal_type = null;
    item.consumed_at = moment().format();
    CacheFactory.getMealBuilderFoods().then(function (mb) {
      $rootScope.itemsInBuilder = mb;

      if (item.alt_measures && item.serving_weight_grams) {
        var temp = {
          'serving_weight': item.serving_weight_grams,
          'seq': null,
          'measure': item.serving_unit,
          'qty': item.serving_qty
        };
        item.alt_measures.unshift(temp);
        item = HelperService.addGramsToAltMeasures(item);
      }

      $rootScope.itemsInBuilder.push(item);
      CacheFactory.setMealBuilderFoods($rootScope.itemsInBuilder);
      $rootScope.showAutocomplete = false;
      $scope.boostFreeform = false;
      $scope.data.search = '';
      addCalories(item.nf_calories);
      $timeout(function () {
        if (currentStateName === 'app.reviewFoods') {
          $state.reload();
        } else {
          // init selected day to todays date
          var params = {};

          if (!$rootScope.selected_day) {
            params = {
              mealConsumed: moment().format('ddd, MM/DD/YY')
            };
          } else {
            params = {
              mealConsumed: $rootScope.selected_day.date
            };
          }

          if ($scope.logging && $scope.logging.meal_type) {
            params.mealType = $scope.logging.meal_type;
            HelperService.resetBasketWhenModuleState();
          }

          $state.go('app.reviewFoods', params);
        }
      }, 200);
    })["catch"](function (err) {
      console.log('there was an error adding suggested food', angular.toJson(err));
      errorMessage(err);
    });
  };

  function errorMessage(err) {
    if (_.isEmpty(err)) {
      err.data = {
        'message': 'Something went wrong.',
        'query': ''
      };
    }

    $ionicPopup.alert({
      title: err.data.message + ' for:',
      template: err.config.data.query,
      buttons: [{
        text: 'Ok',
        type: 'button-balanced'
      }]
    });
  }

  $scope.addCommonFood = function (item_name, is_freeform) {
    // log user interaction with autocomplete for analytics purpose
    if (!is_freeform) {
      ApiService.logAutocompleteStats($scope.data.search, 1, item_name);
    }

    var food_obj = {
      query: item_name
    };
    var cachedResult;
    ApiService.getFoodNutrients(food_obj).then(function (results) {
      $rootScope.cartNumber++;
      cachedResult = results;
      return CacheFactory.getMealBuilderFoods();
    }).then(function (mealBuilder) {
      $rootScope.itemsInBuilder = mealBuilder;
      return _.forEach(cachedResult.data.foods, function (food) {
        addCalories(food.nf_calories); //the the user requested measure/defaul measure to alt_measures so it is part of drop down in review foods

        if (food.alt_measures) {
          var temp = {
            'serving_weight': food.serving_weight_grams,
            'seq': null,
            'measure': food.serving_unit,
            'qty': food.serving_qty
          };
          food.alt_measures.unshift(temp);
          food = HelperService.addGramsToAltMeasures(food);
        }

        return $rootScope.itemsInBuilder.push(food);
      });
    }).then(function () {
      CacheFactory.setMealBuilderFoods($rootScope.itemsInBuilder);
      $rootScope.showAutocomplete = false;
      $scope.boostFreeform = false;
      $rootScope.tempSearchQuery = $scope.data.search;
      $scope.data.search = '';
      $scope.data.suggested = [];
      $scope.data.instant = {
        self: [],
        common: [],
        branded: []
      };
      var naturalEvent = is_freeform ? 'natural_freeform' : 'natural_common';
      AnalyticsService.trackEvent(naturalEvent, item_name);
      $timeout(function () {
        if (currentStateName === 'app.reviewFoods') {
          $state.reload();
        } else {
          var params = {
            mealConsumed: $rootScope.selected_day.date
          };

          if ($scope.logging && $scope.logging.meal_type) {
            params.mealType = $scope.logging.meal_type;
            HelperService.resetBasketWhenModuleState();
          }

          $state.go('app.reviewFoods', params);
        }
      }, 200);
    })["catch"](function (err) {
      console.log('there was an err add common food', angular.toJson(err));
      errorMessage(err);
    });
  };

  $scope.addMyFood = function (item) {
    $rootScope.cartNumber++;
    var cachedResult;
    ApiService.getFoodById(item.uuid).then(function (results) {
      cachedResult = results.data.foods[0];
      cachedResult.consumed_at = moment().format();
      addCalories(cachedResult.nf_calories);

      if (cachedResult.id) {
        delete cachedResult.id;
      }

      if (cachedResult.note) {
        delete cachedResult.note;
      }

      return CacheFactory.getMealBuilderFoods();
    }).then(function (mb) {
      $rootScope.itemsInBuilder.push(cachedResult);
      CacheFactory.setMealBuilderFoods($rootScope.itemsInBuilder);
      $rootScope.showAutocomplete = false;
      $scope.boostFreeform = false;
      $rootScope.tempSearchQuery = $scope.data.search;
      $scope.data.search = '';
      $scope.data.suggested = [];
      $scope.data.instant = {
        self: [],
        common: [],
        branded: []
      };
      $timeout(function () {
        if (currentStateName === 'app.reviewFoods') {
          $state.reload();
        } else {
          var params = {
            mealConsumed: $rootScope.selected_day.date
          };

          if ($scope.logging && $scope.logging.meal_type) {
            params.mealType = $scope.logging.meal_type;
            HelperService.resetBasketWhenModuleState();
          }

          $state.go('app.reviewFoods', params);
        }
      }, 200);
    })["catch"](function (err) {
      console.log('there was an error adding history food', angular.toJson(err));
      errorMessage(err);
    });
  };

  $scope.addCustomFood = function (item) {
    var serving_qty = item.serving_qty;

    var foodToLog = _.cloneDeep(item);

    delete foodToLog.id; //remove public id because the log endpoint not accepting this property.

    delete foodToLog.public_id; // need to do this for top level

    var nf = window.nutritionixApiDataUtilities.convertFullNutrientsToNfAttributes(foodToLog.full_nutrients);
    var accepted = ['nf_calories', 'nf_total_fat', 'nf_saturated_fat', 'nf_cholesterol', 'nf_sodium', 'nf_total_carbohydrate', 'nf_dietary_fiber', 'nf_sugars', 'nf_protein', 'nf_potassium', 'nf_p'];

    var keep = _.pick(nf, accepted);

    _.extend(foodToLog, keep);

    CacheFactory.getMealBuilderFoods().then(function (mb) {
      $rootScope.itemsInBuilder = mb; //only want to log 1 serving

      var scaled_food = HelperService.multiply(foodToLog, 1 / serving_qty, 1);
      return $rootScope.itemsInBuilder.push(scaled_food);
    }).then(function () {
      CacheFactory.setMealBuilderFoods($rootScope.itemsInBuilder);

      if (currentStateName === 'app.reviewFoods') {
        $state.reload();
      } else {
        // init selected day to todays date
        var params = {};

        if (!$rootScope.selected_day) {
          params = {
            mealConsumed: moment().format('ddd, MM/DD/YY')
          };
        } else {
          params = {
            mealConsumed: $rootScope.selected_day.date
          };
        }

        if ($scope.logging && $scope.logging.meal_type) {
          params.mealType = $scope.logging.meal_type;
          HelperService.resetBasketWhenModuleState();
        }

        $state.go('app.reviewFoods', params);
      }
    });
  };

  $scope.addRecipe = function (item) {
    if (!$rootScope.itemsInBuilder.length) {
      $scope.logRecipe(item);
    } else {
      $ionicPopup.show({
        title: 'Warning',
        subTitle: 'The basket is not empty',
        template: '<div class="text-center" style="font-size:12px;">To log a recipe the basket needs to be empty. Tap OK to clear the basket and add this recipe.</div>',
        buttons: [{
          text: 'OK',
          type: 'button-balanced',
          onTap: function onTap() {
            CacheFactory.clearFoods().then(function () {
              $rootScope.$broadcast('clearFoods');
              $rootScope.itemsInBuilder = [];
              $rootScope.cartNumber = 0;
            }).then(function () {
              $scope.logRecipe(item);
            });
          }
        }, {
          text: 'Cancel'
        }]
      });
    }
  };

  $scope.logRecipe = function (item) {
    Recipe2Service.getRecipeById(item.id).then(function (resp) {
      _.forEach(resp.data.ingredients, function (foodObj) {
        if (foodObj.alt_measures) {
          var temp = {
            'serving_weight': foodObj.serving_weight_grams,
            'seq': null,
            'measure': foodObj.serving_unit,
            'qty': foodObj.serving_qty
          };
          foodObj.alt_measures.unshift(temp);
        }
      });

      var serving_qty = resp.data.serving_qty;
      var instruct_copy = resp.data.directions;

      var recipeToLog = _.cloneDeep(resp.data); // need to do this for top level as well as each ingredient


      var nf = window.nutritionixApiDataUtilities.convertFullNutrientsToNfAttributes(recipeToLog.full_nutrients);
      var accepted = ['nf_calories', 'nf_total_fat', 'nf_saturated_fat', 'nf_cholesterol', 'nf_sodium', 'nf_total_carbohydrate', 'nf_dietary_fiber', 'nf_sugars', 'nf_protein', 'nf_potassium', 'nf_p'];

      var keep = _.pick(nf, accepted);

      _.extend(recipeToLog, keep);

      _.forEach(recipeToLog.ingredients, function (ingredient) {
        var ing_nf = window.nutritionixApiDataUtilities.convertFullNutrientsToNfAttributes(ingredient.full_nutrients);

        var ing_keep = _.pick(ing_nf, accepted);

        _.extend(ingredient, ing_keep);
      }); //only want to log 1 serving


      var scaled_recipe = HelperService.multiply(recipeToLog, 1 / serving_qty, 1);
      $rootScope.$broadcast('mealBuilder: addFood', {
        foodArray: scaled_recipe.ingredients
      });
      var params = {
        type: 'singleFood',
        name: scaled_recipe.name,
        recipeBrand: scaled_recipe.brand_name || null,
        servings: serving_qty
      };

      if (!$rootScope.selected_day) {
        params.mealConsumed = moment().format('ddd, MM/DD/YY');
      } else {
        params.mealConsumed = $rootScope.selected_day.date;
      }

      if ($scope.logging && $scope.logging.meal_type) {
        params.mealType = $scope.logging.meal_type;
        HelperService.resetBasketWhenModuleState();
      }

      if (currentStateName === 'app.reviewFoods') {
        $state.go($state.current, params);
      } else {
        $state.go('app.reviewFoods', params);
      }
    });
  };

  $scope.addBrandedFood = function (item) {
    // log user interaction with autocomplete for analytics purpose
    ApiService.logAutocompleteStats($scope.data.search, 8, item.nix_item_id);
    $rootScope.cartNumber++;
    var cachedResult;
    var nixItemId = item.nix_item_id;
    ApiService.getBrandedFood(item.nix_item_id).then(function (results) {
      cachedResult = results.data.foods[0];

      if (!cachedResult.alt_measures) {
        if (cachedResult.serving_weight_grams) {
          cachedResult.alt_measures = [{
            'measure': cachedResult.serving_unit,
            'qty': cachedResult.serving_qty,
            'seq': null,
            'serving_weight': cachedResult.serving_weight_grams
          }];
          cachedResult = HelperService.addGramsToAltMeasures(cachedResult);
        }
      }

      return cachedResult;
    }).then(function (cachedResult) {
      addCalories(cachedResult.nf_calories);
      return CacheFactory.getMealBuilderFoods;
    }).then(function (mb) {
      $rootScope.itemsInBuilder.push(cachedResult);
      CacheFactory.setMealBuilderFoods($rootScope.itemsInBuilder);
      $rootScope.showAutocomplete = false;
      $scope.boostFreeform = false;
      $rootScope.tempSearchQuery = $scope.data.search;
      $scope.data.search = '';
      $scope.data.suggested = [];
      $scope.data.instant = {
        self: [],
        common: [],
        branded: []
      };
      $timeout(function () {
        if (currentStateName === 'app.reviewFoods') {
          $state.reload();
        } else {
          var params = {
            mealConsumed: $rootScope.selected_day.date
          };

          if ($scope.logging && $scope.logging.meal_type) {
            params.mealType = $scope.logging.meal_type;
            HelperService.resetBasketWhenModuleState();
          }

          $state.go('app.reviewFoods', params);
        }
      }, 200);
    })["catch"](function (err) {
      console.log('there was an error adding branded food', angular.toJson(err));
    });
  };
}]).filter('highlight', ["$sce", function ($sce) {
  return function (text, phrase) {
    if (phrase) {
      text = text.replace(new RegExp('(' + phrase.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, '\\$&') + ')', 'gi'), '<b>$1</b>');
    }

    return $sce.trustAsHtml(text);
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:HelpController
 * @description
 * # HelpController
 */

angular.module('Track').controller('HelpController', ["$cordovaDevice", "$cordovaEmailComposer", "$state", "$ionicHistory", "$ionicViewSwitcher", function ($cordovaDevice, $cordovaEmailComposer, $state, $ionicHistory, $ionicViewSwitcher) {
  var vm = this;

  vm.goToInstruction = function () {
    $state.go('instruction');
  };

  vm.goBack = function () {
    $ionicViewSwitcher.nextDirection('back');
    $ionicHistory.goBack() ? $ionicHistory.backView() : $state.go('app.foodlog');
  };

  vm.goToSupport = function () {
    var device = $cordovaDevice.getDevice();
    window.cordova.plugins.email.hasPermission(cordova.plugins.email.permission.GET_ACCOUNTS, function () {
      window.cordova.plugins.email.hasAccount(function () {
        var body = '<br><br><br>';
        body += device.model;
        var email = {
          to: 'support@nutritionix.com',
          cc: '',
          bcc: [],
          subject: 'Track app feedback (' + device.platform + ' ' + device.version + ')',
          body: body,
          isHtml: true
        };
        window.cordova.plugins.email.open(email);
      });
    });
  };

  vm.goToFAQ = function () {
    cordova.InAppBrowser.open('http://nutritionix.helpsite.com/', '_blank', 'location=no');
  };

  vm.openTOS = function () {
    cordova.InAppBrowser.open('http://www.nutritionix.com/terms', '_blank', 'location=no');
    return false;
  };

  vm.openPrivacy = function () {
    cordova.InAppBrowser.open('https://www.nutritionix.com/privacy', '_blank', 'location=no');
    return false;
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:historyController
 * @description
 * # historyController
 */

angular.module('Track').controller('historyController', ["$rootScope", "$scope", "$state", "AnalyticsService", "ApiService", "history", "$timeout", function ($rootScope, $scope, $state, AnalyticsService, ApiService, history, $timeout) {
  var mtype = -1;
  $scope.$on('$ionicView.enter', function (event, data) {
    AnalyticsService.trackView('History tab');
    ApiService.getSuggestedFoods(mtype).then(function (results) {
      $scope.suggested = results.data.foods;
      $scope.suggested = _.remove($scope.suggested, function (el) {
        return el.food_name;
      });
      $scope.foods = $scope.suggested;
    });
  });
  $scope.state = $state.current.name;
  $scope.data = {
    historySearch: ''
  };

  $scope.goBack = function () {
    $state.go('app.foodlog');
  };

  var item = _.reduce(history.response, function (accum, item) {
    return accum + item;
  });

  item = JSON.parse(item);
  $scope.foods = item.data.foods;

  $scope.getCalories = function (food) {
    var cal = 0;

    if (food.nf_calories) {
      cal = food.nf_calories;
    } else if (food.full_nutrients) {
      cal = _.find(food.full_nutrients, {
        attr_id: 208
      }).value;
    }

    return cal;
  };

  $scope.$watch('data.historySearch', function (newValue) {
    if (!newValue) {
      $scope.hideClearItem = true;
      $scope.foods = $scope.suggested;
    } else {
      ApiService.getAutocompleteFoods(newValue + '&branded=false&common=false').then(function (results) {
        // bug where serving_qty in db is null in self foods. filter out these results first
        var selfResults = _.filter(results.data.self, function (res) {
          return res.serving_qty;
        });

        $scope.foods = selfResults;
      });
      $scope.hideClearItem = false;
    }
  });

  $scope.clearSearch = function () {
    $scope.data.historySearch = '';
  };

  $scope.addFood = function (food) {
    var id = food.id ? food.id : food.uuid;
    ApiService.getFoodById(id).then(function (response) {
      $rootScope.mealBuilderClass = 'has-footer';
      response.data.foods[0].consumed_at = new Date();
      response.data.foods[0].note = null;
      $rootScope.$broadcast('mealBuilder: addFood', {
        foodArray: response.data.foods
      });
    });
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:InstructionController
 * @description
 * # InstructionController
 */

angular.module('Track').controller('InstructionController', ["$scope", "$state", "$ionicPlatform", "AnalyticsService", function ($scope, $state, $ionicPlatform, AnalyticsService) {
  $scope.slides = [1];
  $scope.isIOS = window.ionic.Platform.platform() === 'android' ? false : true;
  $ionicPlatform.ready(function () {
    $scope.$watch('sliderIndex', function (newIndex) {
      if (newIndex !== undefined) {
        AnalyticsService.trackView('Slide ' + (newIndex + 1));
      }
    });
  });

  $scope.swipeCloseAtEnd = function ($index) {
    if ($index + 1 == $scope.slides.length) {
      $scope.endTour();
    }
  };

  $scope.slideOnClick = function ($index, $parent) {
    if ($index + 1 < $scope.slides.length) {
      $parent.nextSlide();
    } else {
      $scope.endTour();
    }
  };

  $scope.endTour = function () {
    $state.go('app.foodlog');
  };
}]);
'use strict';

angular.module('Track').controller('LoginController', ["$scope", "$state", "LoginService", function ($scope, $state, LoginService) {
  if (window.SignInWithApple) {
    window.SignInWithApple.isAvailable().then(function (res) {
      return $scope.showAppleLogin = res;
    });
  }

  $scope.loginFacebook = function () {
    return LoginService.loginViaFacebook();
  };

  $scope.loginApple = function () {
    return LoginService.loginViaAppleID();
  };

  $scope.manualLogin = function (userInput, password) {
    return LoginService.manualSignIn(userInput, password).then(function (response) {
      if (response.status === 201) {
        $state.go('app.foodlog');
      } else {
        navigator.notification.alert('There was an error logging in', null, '', 'OK');
      }
    })["catch"](function (err) {
      console.log('[login] error manually signing in:', err);
    });
  };

  $scope.goToManualSignIn = function () {
    $state.go('manualLogin');
  };

  $scope.goToCreateAccount = function () {
    $state.go('signup');
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:MainController
 * @description
 * # MainController
 */

angular.module('Track').controller('MainController', ["$cordovaAppVersion", "$cordovaDevice", "$cordovaInAppBrowser", "$cordovaSocialSharing", "$cordovaAppAvailability", "$ionicPlatform", "$log", "$rootScope", "$scope", "$state", "$window", "ConfigurationService", "UserService", function ($cordovaAppVersion, $cordovaDevice, $cordovaInAppBrowser, $cordovaSocialSharing, $cordovaAppAvailability, $ionicPlatform, $log, $rootScope, $scope, $state, $window, ConfigurationService, UserService) {
  $ionicPlatform.ready(function () {
    $cordovaAppVersion.getVersionNumber().then(function (version) {
      $scope.version = version;
    }); // determine the platform

    $scope.platform = $cordovaDevice.getPlatform();
    $scope.textForButtons = {
      storeName: 'iOS' === $scope.platform ? 'App Store' : 'Google Play'
    };
    UserService.getUser().then(function (res) {
      if (!!res && !!res.coach && !!res.coach.is_active) {
        $rootScope.isCoach = true;
      } else {
        $rootScope.isCoach = false;
      }
    });
  }, false);

  $scope.signout = function () {
    $rootScope.$broadcast('user logout');
    $state.go('login');
  };

  $scope.promptForRating = function () {
    if ($window.cordova) {
      window.AppRate.preferences.storeAppURL = {
        ios: ConfigurationService.application_store_ids.ios,
        android: 'market://details?id=' + ConfigurationService.application_store_ids.android
      };
      window.AppRate.promptForRating();
    }
  };

  $scope.promptToShare = function () {
    var message = 'Try out this cool food tracking app I have been using, it\'s called Nutritionix Track:';
    var subject = 'iOS' === $scope.platform ? 'Nutritionix Track App - Calorie Counter and Food Tracker' : 'Nutritionix Track App - Calorie Counter and Food Tracker';
    var file;
    var link = 'iOS' === $scope.platform ? 'https://appsto.re/us/o_bs_.i' : 'https://play.google.com/store/apps/details?id=com.nutritionix.nixtrack&hl=en';
    $cordovaSocialSharing.share(message, subject, file, link)["catch"](function (error) {
      $log.error(error);
    });
  };

  $scope.goToWebSite = function () {
    cordova.InAppBrowser.open('https://www.nutritionix.com', '_system', "location=no")["catch"](function (error) {
      $log.error(error);
    });
  };

  $scope.goToRecipes = function (type) {
    $state.go('app.recipes', {
      selectedFilter: type
    });
  };

  $scope.openFb = function () {
    var fbAppUrl, chekFbScheme;

    if ($scope.platform === 'iOS') {
      fbAppUrl = 'fb://page?id=110659912291888';
      chekFbScheme = 'fb://';
    } else {
      fbAppUrl = 'fb://page/110659912291888';
      chekFbScheme = 'com.facebook.katana';
    }

    $cordovaAppAvailability.check(chekFbScheme).then(function () {
      cordova.InAppBrowser.open(fbAppUrl, '_system', "location=no");
    }, function () {
      cordova.InAppBrowser.open('https://facebook.com/nutritionix', '_system', "location=no");
    });
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:connectAppController
 * @description
 * # connectAppController
 */

angular.module('Track').controller('manageAppSyncController', ["$rootScope", "$scope", "$state", "$stateParams", "$ionicHistory", "$cordovaSQLite", "AnalyticsService", "ApiService", "HealthKitWeightService", "HealthKitExerciseService", "UserService", function ($rootScope, $scope, $state, $stateParams, $ionicHistory, $cordovaSQLite, AnalyticsService, ApiService, HealthKitWeightService, HealthKitExerciseService, UserService) {
  var baseUrl = 'https://trackapi.nutritionix.com/v2';
  $scope.$on('$ionicView.beforeEnter', function () {
    $scope.managedApp = $stateParams.managedApp;
  });
  $scope.$on('$ionicView.enter', function (event, data) {
    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(false);
    }

    if ($scope.managedApp === 'Fitbit') {
      var userPreferences = JSON.parse(window.localStorage.getItem('userPreferences'));

      if (userPreferences) {
        $scope.userPreferences = userPreferences;
      } else {
        ApiService.getUserData().then(function (user) {
          $scope.userPreferences = user.data;
          window.localStorage.setItem('userPreferences', angular.toJson(user.data));
        });
      }

      if (!!$scope.userPreferences && !!_.find($scope.userPreferences.oauths, {
        provider: 'fitbit'
      })) {
        $scope.syncOptions = {
          fitbit: 'push'
        };
      } else {
        $scope.syncOptions = {
          fitbit: 'off'
        };
      }
    } else {
      var toggle = JSON.parse(window.localStorage.getItem('healthkit'));

      if (toggle) {
        $scope.syncOptions = toggle;
      } else {
        $scope.syncOptions = {
          // three choices: push/pull/off
          nutrition: 'off',
          weight: 'off',
          exercise: 'off'
        };
      }
    }
  });
  $scope.$on('$ionicView.leave', function () {
    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
    }
  });

  $scope.adjustSync = function (type) {
    window.localStorage.setItem('healthkit', angular.toJson($scope.syncOptions));

    if (type === 'nutrition') {
      $rootScope.hk.nutrition = $scope.syncOptions.nutrition;
      toggleHKNutrition();
    } else if (type === 'weight') {
      $rootScope.hk.weight = $scope.syncOptions.weight;
      toggleHKWeight();
    } else {
      $rootScope.hk.exercise = $scope.syncOptions.exercise;
      toggleHKExercise();
    }
  };

  $scope.goBack = function () {
    //in the case of a deep link
    if ($ionicHistory.backView() === undefined) {
      $state.go('app.foodlog');
    } else {
      $ionicHistory.goBack();
    }
  };

  $scope.fitbit = function () {
    if ($scope.syncOptions.fitbit === 'push') {
      return ApiService.fitbitSign().then(function (res) {
        var ref = cordova.InAppBrowser.open(baseUrl + '/oauth/fitbit/authorize?state=' + res.data.state, '_blank', 'location=no,toolbar=yes');
        ref.addEventListener('loadstart', function (res) {
          if (res.url === baseUrl + '/oauth/fitbit/success#_=_') {
            return ApiService.getUserData().then(function (response) {
              console.log(response);
              UserService.setUser(response.data.user);
              window.localStorage.setItem('userPreferences', angular.toJson(response.data));
              return ref.close();
            });
          }
        });
      });
    } else {
      return ApiService.fitbitUnlink().then(function () {
        return ApiService.getUserData().then(function (response) {
          UserService.setUser(response.data.user);
          window.localStorage.setItem('userPreferences', angular.toJson(response.data));
        });
      });
    }
  };

  function toggleHKNutrition() {
    if ($rootScope.hk.nutrition === 'off') {
      $cordovaSQLite.execute(window.db, 'DROP TABLE hkdata');
      AnalyticsService.trackEvent('HealthKit nutrition sync', 'disable');
    } else {
      //create tables on toggle on; shouldnt exist if toggle off
      $cordovaSQLite.execute(window.db, 'CREATE TABLE hkdata (id INTEGER PRIMARY KEY, response TEXT)');
      var hk_types = ['HKQuantityTypeIdentifierDietaryEnergyConsumed', 'HKQuantityTypeIdentifierDietaryCaffeine', 'HKQuantityTypeIdentifierDietaryCalcium', 'HKQuantityTypeIdentifierDietaryCarbohydrates', 'HKQuantityTypeIdentifierDietaryCholesterol', 'HKQuantityTypeIdentifierDietaryCopper', 'HKQuantityTypeIdentifierDietaryFatMonounsaturated', 'HKQuantityTypeIdentifierDietaryFatPolyunsaturated', 'HKQuantityTypeIdentifierDietaryFatSaturated', 'HKQuantityTypeIdentifierDietaryFatTotal', 'HKQuantityTypeIdentifierDietaryFiber', 'HKQuantityTypeIdentifierDietaryIron', 'HKQuantityTypeIdentifierDietaryMagnesium', 'HKQuantityTypeIdentifierDietaryManganese', 'HKQuantityTypeIdentifierDietaryNiacin', 'HKQuantityTypeIdentifierDietaryPantothenicAcid', 'HKQuantityTypeIdentifierDietaryPhosphorus', 'HKQuantityTypeIdentifierDietaryPotassium', 'HKQuantityTypeIdentifierDietaryProtein', 'HKQuantityTypeIdentifierDietaryRiboflavin', 'HKQuantityTypeIdentifierDietarySodium', 'HKQuantityTypeIdentifierDietarySugar', 'HKQuantityTypeIdentifierDietaryThiamin', 'HKQuantityTypeIdentifierDietaryVitaminB6', 'HKQuantityTypeIdentifierDietaryVitaminA', 'HKQuantityTypeIdentifierDietaryVitaminC', 'HKQuantityTypeIdentifierDietaryVitaminD', 'HKQuantityTypeIdentifierDietaryVitaminE', 'HKQuantityTypeIdentifierDietaryZinc'];
      window.plugins.healthkit.requestAuthorization({
        readTypes: hk_types,
        writeTypes: hk_types
      }, function () {
        AnalyticsService.trackEvent('HealthKit nutrition sync', 'enable');
        console.log('successfully requested HK nutrition auth');
      }, function (err) {
        console.log(angular.toJson(err));
        console.log('failed to request HK nutrition auth');
      });
    }
  }

  function toggleHKWeight() {
    if ($rootScope.hk.weight === 'off') {
      $cordovaSQLite.execute(window.db, 'DROP TABLE hkdata_weight');
      AnalyticsService.trackEvent('HealthKit weight sync', 'disable');
    } else if ($rootScope.hk.weight == 'pull') {
      window.plugins.healthkit.requestAuthorization({
        'readTypes': ['HKQuantityTypeIdentifierBodyMass']
      }, function () {
        AnalyticsService.trackEvent('HealthKit pull weight sync', 'enable');
        HealthKitWeightService.pullWeightsFromHK();
        console.log('successfully requested HK weight auth');
      }, function (err) {
        console.log(angular.toJson(err));
        console.log('failed to request HK weight auth');
      });
    } else {
      $cordovaSQLite.execute(window.db, 'CREATE TABLE hkdata_weight (id INTEGER PRIMARY KEY, response TEXT)');
      window.plugins.healthkit.requestAuthorization({
        'readTypes': ['HKQuantityTypeIdentifierBodyMass'],
        'writeTypes': ['HKQuantityTypeIdentifierBodyMass']
      }, function () {
        AnalyticsService.trackEvent('HealthKit push weight sync', 'enable');
        console.log('successfully requested HK weight auth');
      }, function (err) {
        console.log(angular.toJson(err));
        console.log('failed to request HK weight auth');
      });
    }
  }

  function toggleHKExercise() {
    if ($rootScope.hk.exercise === 'off') {
      $cordovaSQLite.execute(window.db, 'DROP TABLE hkdata_exercise');
      AnalyticsService.trackEvent('HealthKit exercise sync', 'disable');
    } else if ($rootScope.hk.exercise == 'pull') {
      window.plugins.healthkit.requestAuthorization({
        'readTypes': ['HKQuantityTypeIdentifierActiveEnergyBurned']
      }, function () {
        AnalyticsService.trackEvent('HealthKit pull exercise sync', 'enable');
        console.log('successfully requested HK exercise auth');
        console.log('here');
        HealthKitExerciseService.pullExerciseFromHK();
      }, function (err) {
        console.log(angular.toJson(err));
        console.log('failed to request HK exercise auth');
      });
    } else {
      $cordovaSQLite.execute(window.db, 'CREATE TABLE hkdata_exercise (id INTEGER PRIMARY KEY, response TEXT)');
      window.plugins.healthkit.requestAuthorization({
        'readTypes': ['HKQuantityTypeIdentifierActiveEnergyBurned'],
        'writeTypes': ['HKQuantityTypeIdentifierActiveEnergyBurned']
      }, function () {
        AnalyticsService.trackEvent('HealthKit push exercise sync', 'enable');
        console.log('successfully requested HK exercise auth');
      }, function (err) {
        console.log(angular.toJson(err));
        console.log('failed to request HK exercise auth');
      });
    }
  }
}]);
'use strict';

angular.module('Track').controller('ManualLoginController', ["$rootScope", "$scope", "$state", "$ionicPopup", "LoginService", function ($rootScope, $scope, $state, $ionicPopup, LoginService) {
  $scope.manualLogin = function (email, password) {
    LoginService.manualSignIn(email, password).then(function (response) {
      $state.go('app.foodlog');
    })["catch"](function () {
      return $ionicPopup.alert({
        title: 'Login Failed',
        template: 'The login credentials you provided do not match our records. Please try again.'
      });
    });
  };

  $scope.goToSignUp = function () {
    $state.go('signup');
  };

  $scope.goBack = function () {
    $state.go('login');
  };
}]);
'use strict';

mealBuilderController.$inject = ["$rootScope", "$scope", "$state", "CacheFactory", "$timeout", "NixService"];
angular.module('Track').controller('mealBuilderController', mealBuilderController);

function mealBuilderController($rootScope, $scope, $state, CacheFactory, $timeout, NixService) {
  function flashMealBuilder(className, timeToLive) {
    $rootScope.mealBuilderClass = 'has-mealbuilder';
    $scope.flashActive = className;
    $timeout(function () {
      $scope.flashActive = '';
    }, timeToLive);
  }

  $rootScope.$on('$ionicView.enter', function () {
    CacheFactory.getMealBuilderFoods().then(function (mealBuilder) {
      $rootScope.itemsInBuilder = mealBuilder;
      addUpCalories(mealBuilder);

      if ($rootScope.itemsInBuilder.length < 1) {
        $rootScope.mealBuilderClass = '';
      }
    });
  });
  $rootScope.$on('mealBuilder: addFood', function (e, value) {
    CacheFactory.getMealBuilderFoods().then(function (mealBuilder) {
      value.foodArray.forEach(function (item) {
        var className;

        if (!item.full_nutrients && !item.alt_measures) {
          var nixItemId = item._id || null;
          item = window.nutritionixApiDataUtilities.convertV1ItemToTrackFood(item);

          if (!item.alt_measures) {
            if (item.serving_weight_grams) {
              item.alt_measures = [{
                'measure': item.serving_unit,
                'qty': item.serving_qty,
                'seq': null,
                'serving_weight': item.serving_weight_grams
              }, {
                'measure': 'g',
                'qty': 1,
                'seq': 104,
                'serving_weight': 1
              }];
            }
          }
        } else {
          delete item.id;
        }

        if (!item.serving_qty) {
          item.serving_qty = 1;
        } else {
          item.serving_qty = +item.serving_qty.toFixed(2);
        }

        if (!item.serving_unit) {
          item.serving_unit = 'Serving';
        }

        mealBuilder.push(item);
        $rootScope.itemsInBuilder = mealBuilder;
        $rootScope.cartNumber = mealBuilder.length;

        if ($rootScope.itemsInBuilder.length === 1) {
          className = 'flash-meal-builder-2x';
          flashMealBuilder(className, 600);
        } else {
          className = 'flash-meal-builder-1x';
          flashMealBuilder(className, 300);
        }

        addUpCalories(mealBuilder);
      });
      CacheFactory.setMealBuilderFoods(mealBuilder);
    }).then(function () {
      $rootScope.$broadcast('mealBuilder: updated');
    });
  });
  $rootScope.$on('mealBuilder: updateFoods', function () {
    $rootScope.mealBuilderClass = '';
  });
  $rootScope.$on('clearFoods', function () {
    $rootScope.itemsInBuilder = [];
    $scope.itemsInBuilderCalories = 0;
  });

  $scope.goToReviewFoods = function () {
    $state.go('app.reviewFoods');
  };

  function addUpCalories(collection) {
    $scope.itemsInBuilderCalories = _.reduce(collection, function (calSum, food) {
      if (food.nf_calories) return calSum + food.nf_calories;else if (_.find(food.full_nutrients, {
        attr_id: 208
      })) return calSum + _.find(food.full_nutrients, {
        attr_id: 208
      }).value;else return calSum;
    }, 0);
  }
}
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:myCoachController
 * @description
 * # myCoachController
 */

angular.module('Track').controller('myCoachController', ["$scope", "$rootScope", "$ionicHistory", "$state", "$timeout", "$filter", "UserService", "CoachService", function ($scope, $rootScope, $ionicHistory, $state, $timeout, $filter, UserService, CoachService) {
  $scope.$on('$ionicView.beforeEnter', function () {
    $scope.coachesList = [];
    $scope.data = {};
    UserService.getUser().then(function (res) {
      $scope.user = res;

      if (!!$scope.user.premium_user) {
        CoachService.getCoaches().then(function (res) {
          $scope.coachesList = res.data.coaches;
        })["catch"](function (err) {
          console.log('Error getting coaches list', err);
        });
      }
    })["catch"](function (err) {
      console.log('Error getting user data', err);
    });
  });
  $scope.$watch('data.coachCodeView', function (newVal, oldVal) {
    if (!newVal) {
      return;
    }

    $scope.data.coachCodeView = newVal.toUpperCase();

    if (!oldVal || newVal.length > oldVal.length) {
      if (newVal.replace(/-/g, '').length > 2 && newVal.replace(/-/g, '').length < 7) {
        $scope.data.coachCodeView = (newVal.replace(/-/g, '').slice(0, 3) + '-' + newVal.replace(/-/g, '').slice(3, newVal.length)).toUpperCase();
      } else if (newVal.replace(/-/g, '').length > 6) {
        var code = newVal.replace(/-/g, '');
        $scope.data.coachCodeView = [code.substring(0, 3), code.substring(3, 6), code.substring(6, 9)].join('-').toUpperCase();
      }
    } else if (newVal.length < oldVal.length) {
      if (newVal.length == 4 || newVal.length == 8) {
        $scope.data.coachCodeView = newVal.slice(0, newVal.length - 1).toUpperCase();
      }
    }

    $scope.data.coachCode = newVal.replace(/-/g, ''); // if (!!newVal && !!oldVal && newVal.replace('-','').length !== oldVal.replace('-','').length)
    // $scope.addCoach();
  });

  $scope.addCoach = function () {
    if (!$scope.data.coachCode || $scope.data.coachCode.length < 6 && $scope.data.coachCode.length > 6) {
      return;
    }

    if (!!_.find($scope.coachesList, ['code', $scope.data.coachCode.toUpperCase()])) {
      $scope.alreadyInList = true;
      return $timeout(function () {
        $scope.alreadyInList = false;
      }, 2000);
    }

    CoachService.addCoach($scope.data.coachCode).then(function (result) {
      angular.element('#coach_id').val('').blur();
      $scope.coachesList.push(result.data);
      $scope.addSuccess = true;
      $timeout(function () {
        $scope.addSuccess = false;
      }, 2000);
    })["catch"](function (err) {
      $scope.addSuccess = false;

      if (err.status == 400) {
        $scope.noCoachError = true;
        $timeout(function () {
          $scope.noCoachError = false;
        }, 2000);
      } else if (err.status == 402) {
        $scope.showSubscribePrompt = true;
        $scope.coachToAdd = err.data;
      }

      console.log('Error adding coach to the coaches list', err);
    });
  };

  $scope.removeCoach = function (index) {
    var coachCode = $scope.coachesList[index].code;
    CoachService.removeCoach(coachCode).then(function () {
      $scope.coachesList.splice(index, 1);
    });
  };

  $scope.becomeCoach = function () {
    CoachService.becomeCoach().then(function (res) {
      if (!!res && !!res.data && !!res.data.code) {
        UserService.updateUser({});
        $scope.user.coach = {
          code: res.data.code
        };
        $rootScope.isCoach = true;
      }
    })["catch"](function (err) {
      console.log('there was an error', angular.toJson(err));
    });
  };

  $scope.stopBeingCoach = function () {
    CoachService.stopBeingCoach().then(function () {
      return UserService.getUser().then(function (res) {
        $scope.user = res;

        if (!!$scope.user && !!$scope.user.coach) {
          $rootScope.isCoach = true;
        } else {
          $rootScope.isCoach = false;
        }
      });
    })["catch"](function (err) {
      console.log('there was an error', angular.toJson(err));
    });
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:myRecipes2Controller
 * @description
 * # myRecipes2Controller
 */

angular.module('Track').controller('myRecipes2Controller', ["$scope", "$rootScope", "$state", "$stateParams", "$ionicPopup", "$ionicListDelegate", "$timeout", "AnalyticsService", "Recipe2Service", "HelperService", "CacheFactory", function ($scope, $rootScope, $state, $stateParams, $ionicPopup, $ionicListDelegate, $timeout, AnalyticsService, Recipe2Service, HelperService, CacheFactory) {
  $scope.recipes = [];
  $scope.loadingData = true;
  $scope.recipesLimit = 25;
  $scope.recipesOffset = 0;
  $scope.searchFilter = '';
  $scope.search = '';

  $scope.loadRecipes = function () {
    Recipe2Service.getMyRecipes({
      limit: $scope.recipesLimit,
      offset: $scope.recipesOffset
    }).then(function (resp) {
      $scope.recipes = $scope.recipes.concat(resp.data.recipes);
      $scope.loadingData = false;
    })["catch"](function (err) {
      console.log('There was an error getting recipes', err);
    });
  };

  var filterTimeout, tempVal;
  $scope.$watch('search', function (oldVal, newVal) {
    if (!!newVal && !!oldVal) {
      if (!!filterTimeout) {
        $timeout.cancel(filterTimeout);
      }

      tempVal = newVal;
      filterTimeout = $timeout(function () {
        $scope.searchFilter = tempVal;
      }, 300);
    }
  });
  $scope.loadRecipes();

  $scope.loadMoreRecipes = function () {
    $scope.recipesOffset += $scope.recipesLimit;
    $scope.loadRecipes();
  };

  $scope.showSavedRecipeMessage = $stateParams.showSavedRecipeMessage || false;

  if ($stateParams.showSavedRecipeMessage) {
    $timeout(function () {
      $scope.showSavedRecipeMessage = false;
    }, 2500);
  }

  $scope.$on('$ionicView.enter', function (event, data) {
    AnalyticsService.trackView('My Recipes');
  });

  $scope.goToCreateRecipe = function () {
    $state.go('app.editRecipe2');
  };

  $scope.editRecipe = function (recipe) {
    $state.go('app.editRecipe2', {
      id: recipe.id
    });
  };

  $scope.copyRecipe = function (recipe) {
    var cloneRecipeIndex = $scope.recipes.indexOf(recipe);
    $scope.clonedRecipe = _.cloneDeep(recipe);
    delete $scope.clonedRecipe.created_at;
    delete $scope.clonedRecipe.updated_at;
    delete $scope.clonedRecipe.id;
    $scope.clonedRecipe.newRecipeName = $scope.clonedRecipe.name;
    $ionicPopup.show({
      'title': 'Copy Recipe',
      scope: $scope,
      'template': 'Enter new unique name for the new recipe <br/><input type="text" ng-model="clonedRecipe.newRecipeName" />',
      buttons: [{
        'text': 'Cancel',
        'type': 'button-default',
        onTap: function onTap() {
          $scope.clonedRecipe = null;
          $scope.newRecipeName = null;
        }
      }, {
        'text': 'Sumbit',
        'type': 'button-positive',
        onTap: function onTap(e) {
          var match = _.find($scope.recipes, function (recipe) {
            return recipe.name == $scope.clonedRecipe.newRecipeName;
          });

          if ($scope.clonedRecipe.newRecipeName === $scope.clonedRecipe.name || !!match || !_.isEmpty(match)) {
            e.preventDefault();
            errorMessage();
            match = null;
          } else {
            $scope.clonedRecipe.name = $scope.clonedRecipe.newRecipeName;
            return Recipe2Service.addRecipe($scope.clonedRecipe).then(function (res) {
              delete $scope.clonedRecipe;
              $ionicListDelegate.closeOptionButtons();
              $scope.recipes.splice(cloneRecipeIndex + 1, 0, res.data);
              AnalyticsService.trackEvent('Recipe copied', 'Copied from the recipes interface');
            })["catch"](function (err) {
              if (!!err && !!err.data && !!err.data.message && err.data.message == 'resource already exists') {
                errorMessage(err);
                delete $scope.clonedRecipe;
                return console.log('resource already exists');
              } else {
                throw err;
              }
            });
          }
        }
      }]
    });
  };

  $scope.showNewRecipeTag = function (created_at) {
    return moment(created_at).isAfter(moment().subtract('5', 'day'));
  };

  var errorMessage = function errorMessage(err) {
    $ionicPopup.alert({
      'title': 'Error',
      'template': 'Recipe name must be unique',
      buttons: [{
        'text': 'Close',
        'type': 'button-positive'
      }]
    });
  };

  $scope.deleteRecipe = function (index, recipe_id) {
    Recipe2Service.deleteRecipe(recipe_id);
    $scope.recipes.splice(index, 1);
  };

  $scope.showCreateHint = function () {
    $scope.alert = $ionicPopup.alert({
      'title': 'Create Recipe',
      'scope': $scope,
      'template': 'To create a recipe, tap the + Track button on the bottom of your screen, add ingredients to your basket, and select "single food" on the review basket page. <a href ng-click="alert.close()" ui-sref="app.reviewFoods"> Tap here </a> to go directly to your basket to start creating a recipe.',
      buttons: [{
        'text': 'Close',
        'type': 'button-positive'
      }]
    });
  };

  $scope.logRecipe = function (recipeId) {
    Recipe2Service.getRecipeById(recipeId).then(function (resp) {
      _.forEach(resp.data.ingredients, function (foodObj) {
        if (foodObj.alt_measures) {
          var temp = {
            'serving_weight': foodObj.serving_weight_grams,
            'seq': null,
            'measure': foodObj.serving_unit,
            'qty': foodObj.serving_qty
          };
          foodObj.alt_measures.unshift(temp);
        }
      });

      var serving_qty = resp.data.serving_qty;
      var instruct_copy = resp.data.directions;

      var recipeToLog = _.cloneDeep(resp.data); // need to do this for top level as well as each ingredient


      var nf = window.nutritionixApiDataUtilities.convertFullNutrientsToNfAttributes(recipeToLog.full_nutrients);
      var accepted = ['nf_calories', 'nf_total_fat', 'nf_saturated_fat', 'nf_cholesterol', 'nf_sodium', 'nf_total_carbohydrate', 'nf_dietary_fiber', 'nf_sugars', 'nf_protein', 'nf_potassium', 'nf_p'];

      var keep = _.pick(nf, accepted);

      _.extend(recipeToLog, keep);

      _.forEach(recipeToLog.ingredients, function (ingredient) {
        var ing_nf = window.nutritionixApiDataUtilities.convertFullNutrientsToNfAttributes(ingredient.full_nutrients);

        var ing_keep = _.pick(ing_nf, accepted);

        ingredient.consumed_at = undefined;

        _.extend(ingredient, ing_keep);
      }); //only want to log 1 serving


      var scaled_recipe = HelperService.multiply(recipeToLog, 1 / serving_qty, 1);
      $rootScope.$broadcast('mealBuilder: addFood', {
        foodArray: scaled_recipe.ingredients
      });
      AnalyticsService.trackEvent('Added recipe to the basket', 'Quick log from the My Recipes');

      if (!!scaled_recipe.photo && !!scaled_recipe.photo.highres) {
        var customPhoto = {
          full: scaled_recipe.photo.highres || null,
          thumb: scaled_recipe.photo.thumb
        };
        window.localStorage.setItem('reviewBasketCustomPhoto', angular.toJson(customPhoto));
      }

      $state.go('app.reviewFoods', {
        type: 'singleFood',
        name: scaled_recipe.name,
        recipeBrand: scaled_recipe.brand_name || null,
        servings: serving_qty
      });
    });
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:MyFoodsController
 * @description
 * # MyFoodsController
 */

angular.module('Track').controller('myRecipesController', ["$scope", "$rootScope", "$state", "$stateParams", "$ionicPopup", "$timeout", "RecipeService", "HelperService", "CacheFactory", function ($scope, $rootScope, $state, $stateParams, $ionicPopup, $timeout, RecipeService, HelperService, CacheFactory) {
  $scope.recipes = [];
  $scope.customFoods = [];
  $scope.allCustom = [];
  RecipeService.getMyFoods().then(function (resp) {
    $scope.recipes = _.filter(resp, function (recipe) {
      return recipe.source === 4;
    });
    $scope.customFoods = _.filter(resp, function (recipe) {
      return recipe.source === 9;
    });
    $scope.allCustom = _.filter(resp, function (recipe) {
      return recipe.source === 4 || recipe.source === 9;
    });
  }).then(function () {
    $scope.filteredFoods = $scope.selectedFilter === 'recipes' ? $scope.recipes : $scope.selectedFilter === 'custom' ? $scope.customFoods : $scope.allCustom;
  });
  $scope.filteredFoods = $scope.recipes;
  $scope.selectedFilter = $stateParams.selectedFilter || 'recipes';
  $scope.showSavedRecipeMessage = $stateParams.showSavedRecipeMessage || false;

  if ($stateParams.showSavedRecipeMessage) {
    $timeout(function () {
      $scope.showSavedRecipeMessage = false;
    }, 2500);
  }

  $scope.searchTitle = $scope.selectedFilter === 'recipes' ? 'my recipes' : $scope.selectedFilter === 'custom' ? 'custom foods' : 'all foods';

  $scope.changeFoodsFilter = function (newFilter) {
    $scope.search = '';
    $scope.selectedFilter = newFilter;
    $scope.searchTitle = newFilter === 'recipes' ? 'my recipes' : newFilter === 'custom' ? 'custom foods' : 'all foods';
    $scope.filteredFoods = newFilter === 'recipes' ? $scope.recipes : newFilter === 'custom' ? $scope.customFoods : $scope.allCustom;
  };

  $scope.goToCreateFood = function () {
    $state.go('app.createFood');
  };

  $scope.editRecipe = function (recipe) {
    if (recipe.source === 9) {
      $state.go('app.customFood', {
        customFoodId: recipe.id
      });
    } else {
      $state.go('app.editRecipe', {
        id: recipe.id
      });
    }
  };

  $scope.deleteRecipe = function (index, recipe_id) {
    RecipeService.deleteRecipe(recipe_id);

    var recipesIndex = _.findIndex($scope.recipes, function (recipe) {
      return recipe.id == recipe_id;
    });

    var customIndex = _.findIndex($scope.customFoods, function (recipe) {
      return recipe.id == recipe_id;
    });

    var allCustomIndex = _.findIndex($scope.allCustom, function (recipe) {
      return recipe.id == recipe_id;
    });

    if (recipesIndex > -1) {
      $scope.recipes.splice(recipesIndex, 1);
    }

    if (customIndex > -1) {
      $scope.customFoods.splice(customIndex, 1);
    }

    if (allCustomIndex > -1) {
      $scope.allCustom.splice(allCustomIndex, 1);
    }
  };

  $scope.showCreateHint = function () {
    $scope.alert = $ionicPopup.alert({
      'title': 'Create Recipe',
      'scope': $scope,
      'template': 'To create a recipe, tap the + Track button on the bottom of your screen, add ingredients to your basket, and select "single food" on the review basket page. <a href ng-click="alert.close()" ui-sref="app.reviewFoods"> Tap here </a> to go directly to your basket to start creating a recipe.',
      buttons: [{
        'text': 'Close',
        'type': 'button-positive'
      }]
    });
  };

  $scope.logRecipe = function (recipeId) {
    RecipeService.getRecipeById(recipeId).then(function (resp) {
      _.forEach(resp.data.ingredients, function (foodObj) {
        if (foodObj.alt_measures) {
          var temp = {
            'serving_weight': foodObj.serving_weight_grams,
            'seq': null,
            'measure': foodObj.serving_unit,
            'qty': foodObj.serving_qty
          };
          foodObj.alt_measures.unshift(temp);
        }
      });

      var serving_qty = resp.data.serving_qty;
      var instruct_copy = resp.data.directions;

      var recipeToLog = _.cloneDeep(resp.data); // need to do this for top level as well as each ingredient


      var nf = window.nutritionixApiDataUtilities.convertFullNutrientsToNfAttributes(recipeToLog.full_nutrients);
      var accepted = ['nf_calories', 'nf_total_fat', 'nf_saturated_fat', 'nf_cholesterol', 'nf_sodium', 'nf_total_carbohydrate', 'nf_dietary_fiber', 'nf_sugars', 'nf_protein', 'nf_potassium', 'nf_p'];

      var keep = _.pick(nf, accepted);

      _.extend(recipeToLog, keep);

      _.forEach(recipeToLog.ingredients, function (ingredient) {
        var ing_nf = window.nutritionixApiDataUtilities.convertFullNutrientsToNfAttributes(ingredient.full_nutrients);

        var ing_keep = _.pick(ing_nf, accepted);

        _.extend(ingredient, ing_keep);
      }); //only want to log 1 serving


      var scaled_recipe = HelperService.multiply(recipeToLog, 1 / serving_qty, 1);

      if (recipeToLog.source === 9) {
        CacheFactory.getMealBuilderFoods().then(function (mb) {
          $rootScope.itemsInBuilder = mb;
          return $rootScope.itemsInBuilder.push(scaled_recipe);
        }).then(function () {
          CacheFactory.setMealBuilderFoods($rootScope.itemsInBuilder);
          $state.go('app.reviewFoods');
        });
      } else if (recipeToLog.source === 4) {
        $rootScope.$broadcast('mealBuilder: addFood', {
          foodArray: scaled_recipe.ingredients
        });
        $state.go('app.reviewFoods', {
          type: 'singleFood',
          name: scaled_recipe.food_name,
          recipeBrand: scaled_recipe.brand_name || null,
          servings: serving_qty
        });
      }
    });
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:NewRecipeController
 * @description
 * # NewRecipeController
 */

angular.module('Track').controller('newRecipeController', ["$scope", "$state", "$ionicPopup", "$timeout", "RecipeService", function ($scope, $state, $ionicPopup, $timeout, RecipeService) {
  $scope.goBack = function () {
    $state.go('app.recipes');
  };

  $scope.isProcessingFood = false;
  $scope.invalidForm = false;
  $scope.food = {
    source: 4,
    source_key: null,
    serving_qty: 1,
    serving_unit: 'Serving'
  };

  $scope.submitRecipe = function () {
    return submit();
  };

  function resubmitRecipe(newName) {
    $scope.food.food_name = newName;
    return submit();
  } //want to be able to access this from the template ($scope) and within this class


  function submit() {
    if ($scope.isProcessingFood) {
      return false;
    }

    $scope.invalidForm = false;

    if (!$scope.food.food_name || !$scope.food.ingredients || !$scope.food.serving_qty || !$scope.food.serving_unit) {
      $scope.invalidForm = true;
      return $timeout(function () {
        $scope.invalidForm = false;
      }, 500);
    }

    RecipeService.addRecipe($scope.food).then(function () {
      return $state.go('app.recipes', {
        showSavedRecipeMessage: true
      });
    })["catch"](function (err) {
      if (err.status === 409) {
        return errorPromptUser(err);
      } else {
        return errorMessage(err);
      }
    });
  }

  function errorMessage(err) {
    $scope.invalidForm = true;
    $timeout(function () {
      $scope.invalidForm = false;
    }, 500);
    $ionicPopup.alert({
      title: err.data.message + ' for:',
      template: '<div>' + $scope.food.ingredients + '</div>',
      buttons: [{
        text: 'Ok',
        type: 'button-balanced'
      }]
    });
  }

  function errorPromptUser(err) {
    $scope.invalidForm = true;
    $timeout(function () {
      $scope.invalidForm = false;
    }, 500);
    $scope.newrecipe = {};
    $ionicPopup.show({
      template: '<input type="text" ng-model="newrecipe.name" focus-me="true">',
      title: 'Please Enter New Recipe Name',
      subTitle: 'Recipe with that name already exists',
      scope: $scope,
      buttons: [{
        text: 'Cancel'
      }, {
        text: 'Save',
        type: 'button-positive',
        onTap: function onTap() {
          resubmitRecipe($scope.newrecipe.name);
        }
      }]
    });
  }
}]);
/************* File is deprecated ************/
'use strict';

angular.module('Track').controller('onboardingController', ["$scope", "$state", "ApiService", "UserService", function ($scope, $state, ApiService, UserService) {
  ApiService.getUserData().then(function (me) {
    UserService.updateUser(me.data);
    $scope.user = {
      first_name: me.data.first_name,
      daily_kcal: !!me.data.daily_kcal,
      sms: !!me.data.enable_weekday_sms,
      fitbit: !!_.find(me.data.oauths, {
        provider: 'fitbit'
      })
    };
  });
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:PreferencesController
 * @description
 * # PreferencesController
 */

angular.module('Track').controller('PreferencesController', ["UserService", "ApiService", "$scope", "$state", "$cordovaDevice", "$cordovaAppVersion", "$ionicHistory", "$ionicViewSwitcher", "AnalyticsService", function (UserService, ApiService, $scope, $state, $cordovaDevice, $cordovaAppVersion, $ionicHistory, $ionicViewSwitcher, AnalyticsService) {
  var vm = this;
  vm.hideDevOptions = true; // Get App Version and Build Identifier for Android Platform

  if ($cordovaDevice.getPlatform() === 'Android') {
    $cordovaAppVersion.getVersionNumber().then(function (version) {
      $scope.versionNumber = version;
    });
    $cordovaAppVersion.getVersionCode().then(function (buildID) {
      $scope.buildIdentifier = buildID;
    }); // vm.hideDevOptions = true;
  }

  ApiService.getUserData().then(function (user) {
    if (!!user.data) {
      UserService.setUser(user.data);
      return user.data;
    } else {
      return UserService.getUser().then(function (user) {
        return user;
      });
    }
  }).then(function (user) {
    window.localStorage.setItem('userPreferences', angular.toJson(user));
    vm.user = user;
  })["catch"](function (err) {
    console.log('there was an err', angular.toJson(err));
    return UserService.getUser().then(function (res) {
      window.localStorage.setItem('userPreferences', angular.toJson(res));
      vm.user = res;
    });
  });
  $scope.$on('$ionicView.enter', function (event, data) {
    AnalyticsService.trackView('Preferences');
  });

  vm.goToCalculateDailyCalories = function () {
    $state.go('app.calculateDailyCalories');
  };

  vm.goToConnectedApps = function () {
    $state.go('app.connectedApps');
  };

  vm.goToPushNotifications = function () {
    $state.go('app.pushNotifications');
  };

  vm.goBack = function () {
    $ionicViewSwitcher.nextDirection('back');
    $ionicHistory.goBack() ? $ionicHistory.backView() : $state.go('app.foodlog');
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:productRecommendationsController
 * @description
 * # productRecommendationsController
 */

angular.module('Track').controller('productRecommendationsController', ["$scope", "$rootScope", "$state", "$http", "AnalyticsService", "UserService", function ($scope, $rootScope, $state, $http, AnalyticsService, UserService) {
  UserService.getUser().then(function (result) {
    $scope.user = result;
  });

  if (!$rootScope.noInternet) {
    $http.get('https://nix-export.s3.amazonaws.com/recommended_products.json.gz').then(function (res) {
      $scope.products = res.data.products;
    });
  }

  $scope.$on('$ionicView.enter', function () {
    AnalyticsService.trackView('Recommended products');
  });

  $scope.openProductLink = function (product) {
    // var url = 'amzn:'+"https://www.amazon.com/gp/product/B004U3Y8NI/ref=as_li_tl?ie=UTF8&camp=1789&creative=9325&creativeASIN=B004U3Y8NI&linkCode=as2&tag=nutritionix07-20&linkId=3534ab3df0db94fc6641dd2cc0791354"
    window.open(product.url, '_system');
  };

  $scope.goBack = function () {
    $state.go('app.foodlog');
  };
}]);
'use strict';

angular.module('Track').controller('ProfileController', ["$cordovaDevice", "$ionicHistory", "$ionicPopup", "$rootScope", "$scope", "ApiService", "UserService", "nixTrackApiClient", function ($cordovaDevice, $ionicHistory, $ionicPopup, $rootScope, $scope, ApiService, UserService, nixTrackApiClient) {
  var vm = this;
  var currentUser;
  var cmToinches;
  var sysMap = {
    0: 'imperial',
    1: 'metric'
  };
  vm.timezones = moment.tz.names();
  $scope.$on('$ionicView.beforeEnter', function (event, data) {
    UserService.getUser().then(function (result) {
      currentUser = result;
      vm.firstName = currentUser.first_name;
      vm.lastName = currentUser.last_name;
      vm.timezone = currentUser.timezone;
      vm.gender = currentUser.gender;
      vm.age = new Date().getFullYear() - currentUser.birth_year;

      if (vm.age > 100) {
        vm.age = 30;
      }

      vm.unitSystem = sysMap[currentUser.measure_system] || sysMap['0']; // weight

      vm.weight = {
        kg: currentUser.weight_kg,
        lb: _.round(currentUser.weight_kg * 2.20462, 2)
      };
      vm.weightView = {
        kg: _.round(currentUser.weight_kg, 1),
        lb: _.round(currentUser.weight_kg * 2.20462, 1)
      }; // height

      cmToinches = currentUser.height_cm * 0.393701;
      vm.height = {
        cm: currentUser.height_cm,
        ft: _.floor(cmToinches / 12),
        inch: _.round(cmToinches % 12, 2)
      };
      vm.heightView = {
        cm: _.round(currentUser.height_cm),
        ft: _.floor(cmToinches / 12),
        inch: _.round(cmToinches % 12, 0)
      };
      vm.initialData = {
        first_name: currentUser.first_name,
        last_name: currentUser.last_name,
        timezone: currentUser.timezone,
        gender: currentUser.gender,
        birth_year: currentUser.birth_year,
        measure_system: currentUser.measure_system,
        weight_kg: currentUser.weight_kg,
        height_cm: currentUser.height_cm
      };
    });

    if ($cordovaDevice.getPlatform() == 'iOS') {
      window.addEventListener('native.keyboardshow', keyboardShowHandler);
      window.addEventListener('native.keyboardhide', keyboardHideHandler);
    }

    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(false);
    }
  });
  $scope.$on('$ionicView.beforeLeave', function (event, data) {
    if ($cordovaDevice.getPlatform() == 'iOS') {
      window.removeEventListener('native.keyboardshow', keyboardShowHandler);
      window.removeEventListener('native.keyboardhide', keyboardHideHandler);
    }

    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
    }
  });

  function keyboardShowHandler(e) {
    $scope.iosFloatingButtonAdjustment = e.keyboardHeight;
    $scope.$apply();
  }

  function keyboardHideHandler(e) {
    $scope.iosFloatingButtonAdjustment = 0;
    $scope.$apply();
  }

  $scope.$watch('vm.weightView', function (newValue, oldValue) {
    if (!newValue || !oldValue) {
      return;
    }

    if (!vm.weight) {
      vm.weight = {};
    }

    if (newValue.kg === oldValue.kg) {
      vm.weight.lb = vm.weightView.lb;
    } else {
      vm.weight.kg = vm.weightView.kg;
    }

    vm.calculateWeights();
  }, true);
  $scope.$watch('vm.heightView', function (newValue, oldValue) {
    if (!newValue || !oldValue) {
      return;
    }

    Object.assign(vm.height, newValue);
    vm.calculateHeights();
  }, true);

  vm.goBack = function () {
    return $ionicHistory.goBack();
  };

  vm.changeUnitSystem = function () {
    vm.calculateWeights(vm.unitSystem === 'metric' ? 'imperial' : 'metric');
    vm.calculateHeights(vm.unitSystem === 'metric' ? 'imperial' : 'metric');
  };

  vm.calculateWeights = function (unitSystem) {
    if (!vm.weight) {
      return;
    }

    if ((unitSystem || vm.unitSystem) === 'metric') {
      vm.weight.lb = _.round(vm.weight.kg * 2.20462, 2);
      vm.weightView.lb = _.round(vm.weight.lb, 1);
    } else {
      vm.weight.kg = _.round(vm.weight.lb * 0.453592, 2);
      vm.weightView.kg = _.round(vm.weight.kg, 1);
    }
  };

  vm.calculateHeights = function (unitSystem) {
    if ((unitSystem || vm.unitSystem) === 'metric') {
      vm.height.inch = _.round(vm.height.cm * 0.393701, 2);

      if (vm.height.inch > 12) {
        vm.height.ft = _.floor(vm.height.inch / 12);
        vm.height.inch -= vm.height.ft * 12;
      } else {
        vm.height.ft = 0;
      }

      vm.heightView.ft = vm.height.ft;
      vm.heightView.inch = _.round(vm.height.inch);
    } else {
      vm.height.cm = _.round((vm.height.ft || 0) * 30.48 + (vm.height.inch || 0) * 2.54, 2);
      vm.heightView.cm = _.round(vm.height.cm);
    }
  };

  vm.changeProfile = function () {
    if ($rootScope.noInternet) {
      $ionicPopup.alert({
        title: 'Not available in offline mode.',
        buttons: [{
          text: 'Ok',
          type: 'button-balanced'
        }]
      });
      return;
    }

    var updatedData = {};
    if (vm.firstName) updatedData.first_name = vm.firstName;
    if (vm.lastName) updatedData.last_name = vm.lastName;
    if (vm.timezone) updatedData.timezone = vm.timezone;
    if (vm.unitSystem) updatedData.measure_system = _.findKey(sysMap, function (o) {
      return o == vm.unitSystem;
    });
    if (vm.gender) updatedData.gender = vm.gender;

    if (vm.weight.kg && vm.weight.kg !== 0 && vm.initialData.weight_kg !== vm.weight.kg) {
      updatedData.weight_kg = parseFloat(vm.weight.kg);
    }

    if (vm.height.cm && vm.height.cm !== 0) {
      updatedData.height_cm = vm.height.cm;
    }

    if (vm.age && vm.age !== 0) {
      updatedData.birth_year = new Date().getFullYear() - vm.age;
    }

    nixTrackApiClient.me.preferences(updatedData).success(function (response) {
      var data = response;
      UserService.getUser().then(function (user) {
        var changedProfile = user;
        changedProfile.first_name = data.first_name;
        changedProfile.last_name = data.last_name;
        changedProfile.timezone = data.timezone;
        changedProfile.measure_system = data.measure_system;
        changedProfile.gender = data.gender;
        changedProfile.weight_kg = data.weight_kg;
        changedProfile.height_cm = data.height_cm;
        changedProfile.birth_year = data.birth_year;
        UserService.updateUser(changedProfile);
        vm.goBack();
      });
    })["catch"](function (err) {
      throw new Error(err);
    });
  };

  vm.isDataChanged = function () {
    if (!vm.initialData || !vm.firstName) {
      return false;
    }

    if (vm.initialData.birth_year !== new Date().getFullYear() - vm.age || vm.initialData.first_name !== vm.firstName || vm.initialData.gender !== vm.gender || vm.initialData.height_cm !== vm.height.cm || vm.initialData.last_name !== vm.lastName || vm.initialData.measure_system !== (vm.unitSystem === 'imperial' ? 0 : 1) || vm.initialData.timezone !== vm.timezone || vm.initialData.weight_kg !== parseFloat(vm.weight.kg)) {
      return true;
    }

    return false;
  };

  vm.requestPasswordUpdate = function () {
    $scope.request = {
      email: ''
    };
    $ionicPopup.show({
      title: 'Please type your email',
      template: "\n          <div>\n            <input type=\"email\" placeholder=\"What is your email address?\" ng-model=\"request.email\"/>\n          </div>\n        ",
      scope: $scope,
      buttons: [{
        text: 'Submit',
        type: 'button-balanced',
        onTap: function onTap() {
          ApiService.requestUpdatePassword($scope.request.email).then(function (res) {
            return $ionicPopup.alert({
              title: 'Success',
              template: '<div class="text-center">Thanks! Please check your email to continue.</div>'
            });
          })["catch"](function (err) {
            console.log(err);

            if (err.data.message == 'No user matched') {
              $ionicPopup.alert({
                title: 'Error',
                template: '<div class="text-center">Something’s not right. Please reach us at support@nutritionix.com.</div>'
              });
            }
          });
        }
      }, {
        text: 'Cancel',
        type: 'button-default'
      }]
    });
  };

  vm.requestEmailChange = function () {
    $scope.request = {
      email: '',
      oldEmail: currentUser.email
    };
    $ionicPopup.show({
      title: 'Email change',
      template: "\n          <div>\n            Old Email\n            <input type=\"email\" placeholder=\"Old Email\" ng-model=\"request.oldEmail\"/>\n          </div>\n          <div>\n            New Email\n            <input type=\"email\" placeholder=\"New Email\" ng-model=\"request.email\" required/>\n          </div>\n        ",
      scope: $scope,
      buttons: [{
        text: 'Submit',
        type: 'button-balanced',
        onTap: function onTap() {
          if (!$scope.request.email || !$scope.request.oldEmail) {
            return $ionicPopup.alert({
              title: 'Error',
              template: '<div class="text-center">Both fields are required</div>'
            });
          } else if ($scope.request.email === $scope.request.oldEmail) {
            return $ionicPopup.alert({
              title: 'Error',
              template: '<div class="text-center">New email address is the same.</div>'
            });
          } else {
            // === old logic. use when email verification will be ON on backend ===
            // ApiService.requestEmailChange($scope.request.email)
            //   .then(function(res){
            //     return $ionicPopup.alert({
            //       title:'Success',
            //       template:'<div class="text-center">Thanks! Please check your email to continue.</div>'
            //     });
            //   })
            //   .catch(function(err){
            //     console.log(err);
            //     if (err.data.message == 'No user matched'){
            //       $ionicPopup.alert({
            //         title:'Error',
            //         template:'<div class="text-center">Something’s not right. Please reach us at support@nutritionix.com.</div>'
            //       });
            //     }
            //   });
            UserService.updateUser({
              email: $scope.request.email
            }).then(function () {
              return UserService.getUser().then(function (user) {
                currentUser = user;
                return;
              });
            }).then(function (res) {
              return $ionicPopup.alert({
                title: 'Success',
                template: '<div class="text-center">Your email has been changed</div>'
              });
            });
          }
        }
      }, {
        text: 'Cancel',
        type: 'button-default'
      }]
    });
  };
}]);
'use strict';
/**
* @ngdoc function
* @name Track.controller:pushNotificationsController
* @description
* # PushNotificationsController
*/

angular.module('Track').controller('pushNotificationsController', ["$scope", "$ionicHistory", "AnalyticsService", "UserService", "PushNotificationService", function ($scope, $ionicHistory, AnalyticsService, UserService, PushNotificationService) {
  $scope.loadMe = function () {
    UserService.getUser().then(function (me) {
      $scope.options = {
        toggle_weekday: !!me.weekday_reminders_enabled,
        toggle_weekend: !!me.weekend_reminders_enabled,
        id: me.id
      };
    });
  };

  $scope.loadMe();
  $scope.$on('$ionicView.enter', function (event, data) {
    AnalyticsService.trackView('Push Notifications');
  });

  $scope.goBack = function () {
    $ionicHistory.goBack();
  };

  $scope.toggleReminderWeekday = function () {
    UserService.togglePN(0, $scope.options.toggle_weekday).then(function () {
      // if both toggles are orig off and one is turned on, need to init
      // if one toggle is on orig and now both are off, need to remove tags
      // otherwise, dont need to init or remove
      // if ($scope.options.toggle_weekday && !$scope.options.toggle_weekend) {
      // console.log('begin PN init');
      // PushNotificationService.initPushwoosh()
      // .then(function() {
      //   PushNotificationService.mergeTagsToUser($scope.options.id, 1);
      // });
      // } else if (!$scope.options.toggle_weekday && !$scope.options.toggle_weekend) {
      // PushNotificationService.mergeTagsToUser($scope.options.id, 0)
      //   .then(function () {
      //     console.log('unlinking user to PN service');
      //     window.sessionStorage.setItem('PW_register', false);
      //   });
      // }
      PushNotificationService.scheduleNotifications($scope.options.toggle_weekday, $scope.options.toggle_weekend);
    });
  };

  $scope.toggleReminderWeekend = function () {
    UserService.togglePN(1, $scope.options.toggle_weekend).then(function () {
      // if both toggles are orig off and one is turned on, need to init
      // if one toggle is on orig and now both are off, need to remove tags
      // otherwise, dont need to init or remove
      // if ($scope.options.toggle_weekend && !$scope.options.toggle_weekday) {
      //   console.log('begin PN init');
      //   PushNotificationService.initPushwoosh()
      //   .then(function() {
      //     PushNotificationService.mergeTagsToUser($scope.options.id, 1);
      //   });
      // } else if (!$scope.options.toggle_weekend && !$scope.options.toggle_weekday) {
      //   PushNotificationService.mergeTagsToUser($scope.options.id, 0)
      //     .then(function () {
      //       console.log('unlinking user to PN service');
      //       window.sessionStorage.setItem('PW_register', false);
      //     });
      // }
      PushNotificationService.scheduleNotifications($scope.options.toggle_weekday, $scope.options.toggle_weekend);
    });
  };
}]);
'use strict';

angular.module('Track').controller('registrationController', ["$scope", "$http", "$stateParams", "$state", "$ionicPopup", "LoginService", "UserService", function ($scope, $http, $stateParams, $state, $ionicPopup, LoginService, UserService) {
  //if email was passed through from step1, dont ask for it again
  $scope.fields = {
    email: $stateParams.email,
    country_code: $stateParams.country_code || 840
  }; //if email was not passed, ask for it and store

  $scope.registration = {
    email: null,
    pushNotificationsWeekday: false,
    pushNotificationsWeekend: false
  };
  $http.get('https://trackapi.nutritionix.com/v2/nutrition_topics').then(function (res) {
    $scope.topics = res.data.topics;
    $scope.topicsList = '';

    for (var i = 0; i < $scope.topics.length; i++) {
      $scope.topicsList = $scope.topicsList + '<ion-item>' + $scope.topics[i].name + '</ion-item>';
    }
  });

  $scope.shopTopicsPopup = function () {
    $ionicPopup.show({
      title: 'Select topics',
      template: '<ion-list><ion-checkbox ng-repeat="topic in topics" ng-model="topic.is_selected">{{topic.name}}</ion-checkbox></ion-list>',
      scope: $scope,
      buttons: [{
        text: 'Done',
        type: 'button-positive'
      }]
    });
  };

  $scope.openTOS = function () {
    cordova.InAppBrowser.open('http://www.nutritionix.com/terms', '_blank', 'location=no');
    return false;
  };

  $scope.openPrivacy = function () {
    cordova.InAppBrowser.open('https://www.nutritionix.com/privacy', '_blank', 'location=no');
    return false;
  };

  $scope.createAccount = function () {
    // if email is inputted, send verification link to email and then save daily_kcal
    if ($scope.registration.email) {
      LoginService.sendEmailVerification($scope.registration.email).then(function () {
        if ($scope.registration.pushNotificationsWeekday) {
          UserService.togglePN(0, $scope.registration.pushNotificationsWeekday);
        }

        if ($scope.registration.pushNotificationsWeekend) {
          UserService.togglePN(1, $scope.registration.pushNotificationsWeekend);
        }

        return;
      }).then(function () {
        var selectedTopics = [];

        for (var i = 0; i < $scope.topics.length; i++) {
          if ($scope.topics[i].is_selected) {
            selectedTopics.push($scope.topics[i].id);
          }
        }

        return UserService.updateUser({
          nutrition_topics: selectedTopics,
          country_code: $scope.fields.country_code
        });
      }).then(function () {
        return setDailyKcal();
      })["catch"](function (error) {
        return $ionicPopup.alert({
          title: 'Account Creation Failed',
          template: 'An unexpected server error has occured. Please email support@nutitionix.com and reference the reference code: ' + error.data.id
        });
      });
    } else {
      if ($scope.registration.pushNotificationsWeekday) {
        UserService.togglePN(0, $scope.registration.pushNotificationsWeekday);
      }

      if ($scope.registration.pushNotificationsWeekend) {
        UserService.togglePN(1, $scope.registration.pushNotificationsWeekend);
      }

      var selectedTopics = [];

      for (var i = 0; i < $scope.topics.length; i++) {
        if ($scope.topics[i].is_selected) {
          selectedTopics.push($scope.topics[i].id);
        }
      }

      return UserService.updateUser({
        nutrition_topics: selectedTopics,
        country_code: $scope.fields.country_code
      }).then(function () {
        return setDailyKcal();
      });
    }
  };

  function setDailyKcal() {
    return UserService.setDailyCalories(2000).then(function () {
      $state.go('app.foodlog');
    })["catch"](function (error) {
      console.log(angular.toJson(error));
    });
  }
}]);
'use strict';

angular.module('Track').controller('ResetPasswordController', ["$ionicHistory", "$ionicPopup", "$stateParams", "$scope", "$state", "ApiService", function ($ionicHistory, $ionicPopup, $stateParams, $scope, $state, ApiService) {
  var vm = this;
  vm.key = $stateParams.key;
  vm.newPassword = '';
  vm.newPasswordConfirmation = '';

  vm.comparePasswords = function () {
    if (vm.newPasswordConfirmation != vm.newPassword) {
      vm.errorMessage = 'Passwords doesn\'t match';
      return vm.errorMessage;
    } else {
      vm.errorMessage = '';
    }
  };

  vm.setNewPassword = function () {
    if (!vm.newPassword || !vm.newPassword.length) {
      vm.errorMessage = 'Please type new password';
      return vm.errorMessage;
    }

    if (!vm.newPasswordConfirmation || !vm.newPasswordConfirmation.length) {
      vm.errorMessage = 'Please confirm your password';
      return vm.errorMessage;
    }

    if (vm.newPasswordConfirmation != vm.newPassword) {
      vm.errorMessage = 'Passwords doesn\'t match';
      return vm.errorMessage;
    } else {
      vm.errorMessage = '';
    }

    var data = {
      link_hash: vm.key,
      password: vm.newPassword
    };
    ApiService.setNewPassword(data).then(function (result) {
      console.log(result);
      $ionicPopup.alert({
        title: 'Success',
        template: '<div class="text-center">Password successfully changed</div>',
        buttons: [{
          text: 'Ok',
          type: 'button-balanced',
          onTap: function onTap() {
            $state.go('app.foodlog');
          }
        }]
      });
    })["catch"](function (err) {
      console.log(err);

      if (err.data.message === 'Did not match a link') {
        $ionicPopup.alert({
          title: 'Error',
          template: '<div class=\'text-center\'>The link it outdated or invalid. Tap "Resubmit" to send a new link.</div>',
          buttons: [{
            text: 'Resubmit',
            type: 'button-balanced',
            onTap: function onTap() {
              $scope.request = {
                email: ''
              };
              $ionicPopup.show({
                title: 'Please type your email',
                template: "\n                        <div>\n                          <input type=\"email\" placeholder=\"What is your email address?\" ng-model=\"request.email\"/>\n                        </div>\n                      ",
                scope: $scope,
                buttons: [{
                  text: 'Submit',
                  type: 'button-balanced',
                  onTap: function onTap() {
                    ApiService.requestUpdatePassword($scope.request.email).then(function (res) {
                      if (res.data.message == 'update link incoming') {
                        $ionicPopup.alert({
                          title: 'Success',
                          template: '<div class="text-center">Thanks! Please check your email to continue.</div>'
                        });
                      }
                    })["catch"](function (err) {
                      console.log(err);

                      if (err.data.message == 'No user matched') {
                        $ionicPopup.alert({
                          title: 'Error',
                          template: '<div class="text-center">Something’s not right. Please reach us at support@nutritionix.com.</div>'
                        });
                      }
                    });
                  }
                }, {
                  text: 'Cancel',
                  type: 'button-default'
                }]
              });
            }
          }, {
            text: 'Cancel',
            type: 'button-default'
          }]
        });
      }
    });
  };

  vm.goBack = function () {
    if ($ionicHistory.backView() === undefined || $ionicHistory.backView() === null) {
      $state.go('app.foodlog');
    } else {
      $ionicHistory.goBack();
    }
  }; //TODO - success message and return to the foodlog

}]);
'use strict';
/*jshint multistr: true */

/**
 * @ngdoc function
 * @name Track.controller:restaurantCalculatorController
 * @description
 * # restaurantCalculatorController
 */

angular.module('Track').controller('RestaurantCalculatorController', ["$rootScope", "$scope", "$state", "$ionicHistory", "$stateParams", "$sce", function ($rootScope, $scope, $state, $ionicHistory, $stateParams, $sce) {
  $scope.brandName = $stateParams.brand_name;
  $scope.brandId = $stateParams.brand_id; // $scope.calculatorUrl = $sce.trustAsResourceUrl($stateParams.calculatorUrl.replace('m.nutritionix.com','devm.nutritionix.com')+'?embed') || null;

  $scope.calculatorUrl = $sce.trustAsResourceUrl($stateParams.calculatorUrl + '?embed') || null;
  $scope.showPreloader = true;
  $rootScope.$on('$messageIncoming', function (event, data) {
    if (data.returnMenuAppButton) {
      return $scope.goBack();
    }

    if (data.text && data.text === 'calculatorLoaded') {
      $scope.togglePreloader(false);
      return;
    }

    if (!_.has(data, 'full_nutrients')) {
      data.full_nutrients = [];
    }

    for (var key in data) {
      if (_.startsWith(key, 'nf_')) {
        var obj = {};
        obj[key] = data[key];
        data.full_nutrients.push(obj);
      }
    }

    var food = window.nutritionixApiDataUtilities.convertV1ItemToTrackFood(data);
    $rootScope.$broadcast('mealBuilder: addFood', {
      foodArray: [food]
    });
  });

  $scope.togglePreloader = function (status) {
    $scope.showPreloader = status;
  };

  $scope.goToReviewFoods = function () {
    $state.go('app.reviewFoods');
  };

  $scope.goBack = function () {
    $ionicHistory.goBack();
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:restaurantFoodsController
 * @description
 * # restaurantFoodsController
 */

angular.module('Track').controller('restaurantFoodsController', ["$rootScope", "$scope", "foods", "calculatorUrl", "$state", "$stateParams", "$ionicPopup", "$ionicHistory", "$ionicViewSwitcher", "$ionicScrollDelegate", "NixService", "ApiService", function ($rootScope, $scope, foods, calculatorUrl, $state, $stateParams, $ionicPopup, $ionicHistory, $ionicViewSwitcher, $ionicScrollDelegate, NixService, ApiService) {
  $scope.data = {
    restFoodSearch: ''
  };
  $scope.brandName = $stateParams.brand_name;
  $scope.restaurantLogoUrl = $stateParams.restaurantLogoUrl;
  $scope.maxHitsInitial = foods.total;
  $scope.maxHits = foods.total;
  $scope.foods = _.map(foods.hits, 'fields');
  $scope.state = $state.current.name;
  $scope.offset = 0;
  $scope.step = 20;
  $scope.$watch('data.restFoodSearch', function (newValue) {
    $scope.offset = 0;

    if (!newValue) {
      $scope.hideClearItem = true;
      $scope.foods = _.map(foods.hits, 'fields');
      return;
    }

    $scope.hideClearItem = false;
    return ApiService.findRestaurantFoods(newValue, $stateParams.brand_id).then(function (response) {
      $scope.foods = response.data.branded;
      $ionicScrollDelegate.scrollTop();
    });
  });

  $scope.clearSearch = function () {
    $scope.data.restFoodSearch = '';
    $scope.offset = 0;
    $scope.maxHits = $scope.maxHitsInitial;
  };

  $scope.addFood = function (food) {
    if (food.nix_item_id) {
      ApiService.getBrandedFood(food.nix_item_id).then(function (res) {
        $rootScope.$broadcast('mealBuilder: addFood', {
          foodArray: res.data.foods
        });
      });
    } else {
      $rootScope.$broadcast('mealBuilder: addFood', {
        foodArray: [food]
      });
    }
  };

  $scope.loadMoreFoods = function () {
    $scope.offset += 20;
    NixService.getRestaurantFoods($scope.data.restFoodSearch, $stateParams.brand_id, $scope.offset, $scope.step).then(function (response) {
      $scope.maxHits = response.total;
      $scope.foods = $scope.foods.concat(_.map(response.hits, 'fields'));
      $scope.$broadcast('scroll.infiniteScrollComplete');
    });
  };

  $scope.requestItem = function () {
    var requestMsg = 'Request missing item. Restaurant name: ' + $scope.brandName + '. Item name: ' + $scope.data.restFoodSearch + '.';
    ApiService.sendBugReport(2, requestMsg).then(function () {
      $scope.data.items = '';
      $ionicPopup.alert({
        title: 'Thank you!',
        template: 'Your feedback has been queued up with our registered dietitian team, and will be reviewed shortly.'
      });
    })["catch"](function (err) {
      $ionicPopup.alert({
        title: 'Error',
        template: 'There was an error with your submission, please email us at <a href="mailto:support@nutritionix.com">support@nutritionix.com</a> to report this problem.'
      });
      console.log('Error sending feedback:', angular.toJson(err));
    });
  };

  $scope.goToReviewFoods = function () {
    $ionicViewSwitcher.nextDirection('forward');
    $state.go('app.reviewFoods');
  };

  $scope.goToRestaurantBrands = function () {
    $ionicViewSwitcher.nextDirection('none');
    $state.go('app.restaurants');
  };

  $scope.openCalc = function () {
    $state.go('app.restaurantcalculator', {
      brand_id: $stateParams.brand_id,
      brand_name: $stateParams.brand_name,
      calculatorUrl: calculatorUrl
    });
  };

  $scope.showCalcButton = function () {
    return calculatorUrl !== null && calculatorUrl !== undefined && !!calculatorUrl.length; // return calculatorUrl !== null && calculatorUrl !== undefined && _.has($rootScope, 'userGroceyAgentInfo.grocery_agent') && !!$rootScope.userGroceyAgentInfo.grocery_agent;
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:restaurantsController
 * @description
 * # restaurantsController
 */

angular.module('Track').controller('restaurantsController', ["$rootScope", "$scope", "AnalyticsService", "NixService", "ApiService", "CacheFactory", "$state", "$filter", "$document", "$ionicBackdrop", "$ionicPopup", "$ionicHistory", "$ionicViewSwitcher", "$cordovaNetwork", "$timeout", "restaurants", function ($rootScope, $scope, AnalyticsService, NixService, ApiService, CacheFactory, $state, $filter, $document, $ionicBackdrop, $ionicPopup, $ionicHistory, $ionicViewSwitcher, $cordovaNetwork, $timeout, restaurants) {
  if ($rootScope.noInternet) {
    navigator.notification.alert('This feature is not available in offline mode', null, '', 'OK');
  }

  $scope.$on('$ionicView.enter', function () {
    AnalyticsService.trackView('Restaurants tab');
  });
  $scope.restaurantsWithCalc = [];
  CacheFactory.getRestaurantsWithCalc().then(function (res) {
    for (var i = 0; i < res.length; i++) {
      if (!!res[i].mobile_calculator_url) {
        var index = _.findIndex(restaurants, function (r) {
          return r.id == res[i].brand_id;
        }, 0);

        $scope.restaurantsWithCalc.push(restaurants.splice(index, 1)[0]);
      }
    }

    $scope.restaurantsWithCalc.sort(function (a, b) {
      var textA = a.name.toUpperCase();
      var textB = b.name.toUpperCase();
      return textA < textB ? -1 : textA > textB ? 1 : 0;
    });
    $scope.restaurantsWithCalcView = $scope.restaurantsWithCalc;
  })["catch"](function () {
    return null;
  });
  $scope.data = {
    items: ''
  };
  $scope.model = '';
  $scope.selectedFoods = [];
  $scope.hideClearItem = true;
  $scope.limit = 50;
  $scope.restaurants = restaurants || [];
  $scope.state = $state.current.name;
  $scope.restaurants.sort(function (a, b) {
    var textA = a.name.toUpperCase();
    var textB = b.name.toUpperCase();
    return textA < textB ? -1 : textA > textB ? 1 : 0;
  });
  $scope.$watch('data.items', function (newValue) {
    $scope.hideClearItem = !newValue ? true : false;
    $scope.restaurants = $filter('fuzzyBy')(restaurants, 'name', newValue, false);
    $scope.restaurantsWithCalcView = $filter('fuzzyBy')($scope.restaurantsWithCalc, 'name', newValue, false);

    if (newValue.length !== 0) {
      sortRestaurantsByMatch(newValue);
    }
  });

  var sortRestaurantsByMatch = function sortRestaurantsByMatch(query) {
    $scope.restaurants.sort(function (a, b) {
      var textA = a.name.toUpperCase();
      var textB = b.name.toUpperCase();
      var textAMatchIndex = window.Levenshtein.get(query.toUpperCase(), textA);
      var textBMatchIndex = window.Levenshtein.get(query.toUpperCase(), textB);
      return textAMatchIndex < textBMatchIndex ? -1 : textAMatchIndex > textBMatchIndex ? 1 : 0;
    });
    $scope.restaurantsWithCalcView.sort(function (a, b) {
      var textA = a.name.toUpperCase();
      var textB = b.name.toUpperCase();
      var textAMatchIndex = window.Levenshtein.get(query.toUpperCase(), textA);
      var textBMatchIndex = window.Levenshtein.get(query.toUpperCase(), textB);
      return textAMatchIndex < textBMatchIndex ? -1 : textAMatchIndex > textBMatchIndex ? 1 : 0;
    });
  };

  $scope.goToRestaurantFoods = function (brand) {
    if ($rootScope.noInternet) {
      return navigator.notification.alert('This feature is not available in offline mode', null, '', 'OK');
    }

    $ionicViewSwitcher.nextDirection('none');
    var params = {
      brand_id: brand.id,
      brand_name: brand.name
    };

    if (brand.logo) {
      params.restaurantLogoUrl = brand.logo;
    }

    $state.go('app.restaurantfoods', params);
  };

  $scope.clearSearch = function () {
    $scope.data.items = '';
  };

  $scope.goToFoodLog = function () {
    $state.go('app.foodlog');
  };

  $scope.moreToLoad = function () {
    if ($scope.limit > $scope.restaurants.length) return false;else return true;
  };

  $scope.loadMore = function () {
    $timeout(function () {
      $scope.limit += 50;
      $rootScope.$broadcast('scroll.infiniteScrollComplete');
    }, 250);
  };

  $scope.requestRestaurant = function () {
    var requestMsg = 'Request missing restaurant. Restaurant name: ' + $scope.data.items + '.';
    ApiService.sendBugReport(2, requestMsg).then(function () {
      $scope.data.items = '';
      $ionicPopup.alert({
        title: 'Thank you!',
        template: 'Your feedback has been queued up with our registered dietitian team, and will be reviewed shortly.'
      });
    })["catch"](function (err) {
      $ionicPopup.alert({
        title: 'Error',
        template: 'There was an error with your submission, please email us at <a href="mailto:support@nutritionix.com">support@nutritionix.com</a> to report this problem.'
      });
      console.log('Error sending feedback:', angular.toJson(err));
    });
  };

  $scope.goToReviewFoods = function () {
    $ionicViewSwitcher.nextDirection('forward');
    $state.go('app.reviewFoods');
  };

  $scope.goBack = function () {
    $ionicViewSwitcher.nextDirection('back');
    $state.go('app.foodlog');
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:reviewFoodsController
 * @description
 * # reviewFoodsController
 */

angular.module('Track').controller('reviewFoodsController', ["$rootScope", "$scope", "$http", "$ionicHistory", "$stateParams", "$state", "$q", "$timeout", "$ionicListDelegate", "$ionicScrollDelegate", "$ionicPlatform", "$ionicPopup", "CacheFactory", "CameraService", "AnalyticsService", "ApiService", "nixTrackUtils", "SQLiteService", "Recipe2Service", "HelperService", "UploadPhotoUtilityService", "WalkthroughService", function ($rootScope, $scope, $http, $ionicHistory, $stateParams, $state, $q, $timeout, $ionicListDelegate, $ionicScrollDelegate, $ionicPlatform, $ionicPopup, CacheFactory, CameraService, AnalyticsService, ApiService, nixTrackUtils, SQLiteService, Recipe2Service, HelperService, UploadPhotoUtilityService, WalkthroughService) {
  $scope.$on('$ionicView.beforeEnter', function () {
    $scope.totals = {
      calories: 0,
      protein: 0,
      carbs: 0,
      fat: 0
    };
    $scope.isAndroid = window.ionic.Platform.isAndroid();
    var cachedRecipeData = HelperService.getBasketRecipeData() || {};
    $scope.logging = {
      type: $stateParams.type || cachedRecipeData.type || 'multipleFoods',
      name: $stateParams.name || cachedRecipeData.name || '',
      servings: $stateParams.servings || cachedRecipeData.servings || 1,
      recipeBrand: $stateParams.recipeBrand || null,
      consumed_at: // If have stored basket 'when' value - use it first
      HelperService.getBasketWhenModuleState() ? HelperService.getBasketWhenModuleState() : $stateParams.mealConsumed ? moment($stateParams.mealConsumed, 'ddd, MM/DD/YY') // Second priority - mealConsumed in params
      .add(moment().hours(), 'hours').add(moment().minutes(), 'minutes').format('YYYY-MM-DDTHH:mm:ssZ') : $stateParams.type === 'singleFood' ? moment().format('YYYY-MM-DDTHH:mm:ssZ') : // if logged as single food (from recipes) - use current date and time
      getMostRecentFoodDate(),
      // if no consumed_at value passed and it's a multiple foods - get most recent date from foods.
      meal_type: $stateParams.mealType
    };
    $scope.uploadPhoto = {
      file: null,
      isChanged: false,
      isUploading: false
    };

    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(false);
    }

    $scope.customPhotoUrl = JSON.parse(window.localStorage.getItem('reviewBasketCustomPhoto'));

    if (!!$scope.customPhotoUrl) {
      $scope.showPhoto = true;
    } // SQLiteService.query(window.db, 'DELETE FROM localdata WHERE dataName = ?', ['photoUploadUserAgreement']);


    SQLiteService.query(window.db, 'SELECT value FROM localdata WHERE dataName = ?', ['photoUploadUserAgreement']).then(function (result) {
      $scope.agreedToUsePhoto = SQLiteService.getById(result);

      if ($scope.agreedToUsePhoto && $scope.agreedToUsePhoto) {
        $scope.isPhotoPopupShown = true;
      } else {
        $scope.isPhotoPopupShown = false;
      }
    })["catch"](function (err) {
      console.log(err);
    });
  });

  $scope.takePhoto = function () {
    console.log('take photo');
    return CameraService.takePhoto({
      destinationType: 'FILE_URI'
    }).then(function (file_uri) {
      if (!!file_uri) {
        $scope.customPhotoUrl = {
          full: file_uri
        };
      }

      return file_uri;
    }).then(function (file_uri) {
      return UploadPhotoUtilityService.getDataURL(file_uri, 'image/jpeg', 1).then(function (dataURL) {
        return UploadPhotoUtilityService.getBlob(dataURL);
      });
    }).then(function (blob) {
      $scope.uploadPhoto.file = blob;
      $scope.uploadPhoto.isChanged = true;
      $scope.showPhoto = true;
      $scope.submitPhoto();
    });
  };

  $scope.$on('$ionicView.enter', function () {
    calculateTotals();
    adjustGoBack();

    if (!!$scope.logging.meal_type) {
      calculateConsumedTimestamp();
    }

    if ($rootScope.itemsInBuilder.length > 1) {
      if (WalkthroughService.eventsList.firstFoodAddedToBasket) {
        WalkthroughService.runWalkthrough(3);
        WalkthroughService.setEventFlag('firstFoodAddedToBasket', false);
        WalkthroughService.setEventFlag('firstMultipleFoodsInBasket', false);
      } else if (WalkthroughService.eventsList.firstMultipleFoodsInBasket) {
        WalkthroughService.runWalkthrough(4);
        WalkthroughService.setEventFlag('firstMultipleFoodsInBasket', false);
      }
    } else if ($rootScope.itemsInBuilder.length > 0) {
      if (WalkthroughService.eventsList.firstFoodAddedToBasket) {
        WalkthroughService.runWalkthrough(2);
        WalkthroughService.setEventFlag('firstFoodAddedToBasket', false);
      }
    }
  });
  $scope.$on('$ionicView.beforeLeave', function () {
    if ($scope.logging) {
      if ($scope.logging.type == 'singleFood') {
        var recipeData = {
          name: $scope.logging.name,
          type: $scope.logging.type,
          servings: $scope.logging.servings
        };
        HelperService.setBasketRecipeData(recipeData);
      } else {
        HelperService.resetBasketRecipeData();
      }
    }

    angular.element('input').blur();

    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
    }
  });
  $scope.$watch('logging.consumed_at', function (newVal, oldVal) {
    if (newVal && $rootScope.itemsInBuilder.length) {
      HelperService.setBasketWhenModuleState(moment(newVal).format('YYYY-MM-DDTHH:mm:ssZ'));
    }
  });
  $scope.bugReport = {
    type: 1
  };

  $scope.showPhotoPopup = function () {
    var permissions = cordova.plugins.permissions;
    $q.when().then(function () {
      var deferred = $q.defer();

      if ($scope.isAndroid) {
        permissions.checkPermission(permissions.WRITE_EXTERNAL_STORAGE, function (result) {
          if (!result.hasPermission) {
            permissions.requestPermission(permissions.WRITE_EXTERNAL_STORAGE, function (result) {
              if (result.hasPermission) {
                deferred.resolve(result.hasPermission);
              } else {
                deferred.reject(result.hasPermission);
              }
            });
          } else {
            deferred.resolve(true);
          }
        });
      } else {
        deferred.resolve(true);
      }

      return deferred.promise;
    }).then(function () {
      var deferred = $q.defer();

      if ($scope.isAndroid) {
        permissions.checkPermission(permissions.CAMERA, function (result) {
          if (!result.hasPermission) {
            permissions.requestPermission(permissions.CAMERA, function (result) {
              if (result.hasPermission) {
                deferred.resolve(result.hasPermission);
              } else {
                deferred.reject(result.hasPermission);
              }
            });
          } else {
            deferred.resolve(true);
          }
        });
      } else {
        deferred.resolve(true);
      }

      return deferred.promise;
    }).then(function () {
      return $ionicPopup.show({
        title: 'Info box',
        template: '<div class="text-center" style="font-size:12px;">All meal photos uploaded become public and viewable on Nutritionix.com. No other personal information is shared with the photo. By uploading a photo, you are agreeing to make it public.</div>',
        buttons: [{
          text: 'I understand',
          type: 'button-balanced',
          onTap: function onTap() {
            SQLiteService.query(window.db, 'INSERT INTO localdata (dataName, value) VALUES (?1, ?2) ON CONFLICT(dataName) DO UPDATE SET dataName=?1, value=?2', ['photoUploadUserAgreement', 'true']);
            $scope.isPhotoPopupShown = true;
            $timeout(function () {
              angular.element('div[ngf-select="fileChanged($files)"]').click();
            }, 1000);
          }
        }]
      });
    });
  };

  $scope.getMealTimeName = function () {
    var name = '';

    switch ($scope.logging.meal_type) {
      case '1':
        name = 'Breakfast';
        break;

      case '2':
        name = 'AM Snack';
        break;

      case '3':
        name = 'Lunch';
        break;

      case '4':
        name = 'PM Snack';
        break;

      case '5':
        name = 'Dinner';
        break;

      case '6':
        name = 'Late Snack';
        break;

      default:
        name = 'Your meal';
    }

    return name;
  };

  function calculateConsumedTimestamp() {
    var date = moment($scope.logging.consumed_at);

    switch ($scope.logging.meal_type) {
      case '1':
        $scope.logging.consumed_at = date.hours(4).minutes(0).seconds(0).format('YYYY-MM-DDTHH:mm:ssZ');
        break;

      case '2':
        $scope.logging.consumed_at = date.hours(10).minutes(0).seconds(0).format('YYYY-MM-DDTHH:mm:ssZ');
        break;

      case '3':
        $scope.logging.consumed_at = date.hours(12).minutes(0).seconds(0).format('YYYY-MM-DDTHH:mm:ssZ');
        break;

      case '4':
        $scope.logging.consumed_at = date.hours(15).minutes(0).seconds(0).format('YYYY-MM-DDTHH:mm:ssZ');
        break;

      case '5':
        $scope.logging.consumed_at = date.hours(17).minutes(0).seconds(0).format('YYYY-MM-DDTHH:mm:ssZ');
        break;

      case '6':
        $scope.logging.consumed_at = date.hours(21).minutes(0).seconds(0).format('YYYY-MM-DDTHH:mm:ssZ');
        break;

      default:
        $scope.logging.consumed_at = getMostRecentFoodDate();
    }
  }

  function calculateTotals() {
    $scope.totals.calories = Math.round(_.reduce($rootScope.itemsInBuilder, function (sum, food) {
      if (food.nf_calories) {
        return sum + food.nf_calories;
      } else {
        return sum;
      }
    }, 0));
    $scope.totals.protein = Math.round(_.reduce($rootScope.itemsInBuilder, function (sum, food) {
      if (food.nf_protein) {
        return sum + food.nf_protein;
      } else {
        return sum;
      }
    }, 0));
    $scope.totals.carbs = Math.round(_.reduce($rootScope.itemsInBuilder, function (sum, food) {
      if (food.nf_total_carbohydrate) {
        return sum + food.nf_total_carbohydrate;
      } else {
        return sum;
      }
    }, 0));
    $scope.totals.fat = Math.round(_.reduce($rootScope.itemsInBuilder, function (sum, food) {
      if (food.nf_total_fat) {
        return sum + food.nf_total_fat;
      } else {
        return sum;
      }
    }, 0));
  }

  function adjustGoBack() {
    var backView = $ionicHistory.backView(),
        forwardView = $ionicHistory.forwardView(),
        currentView = $ionicHistory.currentView();

    if (forwardView && currentView && currentView.stateName && forwardView.stateName && 'app.reviewFoods' === currentView.stateName && 'app.foodlog' === forwardView.stateName) {
      $ionicHistory.backView(forwardView);
    }

    if (backView && backView.stateName && 'app.UploadPhotoUser' === backView.stateName) {
      $ionicHistory.removeBackView();
    }
  }

  function getMostRecentFoodDate() {
    var cachedTimestamp = HelperService.getBasketWhenModuleState();

    if (cachedTimestamp) {
      return cachedTimestamp;
    }

    return $rootScope.itemsInBuilder.length ? _.last($rootScope.itemsInBuilder).consumed_at || moment().format('YYYY-MM-DDTHH:mm:ssZ') : moment().format('YYYY-MM-DDTHH:mm:ssZ');
  }

  $scope.goBack = function () {
    if ($rootScope.itemsInBuilder.length === 0) {
      delete $rootScope.tempSearchQuery;
      $state.go('app.foodlog');
    } else {
      $ionicHistory.goBack();
    }
  };

  $scope.hideKeyboard = function () {
    window.cordova.plugins.Keyboard.close();
  };

  $scope.changeQty = function (newFoodObj, oldFood) {
    var index = _.indexOf($rootScope.itemsInBuilder, newFoodObj);

    if (newFoodObj.serving_qty === '') {
      $rootScope.itemsInBuilder[index] = oldFood;
      return;
    } else if (newFoodObj.serving_qty === 0) {
      $scope.removeFood(index);
    } else {
      var cloneOldFood = _.cloneDeep(oldFood);

      var multiplier = nixTrackUtils.calculateFoodMultiplier(cloneOldFood, newFoodObj.serving_qty); // hacky fix because external lib is putting an int for ingredient statement

      var ing_statement = cloneOldFood.nf_ingredient_statement;
      var newFood = nixTrackUtils.multiplyFoodNutrients(cloneOldFood, multiplier, true);
      newFood.nf_ingredient_statement = ing_statement;
      $rootScope.itemsInBuilder[index] = newFood;
      CacheFactory.setMealBuilderFoods($rootScope.itemsInBuilder);
      calculateTotals();
    }
  };

  $scope.changeMeasure = function (newFoodObj, oldFoodObj, serving_unit) {
    var new_alt_measure = _.find(newFoodObj.alt_measures, {
      'measure': serving_unit
    });

    var old_alt_measure = _.find(oldFoodObj.alt_measures, {
      'measure': oldFoodObj.serving_unit
    });

    var multiplier = new_alt_measure.serving_weight / new_alt_measure.qty / (old_alt_measure.serving_weight / old_alt_measure.qty);

    var index = _.indexOf($rootScope.itemsInBuilder, newFoodObj); // hacky fix because external lib is putting an int for ingredient statement


    var ing_statement = oldFoodObj.nf_ingredient_statement;
    var newFood = nixTrackUtils.multiplyFoodNutrients(oldFoodObj, multiplier / oldFoodObj.serving_qty, false);
    newFood.nf_ingredient_statement = ing_statement;
    newFood.serving_unit = serving_unit;
    newFood.serving_qty = 1;
    $rootScope.itemsInBuilder[index] = newFood;
    CacheFactory.setMealBuilderFoods($rootScope.itemsInBuilder);
    calculateTotals();
  };

  $scope.showFoodInfo = function (food) {
    return ApiService.setCurrentFood(food).then(function () {
      return $state.go('app.food', {
        food_id: food.id,
        readOnly: true
      });
    });
  };

  $scope.swipeRemoveFood = function (index) {
    AnalyticsService.trackEvent('swipe-left', 'swipe-left-delete');
    $scope.removeFood(index);
  };

  $scope.removeFood = function (index) {
    if ($rootScope.itemsInBuilder.length == 1) {
      clearFoods();
    } else {
      var deleted = $rootScope.itemsInBuilder.splice(index, 1);

      if (deleted[0]._hiddenQuery !== undefined) {
        AnalyticsService.trackEvent('deleted_natural', deleted[0].food_name + '; ' + deleted[0]._hiddenQuery, 'Deleted Natural');
      }

      if ($rootScope.itemsInBuilder.length === 1) {
        $scope.logging.type = 'multipleFoods';
        $scope.logging.name = '';
        $scope.servings = 1;
        $scope.recipeBrand = '';
      }

      $ionicListDelegate.closeOptionButtons();
      return CacheFactory.setMealBuilderFoods($rootScope.itemsInBuilder).then(function () {
        calculateTotals();
      }).then(function () {
        $rootScope.cartNumber -= 1;
        $rootScope.$broadcast('mealBuilder: updateFoods');
      });
    }
  };

  $scope.deleteAllFoods = function () {
    $ionicPopup.show({
      title: 'Clear Foods',
      subTitle: 'Are you sure you want to clear the meal builder?',
      buttons: [{
        text: 'Cancel'
      }, {
        text: 'Yes',
        type: 'button-balanced',
        onTap: function onTap() {
          clearFoods();
          $scope.clearCustomPhoto();
        }
      }]
    });
  };

  $scope.logFoods = function () {
    // validation
    if ($rootScope.itemsInBuilder.length === 0) {
      delete $rootScope.tempSearchQuery;
      return $state.go('app.foodlog');
    }

    angular.element('input').blur();

    if ($scope.logging.type === 'singleFood') {
      if (!$scope.logging.name) {
        $scope.errorMessage = 'Please enter a food name';
        return;
      }

      if (!$scope.logging.servings) {
        $scope.errorMessage = 'Please enter a valid serving size';
        return;
      }

      if (!$scope.logging.consumed_at) {
        $scope.errorMessage = 'Please enter date of consumption';
        return;
      } else if (!$scope.logging.meal_type) {
        $scope.logging.meal_type = HelperService.calculateMealTypeByTime(moment($scope.logging.consumed_at).hours());
      }
    } else {
      $scope.logging.name = null;
    }

    if ($scope.logging.consumed_at) {
      var changeDayLogDate = moment($scope.logging.consumed_at).format('MM/DD/YY');
      $scope.logging.consumed_at = moment($scope.logging.consumed_at).format('YYYY-MM-DDTHH:mm:ssZ');
    }

    return $q.when().then(function () {
      if (!!$scope.uploadPhoto.file) {
        return $scope.submitPhoto().then(function (res) {
          if (!!res) {
            $scope.logging.customPhoto = res.data;
            return $scope.logging.customPhoto;
          }
        })["catch"](function (err) {
          $ionicPopup.show({
            title: 'Oops, something went wrong',
            subTitle: 'Image upload failed',
            template: '<div class="text-center">Tap "Ok" to try again, or "Cancel" to proceed without image</div>',
            scope: $scope,
            buttons: [{
              text: 'Ok',
              type: 'button-positive',
              onTap: function onTap() {
                $scope.logFoods();
              }
            }, {
              text: 'Cancel',
              onTap: function onTap() {
                $scope.clearCustomPhoto();
                $scope.showPhoto = false;
                $scope.logFoods();
              }
            }]
          });
          return Promise.reject(err);
        });
      } else if (!!$scope.customPhotoUrl) {
        $scope.logging.customPhoto = $scope.customPhotoUrl;
        return $scope.logging.customPhoto;
      }

      return;
    }).then(function () {
      _.forEach($rootScope.itemsInBuilder, function (food) {
        // used to track deleting natural items; need to remove before sending to api.
        if (food._hiddenQuery !== undefined) {
          delete food._hiddenQuery;
        }

        food.consumed_at = moment(food.consumed_at).format('YYYY-MM-DDTHH:mm:ssZ');
        food.meal_type = HelperService.calculateMealTypeByTime(moment(food.consumed_at).hours());
      });

      var loggingOptions = angular.toJson($scope.logging);
      return ApiService.postFoodObj($rootScope.itemsInBuilder, JSON.parse(loggingOptions));
    }).then(function () {
      $rootScope.cartNumber = 0;

      if ($scope.logging.customPhoto) {
        AnalyticsService.trackEvent('Custom photo added', ' ');
      }

      if ($scope.logging.type == 'singleFood') {
        var cachedRecipes = Recipe2Service.getCachedRecipes();

        var cachedRecipeToLog = _.find(cachedRecipes, {
          'name': $scope.logging.name
        });

        if (!cachedRecipeToLog || _.isEmpty(cachedRecipeToLog)) {
          AnalyticsService.trackEvent('Recipe created', 'Created from the basket');
        }
      }

      return clearFoods();
    }).then(function () {
      var askForReview;
      var reviewCheck = JSON.parse(window.localStorage.getItem('reviewCheck')) || {};

      if (!!reviewCheck.rateClicked || !!reviewCheck.scheduleDate && moment(reviewCheck.scheduleDate, 'DD-MM-YYYY').isAfter(moment())) {
        askForReview = false;
      } else {
        if (reviewCheck.runCounter > 4) {
          askForReview = true;
        } else {
          askForReview = false;
        }
      }

      $state.go('app.foodlog', {
        change_day: changeDayLogDate,
        startWalkthroughAfterLog: WalkthroughService.eventsList.firstFoodAddedToFoodLog,
        askForReview: askForReview
      });
    })["catch"](function (e) {
      console.log('review foods went wrong', angular.toJson(e));
    });
  };

  function clearFoods() {
    return CacheFactory.clearFoods().then(function () {
      $rootScope.$broadcast('clearFoods');
      $ionicScrollDelegate.scrollTop();
      delete $scope.errorMessage;
      $scope.logging.consumed_at = Date.now();
      $scope.logging.type = 'multipleFoods';
      $scope.logging.meal_type = null;
      $rootScope.cartNumber = 0;
      $scope.totalCalories = 0;
      HelperService.resetBasketWhenModuleState();
      HelperService.resetBasketRecipeData();
      $scope.clearCustomPhoto();
      return;
    });
  }

  $scope.togglePhotoDropdown = function () {
    if (!$scope.uploadPhoto.isChanged && !$scope.customPhotoUrl && $rootScope.itemsInBuilder.length <= 1) {
      $scope.showPhoto = !$scope.showPhoto;
    }
  };

  $scope.sendBugReport = function () {
    $ionicPopup.show({
      title: 'Report a problem',
      subTitle: 'Please describe the issue you are experiencing below',
      template: '<textarea class="input-bg-color" style="text-indent:0!important; padding:5px;" rows=5 ng-model="bugReport.message" focus-me="true"></textarea>',
      scope: $scope,
      cssClass: 'custom-popup',
      buttons: [{
        text: 'Cancel'
      }, {
        text: 'Send',
        type: 'button-balanced',
        onTap: function onTap() {
          $scope.bugReport.payload = angular.toJson({
            foods: $rootScope.itemsInBuilder
          });
          $scope.bugReport.metadata = '{"version": ' + window.device.version + ', "device": ' + window.device.manufacturer + ' ' + window.device.model + ', "track_version": 1.4.8}';

          if ($scope.bugReport.message) {
            ApiService.sendBugReport($scope.bugReport.type, $scope.bugReport.message, $scope.bugReport.payload, $scope.bugReport.metadata).then(function () {
              successMessageBugreport();
              $scope.bugReport.message = '';
            });
          } else {
            errorMessageBugreport();
          }
        }
      }]
    });
  };

  $scope.goToPhotoUpload = function () {
    $scope.photoPopup.close();
    window.localStorage.setItem('force_photo_upload', true);
    setTimeout(function () {
      angular.element('barcode-scanner:not(.ng-hide)').find('button').click();
    }, 50);
  };

  $scope.shopNutritionDiscrepancyPopup = function () {
    $scope.photoPopup = $ionicPopup.show({
      title: 'Report Updated Nutrition Labels',
      subTitle: 'Flag a product that needs to be updated or corrected by scanning the barcode and sending a photo of packaging:',
      template: '<button class="button button-positive button-large" style="display:block; margin: 0 auto;" ng-click="goToPhotoUpload()"><i class="fa fa-barcode"></i></button></button>',
      scope: $scope,
      cssClass: 'custom-popup',
      buttons: [{
        text: 'Cancel'
      }]
    });
  };

  $scope.fileChanged = function (files) {
    $scope.uploadPhoto.file = files[0];
    $scope.uploadPhoto.isChanged = true;
    $scope.showPhoto = true;
    $scope.submitPhoto();
  };

  $scope.submitPhoto = function () {
    var formData = new FormData();
    formData.append('file', $scope.uploadPhoto.file);
    $scope.uploadPhoto.isUploading = true;
    return $http.post('https://trackapi.nutritionix.com/v2/upload/image/foods/' + moment().format('YYYY-MM-DD'), formData, {
      headers: {
        'Content-Type': undefined
      }
    }).then(function (resp) {
      $scope.showPhoto = true;
      $scope.uploadPhoto.isUploading = false;
      window.localStorage.setItem('reviewBasketCustomPhoto', angular.toJson(resp.data));
      return resp;
    })["catch"](function (e) {
      $scope.uploadPhoto.isUploading = false;
      console.log('there was an error uploading photo', e);
    });
  };

  $scope.clearCustomPhoto = function () {
    $scope.uploadPhoto = {
      file: null,
      isChanged: false,
      isUploading: false
    };
    $scope.customPhotoUrl = null;
    window.localStorage.removeItem('reviewBasketCustomPhoto');
    $scope.showPhoto = false;
  };

  function successMessageBugreport() {
    $ionicPopup.alert({
      title: 'Thank you for submitting this feedback, we review each and every submission, and we will get back to you if we have any further questions.',
      buttons: [{
        text: 'Close',
        type: 'button-balanced'
      }]
    });
  }

  function errorMessageBugreport() {
    $ionicPopup.alert({
      title: 'Unfortunately the message you are trying to submit is empty. Please describe the problem that you want to report.',
      buttons: [{
        text: 'Ok',
        type: 'button-balanced'
      }]
    });
  }
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:SettingsController
 * @description
 * # SettingsController
 */

angular.module('Track').controller('SettingsController', function () {// do something with $scope
});
'use strict';
/**
* @ngdog function
* @name Track.controller:shareController
* @description
* # shareController
*/

angular.module('Track').controller('shareController', ["$scope", "$state", "$cordovaDatePicker", "$ionicPopup", "AnalyticsService", "ApiService", function ($scope, $state, $cordovaDatePicker, $ionicPopup, AnalyticsService, ApiService) {
  $scope.tz = moment.tz.guess();
  $scope.share = {
    email: window.localStorage.getItem('shareEmail') || '',
    start: moment().tz($scope.tz).subtract(8, 'days'),
    end: moment().tz($scope.tz).subtract(1, 'day')
  };
  $scope.$on('$ionicView.enter', function (event, data) {
    AnalyticsService.trackView('Share food log');
  });

  $scope.goBack = function () {
    $state.go('app.foodlog');
  };

  $scope.showDatePicker = function (input) {
    var dpDate = '';

    if (input === 'start') {
      dpDate = $scope.share.start;
    } else {
      dpDate = $scope.share.end;
    }

    var datePickerOptions = {
      date: dpDate._d,
      mode: 'date',
      allowFutureDates: false,
      androidTheme: '16973939'
    };
    return $cordovaDatePicker.show(datePickerOptions).then(function (date) {
      if (input === 'start') {
        $scope.share.start = moment(date);
      } else {
        $scope.share.end = moment(date);
      }
    });
  };

  $scope.sendEmail = function () {
    if ($scope.share.end.diff($scope.share.start, 'days') > 10) {
      return $ionicPopup.alert({
        title: 'Max Range Exceeded',
        template: 'Please specify a Start and End Date within a 10 day range.'
      }).then(function (res) {
        if (res) {
          return;
        }
      });
    } else if ($scope.share.end.diff($scope.share.start, 'days') < 0) {
      return $ionicPopup.alert({
        title: 'Invalid Date Range',
        template: 'End Date should not be less than Start Date. Please specify a valid date range.'
      }).then(function (res) {
        if (res) {
          return;
        }
      });
    }

    ApiService.shareFoodLog($scope.share.email, $scope.share.start.format('YYYY-MM-DD'), $scope.share.end.format('YYYY-MM-DD'), $scope.tz).then(function (response) {
      if (response.status === 200) {
        window.localStorage.setItem('shareEmail', $scope.share.email);
        return $ionicPopup.alert({
          title: 'Success',
          template: 'Your food log from ' + $scope.share.start.format('L') + ' through ' + $scope.share.end.format('L') + ' was successfully sent to ' + $scope.share.email + '.'
        }).then(function (res) {
          if (res) {
            $state.go('app.foodlog');
          }
        });
      } else {
        return $ionicPopup.alert({
          title: 'Failure',
          template: 'There was an error sharing your food log. Please make sure the email address you are attempting to send to is correct.'
        }).then(function (res) {
          if (res) {
            return;
          }
        });
      }
    });
  };
}]);
'use strict';

angular.module('Track').controller('SignupController', ["$scope", "$state", "$ionicPopup", "$q", "moment", "ApiService", "LoginService", function ($scope, $state, $ionicPopup, $q, moment, ApiService, LoginService) {
  $scope.signup = {
    first_name: $state.params.first_name || '',
    email: '',
    password: '',
    timezone: moment.tz.guess() || 'US/Eastern'
  };
  $scope.emailConfirm = '';
  $scope.countries = [];
  $scope.location = {
    selected: {
      'ISO3166-1-numeric': 840,
      'official_name_en': 'United States of America'
    }
  };
  ApiService.getCountriesList().then(function (res) {
    $scope.countries = res.data;
  })["catch"](function (err) {
    console.log('error getting countries list', err);
  });

  $scope.filterCountries = function (query) {
    var result = [];

    for (var i = 0; i < $scope.countries.length; i++) {
      if ($scope.countries[i].official_name_en.toLowerCase().indexOf(query.toLowerCase()) !== -1) {
        result[i] = $scope.countries[i];
      }
    }

    return result;
  };

  $scope.goBack = function () {
    $state.go('manualLogin');
  };

  $scope.createAccount = function () {
    $scope.createAccount.$error = null;

    if ($scope.signupForm && $scope.signupForm.$invalid && $scope.emailConfirm !== $scope.signup.email) {
      return false;
    }

    LoginService.manualSignUp($scope.signup, $scope.location.selected['ISO3166-1-numeric'])["catch"](function (error) {
      var error_code = error.status;

      if (error_code === 409) {
        return $ionicPopup.alert({
          title: 'Account Creation Failed',
          template: 'An account with this email already exists.'
        });
      } else {
        $ionicPopup.alert({
          title: 'Account Creation Failed',
          template: 'An unexpected server error has occured. Please email support@nutritionix.com and reference the reference code: ' + error.data.id
        });
        throw error;
      }
    });
  };

  $scope.openTOS = function () {
    cordova.InAppBrowser.open('http://www.nutritionix.com/terms', '_blank', 'location=no');
    return false;
  };

  $scope.openPrivacy = function () {
    cordova.InAppBrowser.open('https://www.nutritionix.com/privacy', '_blank', 'location=no');
    return false;
  };
}]);
/***** FILE IS DEPRECATED *******/
'use strict';
/**
* @ngdoc function
* @name Track.controller:smsRemindersController
* @description
* # smsRemindersController
*/

angular.module('Track').controller('smsRemindersController', ["$scope", "$ionicPopup", "$ionicHistory", "ApiService", "UserService", function ($scope, $ionicPopup, $ionicHistory, ApiService, UserService) {
  $scope.loadMe = function () {
    ApiService.getUserData().then(function (me) {
      $scope.options = {
        toggle: !!me.data.enable_weekday_sms,
        verification: !!me.data.mobile_number,
        mobileNumber: me.data.mobile_number
      };
    });
  };

  $scope.loadMe();

  $scope.goBack = function () {
    $ionicHistory.goBack();
  };

  $scope.toggleReminder = function () {
    // scope.toggle is the current state of the button
    // if enabled, we want to disable
    // only hit api if number is verified
    if ($scope.options.verification) {
      return ApiService.toggleSMS($scope.options.toggle);
    }
  };

  $scope.unlinkConfirm = function () {
    return $ionicPopup.confirm({
      title: 'Unlink Mobile Number',
      template: 'Are you sure you want to unlink your mobile number?'
    }).then(function (res) {
      if (res) {
        return $scope.unlink();
      }
    });
  };

  $scope.unlink = function () {
    return ApiService.unlinkPhoneNumber().then(function (response) {
      return ApiService.toggleSMS(false).then(function () {
        $scope.loadMe();
      });
    })["catch"](function () {
      $scope.options.unlinkMessage = 'Unlinking mobile number verification failed :(';
    });
  };

  $scope.link = function () {
    if (!$scope.options.phoneNumber) {
      return;
    }

    ApiService.linkPhoneNumber($scope.options.phoneNumber).then(function () {
      $scope.options.initiated = true;
    })["catch"](function () {
      return $ionicPopup.alert({
        title: 'Verification Failed',
        template: 'The phone number provided is invalid.'
      }).then(function (res) {
        if (res) {
          return;
        }
      });
    });
  };

  $scope.codeConfirmation = function () {
    if (!$scope.options.confirmCode) {
      return;
    }

    var code = $scope.options.confirmCode.toString();

    if (code.indexOf('-') === -1) {
      code = code.substr(0, 3) + '-' + code.substr(3, 3);
    }

    return ApiService.confirmCodeSMS(code).then(function () {
      $scope.options.completed = true;
      return ApiService.toggleSMS(true).then(function () {
        return $ionicPopup.alert({
          title: 'Verification Successful',
          template: 'Successfully linked phone number'
        }).then(function (res) {
          if (res) {
            $scope.loadMe();
            return;
          }
        });
      });
    })["catch"](function () {
      return $ionicPopup.alert({
        title: 'Verification Failed',
        template: 'Mobile number verification failed'
      }).then(function (res) {
        if (res) {
          return;
        }
      });
    });
  };

  $scope.linkCloseMessage = function () {
    $scope.options.linkMessage = null;
    $scope.options.linkMessageType = null;
  };

  $scope.confirmCloseMEssage = function () {
    $scope.options.confirmMessage = null;
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:CalendarController
 * @description
 * # CalendarController
 */

angular.module('Track').controller('StatsController', ["UserService", "ApiService", "$state", "$rootScope", "$ionicHistory", "$scope", function (UserService, ApiService, $state, $rootScope, $ionicHistory, $scope) {
  var vm = this;
  $scope.$on('$ionicView.beforeEnter', function (event, data) {
    $scope.initialDisplayDate = moment($rootScope.selected_day.date, 'ddd, MM/DD/YY');
    vm.showMissedDays = true;

    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(false);
    }

    UserService.getUser().then(function (result) {
      vm.user = result;
    })["catch"](function (err) {
      console.log('Error getting active user from local DB:', err);
    });
  });
  $scope.$on('$ionicView.leave', function (event, data) {
    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
    }
  });
  vm.dietGraphApi = null;

  vm.goBack = function () {
    $state.go('app.foodlog');
  };

  vm.changeDayToDate = function (date) {
    var newDate = moment(date, 'ddd, MM/DD/YY').format('MM/DD/YY');
    $state.go('app.foodlog', {
      change_day: newDate
    });
  }; // var stats = JSON.parse(window.localStorage.getItem('stats'));
  // if (stats) {
  //   vm.daysTracked = stats.daysLogged;
  //   vm.currentStreak = stats.streak;
  //   vm.uniqueFoods = stats.uniqueFoods;
  // }
  // ApiService.getUserReport()
  //   .then(function(resp) {
  //     vm.daysTracked = resp.data.daysLogged;
  //     vm.currentStreak = resp.data.streak;
  //     vm.uniqueFoods = resp.data.uniqueFoods;
  //     window.localStorage.setItem('stats', angular.toJson({daysLogged: vm.daysTracked, streak: vm.currentStreak, uniqueFoods:  vm.uniqueFoods}));
  //   });

}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:subscribeController
 * @description
 * # subscribeController
 */

angular.module('Track').controller('subscribeController', ["$scope", "$state", "$ionicHistory", "$ionicPopup", "$cordovaDevice", "ApiService", "SQLiteService", "userObj", function ($scope, $state, $ionicHistory, $ionicPopup, $cordovaDevice, ApiService, SQLiteService, userObj) {
  (function init() {
    $scope.user = userObj;
    $scope.showTrial = true;
    $scope.platform = {
      store: 'ios'
    };

    if ($cordovaDevice.getPlatform() === 'Android') {
      $scope.platform.store = 'android';
      $scope.ids = ['track_pro_automatic_renewal', 'track_pro_renewal_yearly'];
    } else {
      $scope.ids = ['Track_Pro_Automatic_Renewal', 'Track_Pro_Renewal_Yearly'];
    }

    $scope.products = [];
    window.inAppPurchase.getProducts($scope.ids).then(function (products) {
      $scope.products = products;
      window.inAppPurchase.restorePurchases($scope.ids).then(function (res) {
        if (!!res && res.length > 0) {
          $scope.showTrial = false;
          $scope.$apply();
        }
      })["catch"](function (err) {
        console.log(err);
      });
    })["catch"](function (err) {
      console.log(angular.toJson(err));
    });
  })();

  $scope.$watch('license.accessCode', function (newVal, oldVal) {
    if (!newVal) {
      return;
    }

    $scope.license.accessCode = newVal.toUpperCase();

    if (!oldVal || newVal.length > oldVal.length) {
      if (newVal.replace('-', '').length > 2 && newVal.replace('-', '').length < 7) {
        $scope.license.accessCode = (newVal.replace('-', '').slice(0, 3) + '-' + newVal.replace('-', '').slice(3, newVal.length)).toUpperCase();
      }
    } else if (newVal.length < oldVal.length) {
      if (newVal.length == 4) {
        $scope.license.accessCode = newVal.replace('-', '').toUpperCase();
      }
    }
  });
  $scope.license = {
    accessCode: ''
  };

  $scope.purchaseSubscription = function (product) {
    if ($scope.platform.store === 'android') {
      product = product.toLowerCase();
    }

    var androidSignature = '';
    window.inAppPurchase.subscribe(product).then(function (data) {
      androidSignature = data.signature; // validate the receipt

      validatePurchase(data.receipt, androidSignature, $scope.platform.store);
    })["catch"](function (err) {
      console.log(angular.toJson(err));
    });
  };

  $scope.restorePurchases = function () {
    window.inAppPurchase.restorePurchases($scope.ids).then(function (data) {
      var androidSignature = '';

      if (data.length) {
        androidSignature = data[0].signature; // validate the receipt

        if ($scope.platform.store === 'android') {
          validatePurchase(data[0].receipt, androidSignature, $scope.platform.store);
        } else {
          window.inAppPurchase.getReceipt().then(function (receiptString) {
            validatePurchase(receiptString, androidSignature, $scope.platform.store);
          });
        }
      } else {
        $ionicPopup.alert({
          title: 'Error',
          template: 'Nothing to restore'
        });
        console.log('nothing to restore');
      }
    })["catch"](function (err) {
      console.log(angular.toJson(err));
    });
  };

  var validatePurchase = function validatePurchase(receiptString, androidSignature, store) {
    ApiService.validatePurchase(receiptString, androidSignature, store).then(function (res) {
      var receipt = res.data.latest_receipt;
      SQLiteService.query(window.db, 'INSERT INTO iap_receipts (receipt, signature) VALUES (?, ?)', [angular.toJson(receipt), androidSignature]).then(function () {
        $state.go('app.myCoach');
      })["catch"](function (err) {
        console.log('there was error adding receipt data to db', angular.toJson(err));
      });
    })["catch"](function (err) {
      console.log(angular.toJson(err));
    });
  };

  $scope.submitAccessCode = function () {
    ApiService.submitAccessCode($scope.license.accessCode).then(function () {
      var successPopup = $ionicPopup.alert({
        title: 'Valid Access Code',
        template: 'Congrats, you are now a premium user!'
      });
      successPopup.then(function () {
        $state.go('app.myCoach');
      });
    })["catch"](function (err) {
      console.log(angular.toJson(err));
      $ionicPopup.alert({
        title: 'Invalid Access Code',
        template: 'The access code provided is invalid.'
      });
    });
  };

  $scope.unsubscribeFromPro = function () {
    ApiService.updatePreferences({
      premium_user: 0
    }).then(function () {
      console.log('unsubscribe success');
      $state.go($state.current, {}, {
        reload: true
      });
    })["catch"](function (err) {
      console.log('unsubscribe error', angular.toJson(err));
    });
  };

  $scope.openTOS = function () {
    cordova.InAppBrowser.open('http://www.nutritionix.com/terms', '_blank', 'location=no');
    return false;
  };

  $scope.openPrivacy = function () {
    cordova.InAppBrowser.open('https://www.nutritionix.com/privacy', '_blank', 'location=no');
    return false;
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:FoodlogController
 * @description
 * # FoodlogController
 */

angular.module('Track').controller('TotalController', ["$rootScope", "$scope", "$ionicHistory", "$ionicPopup", "$state", "$stateParams", "$filter", "$timeout", "AnalyticsService", "ApiService", "dayTotal", "UserService", "CoachService", function ($rootScope, $scope, $ionicHistory, $ionicPopup, $state, $stateParams, $filter, $timeout, AnalyticsService, ApiService, dayTotal, UserService, CoachService) {
  var vm = $scope.vm = this;
  var mealTypeFilter = $stateParams.mealTypeFilter || null;
  vm.readOnly = $stateParams.readOnly || false;
  vm.clientId = $stateParams.clientId || '';
  vm.date = $stateParams.date || $rootScope.selected_day.date;
  vm.dayTotal = $stateParams.dayValue || dayTotal;
  vm.showMealControls = !!mealTypeFilter && !vm.readOnly;

  switch (mealTypeFilter) {
    case 1:
      $scope.mealTypeName = 'Breakfast';
      break;

    case 2:
      $scope.mealTypeName = 'AM Snack';
      break;

    case 3:
      $scope.mealTypeName = 'Lunch';
      break;

    case 4:
      $scope.mealTypeName = 'PM Snack';
      break;

    case 5:
      $scope.mealTypeName = 'Dinner';
      break;

    case 6:
      $scope.mealTypeName = 'Late Snack';
      break;

    default:
      $scope.mealTypeName = 'Daily';
  }

  $scope.$watch('vm.dayNote', function (newVal, oldVal) {
    if (oldVal !== null && oldVal !== undefined && newVal !== null && newVal !== undefined) {
      vm.showNotes = true;
    }

    if (newVal !== oldVal) {
      if (newVal !== null) {
        ApiService.setDayNote(vm.date, newVal)["catch"](function (err) {
          console.log(err);
        });
      }
    }
  });
  $scope.mealTypeTitle = $scope.mealTypeName === 'Daily' ? 'Summary of ' + moment(vm.date, 'ddd, MM/DD/YY').format('dddd, MM/DD') : $scope.mealTypeName + ' - ' + moment(vm.date, 'ddd, MM/DD/YY').format('ddd, MM/DD');
  $scope.$on('$ionicView.enter', function () {
    if ($scope.mealTypeName === 'Daily') {
      AnalyticsService.trackView('Daily summary');
    } else {
      AnalyticsService.trackView('Meal summary');
    }

    var selected_day = moment(vm.date, 'ddd, MM/DD/YY').format('YYYY-MM-DD'),
        previous_day = moment(vm.date, 'ddd, MM/DD/YY').subtract(1, 'day').format('YYYY-MM-DD');

    if (!!vm.clientId) {
      var options = {
        clientId: vm.clientId,
        begin: selected_day,
        end: previous_day
      };
      CoachService.getClientTotals(options).then(function (res) {
        if (res && res.data && res.data.dates && res.data.dates[0]) {
          $scope.labelData.calorieIntake = res.data.dates[0].daily_kcal_limit;
          $scope.labelData.initialCalorieLimit = res.data.dates[0].daily_kcal_limit;
        }
      });
    } else {
      UserService.getUser().then(function (user) {
        ApiService.getUserTotals(0, previous_day, selected_day, user.timezone || null).then(function (res) {
          if (!!res && res[vm.date]) {
            vm.dayNote = res[vm.date].notes;
            $scope.labelData.calorieIntake = res[vm.date].daily_kcal_limit || 0;
            $scope.labelData.initialCalorieLimit = res[vm.date].daily_kcal_limit;
          }
        })["catch"](function (err) {
          ApiService.getCachedUserTotals().then(function (res) {
            if (res[vm.date]) {
              vm.dayNote = res[vm.date].notes;
              $scope.labelData.calorieIntake = res[vm.date].daily_kcal_limit;
            }
          })["catch"](function (error) {
            console.log('error getting cached user totals', angular.toJson(error));
          });
        });
      });
    }

    AnalyticsService.trackView('Daily Total Page');
  });
  var totalCalForPieChart = 0;

  if (vm.dayTotal && vm.dayTotal.foods) {
    vm.total = {
      item_name: 'Total',
      brand_name: 'Nutritionix',
      full_nutrients: [],
      metric_qty: 0,
      calories: 0,
      total_fat: 0,
      nf_saturated_fat: 0,
      nf_cholesterol: 0,
      nf_sodium: 0,
      nf_total_carbohydrate: 0,
      nf_dietary_fiber: 0,
      nf_sugars: 0,
      nf_protein: 0,
      nf_potassium: 0,
      nf_vitamin_a_dv: 0,
      nf_vitamin_c_dv: 0,
      nf_calcium_dv: 0,
      nf_iron_dv: 0,
      nf_p: 0,
      caffeine: 0,
      alcohol: 0,
      vitamin_d: 0,
      vitamin_e: 0,
      vitamin_k: 0,
      thiamine: 0,
      riboflavin: 0,
      niacin: 0,
      pantothenic_acid: 0,
      vitamin_b6: 0,
      vitamin_b12: 0,
      folic_acid: 0,
      folate: 0,
      zinc: 0,
      magnesium: 0
    };
    vm.servingsQty = 1;

    _.forEach(vm.dayTotal.foods, function (food) {
      if (mealTypeFilter && mealTypeFilter !== food.meal_type) {
        return;
      }

      var foodCalories = food.nf_calories;
      vm.total.metric_qty += food.serving_weight_grams;
      vm.total.total_fat += food.nf_total_fat;
      vm.total.nf_saturated_fat += food.nf_saturated_fat;
      vm.total.nf_cholesterol += food.nf_cholesterol;
      vm.total.nf_sodium += food.nf_sodium;
      vm.total.nf_total_carbohydrate += food.nf_total_carbohydrate;
      vm.total.nf_dietary_fiber += food.nf_dietary_fiber;
      vm.total.nf_sugars += food.nf_sugars;
      vm.total.nf_protein += food.nf_protein;
      vm.total.nf_potassium += food.nf_potassium;
      vm.total.nf_p += food.nf_p;
      vm.total.caffeine += $filter('nutrient')(food.full_nutrients, 262, 'value') || 0;
      vm.total.vitamin_d += $filter('nutrient')(food.full_nutrients, 324, 'value') || 0;
      vm.total.vitamin_e += $filter('nutrient')(food.full_nutrients, 323, 'value') || 0;
      vm.total.vitamin_k += $filter('nutrient')(food.full_nutrients, 430, 'value') || 0;
      vm.total.thiamine += $filter('nutrient')(food.full_nutrients, 404, 'value') || 0;
      vm.total.riboflavin += $filter('nutrient')(food.full_nutrients, 405, 'value') || 0;
      vm.total.niacin += $filter('nutrient')(food.full_nutrients, 406, 'value') || 0;
      vm.total.pantothenic_acid += $filter('nutrient')(food.full_nutrients, 410, 'value') || 0;
      vm.total.vitamin_b6 += $filter('nutrient')(food.full_nutrients, 415, 'value') || 0;
      vm.total.vitamin_b12 += $filter('nutrient')(food.full_nutrients, 418, 'value') || 0;
      vm.total.folic_acid += $filter('nutrient')(food.full_nutrients, 431, 'value') || 0;
      vm.total.folate += $filter('nutrient')(food.full_nutrients, 417, 'value') || 0;
      vm.total.zinc += $filter('nutrient')(food.full_nutrients, 309, 'value') || 0;
      vm.total.magnesium += $filter('nutrient')(food.full_nutrients, 304, 'value') || 0;
      var foodExtendedNf = window.nutritionixApiDataUtilities.convertFullNutrientsToNfAttributes(food.full_nutrients);
      vm.total.nf_vitamin_a_dv += foodExtendedNf.nf_vitamin_a_dv || 0;
      vm.total.nf_vitamin_c_dv += foodExtendedNf.nf_vitamin_c_dv || 0;
      vm.total.nf_calcium_dv += foodExtendedNf.nf_calcium_dv || 0;
      vm.total.nf_iron_dv += foodExtendedNf.nf_iron_dv || 0;
      vm.total.alcohol += $filter('nutrient')(food.full_nutrients, 221, 'value') || 0;
      var calories_calculated_by_formula = (food.nf_protein || 0) * 4 + (food.nf_total_carbohydrate || 0) * 4 + (food.nf_total_fat || 0) * 9;

      if ($filter('nutrient')(food.full_nutrients, 221, 'value') !== null && $filter('nutrient')(food.full_nutrients, 221, 'value') !== undefined) {
        //if have alcohol in nutrients - calculate totals based on the nutients
        foodCalories = calories_calculated_by_formula + ($filter('nutrient')(food.full_nutrients, 221, 'value') || 0) * 7;
      } else {
        //if no alcohol in nutrients - check if it's missing in the total calories number
        if (calories_calculated_by_formula / food.nf_calories > 0.85) {
          // if total calories calculated by formula not lesser than 85% of food.nf_calories field - use this value.
          foodCalories = calories_calculated_by_formula;
        } else {
          // if total calories calculated by formula is lesser than 85% of nf_valories field - use nf_calories and count the rest as an alcohol calories.
          foodCalories = food.nf_calories;
          vm.total.alcohol += (foodCalories - calories_calculated_by_formula) / 7;
        }
      }

      vm.total.calories += food.nf_calories;
      totalCalForPieChart += foodCalories;
    });

    vm.total.serving_qty = 1;
    vm.total.serving_unit = 'Serving';
    vm.total.showServingUnitQuantityTextbox = false;

    if (vm.total.nf_total_carbohydrate === 0 || vm.total.nf_total_carbohydrate - vm.total.nf_dietary_fiber <= 0) {
      vm.total.net_carbs = 0;
    } else {
      vm.total.net_carbs = vm.total.nf_total_carbohydrate - vm.total.nf_dietary_fiber;
    }

    $scope.labelData = {
      adjustUserDailyValues: true,
      allowFDARounding: false,
      applyMathRounding: true,
      brandName: 'Nutritionix',
      decimalPlacesForQuantityTextbox: 2,
      itemName: 'cheeseburger',
      scrollLongItemNamePixel: 38,
      showAmountPerServing: false,
      showCalcium: true,
      showCalories: true,
      showCholesterol: true,
      showFatCalories: true,
      showFibers: true,
      showItemName: false,
      showIngredients: false,
      showIron: true,
      showMonoFat: false,
      showPolyFat: false,
      showProteins: true,
      showSatFat: true,
      showServingSize: true,
      showServingUnitQuantity: false,
      showServingsPerContainer: false,
      showSodium: true,
      showSugars: true,
      showTotalCarb: true,
      showTotalFat: true,
      showTransFat: false,
      showVitaminA: true,
      showVitaminC: true,
      'valueServingUnitQuantity': vm.total.serving_qty || 0,
      'valueServingSizeUnit': vm.total.serving_unit || 0,
      'valueCalories': vm.total.calories || 0,
      'valueFatCalories': (vm.total.total_fat || 0) * 9,
      'valueTotalFat': vm.total.total_fat || 0,
      'valueSatFat': vm.total.nf_saturated_fat || 0,
      'valueCholesterol': vm.total.nf_cholesterol || 0,
      'valueSodium': vm.total.nf_sodium || 0,
      'valueTotalCarb': vm.total.nf_total_carbohydrate || 0,
      'valueFibers': vm.total.nf_dietary_fiber || 0,
      'valueSugars': vm.total.nf_sugars || 0,
      'valueProteins': vm.total.nf_protein || 0,
      'valueVitaminA': vm.total.nf_vitamin_a_dv || 0,
      'valueVitaminC': vm.total.nf_vitamin_c_dv || 0,
      'valueCalcium': vm.total.nf_calcium_dv || 0,
      'valueIron': vm.total.nf_iron_dv || 0
    };
    $scope.dailyGoals = {};

    if (!!vm.clientId) {
      var options = {
        clientId: vm.clientId,
        begin: moment(vm.date, 'ddd, MM/DD/YY').format('YYYY-MM-DD'),
        end: moment(vm.date, 'ddd, MM/DD/YY').add(1, 'day').format('YYYY-MM-DD')
      };
      CoachService.getClientTotals(options).then(function (res) {
        if (!$scope.labelData.calorieIntake) {
          $scope.labelData.calorieIntake = res.data.dates[0].daily_kcal_limit;
        }

        $scope.dailyGoals.protein_pct = res.data.dates[0].daily_protein_pct;
        $scope.dailyGoals.protein_progress = Math.round($scope.pieChart.data[0] / $scope.dailyGoals.protein_pct * 100);
        $scope.dailyGoals.carbohydrate_pct = res.data.dates[0].daily_carbs_pct;
        $scope.dailyGoals.carbohydrate_progress = Math.round($scope.pieChart.data[1] / $scope.dailyGoals.carbohydrate_pct * 100);
        $scope.dailyGoals.fat_pct = res.data.dates[0].daily_fat_pct;
        $scope.dailyGoals.fat_progress = Math.round($scope.pieChart.data[2] / $scope.dailyGoals.fat_pct * 100);
      });
    } else {
      UserService.getUser().then(function (data) {
        if (!$scope.labelData.calorieIntake) {
          $scope.labelData.calorieIntake = data.daily_kcal;
        }

        $scope.dailyGoals.protein_pct = data.daily_protein_pct;
        $scope.dailyGoals.protein_progress = Math.round($scope.pieChart.data[0] / $scope.dailyGoals.protein_pct * 100);
        $scope.dailyGoals.carbohydrate_pct = data.daily_carbs_pct;
        $scope.dailyGoals.carbohydrate_progress = Math.round($scope.pieChart.data[1] / $scope.dailyGoals.carbohydrate_pct * 100);
        $scope.dailyGoals.fat_pct = data.daily_fat_pct;
        $scope.dailyGoals.fat_progress = Math.round($scope.pieChart.data[2] / $scope.dailyGoals.fat_pct * 100);
      })["catch"](function (err) {
        console.log('Error getting user from local DB:', err);
      });
    }

    var pieChartData = []; // if (vm.total.nf_protein*4+vm.total.nf_total_carbohydrate*4+vm.total.total_fat*9+vm.total.alcohol*7 > vm.total.calories){
    //   totalCalForPieChart = vm.total.nf_protein*4+vm.total.nf_total_carbohydrate*4+vm.total.total_fat*9+vm.total.alcohol*7;
    // }

    pieChartData = [_.round(vm.total.nf_protein * 4 / totalCalForPieChart * 100, 0), _.round(vm.total.nf_total_carbohydrate * 4 / totalCalForPieChart * 100, 0), _.round(vm.total.total_fat * 9 / totalCalForPieChart * 100, 0), _.round(vm.total.alcohol * 7 / totalCalForPieChart * 100, 0)]; // adjustment to make sure that pie chart will not show more than 100%

    if (_.sum(pieChartData) > 100) {
      var i = pieChartData.indexOf(_.max(pieChartData));
      pieChartData[i] = pieChartData[i] - (_.sum(pieChartData) - 100);
    }

    $scope.pieChart = {
      labels: ['Protein', 'Carbohydrate', 'Fat', 'Alcohol'],
      data: pieChartData,
      generateLabels: function generateLabels(chart) {
        var data = chart.data;

        if (data.labels.length && data.datasets.length) {
          return data.labels.map(function (label, i) {
            var meta = chart.getDatasetMeta(0);
            var ds = data.datasets[0];
            var arc = meta.data[i];
            var custom = arc.custom || {};
            var getValueAtIndexOrDefault = window.Chart.helpers.getValueAtIndexOrDefault;
            var arcOpts = chart.options.elements.arc;
            var fill = custom.backgroundColor ? custom.backgroundColor : getValueAtIndexOrDefault(ds.backgroundColor, i, arcOpts.backgroundColor);
            var stroke = custom.borderColor ? custom.borderColor : getValueAtIndexOrDefault(ds.borderColor, i, arcOpts.borderColor);
            var bw = custom.borderWidth ? custom.borderWidth : getValueAtIndexOrDefault(ds.borderWidth, i, arcOpts.borderWidth);
            return {
              text: label + ' ' + ds.data[i] + '%',
              fillStyle: fill,
              strokeStyle: stroke,
              lineWidth: bw,
              hidden: isNaN(ds.data[i]) || meta.data[i].hidden,
              // Extra data used for toggling the correct item
              index: i
            };
          });
        } else {
          return [];
        }
      },
      label: function label(tooltipItem, data) {
        return data.labels[tooltipItem.index] + ': ' + data.datasets[tooltipItem.datasetIndex].data[tooltipItem.index] + '%';
      }
    };

    if (pieChartData.length > 3 && pieChartData[3] < 0) {
      $scope.pieChart.labels.pop();
      pieChartData.pop();
    }
  }

  $scope.updateCalorieLimit = function () {
    $timeout(function () {
      if (!$scope.labelData.calorieIntake) {
        $scope.showCalorieError = true;
        return $timeout(function () {
          $scope.showCalorieError = false;
        }, 2000);
      }

      if (moment(vm.date, 'ddd, MM/DD/YY').isSame(moment(), 'day')) {
        UserService.setDailyCalories($scope.labelData.calorieIntake).then(function (res) {
          AnalyticsService.trackEvent('changedCalorieLimit', 'From ' + $scope.labelData.initialCalorieLimit + ' to ' + $scope.labelData.calorieIntake);
        })["catch"](function (err) {
          console.log(err);
        });
      } else {
        ApiService.setDayCalorieLimit(vm.date, $scope.labelData.calorieIntake).then(function (res) {
          AnalyticsService.trackEvent('retroactiveChangeCalorieLimit', 'From ' + $scope.labelData.initialCalorieLimit + ' to ' + $scope.labelData.calorieIntake);
        })["catch"](function (err) {
          console.log(err);
        });
      }
    }, 300);
  };

  vm.deleteFoodBulk = function () {
    if ($rootScope.noInternet) {
      navigator.notification.alert('We cannot delete this item in offline mode', null, '', 'OK');
      return;
    }

    var confirmDeletionPopup = $ionicPopup.confirm({
      title: 'Delete foods',
      template: 'Are you sure you want to delete all of your ' + $scope.mealTypeName + ' items?',
      buttons: [{
        text: 'Yes',
        type: 'button-positive',
        onTap: function onTap(e) {
          return true;
        }
      }, {
        text: 'No',
        type: 'button-default',
        onTap: function onTap(e) {
          return false;
        }
      }]
    });
    confirmDeletionPopup.then(function (res) {
      if (res) {
        var foodArray = [];
        vm.dayTotal.foods.forEach(function (food) {
          if (mealTypeFilter && mealTypeFilter !== food.meal_type) {
            return;
          }

          foodArray.push({
            id: food.id
          });
        });
        return ApiService.deleteFood(foodArray).then(function (errs) {
          errs.forEach(function (err) {
            console.log(err);
          });
        }).then(function () {
          $scope.$broadcast('refresh foodlog', 'delete');
          AnalyticsService.trackEvent('Delete - From Summary', ' ');
          return $state.go('app.foodlog');
        });
      }
    });
  };

  vm.copyFoodBulk = function () {
    if ($rootScope.noInternet) {
      navigator.notification.alert('We cannot copy this item in offline mode', null, '', 'OK');
      return;
    }

    var foodArray = [];
    vm.dayTotal.foods.forEach(function (food) {
      if (mealTypeFilter && mealTypeFilter !== food.meal_type) {
        return;
      }

      food.meal_type = null;
      food.consumed_at = moment();
      foodArray.push(food);
    });
    var newFood = JSON.parse(angular.toJson(foodArray));
    $rootScope.$broadcast('mealBuilder: addFood', {
      foodArray: newFood
    });
    AnalyticsService.trackEvent('Copy - From Summary', ' ');
    $state.go('app.reviewFoods', {
      reload: true
    });
  };

  $scope.goBack = function () {
    $ionicHistory.goBack();
  };
}]);
'use strict';

angular.module('Track').controller('UploadPhotoAgentController', ["$cordovaNetwork", "$ionicLoading", "$log", "$q", "$rootScope", "$scope", "$timeout", "UploadPhotoAgentService", "userObj", function ($cordovaNetwork, $ionicLoading, $log, $q, $rootScope, $scope, $timeout, UploadPhotoAgentService, userObj) {
  $scope.WiFiNetworkIsInUse = false;
  $scope.existingBarcodesCount = 0;
  $scope.barcodesForSyncCount = 0;
  $scope.photoTemplates = UploadPhotoAgentService.photoTemplates;
  $scope.currentSession = UploadPhotoAgentService.currentSession;
  $scope.$on('$ionicView.enter', function (event, data) {
    $scope.WiFiNetworkIsInUse = 'wifi' === $cordovaNetwork.getNetwork(); // UploadPhotoAgentService.dropExistingBarcodesTable();

    UploadPhotoAgentService.needToUpdateExistingBarcodes().then(function (needToUpdateExistingBarcodes) {
      if (needToUpdateExistingBarcodes) {
        $ionicLoading.show({
          template: 'Please hold while the barcodes table is updated.<br/>This should complete within 15 seconds.'
        });
        return UploadPhotoAgentService.checkExistingBarcodesTableExists().then(function (existingBarcodesTableExists) {
          return existingBarcodesTableExists ? true : UploadPhotoAgentService.createExistingBarcodesTable();
        }).then(function () {
          return UploadPhotoAgentService.deleteExistingBarcodes();
        }).then(function () {
          return UploadPhotoAgentService.requestExistingBarcodes();
        }).then(function (barcodes) {
          var chunks = _.chunk(barcodes, 500);

          return chunks.reduce(function (promise, chunk) {
            return promise.then(function (result) {
              return UploadPhotoAgentService.insertExistingBarcodes(chunk).then(function (count) {
                if (barcodes.length === count) {
                  $ionicLoading.hide();
                } else {
                  $ionicLoading.show({
                    template: 'Synced ' + count + ' out of ' + barcodes.length + ' records.'
                  });
                }

                return count;
              });
            })["catch"](function (error) {
              throw error;
            });
          }, $q.when(''));
        });
      } else {
        return UploadPhotoAgentService.countExistingBarcodes();
      }
    }).then(function (count) {
      $scope.existingBarcodesCount = count;
    })["catch"](function (error) {
      $log.error(error);
      $ionicLoading.show({
        template: 'Error during existing barcodes sync. Our developers has been informed.',
        duration: 3000
      });
      throw error;
    }); // UploadPhotoAgentService.dropRecordsForSyncTable();

    UploadPhotoAgentService.checkRecordsForSyncTableExists().then(function (recordsForSyncTableExists) {
      return recordsForSyncTableExists ? true : UploadPhotoAgentService.createRecordsForSyncTable();
    }).then(function () {
      return UploadPhotoAgentService.countRecordsForSyncBarcodes();
    }).then(function (count) {
      $scope.barcodesForSyncCount = count;
    })["catch"](function (error) {
      $log.error(error);
    });
  });
  $rootScope.$on('$cordovaNetwork:online', function (event, networkState) {
    $scope.WiFiNetworkIsInUse = 'wifi' === $cordovaNetwork.getNetwork();
  });
  $rootScope.$on('$cordovaNetwork:offline', function (event, networkState) {
    $scope.WiFiNetworkIsInUse = false;
  });
  $scope.$watch('currentSession', function (newValue, oldValue) {}, true);

  $scope.scanBarcode = function () {
    UploadPhotoAgentService.scanBarcode({
      userId: userObj.id
    }).then(function (scanBarcodeResult) {
      if (!scanBarcodeResult) {
        $ionicLoading.show({
          template: 'Looks like we already have<br/>this product in our DB.',
          duration: 2000
        });
      }
    })["catch"](function (error) {
      $log.error(error);
    });
  };

  $scope.takePhoto = function (photoType) {
    UploadPhotoAgentService.takePhoto(photoType)["catch"](function (error) {
      if ('Camera cancelled.' !== error) {
        $log.error(error);
      }
    });
  };

  $scope.saveRecordsForSync = function () {
    UploadPhotoAgentService.saveRecordsForSync().then(function (saveResult) {
      $scope.currentSession = UploadPhotoAgentService.resetCurrentSession();
      return UploadPhotoAgentService.countRecordsForSyncBarcodes();
    }).then(function (count) {
      $scope.barcodesForSyncCount = count;
      $scope.scanBarcode();
    })["catch"](function (error) {
      $log.error(error);
    });
  };

  $scope.cancel = function () {
    $scope.currentSession = UploadPhotoAgentService.resetCurrentSession();
  };

  $scope.sequentialSync = function () {
    $ionicLoading.show({
      template: 'Please hold while the sync is in progress.<br/>This should complete within 15 seconds.'
    });
    UploadPhotoAgentService.getRecordsForSync().then(function (recordsForSync) {
      return recordsForSync.reduce(function (promise, record) {
        return promise.then(function (result) {
          return UploadPhotoAgentService.syncRecord(record).then(function (uploadResult) {
            return UploadPhotoAgentService.countRecordsForSyncBarcodes();
          }).then(function (count) {
            $scope.barcodesForSyncCount = count;

            if (!count) {
              $ionicLoading.show({
                template: 'Sync is complete!<br/>Thanks for being so patient.',
                duration: 2000
              });
            } else {
              $ionicLoading.show({
                template: 'Please hold while the sync is in progress.<br/>' + count + ' barcodes left.'
              });
            }
          })["catch"](function (e) {
            $log.error(e);
          });
        });
      }, $q.when(''));
    });
  };

  $scope.parallelSync = function () {
    $ionicLoading.show({
      template: 'Please hold while the sync is in progress.<br/>This should complete within 15 seconds.'
    });
    UploadPhotoAgentService.sync().then(function (promises) {
      return UploadPhotoAgentService.countRecordsForSyncBarcodes();
    }).then(function (count) {
      $scope.barcodesForSyncCount = count;
    }).then(function () {
      $ionicLoading.show({
        template: 'Sync is complete!<br/>Thanks for being so patient.'
      });
    })["catch"](function (e) {
      $log.error(e);
    })["finally"](function () {
      $timeout(function () {
        $ionicLoading.hide();
      }, 2000);
    });
  };
}]);
'use strict';

angular.module('Track').controller('UploadPhotoUserController', ["$ionicHistory", "$ionicLoading", "$ionicPopup", "$log", "$rootScope", "$scope", "$state", "$stateParams", "UploadPhotoUserService", "userObj", "_", function ($ionicHistory, $ionicLoading, $ionicPopup, $log, $rootScope, $scope, $state, $stateParams, UploadPhotoUserService, userObj, _) {
  $scope.canUpload = false;
  $scope.barcode = _.trimStart($stateParams.barcode, 0);
  $scope.redirectState = $stateParams.redirectState;
  $scope.$on('$ionicView.beforeEnter', function (event, data) {
    $scope.photos = UploadPhotoUserService.photos;
  });
  $scope.$on('$ionicView.beforeLeave', function (event, data) {
    UploadPhotoUserService.resetPhotos()["catch"](function (error) {
      $log.error(error);
    });
  });
  $scope.message = !!$scope.redirectState ? 'Thanks for helping us to keep Nutritionix database up-to-date!' : 'Congratulations! You found a product we do not yet have in the Nutritionix database. Can you help us by taking 2 photos of the product?';
  $rootScope.$on('photos changed', function () {
    $scope.canUpload = UploadPhotoUserService.canUpload();

    if (!UploadPhotoUserService.photos.front.notUploaded && !UploadPhotoUserService.photos.nutrition.notUploaded) {
      $ionicLoading.show({
        template: !!$scope.redirectState ? '<p class="text-center">Thank You!</p>' + '<p>We will have this product updated in our database in the next three business days.</p>' : '<p class="text-center">Thank You!</p>' + '<p>We will have this product added to our database in the next three business days.</p>' + '<p>To add a comparable food to your log right now, use the "Smart" tab and enter the calories of the food, followed by a generic name of the food.</p>' + '<p>Examples:<br/>100 cal greek yogurt<br/>150 cal granola bar<br/>250 cal lean cuisine</p>',
        duration: 3000
      });
      UploadPhotoUserService.resetPhotos();

      if ($scope.redirectState) {
        $state.go($scope.redirectState);
      } else {
        $state.go('app.addfoodsmart');
      }
    }
  });

  $scope.takePhoto = function (photoType) {
    UploadPhotoUserService.takePhoto({
      photoType: photoType,
      barcode: $scope.barcode,
      user: userObj
    }) // .then(function(){
    //   return UploadPhotoUserService.upload();
    // })
    ["catch"](function (error) {
      if ('Camera cancelled.' !== error) {
        $log.error(error);
      }
    });
  };

  $scope.upload = function () {
    $ionicLoading.show({
      template: 'Please hold while the photos are uploaded...'
    });
    UploadPhotoUserService.upload().then(function (promises) {
      $ionicLoading.hide();
      var template = !!$scope.redirectState ? '<p>We will have this product updated in our database in the next three business days.</p>' : '<p>We will have this product added to our database in the next three business days.</p>' + '<p>To add a comparable food to your log right now, use the "Smart" tab and enter the calories of the food, followed by a generic name of the food.</p>' + '<p>Examples:<br/>100 cal greek yogurt<br/>150 cal granola bar<br/>250 cal lean cuisine</p>';
      return $ionicPopup.alert({
        title: 'Thank you!',
        template: template,
        okText: 'Close'
      });
    }).then(function () {
      if ($scope.redirectState) {
        $state.go($scope.redirectState);
      } else {
        $state.go('app.addfoodsmart');
      }
    })["catch"](function (error) {
      $log.error(error);
      $ionicLoading.hide();
    });
  };

  $scope.goBack = function () {
    // UploadPhotoUserService.resetPhotos();
    $ionicHistory.goBack();
  };

  $scope.goToPrivacyPolicy = function () {
    var options = {
      location: 'no',
      toolbar: 'yes'
    };
    cordova.InAppBrowser.open('https://www.nutritionix.com/privacy', '_blank', options)["catch"](function (error) {
      $log.error(error);
    });
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:UsersController
 * @description
 * # UsersController
 */

angular.module('Track').controller('UsersController', ["$scope", "users", "LoginService", "$state", function ($scope, users, LoginService, $state) {
  $scope.usersObj = users.data.users;

  $scope.changeActiveUser = function (user) {
    LoginService.setActiveUser(user);
    $state.go('app.foodlog');
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:viewClientController
 * @description
 * # viewClientController
 */

angular.module('Track').controller('viewClientController', ["$scope", "$state", "$ionicHistory", "$stateParams", "CoachService", function ($scope, $state, $ionicHistory, $stateParams, CoachService) {
  $scope.$on('$ionicView.beforeEnter', function () {
    $scope.data = {};
    $scope.data.showPreloader = true;
    $scope.data.clientId = $stateParams.clientId;
    $scope.data.client = $stateParams.client;

    if (_.isEmpty($scope.data.client) && !!$scope.data.clientId) {
      CoachService.getClients().then(function (res) {
        $scope.data.client = res.data.users[$scope.data.clientId];
        $scope.data.age = moment().diff(moment($scope.data.client.birth_year, 'YYYY'), 'years') || '';
      })["catch"](function (err) {
        console.log('error getting list of clients:', err);
      });
    }

    $scope.data.age = moment().diff(moment($scope.data.client.birth_year, 'YYYY'), 'years') || '';
    $scope.data.currentMonth = moment().startOf('month').format('YYYY-MM-DD');
    $scope.data.nextMonth = moment($scope.data.currentMonth).add(1, 'month').format('YYYY-MM-DD');
    $scope.data.prevMonth = moment($scope.data.currentMonth).subtract(1, 'month').format('YYYY-MM-DD');

    $scope.barColor = function (totalCalories, calorieLimit) {
      if (!calorieLimit) {
        calorieLimit = !!$scope.dayTotals && $scope.dayTotals.daily_kcal_limit ? $scope.dayTotals.daily_kcal_limit : 2000;
      }

      if (totalCalories < calorieLimit && totalCalories > calorieLimit * 0.9) {
        return '#f0b840';
      } else if (totalCalories > calorieLimit) {
        return '#ef4e3a';
      } else {
        return '#28a54c';
      }
    };

    CoachService.getClientTotals({
      clientId: $scope.data.client.id || $scope.data.clientId,
      timezone: $scope.data.client.timezone
    }).then(function (res) {
      if (!res || !res.data || !res.data.dates) {
        return;
      }

      var totalsCopy = res.data.dates;
      $scope.data.daysLastWeek = 0;

      for (var i = 0; i < totalsCopy.length; i++) {
        // if (!totalsCopy[i].exercises_logged && !totalsCopy[i].foods_logged && !totalsCopy[i].weights_logged && !totalsCopy[i].water_consumed_liter){
        //   totalsCopy.splice(i, 1);
        //   i--;
        //   continue;
        // }
        if (!totalsCopy[i].total_cal) {
          totalsCopy[i].total_cal = 0;
        }

        totalsCopy[i].totalProtein = totalsCopy[i].totalProtein ? totalsCopy[i].totalProtein : 0;
        totalsCopy[i].totalCarbohydrate = totalsCopy[i].totalCarbohydrate ? totalsCopy[i].totalCarbohydrate : 0;
        totalsCopy[i].totalFat = totalsCopy[i].totalFat ? totalsCopy[i].totalFat : 0;
        totalsCopy[i].noCalFromTotals = !totalsCopy[i].total_cal;

        if (moment(totalsCopy[i].date, 'YYYY-MM-DD').diff(moment().startOf('week'), 'days') > 0) {
          $scope.data.daysLastWeek++;
        }
      }

      CoachService.getClientFoodLog({
        clientId: $scope.data.client.id || $scope.data.clientId,
        timezone: $scope.data.client.timezone
      }).then(function (res) {
        if (!res || !res.data || !res.data.foods) {
          return;
        }

        $scope.data.foodLog = res.data.foods;

        for (var i = 0; i < res.data.foods.length; i++) {
          var date = moment(res.data.foods[i].consumed_at).tz($scope.data.client.timezone).format('YYYY-MM-DD');

          var dayTotalsIndex = _.findIndex(totalsCopy, function (dayTotals) {
            return dayTotals.date === date;
          });

          if (totalsCopy[dayTotalsIndex].noCalFromTotals) {
            totalsCopy[dayTotalsIndex].total_cal += result.data.foods[i].nf_calories;
          }

          totalsCopy[dayTotalsIndex].totalProtein += res.data.foods[i].nf_protein;
          totalsCopy[dayTotalsIndex].totalCarbohydrate += res.data.foods[i].nf_total_carbohydrate;
          totalsCopy[dayTotalsIndex].totalFat += res.data.foods[i].nf_total_fat;
        }

        $scope.data.totals = totalsCopy;
        $scope.data.showPreloader = false;
      })["catch"](function (err) {
        console.log('error getting client\'s log', err);
      });
    })["catch"](function (err) {
      console.log('error getting client\'s totals', err);
    });
  });

  $scope.changeMonth = function (count) {
    if (!count) return;
    $scope.data.showPreloader = true;
    $scope.data.totals = [];
    $scope.data.foodLog = [];
    $scope.data.currentMonth = moment($scope.data.currentMonth, 'YYYY-MM-DD').add(count, 'month').startOf('month').format('YYYY-MM-DD');
    $scope.data.nextMonth = moment($scope.data.currentMonth).add(1, 'month').format('YYYY-MM-DD');
    $scope.data.prevMonth = moment($scope.data.currentMonth).subtract(1, 'month').format('YYYY-MM-DD');
    var options = {
      clientId: $scope.data.client.id || $scope.data.clientId,
      timezone: $scope.data.client.timezone,
      begin: moment($scope.data.currentMonth, 'YYYY-MM-DD').startOf('month').format('YYYY-MM-DD'),
      end: moment($scope.data.currentMonth, 'YYYY-MM-DD').endOf('month').add(1, 'day').format('YYYY-MM-DD')
    };
    CoachService.getClientTotals(options).then(function (res) {
      if (!res || !res.data || !res.data.dates) {
        return;
      }

      var totalsCopy = [];
      totalsCopy = totalsCopy.concat(res.data.dates);
      $scope.data.daysLastWeek = 0;

      for (var i = 0; i < totalsCopy.length; i++) {
        // if (!totalsCopy[i].exercises_logged && !totalsCopy[i].foods_logged && !totalsCopy[i].weights_logged && !totalsCopy[i].water_consumed_liter){
        //   totalsCopy.splice(i, 1);
        //   i--;
        //   continue;
        // }
        if (!totalsCopy[i].total_cal) {
          totalsCopy[i].total_cal = 0;
        }

        totalsCopy[i].totalProtein = totalsCopy[i].totalProtein ? totalsCopy[i].totalProtein : 0;
        totalsCopy[i].totalCarbohydrate = totalsCopy[i].totalCarbohydrate ? totalsCopy[i].totalCarbohydrate : 0;
        totalsCopy[i].totalFat = totalsCopy[i].totalFat ? totalsCopy[i].totalFat : 0;

        if (moment(totalsCopy[i].date, 'YYYY-MM-DD').diff(moment().startOf('week'), 'days') > 0) {
          $scope.data.daysLastWeek++;
        }
      }

      CoachService.getClientFoodLog(options).then(function (result) {
        if (!result || !result.data || !result.data.foods) {
          return;
        }

        $scope.data.foodLog = result.data.foods;

        for (var i = 0; i < result.data.foods.length; i++) {
          var date = moment(result.data.foods[i].consumed_at).tz($scope.data.client.timezone).format('YYYY-MM-DD');

          var dayTotalsIndex = _.findIndex(totalsCopy, function (dayTotals) {
            return dayTotals.date === date;
          });

          if (!totalsCopy[dayTotalsIndex].total_cal) {
            totalsCopy[dayTotalsIndex].total_cal += parseFloat(result.data.foods[i].nf_calories);
          }

          totalsCopy[dayTotalsIndex].totalProtein += result.data.foods[i].nf_protein;
          totalsCopy[dayTotalsIndex].totalCarbohydrate += result.data.foods[i].nf_total_carbohydrate;
          totalsCopy[dayTotalsIndex].totalFat += result.data.foods[i].nf_total_fat;
        }

        $scope.data.totals = totalsCopy;
        $scope.data.showPreloader = false;
      })["catch"](function (err) {
        console.log('error getting client\'s log', err);
      });
    })["catch"](function (err) {
      console.log('error getting client\'s totals', err);
    });
  };

  $scope.goToDayLog = function (date) {
    $state.go('app.viewClientDayLog', {
      date: date,
      client: $scope.data.client,
      foodLog: $scope.data.foodLog,
      totals: $scope.data.totals
    });
  };

  $scope.emailToClient = function () {
    if (!window.cordova && !window.cordova.plugins && !window.cordova.plugins.email && !$scope.data && !$scope.data.client && !$scope.data.client.email) {
      return;
    }

    window.cordova.plugins.email.open({
      'to': $scope.data.client.email
    });
  };

  $scope.goBack = function () {
    $ionicHistory.goBack();
  };
}]);
'use strict';
/*jshint multistr: true */

/**
 * @ngdoc function
 * @name Track.controller:ViewClientDayLogController
 * @description
 * # ViewClientDayLogController
 */

angular.module('Track').controller('viewClientDayLogController', ["$scope", "$state", "$stateParams", "$window", "$timeout", "$ionicHistory", "CoachService", "ApiService", "HelperService", "UserService", function ($scope, $state, $stateParams, $window, $timeout, $ionicHistory, CoachService, ApiService, HelperService, UserService) {
  $scope.isNewLogLoading = false;
  $scope.cut = 34;

  if ($window.screen.width >= 375) {
    $scope.cut = 42;
  }

  function generateLogDates() {
    var dates = [],
        days = $scope.logDatesInterval && $scope.logDatesInterval.begin ? moment($scope.logDatesInterval.begin).daysInMonth() : moment().daysInMonth(),
        start = $scope.logDatesInterval && $scope.logDatesInterval.begin ? $scope.logDatesInterval.begin : moment().startOf('month').format('YYYY-MM-DD'),
        end = $scope.logDatesInterval && $scope.logDatesInterval.begin ? moment($scope.logDatesInterval.end) : moment().endOf('month');

    for (var i = 0; i < days; i++) {
      var date = end.format('ddd, MM/DD/YY');
      dates.push(date);
      end.subtract(1, 'day');
    }

    return dates;
  }

  function generateFoodLog() {
    var datesArray = generateLogDates();
    $scope.foodLog = {};
    $scope.clientTotals = {};

    _.forEach(datesArray, function (date) {
      $scope.foodLog[date] = {
        foods: [],
        totalCalories: 0,
        totalProtein: 0,
        totalCarbohydrate: 0,
        totalFat: 0,
        totalSodium: 0
      };
      $scope.clientTotals[date] = {
        date: moment(date, 'ddd, MM/DD/YY').format('YYYY-MM-DD'),
        total_cal: 0,
        total_cal_burned: 0,
        total_proteins: 0,
        total_carbs: 0,
        total_fat: 0,
        total_sodium: 0,
        water_consumed_liter: 0,
        avg_weight_kg: null,
        daily_kcal_limit: 2000,
        daily_carbs_pct: 0,
        daily_fat_pct: 0,
        daily_protein_pct: 0,
        foods_logged: 0,
        exercises_logged: 0,
        weights_logged: 0
      };
    });

    for (var j = 0; j < $scope.totals.length; j++) {
      if ($scope.clientTotals[moment($scope.totals[j].date, 'YYYY-MM-DD').format('ddd, MM/DD/YY')]) {
        $scope.clientTotals[moment($scope.totals[j].date, 'YYYY-MM-DD').format('ddd, MM/DD/YY')] = $scope.totals[j];
      }
    }

    for (var i = 0; i < $scope.monthFoodLog.length; i++) {
      if (!$scope.monthFoodLog[i].meal_type) {
        $scope.monthFoodLog[i].meal_type = HelperService.calculateMealTypeByTime(moment($scope.monthFoodLog[i].consumed_at).tz($scope.user.timezone).format('H'));
      }

      var foodDate = moment($scope.monthFoodLog[i].consumed_at.toString()).tz($scope.user.timezone).format('ddd, MM/DD/YY');

      if ($scope.foodLog[foodDate]) {
        $scope.monthFoodLog[i].serving_qty = $scope.monthFoodLog[i].serving_qty || '1';

        if ($scope.monthFoodLog[i].alt_measures) {
          var temp = {
            'serving_weight': $scope.monthFoodLog[i].serving_weight_grams,
            'seq': null,
            'measure': $scope.monthFoodLog[i].serving_unit,
            'qty': $scope.monthFoodLog[i].serving_qty
          };
          $scope.monthFoodLog[i].alt_measures.unshift(temp);
        }

        $scope.foodLog[foodDate].foods.push($scope.monthFoodLog[i]);
        $scope.foodLog[foodDate].totalCalories = $scope.foodLog[foodDate].totalCalories + $scope.monthFoodLog[i].nf_calories;
        $scope.foodLog[foodDate].totalProtein = $scope.foodLog[foodDate].totalProtein + $scope.monthFoodLog[i].nf_protein;
        $scope.foodLog[foodDate].totalCarbohydrate = $scope.foodLog[foodDate].totalCarbohydrate + $scope.monthFoodLog[i].nf_total_carbohydrate;
        $scope.foodLog[foodDate].totalFat = $scope.foodLog[foodDate].totalFat + $scope.monthFoodLog[i].nf_total_fat;
        $scope.foodLog[foodDate].totalSodium = $scope.foodLog[foodDate].totalSodium + $scope.monthFoodLog[i].nf_sodium;
      }
    }

    $scope.selected_day.log = formatLogSelectedDate($scope.foodLog[$scope.selected_day.date]);
  }

  function generateExerciseLog() {
    var datesArray = generateLogDates();
    $scope.exerciseLog = {};

    _.forEach(datesArray, function (date) {
      $scope.exerciseLog[date] = [];
    });

    for (var i = 0; i < $scope.monthExerciseLog.length; i++) {
      var exerciseDate = moment($scope.monthExerciseLog[i].timestamp.toString()).tz($scope.user.timezone).format('ddd, MM/DD/YY');

      if ($scope.exerciseLog[exerciseDate]) {
        $scope.exerciseLog[exerciseDate].push($scope.monthExerciseLog[i]);
      }
    }
  }

  $scope.$on('$ionicView.beforeEnter', function () {
    $scope.monthFoodLog = $stateParams.foodLog;
    $scope.user = $stateParams.client;
    $scope.totals = $stateParams.totals;
    UserService.getUser().then(function (res) {
      $scope.coach = res;
    });
    $scope.logDatesInterval = {
      begin: $stateParams.date ? moment($stateParams.date).startOf('month').format('YYYY-MM-DD') : moment().startOf('month').format('YYYY-MM-DD'),
      end: $stateParams.date ? moment($stateParams.date).endOf('month').format('YYYY-MM-DD') : moment().endOf('month').format('YYYY-MM-DD')
    };
    $scope.selected_day = {
      date: $stateParams.date ? moment($stateParams.date).format('ddd, MM/DD/YY') : moment().startOf('month').format('ddd, MM/DD/YY'),
      log: {}
    };
    generateFoodLog();
  });
  $scope.$on('$ionicView.enter', function () {
    $scope.calculateFoodLogOffset($scope.selected_day.date);
    var options = {
      begin: $scope.logDatesInterval.begin,
      end: $scope.logDatesInterval.end,
      timezone: '',
      clientId: $scope.user.id
    };
    CoachService.getClientExerciseLog(options).then(function (res) {
      $scope.monthExerciseLog = res.data.exercises;
      generateExerciseLog();
    })["catch"](function (err) {
      console.log(err);
    });
    $scope.$watch('isNewLogLoading', function (oldVal, newVal) {
      if (newVal) {
        setTimeout(function () {
          $scope.isNewLogLoading = false;
        }, 3000);
      }
    });
  });

  $scope.getCurrentDayName = function () {
    var currentDayName = moment().format('ddd, MM/DD/YY') === moment($scope.selected_day.date, 'ddd, MM/DD/YY').format('ddd, MM/DD/YY') ? 'Today' : moment($scope.selected_day.date, 'ddd, MM/DD/YY').format('dddd');
    return currentDayName;
  };

  $scope.barColor = function (totalCalories, calorieLimit) {
    if (!calorieLimit) {
      calorieLimit = !!$scope.dayTotals && $scope.dayTotals.daily_kcal_limit ? $scope.dayTotals.daily_kcal_limit : 2000;
    }

    if (totalCalories < calorieLimit && totalCalories > calorieLimit * 0.9) {
      return '#f0b840';
    } else if (totalCalories > calorieLimit) {
      return '#ef4e3a';
    } else {
      return '#28a54c';
    }
  };

  function formatLogSelectedDate(days_log) {
    var output = {};
    output.totalCalories = days_log && days_log.totalCalories ? days_log.totalCalories : 0;
    output.totalCarbohydrate = days_log && days_log.totalCarbohydrate ? days_log.totalCarbohydrate : 0;
    output.totalFat = days_log && days_log.totalFat ? days_log.totalFat : 0;
    output.totalProtein = days_log && days_log.totalProtein ? days_log.totalProtein : 0;
    output.totalSodium = days_log && days_log.totalSodium ? days_log.totalSodium : 0;
    output.breakfast = [];
    output.am_snack = [];
    output.lunch = [];
    output.pm_snack = [];
    output.dinner = [];
    output.late_snack = [];

    if (!!days_log) {
      output.breakfast = _.filter(days_log.foods, function (food) {
        return food.meal_type == 1;
      });
      output.am_snack = _.filter(days_log.foods, function (food) {
        return food.meal_type == 2;
      });
      output.lunch = _.filter(days_log.foods, function (food) {
        return food.meal_type == 3;
      });
      output.pm_snack = _.filter(days_log.foods, function (food) {
        return food.meal_type == 4;
      });
      output.dinner = _.filter(days_log.foods, function (food) {
        return food.meal_type == 5;
      });
      output.late_snack = _.filter(days_log.foods, function (food) {
        return food.meal_type == 6;
      });
      output.breakfast_calories = _.reduce(output.breakfast, function (sum, food) {
        return sum + food.nf_calories;
      }, 0);
      output.am_snack_calories = _.reduce(output.am_snack, function (sum, food) {
        return sum + food.nf_calories;
      }, 0);
      output.lunch_calories = _.reduce(output.lunch, function (sum, food) {
        return sum + food.nf_calories;
      }, 0);
      output.pm_snack_calories = _.reduce(output.pm_snack, function (sum, food) {
        return sum + food.nf_calories;
      }, 0);
      output.dinner_calories = _.reduce(output.dinner, function (sum, food) {
        return sum + food.nf_calories;
      }, 0);
      output.late_snack_calories = _.reduce(output.late_snack, function (sum, food) {
        return sum + food.nf_calories;
      }, 0);
    }

    return output;
  }

  $scope.goToFood = function (food) {
    return ApiService.setCurrentFood(food).then(function () {
      return $state.go('app.food', {
        food_id: food.id,
        readOnly: true
      });
    });
  };

  $scope.goToTotal = function (dayValue, mealType) {
    var params = {
      mealTypeFilter: mealType || null,
      readOnly: true,
      clientId: $scope.user.id,
      date: $scope.selected_day.date,
      dayValue: dayValue
    };
    $state.go('app.total', params);
  };

  $scope.isNewLogLoading = false;

  $scope.changeOnDays = function (dayDiff) {
    var newDay = moment($scope.selected_day.date, 'ddd, MM/DD/YY').add(dayDiff, 'days').format('ddd, MM/DD/YY');

    if ($scope.foodLog[newDay]) {
      $scope.selected_day.date = newDay;
      $scope.selected_day.log = formatLogSelectedDate($scope.foodLog[$scope.selected_day.date]);
      $scope.selected_day.meta = $scope.clientTotals[$scope.selected_day.date];

      if ($scope.selected_day.meta.daily_kcal_limit === null || $scope.selected_day.meta.daily_kcal_limit === undefined) {
        $scope.selected_day.meta.daily_kcal_limit = $scope.user.daily_kcal;
      }
    } else {
      if (!$scope.isNewLogLoading) {
        $scope.selected_day.date = newDay;
        $scope.calculateFoodLogOffset(newDay);
        $scope.isNewLogLoading = true;
        var options = {
          begin: moment(newDay).startOf('month').format('YYYY-MM-DD'),
          end: moment(newDay).endOf('month').add(1, 'day').format('YYYY-MM-DD'),
          timezone: '',
          clientId: $scope.user.id
        };
        CoachService.getClientFoodLog(options).then(function (res) {
          $scope.monthFoodLog = res.data.foods;
          return;
        }).then(function () {
          return CoachService.getClientTotals(options).then(function (res) {
            $scope.totals = res.data.dates;
            return;
          })["catch"](function (err) {
            console.log(err);
          });
        }).then(function () {
          return CoachService.getClientExerciseLog(options).then(function (res) {
            $scope.monthExerciseLog = res.data.exercises;
            return;
          })["catch"](function (err) {
            console.log(err);
          });
        }).then(function () {
          generateFoodLog();
          generateExerciseLog();
          $scope.isNewLogLoading = false;
        })["catch"](function (err) {
          $scope.isNewLogLoading = false;
          console.log(err);
        });
      } else {
        return false;
      }
    }
  };

  $scope.calculateFoodLogOffset = function (newDate) {
    var differenceInDays = moment().startOf('day').diff(moment(newDate, 'ddd, MM/DD/YY').startOf('day'), 'days');
    $scope.foodLogOffset = _.floor(differenceInDays / 7, 0) * 7;
    $scope.logDatesInterval = {
      begin: moment(newDate, 'ddd, MM/DD/YY').startOf('month').format('YYYY-MM-DD'),
      end: moment(newDate, 'ddd, MM/DD/YY').endOf('month').format('YYYY-MM-DD')
    };
  };

  $scope.goBack = function () {
    $ionicHistory.goBack();
  };
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.controller:weightGraphController
 * @description
 * # weightGraphController
 */

angular.module('Track').controller('weightGraphController', ["$cordovaDatePicker", "$filter", "$q", "$rootScope", "$state", "$scope", "nixTrackApiClient", "UserService", function ($cordovaDatePicker, $filter, $q, $rootScope, $state, $scope, nixTrackApiClient, UserService) {
  var vm = this;
  var maxPoints = $scope.maxPoints || 12;
  $scope.dayDateFormat = 'YYYY-MM-DD';
  $scope.monthDateFormat = 'YYYY-MM';
  UserService.getUser().then(function (user) {
    $scope.measureSystem = user.measure_system;
    $scope.timezone = user.timezone;
    $scope.weightUnit = user.measure_system ? 'kg' : 'lbs';
    $scope.lastWeight = user.weight_kg;
  })["catch"](function (err) {
    console.log('There was error getting active user from DB:', err);
  });
  vm.interval = 4;
  $scope.intervals = ['Last 7 days', 'Last 30 days', 'This Month', 'Previous Month', 'Last 3 Months', 'Last 6 Months', 'Since Starting Weight'];
  $scope.stats = {
    startValue: '',
    endValue: '',
    endText: '',
    change: ''
  };

  $scope.setInterval = function () {
    switch (vm.interval) {
      case 1:
        $scope.begin.value = moment().startOf('day').subtract(30, 'days').toDate();
        $scope.end.value = moment().startOf('day').toDate();
        break;

      case 2:
        $scope.begin.value = moment().startOf('month').toDate();
        $scope.end.value = moment().startOf('day').toDate();
        break;

      case 3:
        $scope.begin.value = moment().subtract(1, 'month').startOf('month').toDate();
        $scope.end.value = moment($scope.begin.value).endOf('month').toDate();
        break;

      case 4:
        $scope.begin.value = moment().subtract(3, 'month').toDate();
        $scope.end.value = moment().startOf('day').toDate();
        break;

      case 5:
        $scope.begin.value = moment().subtract(6, 'month').toDate();
        $scope.end.value = moment().startOf('day').toDate();
        break;

      case 6:
        $scope.begin.value = null;
        $scope.end.value = moment().startOf('day').toDate();
        break;

      default:
        $scope.begin.value = moment().subtract(7, 'days').toDate();
        $scope.end.value = moment().startOf('day').toDate();
        break;
    }

    $scope.loadWeights();
  };

  $scope.setCustomInterval = function () {
    $scope.interval = '';
    $scope.loadWeights();
  };

  $scope.showDatePicker = function (input) {
    var datePickerOptions = {
      mode: 'date',
      allowFutureDates: true,
      doneButtonLabel: 'DONE',
      doneButtonColor: '#000',
      cancelButtonLabel: 'CANCEL',
      cancelButtonColor: '#000',
      androidTheme: '16973939'
    };
    var isIOS = window.ionic.Platform.isIOS();

    if (input === 'begin') {
      datePickerOptions.date = moment($scope.begin.value).toDate();
      datePickerOptions.maxDate = isIOS ? moment($scope.end.value) : moment($scope.end.value).valueOf();
    } else {
      datePickerOptions.date = moment($scope.end.value).toDate();
      datePickerOptions.minDate = isIOS ? moment($scope.begin.value) : moment($scope.begin.value).valueOf();
      datePickerOptions.maxDate = isIOS ? moment() : moment().valueOf();
    }

    return $cordovaDatePicker.show(datePickerOptions).then(function (date) {
      if (input === 'begin') {
        $scope.begin.value = moment(date).toDate();
        $scope.setCustomInterval();
      } else {
        $scope.end.value = moment(date).toDate();
        $scope.setCustomInterval();
      }
    })["catch"](function (err) {
      console.log('Error opening datepicker', err);
    });
  };

  $scope.begin = {
    minDate: null,
    maxDate: moment().startOf('day').toDate(),
    value: moment().subtract(3, 'month').toDate(),
    opened: false
  };
  $scope.begin.initialValue = $scope.begin.value;
  $scope.end = {
    minDate: null,
    maxDate: moment().startOf('day').toDate(),
    value: moment().startOf('day').toDate(),
    opened: false
  };
  $scope.end.initialValue = $scope.end.value; // Line Chart

  $scope.chartLineOptions = {
    maintainAspectRatio: true,
    responsive: true,
    tooltips: {
      callbacks: {
        label: function label(tooltipItem, data) {
          return data.datasets[tooltipItem.datasetIndex].data[tooltipItem.index] + ' ' + $scope.weightUnit;
        }
      }
    }
  };
  $scope.datasetOverride = [{
    hitRadius: 10
  }];
  $scope.chartLineColours = ['#494750'];

  var calculateWeightGraph = function calculateWeightGraph() {
    var dates = {};

    var months = _.round(moment($scope.end.value).diff(moment($scope.begin.value), 'month', true), 0);

    var dateFormat = '',
        labelDateFormat = '';

    if (months < 4) {
      dateFormat = $scope.dayDateFormat;
      labelDateFormat = 'MMM DD';
    } else {
      dateFormat = $scope.monthDateFormat;
      labelDateFormat = 'MMM \'YY';
    }

    $scope.weights.forEach(function (weight) {
      var date = moment(weight.timestamp).format(dateFormat);

      if (!dates[date]) {
        dates[date] = [];
      }

      dates[date].push(weight.kg);

      if (!dates[date].mostRecent || dates[date].mostRecent.timestamp < weight.timestamp) {
        dates[date].mostRecent = weight;
      }

      if (!dates[date].veryFirst || dates[date].veryFirst.timestamp > weight.timestamp) {
        dates[date].veryFirst = weight;
      }
    });

    var datesKeys = _.keys(dates).sort();

    _.forEach(dates, function (weights, date) {
      if (date === datesKeys[datesKeys.length - 1]) {
        dates[date] = weights.mostRecent.kg;
      } else if (date === datesKeys[0] && $scope.begin.value === null) {
        dates[date] = weights.veryFirst.kg;
      } else {
        dates[date] = _.sum(weights) / weights.length;
      }
    });

    if (datesKeys.length > maxPoints) {
      var intervalLength = (datesKeys.length - 2) / (maxPoints - 2);
      var tmp = [];

      for (var i = 1; i <= maxPoints - 2; i += 1) {
        var startIndex = 1 + (i - 1) * intervalLength;
        var endIndex = 1 + i * intervalLength;
        var index = (startIndex + endIndex) / 2;
        index = _[i <= (maxPoints - 2) / 2 ? 'ceil' : 'floor'](index);
        tmp.push(datesKeys[index]);
      }

      tmp.unshift(datesKeys[0]);
      tmp.push(datesKeys[datesKeys.length - 1]);
      datesKeys = _.uniq(tmp);
    }

    $scope.chartLineLabels = [];
    $scope.chartLineCharts = [[]];
    $scope.datesKeys = datesKeys;
    var promises = [];
    datesKeys.forEach(function (date) {
      $scope.chartLineLabels.push(moment.utc(date, dateFormat).format(labelDateFormat));
      promises.push($filter('kgToUserUnits')(dates[date]));
    });
    $q.all(promises).then(function (resolvedPromises) {
      _.each(resolvedPromises, function (result) {
        $scope.chartLineCharts[0].push(_.round(result, 1));
      });

      $scope.stats.startValue = $scope.chartLineCharts[0][0];
      $scope.stats.endValue = $scope.chartLineCharts[0][$scope.chartLineCharts[0].length - 1];
      $scope.stats.change = _.round($scope.stats.endValue - $scope.stats.startValue, 1);
      $scope.stats.changePercentage = _.round($scope.stats.change / $scope.stats.startValue * 100, 0);
    })["catch"](function (error) {
      console.log('error', error);
    });
    $scope.stats.endText = moment($scope.end.value).format(dateFormat) === moment().format(dateFormat) ? 'Current' : 'End';
  };

  $scope.loadWeights = function () {
    var begin = $scope.begin.value ? moment($scope.begin.value).format($scope.dayDateFormat) : null,
        end = moment($scope.end.value).add('1', 'day').format($scope.dayDateFormat),
        timezone = $scope.timezone,
        params = {
      end: end,
      offset: 0,
      limit: 500,
      timezone: timezone
    };

    if (begin !== null) {
      params.begin = begin;
    }

    nixTrackApiClient('/weight/log', {
      params: params
    }).success(function (log) {
      $scope.weights = log.weights ? log.weights : [];

      if ($scope.weights && $scope.weights.length === 500) {
        params.offset = 500;
        nixTrackApiClient('/weight/log', {
          params: params
        }).success(function (log) {
          $scope.weights = $scope.weights.concat(log.weights);
          calculateWeightGraph();
        });
      } else {
        calculateWeightGraph();
      }
    })["catch"](function (err) {
      console.log('Error geting weight log:', err);
    });
  };

  $scope.loadWeights();
}]);
'use strict';

whenModuleController.$inject = ["$scope", "$cordovaDatePicker", "$q"];
angular.module('Track').controller('whenModuleController', whenModuleController);

function whenModuleController($scope, $cordovaDatePicker, $q) {
  if ($scope.mtype) {
    $scope.displayMeal = calculateMealTimeByType($scope.mtype);
  } else {
    $scope.displayMeal = calculateMealTimeByConsumedAt($scope.state);
  }

  $scope.displayDay = formatCustomDate($scope.state) || 'Today';
  $scope.whenSection = {
    show: false,
    timestamp: null,
    selectedMealTime: null,
    selectedMealDate: null,
    mealTimeTemplates: {
      breakfast: {
        time: {
          hours: 4,
          minutes: 0,
          seconds: 0
        },
        title: 'Breakfast',
        selected: false,
        type: 1
      },
      lunch: {
        time: {
          hours: 12,
          minutes: 0,
          seconds: 0
        },
        title: 'Lunch',
        selected: false,
        type: 3
      },
      dinner: {
        time: {
          hours: 17,
          minutes: 0,
          seconds: 0
        },
        title: 'Dinner',
        selected: false,
        type: 5
      },
      morningsnack: {
        time: {
          hours: 10,
          minutes: 0,
          seconds: 0
        },
        title: 'AM Snack',
        selected: false,
        type: 2
      },
      afternoonsnack: {
        time: {
          hours: 15,
          minutes: 0,
          seconds: 0
        },
        title: 'PM Snack',
        selected: false,
        type: 4
      },
      eveningsnack: {
        time: {
          hours: 21,
          minutes: 0,
          seconds: 0
        },
        title: 'Late Snack',
        selected: false,
        type: 6
      }
    },
    mealDateTemplates: {
      today: {
        date: moment(),
        title: 'Today',
        selected: false
      },
      yesterday: {
        date: moment().subtract(1, 'days'),
        title: 'Yesterday',
        selected: false
      },
      customday: {
        date: null,
        title: 'Choose a date',
        selected: false
      }
    },
    changeActiveMealTimeTemplate: function changeActiveMealTimeTemplate(key) {
      var self = this;

      for (var k in self.mealTimeTemplates) {
        self.mealTimeTemplates[k].selected = false;
      }

      self.mealTimeTemplates[key].selected = true;
      self.selectedMealTime = self.mealTimeTemplates[key];
      $scope.displayMeal = self.selectedMealTime.title;
      self.calcualteTimestamp();
      $scope.mtype = self.mealTimeTemplates[key].type;
    },
    changeActiveMealDateTemplate: function changeActiveMealDateTemplate(key) {
      var self = this;

      for (var k in self.mealDateTemplates) {
        self.mealDateTemplates[k].selected = false;
      }

      self.mealDateTemplates[key].selected = true;
      var promise = 'customday' === key ? self.getCustomDate().then(function (date) {
        self.mealDateTemplates[key].date = moment(date);
      }) : $q.when();
      promise.then(function () {
        self.selectedMealDate = self.mealDateTemplates[key];

        if (self.selectedMealDate.title === 'Choose a date') {
          $scope.displayDay = formatCustomDate(self.selectedMealDate.date);
        } else {
          $scope.displayDay = self.selectedMealDate.title;
        }

        self.calcualteTimestamp();
      });
    },
    calcualteTimestamp: function calcualteTimestamp() {
      var self = this;

      if (!self.selectedMealDate.date) {
        self.selectedMealDate.date = moment($scope.state).hours(self.selectedMealTime.time.hours).minutes(self.selectedMealTime.time.minutes).seconds(self.selectedMealTime.time.seconds);
      }

      self.timestamp = self.show ? self.selectedMealDate.date.hours(self.selectedMealTime.time.hours).minutes(self.selectedMealTime.time.minutes).seconds(self.selectedMealTime.time.seconds) : $scope.state;
      $scope.state = self.timestamp.format();
    },
    toggleWhenSection: function toggleWhenSection() {
      var self = this;
      self.show = !self.show;
      self.selectedMealTime = self.mealTimeTemplates[$scope.displayMeal.toLowerCase().replace(/\s/g, '')];
      self.mealTimeTemplates[$scope.displayMeal.toLowerCase().replace(/\s/g, '')].selected = true;

      if ($scope.displayDay === 'Today' || $scope.displayDay === 'Yesterday') {
        self.selectedMealDate = self.mealDateTemplates[$scope.displayDay.toLowerCase()];
        self.mealDateTemplates.customday.selected = false;
        self.mealDateTemplates[$scope.displayDay.toLowerCase()].selected = true;
      } else {
        self.selectedMealDate = self.mealDateTemplates.customday;
        self.mealDateTemplates.customday.selected = true;
      }
    },
    getCustomDate: function getCustomDate() {
      var options = {
        date: new Date(),
        mode: 'date',
        allowOldDates: true,
        allowFutureDates: true,
        doneButtonLabel: 'DONE',
        doneButtonColor: '#000',
        cancelButtonLabel: 'CANCEL',
        cancelButtonColor: '#000',
        androidTheme: '16973939'
      };
      return $cordovaDatePicker.show(options);
    },
    convertMealTimeString: function convertMealTimeString(displayMeal) {
      var map = {
        'Morning Snack': 'AM Snack',
        'Afternoon Snack': 'PM Snack',
        'Evening Snack': 'Late Snack'
      };
      return map[displayMeal] ? map[displayMeal] : displayMeal;
    }
  };
}

function calculateMealTimeByConsumedAt(date) {
  var hour;

  if (!date) {
    hour = new Date().getHours();
  } else {
    var momentObj = moment(date);
    hour = momentObj.hour();
  }

  if (hour >= 4 && hour < 10) {
    return 'Breakfast';
  } else if (hour >= 10 && hour < 12) {
    return 'Morning Snack';
  } else if (hour >= 12 && hour < 15) {
    return 'Lunch';
  } else if (hour >= 15 && hour < 17) {
    return 'Afternoon Snack';
  } else if (hour >= 17 && hour < 21) {
    return 'Dinner';
  } else {
    return 'Evening Snack';
  }
}

function calculateMealTimeByType(meal_type) {
  var mtypeDict = {
    1: 'Breakfast',
    2: 'Morning Snack',
    3: 'Lunch',
    4: 'Afternoon Snack',
    5: 'Dinner',
    6: 'Evening Snack'
  };
  var type_str = meal_type.toString();
  return mtypeDict[type_str];
}

function formatCustomDate(date) {
  if (!date) {
    return 'Today';
  }

  var momentObj = moment(date);
  var today = moment();
  var yesterday = moment().subtract(1, 'day');

  if (momentObj.isSame(today, 'day')) {
    return 'Today';
  } else if (momentObj.isSame(yesterday, 'day')) {
    return 'Yesterday';
  } else {
    var dateFormatted = momentObj.format('ddd., l');
    return dateFormatted;
  }
}
'use strict';

angular.module('Track').directive('addFoodTabs', addFoodTabs);

function addFoodTabs() {
  return {
    templateUrl: 'templates/views/directives/addFoodTabs.html',
    scope: {
      state: '='
    },
    controller: 'addFoodTabsController'
  };
}
'use strict';

angular.module('Track').directive('barcodeScanner', barcodeScanner);

function barcodeScanner() {
  return {
    templateUrl: 'templates/views/directives/barcodeScanner.html',
    scope: {
      returnToCurrentView: '='
    },
    controller: 'barcodeScannerController'
  };
}
"use strict";

(function () {
  'use strict';

  countUp.$inject = ["$timeout"];
  angular.module('Track').directive('countUp', countUp);

  function countUp($timeout) {
    return {
      replace: false,
      scope: true,
      link: function link(scope, element, attrs) {
        var e = element[0];
        var num, refreshInterval, duration, steps, step, countUp, increment;

        var calculate = function calculate() {
          refreshInterval = 30;
          step = 0;
          scope.timoutId = null;
          countUp = parseInt(attrs.countUp) || 0;
          scope.value = parseInt(attrs.value, 10) || 0;
          duration = parseFloat(attrs.duration) * 1000 || 0;
          steps = Math.ceil(duration / refreshInterval);
          increment = (countUp - scope.value) / steps;
          num = scope.value;
        };

        var tick = function tick() {
          scope.timoutId = $timeout(function () {
            num += increment;
            step++;

            if (step >= steps) {
              $timeout.cancel(scope.timoutId);
              num = countUp;
              e.textContent = countUp;
            } else {
              e.textContent = Math.round(num);
              tick();
            }
          }, refreshInterval);
        };

        var start = function start() {
          if (scope.timoutId) {
            $timeout.cancel(scope.timoutId);
          }

          calculate();
          tick();
        };

        attrs.$observe('countUp', function (val) {
          if (val) {
            start();
          }
        });
        attrs.$observe('value', function () {
          start();
        });
        return true;
      }
    };
  }
})();
'use strict';

focusMe.$inject = ["$ionicPlatform", "$timeout"];
angular.module('Track').directive('focusMe', focusMe);

function focusMe($ionicPlatform, $timeout) {
  return {
    link: function link(scope, element, attrs) {
      $timeout(function () {
        element[0].focus();

        if (window.ionic.Platform.isAndroid()) {
          window.jQuery(element).select();
        } else {
          element[0].setSelectionRange(0, element[0].value.length);
        }
      }, 300);
    }
  };
}
'use strict';

angular.module('Track').directive('mainFooter', footer);

function footer() {
  return {
    templateUrl: 'templates/views/directives/footer.html',
    controller: 'footerController'
  };
}
'use strict';

angular.module('Track').directive('mainHeader', header);

function header() {
  return {
    templateUrl: 'templates/views/directives/header.html',
    controller: 'headerController'
  };
}
"use strict";

(function () {
  'use strict';

  angular.module('Track').directive('hideKeyboardOnGo', function () {
    return {
      link: function link(scope, element, attrs) {
        window.jQuery(element[0]).on('keydown', function (e) {
          var code = e.keyCode ? e.keyCode : e.which;

          if (code == 13 || code == 10 || code == 9) {
            window.jQuery(this).blur();
            return false;
          }
        });
      }
    };
  });
})();
'use strict';

angular.module('Track').directive('mealBuilder', mealBuilder);

function mealBuilder() {
  return {
    templateUrl: 'templates/views/directives/mealBuilder.html',
    scope: {},
    controller: 'mealBuilderController'
  };
}
"use strict";

(function () {
  'use strict';

  angular.module('Track').directive('multilinePlaceholder', function () {
    return {
      restrict: 'A',
      link: function link(scope, element, attrs) {
        if (window.ionic.Platform.isAndroid()) {
          attrs.$set('placeholder', attrs.placeholder.replace(/\\n/g, '\n'));
        } else {
          // hack to make iOS break line as desired.
          attrs.$set('placeholder', attrs.placeholder.replace(/\\n/g, "\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0\n"));
        }
      }
    };
  });
})();
/***** FILE IS DEPRECATED *****/
'use strict';

angular.module('Track').directive('onBoarding', showOnboarding);

function showOnboarding() {
  return {
    restrict: 'E',
    trasclude: true,
    templateUrl: 'templates/views/onboarding.html',
    controller: 'onboardingController'
  };
}
"use strict";

(function () {
  'use strict';

  angular.module('Track').directive('selectOnClick', ["$timeout", function ($timeout) {
    return {
      restrict: 'A',
      link: function link(scope, element) {
        element.on('focus', function () {
          var self = this;
          $timeout(function () {
            var prevType = self.type;

            if (prevType == 'number') {
              self.type = 'text';
            }

            self.setSelectionRange(0, self.value.length);
            self.type = prevType;
          }, 0);
        });
      }
    };
  }]);
})();
"use strict";

(function () {
  'use strict';

  angular.module('Track').directive('validNumber', ["$parse", function ($parse) {
    return {
      require: '?ngModel',
      link: function link(scope, element, attrs, ngModelCtrl) {
        if (!ngModelCtrl) {
          return;
        }

        var lastValid;
        var invalidityCounter;
        element.bind('keydown', function (e) {
          if (ngModelCtrl.$valid) {
            lastValid = parseFloat(ngModelCtrl.$modelValue);
            invalidityCounter = 0;
          }
        });
        element.bind('keyup', function (e) {
          if (ngModelCtrl.$invalid) {
            invalidityCounter++;

            if (invalidityCounter >= 2) {
              $parse(attrs.ngModel).assign(scope, lastValid);
              ngModelCtrl.$setViewValue(parseFloat(lastValid));
              ngModelCtrl.$render();
              invalidityCounter = 0;
            }
          }
        });
        element.bind('blur', function (e) {
          if (ngModelCtrl.$invalid) {
            $parse(attrs.ngModel).assign(scope, lastValid);
            ngModelCtrl.$setViewValue(parseFloat(lastValid));
            ngModelCtrl.$render();
            invalidityCounter = 0;
          }

          if (!element.val()) {
            $parse(attrs.ngModel).assign(scope, '');
          }
        });
        ngModelCtrl.$parsers.push(function (val) {
          var clean;

          if (angular.isUndefined(val) || val === null) {
            val = '';
          }

          val = val.toString();

          if (attrs.decimal && attrs.decimal !== 'false') {
            clean = val.replace(/[^0-9\.]/g, '');
            var decimalCheck = clean.split('.');
            decimalCheck[0] = decimalCheck[0].slice(0, 3);

            if (!angular.isUndefined(decimalCheck[1])) {
              decimalCheck[1] = decimalCheck[1].slice(0, 1);
              clean = decimalCheck[0] + '.' + decimalCheck[1];
            } else {
              clean = decimalCheck[0];
            }

            if (val !== clean) {
              ngModelCtrl.$setViewValue(parseFloat(clean));
              ngModelCtrl.$render();
            }

            return parseFloat(clean);
          } else {
            clean = val.replace(/[^0-9]/g, '');
            clean = clean.slice(0, 3);

            if (val !== clean) {
              ngModelCtrl.$setViewValue(parseInt(clean));
              ngModelCtrl.$render();
            }

            return parseInt(clean);
          }
        });
        element.bind('keypress', function (event) {
          if (event.keyCode === 32) {
            event.preventDefault();
          }
        });
      }
    };
  }]);
})();
"use strict";

// Directive used to show step-by-step walkthrough in ionic app. Set up $scope.wtSteps for each slide.
// wtSteps disclamer:
// id* => field that declares selector for element to focus, set in wt-step attribute of element. Required. String.
// title => title of the slide caption. Optional. String
// content => content of the slide caption. Optional. String
// state* => Name of state where slide must be shown. Required. String 
// lastSlide => Declares the last slide, where walkthrough must end. Optional. Boolean
// captionWidth => defines the width of caption popup (set as number if need to define in pixels, or as string with % to set in percent). Optional. String
// fixed => set to true if element or it's parent have position:fixed style to avoid scrolling to it.
// Note: Title and content accepts HTML so you can customize your slides caption.
// Note: make sure that you setting correct state names. otherwise slide will not be changed.
// TODO:
// - custom events on start/finish/next/prev
// - custom click function on focused element click
// - wrap control functions so they can be accessed from other controllers.
(function () {
  'use strict';

  angular.module('Track').directive('walkthrough', function () {
    return {
      template: "<div class=\"wt-wrapper\" ng-class=\"{'wt-show' : wtRunning}\">\n                    <div class=\"wt-overlay top\" ng-style=\"wtOverlayPositions.top\"></div>\n                    <div class=\"wt-overlay bottom\" ng-style=\"wtOverlayPositions.bottom\"></div>\n                    <div class=\"wt-overlay left\" ng-style=\"wtOverlayPositions.left\"></div>\n                    <div class=\"wt-overlay right\" ng-style=\"wtOverlayPositions.right\"></div>\n                    <div class=\"wt-elem-overlay\"></div>\n                    <div class=\"wt-caption\" ng-style=\"wtCaptionPosition\" ng-class=\"{'bottom-pointer' : isCaptionAbove, 'not-focused' : !focusedElement.length, 'shown' : showCaption}\">\n                      <div class=\"pointer\" ng-style=\"pointerOffset\"></div>\n                      <div class=\"wt-header\" ng-bind-html=\"trustedHtml(wtCaptionContent.title)\"></div>\n                      <div class=\"wt-content\" ng-bind-html=\"trustedHtml(wtCaptionContent.text)\"></div>\n                      <div class=\"wt-navigation\">\n                          <button ng-click=\"changeSlide(-1)\" ng-hide=\"focusedElementData.isFirst\" class=\"btn wt-prev\">&lt; Prev</button>\n                          <button ng-click=\"changeSlide(1)\" ng-hide=\"focusedElementData.isLast\" class=\"btn wt-next\">Next &gt;</button>\n                          <button ng-click=\"closeWalkthrough()\" class=\"btn wt-finish\">Finish</button>\n                      </div>\n                    </div>\n                  </div>",
      replace: true,
      controller: ["$ionicScrollDelegate", "$ionicPlatform", "$scope", "$sce", "$state", "$timeout", "$window", function ($ionicScrollDelegate, $ionicPlatform, $scope, $sce, $state, $timeout, $window) {
        var vm = this;
        $scope.wtRunning = false;
        $scope.focusedElementOffsets = {
          'top': 0,
          'bottom': 0,
          'left': 0,
          'right': 0
        };
        $scope.showCaption = false;
        $scope.wtCaptionContent = {
          'title': '',
          'text': ''
        };
        $ionicPlatform.ready(function () {
          vm.elementCenter = {
            'horizontal': '',
            'vertical': ''
          };
          vm.captionLimits = {
            'left': 10,
            'right': ''
          };
          vm.screenSizes = {
            'height': window.ionic.Platform.platform() === 'android' ? $window.outerHeight : $window.screen.height,
            'width': window.ionic.Platform.platform() === 'android' ? $window.outerWidth : $window.screen.width
          };
          vm.wtCaption = angular.element('.wt-caption');
        });

        $scope.trustedHtml = function (code) {
          return $sce.trustAsHtml(code);
        };

        vm.scrollToElement = function () {
          $ionicScrollDelegate.scrollBy(0, $scope.focusedElementData.position.top - vm.screenSizes.height / 3, false);
          $timeout(function () {
            $scope.focusedElementData.position = $scope.focusedElement.offset();
            $scope.calculateNewSlide(vm.slideIndex);
          }, 200);
        };

        $scope.calculateNewSlide = function (slideIndex) {
          $scope.focusedElement = $scope.wtSteps[slideIndex].isIdSelector ? angular.element($scope.wtSteps[slideIndex].id) : angular.element('[wt-step="' + $scope.wtSteps[slideIndex].id + '"]');

          if (!!$scope.wtSteps[slideIndex].focusOffset) {
            $scope.focusedElementOffsets = {
              'top': $scope.wtSteps[slideIndex].focusOffset.top || 0,
              'bottom': $scope.wtSteps[slideIndex].focusOffset.bottom || 0,
              'left': $scope.wtSteps[slideIndex].focusOffset.left || 0,
              'right': $scope.wtSteps[slideIndex].focusOffset.right || 0
            };
          } else {
            $scope.focusedElementOffsets = {
              'top': 0,
              'bottom': 0,
              'left': 0,
              'right': 0
            };
          }

          if (!!$scope.focusedElement.length) {
            $scope.focusedElementData = {
              'position': {
                'top': $scope.focusedElement.offset().top - $scope.focusedElementOffsets.top,
                'left': $scope.focusedElement.offset().left - $scope.focusedElementOffsets.left
              },
              'dimensions': {
                'width': $scope.focusedElement.outerWidth() + $scope.focusedElementOffsets.right + $scope.focusedElementOffsets.left,
                'height': $scope.focusedElement.outerHeight() + $scope.focusedElementOffsets.bottom + $scope.focusedElementOffsets.top
              },
              'fixed': $scope.wtSteps[slideIndex].fixed || false
            };

            if (!$scope.focusedElementData.fixed && ($scope.focusedElementData.position.top < 44 || $scope.focusedElementData.position.top + $scope.focusedElementData.dimensions.height > vm.screenSizes.height - 60)) {
              vm.scrollToElement();
            }
          } else {
            $scope.focusedElementData = {
              'position': {
                'top': vm.screenSizes.height / 2,
                'left': vm.screenSizes.width / 2
              },
              'dimensions': {
                'width': 0,
                'height': 0
              }
            };
          }

          $scope.wtOverlayPositions = {
            'top': {},
            'bottom': {},
            'left': {},
            'right': {}
          };
          $timeout(function () {
            $scope.wtOverlayPositions = {
              'top': {
                'top': '0px',
                'bottom': vm.screenSizes.height - $scope.focusedElementData.position.top + 'px',
                'left': '0px',
                'right': '0px'
              },
              'bottom': {
                'top': $scope.focusedElementData.position.top + $scope.focusedElementData.dimensions.height + 'px',
                'bottom': '0px',
                'left': '0px',
                'right': '0px'
              },
              'left': {
                'top': $scope.focusedElementData.position.top + 'px',
                'bottom': vm.screenSizes.height - $scope.focusedElementData.dimensions.height - $scope.focusedElementData.position.top + 'px',
                'left': '0px',
                'right': vm.screenSizes.width - $scope.focusedElementData.position.left + 'px'
              },
              'right': {
                'top': $scope.focusedElementData.position.top + 'px',
                'bottom': vm.screenSizes.height - $scope.focusedElementData.dimensions.height - $scope.focusedElementData.position.top + 'px',
                'left': $scope.focusedElementData.dimensions.width + $scope.focusedElementData.position.left + 'px',
                'right': '0px'
              }
            };
          }, 300);
          $scope.showNewCaption();
        };

        $scope.showNewCaption = function () {
          $scope.showCaption = false;
          $timeout(function () {
            vm.wtCaption.outerWidth($scope.wtSteps[vm.slideIndex].captionWidth || '');
            var captionWidth = vm.wtCaption.outerWidth();
            vm.elementCenter = {
              'horizontal': $scope.focusedElementData.position.left + $scope.focusedElementData.dimensions.width / 2,
              'vertical': $scope.focusedElementData.position.top + $scope.focusedElementData.dimensions.height / 2
            };
            vm.captionLimits.right = vm.screenSizes.width - captionWidth - 10;
            var captionPositionLeft;

            if (vm.elementCenter.horizontal - captionWidth / 2 < vm.captionLimits.right) {
              if (vm.elementCenter.horizontal - captionWidth / 2 < vm.captionLimits.left) {
                captionPositionLeft = vm.captionLimits.left;
              } else {
                captionPositionLeft = vm.elementCenter.horizontal - captionWidth / 2;
              }
            } else {
              captionPositionLeft = vm.captionLimits.right;
            }

            if (vm.elementCenter.vertical < vm.screenSizes.height / 2) {
              $scope.isCaptionAbove = false;
            } else {
              $scope.isCaptionAbove = true;
            }

            $scope.wtCaptionPosition = {
              'top': $scope.isCaptionAbove ? '' : $scope.focusedElementData.position.top + $scope.focusedElementData.dimensions.height + 10 + 'px',
              'bottom': $scope.isCaptionAbove ? vm.screenSizes.height - $scope.focusedElementData.position.top + 10 + 'px' : '',
              'left': captionPositionLeft + 'px',
              'right': 'auto'
            };
            $scope.pointerOffset = {
              'margin-left': vm.elementCenter.horizontal - (captionPositionLeft + captionWidth / 2) - 10 + 'px'
            };
          }, 300);
          $timeout(function () {
            $scope.wtCaptionContent = {
              'title': $scope.wtSteps[vm.slideIndex].title ? $scope.wtSteps[vm.slideIndex].title : '',
              'text': $scope.wtSteps[vm.slideIndex].content ? $scope.wtSteps[vm.slideIndex].content : ''
            };
            $scope.focusedElementData.isLast = $scope.wtSteps[vm.slideIndex].lastSlide || vm.slideIndex == $scope.wtSteps.length - 1 ? true : false;
            $scope.focusedElementData.isFirst = vm.slideIndex == 0 ? true : false;
            $scope.showCaption = true;
          }, 600);
        };

        $scope.changeSlide = function (index) {
          vm.slideIndex += index;

          if (!!$scope.wtSteps && !!$scope.wtSteps[vm.slideIndex] && !!$scope.wtSteps[vm.slideIndex - index] && $scope.wtSteps[vm.slideIndex].state !== $scope.wtSteps[vm.slideIndex - index].state) {
            $scope.wtOverlayPositions = {
              'top': {},
              'bottom': {},
              'left': {},
              'right': {}
            };
            return $state.go($scope.wtSteps[vm.slideIndex].state).then(function () {
              $timeout(function () {
                if ($scope.wtSteps[vm.slideIndex] !== undefined) {
                  $scope.calculateNewSlide(vm.slideIndex);
                }
              }, 0);
            });
          }

          if ($scope.wtSteps[vm.slideIndex] !== undefined) {
            $scope.calculateNewSlide(vm.slideIndex);
          }
        };

        $scope.startWalkthrough = function (wtSteps) {
          if (!$scope.wtRunning) {
            if (!wtSteps) {
              return console.log('walkthrough steps are not defined.');
            }

            $timeout(function () {
              $scope.wtSteps = wtSteps;
              $scope.wtRunning = true;
              vm.slideIndex = 0;
              $scope.calculateNewSlide(vm.slideIndex);
            }, 0);
          }
        };

        $scope.closeWalkthrough = function () {
          vm.wtCaption.removeClass('shown');
          $scope.wtRunning = false;
          $scope.wtCaptionContent = {
            'title': '',
            'text': ''
          };
          $scope.wtCaptionPosition = {
            'top': '',
            'bottom': '',
            'left': '',
            'right': ''
          };
          $scope.wtOverlayPositions = {
            'top': {},
            'bottom': {},
            'left': {},
            'right': {}
          };
          $scope.focusedElementOffsets = {
            'top': 0,
            'bottom': 0,
            'left': 0,
            'right': 0
          };
        };
      }]
    };
  });
})();
'use strict';

angular.module('Track').directive('weightGraph', weightGraph);

function weightGraph() {
  return {
    templateUrl: 'templates/views/directives/weightGraph.html',
    controller: 'weightGraphController',
    scope: {},
    controllerAs: 'vm'
  };
}
'use strict';

angular.module('Track').directive('whenModule', whenModule);

function whenModule() {
  return {
    templateUrl: 'templates/views/directives/whenModule.html',
    scope: {
      state: '=',
      mtype: '='
    },
    controller: 'whenModuleController'
  };
}
'use strict';

angular.module('Track').service('AnalyticsService', function () {
  var factory = {
    // init: init,
    setUserId: setUserId,
    trackEvent: trackEvent,
    trackView: trackView
  };
  return factory; // function init() {
  //   if ($cordovaGoogleAnalytics) {
  //     $cordovaGoogleAnalytics.debugMode();
  //     $cordovaGoogleAnalytics.startTrackerWithId('UA-19183277-12');
  //     // allow IDFA collection to enable demographics and interest reports
  //     // ngCordova does not yet support setAllowIDFACollection (most recent is 0.1.27-alpha)
  //     if (window.ga) {
  //       window.ga.setAllowIDFACollection(true);
  //     }
  //   }
  // }

  function setUserId(userId) {
    // $cordovaGoogleAnalytics.setUserId(userId);
    cordova.plugins.firebase.analytics.setUserId(userId);
  }

  function trackEvent(name, data) {
    // $cordovaGoogleAnalytics.trackEvent(name, data, 'Label', 1);
    cordova.plugins.firebase.analytics.logEvent(name, {
      'info': data
    });
  }

  function trackView(viewName) {
    // $cordovaGoogleAnalytics.trackView(viewName);
    cordova.plugins.firebase.analytics.setCurrentScreen(viewName);
    window.Sentry.configureScope(function (scope) {
      scope.setExtra('currentView', viewName);
    });
  }
});
'use strict';
/**
 * @ngdoc service
 * @name Track.ApiService
 * @description
 * # ApiService should always make an API call
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

angular.module('Track').factory('ApiService', ["$rootScope", "$http", "$timeout", "UserService", "HelperService", "nixTrackApiClient", "$q", "QueueService", "CacheFactory", "$cordovaSQLite", "SQLiteService", function ($rootScope, $http, $timeout, UserService, HelperService, nixTrackApiClient, $q, QueueService, CacheFactory, $cordovaSQLite, SQLiteService) {
  var baseUrl = 'https://trackapi.nutritionix.com/v2';

  function getLastXDaysDates(days, offset) {
    days = _.isNumber(days) ? days : 7;
    offset = _.isNumber(offset) ? offset : 0;
    var dates = [],
        today = moment().subtract(offset, 'days');

    for (var i = 0; i < days; i++) {
      var date = today.format('ddd, MM/DD/YY');
      dates.push(date);
      today.subtract(1, 'day');
    }

    return dates;
  }

  function roundNumber(number) {
    number = _.isNaN(number) || _.isNil(number) ? 0 : _.isNumber(number) ? number : 0;
    return Math.round(number);
  } //specific endpoint for grabbing userfoodlog on frontpage


  function getUserFoodLog(userId, offset, begin, end) {
    if (!offset) offset = 0;
    if (!begin) begin = moment().subtract(7, 'days').format('YYYY-MM-DD');
    if (!end) end = moment().add(1, 'days').format('YYYY-MM-DD');

    var requestLimit = 500,
        foodLogOffset = 0,
        foodlog = [],
        timezone = 'US/Eastern',
        requestFoodLog = function requestFoodLog() {
      return $http({
        method: 'GET',
        url: baseUrl + '/log?offset=' + foodLogOffset + '&begin=' + begin + '&end=' + end + '&limit=' + requestLimit + '&timezone=' + timezone,
        headers: {
          'Content-Encoding': 'gzip'
        }
      }).then(function (response) {
        foodlog = foodlog.concat(response.data.foods);

        if (foodlog.length === requestLimit + foodLogOffset) {
          foodLogOffset += requestLimit;
          return $timeout(requestFoodLog, 0);
        }

        return foodlog;
      }).then(function (foodlog) {
        // https://github.com/mattsilvllc/ionic-track/issues/728
        // show 7 days regardless to existing logs
        if (!_.isArray(foodlog)) {
          return;
        }

        var targetDatesArray = getLastXDaysDates(7, offset);
        var result = {}; // generate last 7 days dates array

        _.forEach(targetDatesArray, function (date) {
          result[date] = {
            foods: [],
            totalCalories: 0,
            totalProtein: 0,
            totalCarbohydrate: 0,
            totalFat: 0,
            totalSodium: 0
          };
        }); // walk on the foods array and pick only the ones that belong to last 7 days


        _.forEach(foodlog, function (food) {
          if (!food.consumed_at) {
            food.consumed_at = food.created_at;
          }

          if (!food.meal_type) {
            food.meal_type = HelperService.calculateMealTypeByTime(moment(food.consumed_at).format('H'));
          }

          var foodDate = moment.tz(food.consumed_at.toString(), timezone).format('ddd, MM/DD/YY');

          if (foodDate && result[foodDate]) {
            food.serving_qty = food.serving_qty || '1';

            if (food.alt_measures) {
              var temp = {
                'serving_weight': food.serving_weight_grams,
                'seq': null,
                'measure': food.serving_unit,
                'qty': food.serving_qty
              };
              food.alt_measures.unshift(temp);
            }

            result[foodDate].foods.push(food);
            result[foodDate].totalCalories = result[foodDate].totalCalories + food.nf_calories;
            result[foodDate].totalProtein = result[foodDate].totalProtein + food.nf_protein;
            result[foodDate].totalCarbohydrate = result[foodDate].totalCarbohydrate + food.nf_total_carbohydrate;
            result[foodDate].totalFat = result[foodDate].totalFat + food.nf_total_fat;
            result[foodDate].totalSodium = result[foodDate].totalSodium + food.nf_sodium;
          }
        }); // need this to make sure the rounded totals match the totals on nutrition-labels
        // https://github.com/mattsilvllc/ionic-track/issues/755


        _.forEach(result, function (res) {
          res.totalCalories = roundNumber(res.totalCalories);
          res.totalProtein = roundNumber(res.totalProtein);
          res.totalCarbohydrate = roundNumber(res.totalCarbohydrate);
          res.totalFat = roundNumber(res.totalFat);
          res.totalSodium = roundNumber(res.totalSodium);
        });

        factory.setCachedFoodLog(result);
        $rootScope.foodlog = result;
        return result;
      })["catch"](function (err) {
        console.log('error getting user food log:', angular.toJson(err));
        console.log(err);
      });
    };

    return UserService.getUser().then(function (result) {
      if (result.timezone) {
        timezone = result.timezone;
      }

      return $timeout(requestFoodLog, 0);
    });
  }

  function getUserExerciseLog(offset, begin, end) {
    if (!offset) offset = 0;
    if (!begin) begin = moment().subtract(6, 'days').format('YYYY-MM-DD');
    if (!end) end = moment().format('YYYY-MM-DD');

    var exLogLimit = 500,
        exlogoffset = 0,
        exLog = [],
        timezone = 'US/Eastern',
        requestExerciseLog = function requestExerciseLog() {
      return $http({
        method: 'GET',
        url: baseUrl + '/exercise/log?offset=' + exlogoffset + '&begin=' + begin + '&end=' + end + '&limit=' + exLogLimit + '&timezone=' + timezone,
        headers: {
          'Content-Encoding': 'gzip'
        }
      }).then(function (response) {
        exLog = exLog.concat(response.data.exercises);

        if (exLog.length === exLogLimit + exlogoffset) {
          exlogoffset += exLogLimit;
          return $timeout(requestExerciseLog, 0);
        }

        return exLog;
      }).then(function (exLog) {
        var targetDatesArray = getLastXDaysDates(7, offset);
        var result = {}; // generate last 7 days dates array

        _.forEach(targetDatesArray, function (date) {
          result[date] = {
            exercises: [],
            totalCaloriesBurned: 0
          };
        }); // walk on the foods array and pick only the ones that belong to last 7 days


        _.forEach(exLog, function (exercise) {
          var exDate = moment(exercise.timestamp.toString()).format('ddd, MM/DD/YY');

          if (result[exDate]) {
            result[exDate].exercises.push(exercise);
            result[exDate].totalCaloriesBurned = result[exDate].totalCaloriesBurned + exercise.nf_calories;
          }
        });

        factory.setCachedExerciseLog(result);
        $rootScope.exerciseLog = result;
        return result;
      })["catch"](function (err) {
        console.log('There was an error getting exercise log', angular.toJson(err));
      });
    };

    return UserService.getUser().then(function (result) {
      if (result.timezone) {
        timezone = result.timezone;
      }

      return $timeout(requestExerciseLog, 0);
    });
  }

  function getUserWeighIns(offset, begin, end) {
    if (!offset) offset = 0;
    if (!begin) begin = moment().subtract(6, 'days').format('YYYY-MM-DD');
    if (!end) end = moment().format('YYYY-MM-DD');

    var weightLogLimit = 500,
        weightLogOffset = 0,
        weightLog = [],
        timezone = 'US/Eastern',
        requestWeightLog = function requestWeightLog() {
      return $http({
        method: 'GET',
        url: baseUrl + '/weight/log?offset=' + weightLogOffset + '&begin=' + begin + '&end=' + end + '&limit=' + weightLogLimit + '&timezone=' + timezone,
        headers: {
          'Content-Encoding': 'gzip'
        }
      }).then(function (response) {
        weightLog = weightLog.concat(response.data.weights);

        if (weightLog.length === weightLogLimit + weightLogOffset) {
          weightLogOffset += weightLogLimit;
          return $timeout(requestWeightLog, 0);
        }

        return weightLog;
      }).then(function (weightLog) {
        var targetDatesArray = getLastXDaysDates(7, offset);
        var result = {}; // generate last 7 days dates array

        _.forEach(targetDatesArray, function (date) {
          result[date] = {
            weights: []
          };
        });

        _.forEach(weightLog, function (weight) {
          var weightDate = moment(weight.timestamp.toString()).format('ddd, MM/DD/YY');

          if (result[weightDate]) {
            result[weightDate].weights.push(weight);
          }
        });

        factory.setCachedWeightLog(result);
        $rootScope.weightLog = result;
        return result;
      })["catch"](function (err) {
        console.log('There wasn an error getting weight log', angular.toJson(err));
      });
    };

    return UserService.getUser().then(function (result) {
      if (result.timezone) {
        timezone = result.timezone;
      }

      return $timeout(requestWeightLog, 0);
    });
  }

  function getUserWaterLog(offset, begin, end) {
    if (!offset) offset = 0;
    if (!begin) begin = moment().subtract(6, 'days').format('YYYY-MM-DD');
    if (!end) end = moment().format('YYYY-MM-DD');

    var waterLogLimit = 500,
        waterLogOffset = 0,
        waterLog = [],
        timezone = 'US/Eastern',
        requestWaterLog = function requestWaterLog() {
      return $http({
        method: 'GET',
        url: baseUrl + '/water/log?offset=' + waterLogOffset + '&begin=' + begin + '&end=' + end + '&limit=' + waterLogLimit + '&timezone=' + timezone,
        headers: {
          'Content-Encoding': 'gzip'
        }
      }).then(function (response) {
        waterLog = waterLog.concat(response.data.logs);

        if (waterLog.length === waterLogLimit + waterLogOffset) {
          waterLogOffset += waterLogLimit;
          return $timeout(requestWaterLog, 0);
        }

        return waterLog;
      }).then(function (waterLog) {
        var targetDatesArray = getLastXDaysDates(7, offset);
        var result = {}; // generate last 7 days dates array

        _.forEach(targetDatesArray, function (date) {
          result[date] = 0;
        });

        _.forEach(waterLog, function (waterEntry) {
          var waterDate = moment(waterEntry.date.toString()).format('ddd, MM/DD/YY');

          if (result[waterDate] !== undefined, result[waterDate] !== null) {
            result[waterDate] = waterEntry.consumed || 0;
          }
        });

        factory.setCachedWaterLog(result);
        $rootScope.waterLog = result;
        return result;
      })["catch"](function (err) {
        console.log('There wasn an error getting water log', angular.toJson(err));
      });
    };

    return UserService.getUser().then(function (result) {
      if (result.timezone) {
        timezone = result.timezone;
      }

      return $timeout(requestWaterLog, 0);
    });
  }

  function getFoodHistory() {
    var request = {
      method: 'GET',
      url: baseUrl + '/me/autocomplete?limit=500',
      headers: {
        'Content-Encoding': 'gzip'
      },
      timeout: 15000
    };
    var query = 'INSERT INTO history (response) values (?)';
    var deleteQuery = 'DELETE FROM history;';
    return $http(request).then(function (response) {
      $cordovaSQLite.execute(window.db, deleteQuery).then(function () {
        return $cordovaSQLite.execute(window.db, query, [angular.toJson(response)]);
      }).then(function (sqlResponse) {
        return sqlResponse;
      })["catch"](function (err) {
        console.log('there was an err writing to sql', angular.toJson(err));
        throw err;
      });
    })["catch"](function (err) {
      console.log('There was error getting user\'s food log history:', angular.toJson(err));
      throw err;
    });
  }

  function getFoodById(id) {
    var request = {
      method: 'GET',
      url: baseUrl + '/log/' + id + '/detailed',
      timeout: 15000
    };
    return $http(request).then(function (food) {
      return food;
    })["catch"](function (err) {
      console.log('there was an err getting food by id', angular.toJson(err));
      throw err;
    });
  }

  function getUsers() {
    return $http({
      method: 'GET',
      url: baseUrl + '/users'
    });
  } //this uses the natural endpoint which will parse a string and determine what foods were in it.


  function addFood(food, num_servings, aggregate, line_delimited) {
    var postObj = 'object' === _typeof(food) && food.query ? food : {
      query: food ? food : ''
    };
    if (num_servings) postObj.num_servings = num_servings;
    if (aggregate) postObj.aggregate = aggregate;
    if (line_delimited) postObj.line_delimited = line_delimited;
    var request = {
      method: 'POST',
      url: baseUrl + '/natural/add',
      data: postObj,
      timeout: 15000
    }; // queue the request

    return QueueService.queue(request).then(QueueService.clearQ)["catch"](function (error) {
      return error;
    });
  } //this will post a food objects directly to the log. Method 1 = natural. Method 2 = API V1.1.
  //barcode is the scanned UPC barcode if the method is 2.


  function postFoodObj(foodArray, loggingOptions) {
    UserService.getUser().then(function (user) {
      var timezone = user.timezone;
      var mtype = false;

      if (loggingOptions.meal_type) {
        mtype = true;
      }

      if (loggingOptions.type === 'multipleFoods') {
        foodArray.forEach(function (food) {
          food.consumed_at = moment(loggingOptions.consumed_at).format('YYYY-MM-DDTHH:mm:ss') + moment.tz(timezone).format('Z');

          if (mtype) {
            food.meal_type = loggingOptions.meal_type;
          }

          if (!!loggingOptions.customPhoto) {
            food.photo = {
              highres: loggingOptions.customPhoto.full || null,
              thumb: loggingOptions.customPhoto.thumb || null,
              is_user_uploaded: !!loggingOptions.customPhoto.full || !!loggingOptions.customPhoto.thumb
            };
          }
        });
      } else if (loggingOptions.type === 'singleFood') {
        if (loggingOptions.servings !== 1) {
          var mult = 1 / loggingOptions.servings;

          for (var i = 0; i < foodArray.length; i++) {
            var foodObj = foodArray[i];
            var newFood = HelperService.multiply(foodObj, mult, foodObj.serving_qty * mult);

            if (mtype) {
              newFood.meal_type = loggingOptions.meal_type;
            }

            foodArray[i] = newFood;
          }
        }
      } // coming from edit food - copy
      else {
          foodArray[0].consumed_at = moment(loggingOptions.consumed_at).format('YYYY-MM-DDTHH:mm:ss') + moment.tz(timezone).format('Z');

          if (mtype) {
            foodArray[0].meal_type = loggingOptions.meal_type;
          }
        }

      var data = {
        aggregate: loggingOptions.name || null,
        foods: foodArray
      };

      if (loggingOptions.type === 'singleFood') {
        data.consumed_at = moment(loggingOptions.consumed_at).format('YYYY-MM-DDTHH:mm:ss') + moment.tz(timezone).format('Z');

        if (mtype) {
          data.meal_type = loggingOptions.meal_type;
        }

        if (loggingOptions.servings >= 1) {
          data.serving_qty = loggingOptions.servings;
        }

        if (!!loggingOptions.customPhoto) {
          data.aggregate_photo = {
            highres: loggingOptions.customPhoto.full || null,
            thumb: loggingOptions.customPhoto.thumb || null,
            is_user_uploaded: !!loggingOptions.customPhoto.full || !!loggingOptions.customPhoto.thumb
          };
        }
      }

      if (loggingOptions.recipeBrand) {
        data.brand_name = loggingOptions.recipeBrand;
      }

      var request = {
        method: 'POST',
        url: baseUrl + '/log',
        data: data,
        timeout: 15000
      };
      return QueueService.queue(request).then(QueueService.clearQ)["catch"](function (error) {
        console.log('postFoodObj', error);
        throw error;
      });
    });
  } //getting a food via a barcode


  function getFoodViaBarcode(upc) {
    var request = {
      method: 'GET',
      url: baseUrl + '/search/item?upc=' + upc,
      timeout: 5000
    };
    return $http(request).then(function (response) {
      return response.data.foods;
    })["catch"](function (err) {
      console.log(err);

      if (err.status !== 404) {
        throw err;
      }

      return Promise.reject(err);
    });
  } //posting a food via a barcode


  function postFoodViaBarcode(upc) {
    var data = {
      upc: upc
    };
    var request = {
      method: 'POST',
      url: baseUrl + '/log/barcode',
      data: data,
      timeout: 5000
    };
    return QueueService.queue(request).then(QueueService.clearQ)["catch"](function (error) {
      throw error;
    });
  } //this is updating foods that were logged via restaurant or barcode


  function updateFood(food) {
    var data = {
      foods: [food]
    };
    var request = {
      method: 'PUT',
      url: baseUrl + '/log/',
      data: data
    };
    return QueueService.queue(request).then(QueueService.clearQ)["catch"](function (e) {
      console.log('error updating food', angular.toJson(e));
      return e;
    });
  }

  function deleteFood(foodArrayWithIds) {
    var request = {
      method: 'DELETE',
      url: baseUrl + '/log',
      data: {
        foods: foodArrayWithIds
      }
    };
    return QueueService.queue(request).then(QueueService.clearQ)["catch"](function (err) {
      throw err;
    });
  }

  function requestUserPermissionByPhoneNumber(phone) {
    var data = {
      users: [{
        mobile_number: phone
      }]
    };
    return $http.post(baseUrl + '/permissions/request', data).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error requesting permission', e);
    });
  }

  function getCachedFoodLog() {
    // return SQLiteService.query(window.db, 'SELECT value FROM localdata WHERE dataName=?', ["cachedFoodLog"])
    //   .then(function(result){
    //     var cachedFoodLog = SQLiteService.getById(result).value;
    //     console.log(JSON.parse(cachedFoodLog));
    //     return JSON.parse(cachedFoodLog);
    //   })
    //   .catch(function(err){
    //     console.log('there was error setting cached food log:', err);
    //   });
    var deferred = $q.defer();

    if (JSON.parse(window.localStorage.getItem('cachedFoodLog'))) {
      deferred.resolve(JSON.parse(window.localStorage.getItem('cachedFoodLog')));
    } else {
      deferred.reject(null);
      console.log('there was an error getting the cached food log');
    }

    return deferred.promise;
  }

  function getCachedExerciseLog() {
    var deferred = $q.defer();

    if (JSON.parse(window.localStorage.getItem('cachedExerciseLog'))) {
      deferred.resolve(JSON.parse(window.localStorage.getItem('cachedExerciseLog')));
    } else {
      deferred.reject(null);
      console.log('there was an error getting the cached exercise log');
    }

    return deferred.promise;
  }

  function getCachedWeightLog() {
    var deferred = $q.defer();

    if (JSON.parse(window.localStorage.getItem('cachedWeightLog'))) {
      deferred.resolve(JSON.parse(window.localStorage.getItem('cachedWeightLog')));
    } else {
      deferred.reject(null);
      console.log('there was an error getting the cached weight log');
    }

    return deferred.promise;
  }

  function getCachedWaterLog() {
    var deferred = $q.defer();

    if (JSON.parse(window.localStorage.getItem('cachedWaterLog'))) {
      deferred.resolve(JSON.parse(window.localStorage.getItem('cachedWaterLog')));
    } else {
      deferred.reject(null);
      console.log('there was an error getting the cached water log');
    }

    return deferred.promise;
  }

  function setCachedFoodLog(foodlog) {
    // var queryString = 'REPLACE INTO localdata (value, dataName) VALUES (?, ?)'
    // return SQLiteService.query(window.db, queryString, [angular.toJson(foodlog), 'cachedFoodLog'])
    //   .catch(function(err){
    //     console.log('there was error setting cached food log:', err);
    //   });
    var deferred = $q.defer();

    if (foodlog) {
      try {
        window.localStorage.setItem('cachedFoodLog', angular.toJson(foodlog));
      } catch (err) {
        console.log('err', err);
      }

      deferred.resolve('we stored the foodlog in localstorage');
    } else {
      deferred.reject('cannot set foodlog');
      console.log('there was an error storing the foodlog in localstorage');
    }

    return deferred.promise;
  }

  function setCachedExerciseLog(exLog) {
    var deferred = $q.defer();

    if (exLog) {
      window.localStorage.setItem('cachedExerciseLog', angular.toJson(exLog));
      deferred.resolve('we stored the exercise log in localstorage');
    } else {
      deferred.reject('cannot set exercise food log');
      console.log('there was an error storing the exercise log in localstorage');
    }
  }

  function setCachedWeightLog(weightLog) {
    var deferred = $q.defer();

    if (weightLog) {
      window.localStorage.setItem('cachedWeightLog', angular.toJson(weightLog));
      deferred.resolve('we stored the weight log in localStorage');
    } else {
      deferred.reject('cannot set weight log');
      console.log('there was an error storing the weight log in localstorage');
    }
  }

  function setCachedWaterLog(waterLog) {
    var deferred = $q.defer();

    if (waterLog) {
      window.localStorage.setItem('cachedWaterLog', angular.toJson(waterLog));
      deferred.resolve('we stored the water log in localStorage');
    } else {
      deferred.reject('cannot set water log');
      console.log('there was an error storing the water log in localstorage');
    }
  }

  function getCurrentFood() {
    var deferred = $q.defer();

    if (JSON.parse(window.localStorage.getItem('currentFood'))) {
      deferred.resolve(JSON.parse(window.localStorage.getItem('currentFood')));
    } else {
      deferred.reject('cannot get food');
      console.log('there was an error grabbing the food');
    }

    return deferred.promise;
  }

  function setCurrentFood(food) {
    var deferred = $q.defer();

    if (food) {
      window.localStorage.setItem('currentFood', angular.toJson(food));
      deferred.resolve('we stored the item in localStorage');
    } else {
      deferred.reject('cannot set food');
      console.log('there was an error setting the food');
    }

    return deferred.promise;
  }

  function getFoodNutrients(query) {
    var data = 'object' === _typeof(query) ? query : {
      query: query
    };
    return $http.post(baseUrl + '/natural/nutrients', data).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error grabbing nutrients for these food items');
      return Promise.reject(e);
    });
  }

  function findFoodViaBarcode(upc, appId, appKey) {
    return $http.get('https://api.nutritionix.com/v1_1/item?upc=' + upc + '&appId=' + appId + '&appKey=' + appKey).then(function (response) {
      return response;
    })["catch"](function (e) {
      return e;
    });
  }

  function setCurrentDayTotal(dayTotal) {
    window.localStorage.setItem('currentDayTotal', angular.toJson(dayTotal));
  }

  function getCurrentDayTotal() {
    return JSON.parse(window.localStorage.getItem('currentDayTotal'));
  }

  function updatePreferences(userPrefs) {
    return $http.put(baseUrl + '/me/preferences', userPrefs).then(function (response) {
      return response.data;
    })["catch"](function (e) {
      console.log('there was an error updating the user preferences', angular.toJson(e));
    });
  }

  function fitbitSign() {
    var data = {};
    return $http.post(baseUrl + '/oauth/fitbit/sign', data).then(function (response) {
      return response;
    })["catch"](function (err) {
      console.log('err', angular.toJson(err));
      throw err;
    });
  }

  function fitbitUnlink() {
    return $http.get(baseUrl + '/oauth/fitbit/unlink').then(function (res) {
      return res;
    })["catch"](function (err) {
      throw err;
    });
  }

  function getUserData() {
    return $http.get(baseUrl + '/me').then(function (response) {
      return response;
    })["catch"](function (err) {
      console.log('there was an error getting user from API', angular.toJson(err));
      return Promise.reject(err);
    });
  }

  function unlinkPhoneNumber() {
    return $http["delete"](baseUrl + '/auth/sms/verification').then(function (response) {
      return response;
    })["catch"](function (err) {
      throw err;
    });
  }

  function linkPhoneNumber(phoneNumber) {
    return $http({
      method: 'GET',
      url: baseUrl + '/auth/sms/verification',
      params: {
        'mobile_number': phoneNumber
      },
      timeout: 5000
    }).then(function (response) {
      return response;
    })["catch"](function (err) {
      throw err;
    });
  }

  function confirmCodeSMS(code) {
    var data = {
      code: code
    };
    return $http.post(baseUrl + '/auth/sms/verification', data).then(function (response) {
      return response;
    })["catch"](function (err) {
      throw err;
    });
  }

  function shareMeal(foodId, shareKey) {
    return $http.get(baseUrl + '/share/food/' + foodId + '/' + shareKey).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error sharing meal', angular.toJson(e));
    });
  }

  function getSuggestedFoods(mtype) {
    var url = baseUrl + (mtype !== undefined && mtype != -1 ? '/reports/suggested?meal_types=[' + mtype + ']' : '/reports/suggested');
    return $http.get(url).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error getting suggested foods', angular.toJson(e));
    });
  }

  function getAutocompleteFoods(query) {
    var data = {
      query: query,
      self: true,
      common: true,
      branded: true
    };
    return nixTrackApiClient('/search/instant', {
      params: data
    }).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error getting autocomplete foods', angular.toJson(e));
    });
  }

  function findRestaurantFoods(query, brand_id) {
    query = query.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, '\\$&');
    var data = {
      query: query,
      brand_ids: [brand_id],
      self: false,
      common: false,
      detailed: true,
      branded_type: 1
    };
    return $http.post(baseUrl + '/search/instant', data).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error getting autocomplete foods', angular.toJson(e));
    });
  }

  function getBrandedFood(nix_item_id) {
    return $http.get(baseUrl + '/search/item?nix_item_id=' + nix_item_id).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error getting branded foods', angular.toJson(e));
    });
  }

  function shareFoodLog(email, start, end, timezone) {
    var data = {
      email: email,
      begin: start,
      end: end,
      timezone: timezone
    };
    return $http.post(baseUrl + '/share/log', data).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error sharing food log', angular.toJson(e));
      return {
        status: 500
      };
    });
  }

  function logAutocompleteStats(input, source, result_key) {
    var data = {
      meta: {
        input: input,
        source: source,
        result_key: result_key
      }
    };
    return $http.post(baseUrl + '/stats/log', data)["catch"](function (e) {
      console.log('there was an error logging autocomplete stats', angular.toJson(e));
    });
  }

  function addExercise(query, editObj, userObj) {
    var age = new Date().getFullYear() - userObj.birth_year;

    if (age > 100) {
      age = 30;
    }

    delete userObj.birth_year;
    userObj.age = age;
    userObj.query = query;
    return $http.post(baseUrl + '/natural/exercise', userObj).then(function (resp) {
      return resp.data.exercises;
    }).then(function (exerciseArr) {
      _.forEach(exerciseArr, function (ex) {
        ex.timestamp = moment($rootScope.selected_day.date, 'ddd, MM/DD/YY').clone().hours(moment().hours()).minutes(moment().minutes()).format();
      }); // if editing, there will only be one exercise in response


      if (editObj) {
        exerciseArr[0].id = editObj.id;
        exerciseArr[0].timestamp = editObj.timestamp;
        return $http.put(baseUrl + '/exercise/log', {
          'exercises': exerciseArr
        });
      } else {
        return $http.post(baseUrl + '/exercise/log', {
          'exercises': exerciseArr
        });
      }
    })["catch"](function (err) {
      console.log('There was an error logging exercises', angular.toJson(err));
      throw err;
    });
  }

  function addOrUpdateHKExercise(add_update_map) {
    var add_arr = [];
    var update_arr = [];

    _.forEach(Object.keys(add_update_map), function (day) {
      var add_data = {};
      var ts;

      if ($rootScope.exerciseLog && $rootScope.exerciseLog[day] && $rootScope.exerciseLog[day].exercises.length === 0) {
        ts = moment(day, 'ddd, MM/DD/YY').format();
        add_data = {
          'tag_id': 939,
          'nf_calories': add_update_map[day],
          'user_input': 'HealthKit Exercise Total',
          'name': 'HealthKit Exercise Total',
          'timestamp': ts,
          'duration_min': 0,
          'met': 0
        };
        add_arr.push(add_data);
      } else {
        if ($rootScope.exerciseLog && $rootScope.exerciseLog[day]) {
          var found = false;

          _.forEach($rootScope.exerciseLog[day].exercises, function (ex) {
            // log already has HK, so update
            if (ex.name === 'HealthKit Exercise Total') {
              found = true;

              if (add_update_map[day] !== ex.nf_calories) {
                var update_data = {
                  'id': ex.id,
                  'nf_calories': add_update_map[day]
                };
                update_arr.push(update_data);
              }

              return;
            }
          });

          if (!found) {
            ts = moment(day, 'ddd, MM/DD/YY').format();
            add_data = {
              'tag_id': 939,
              'nf_calories': add_update_map[day],
              'user_input': 'HealthKit Exercise Total',
              'name': 'HealthKit Exercise Total',
              'timestamp': ts,
              'duration_min': 0,
              'met': 0
            };
            add_arr.push(add_data);
          }
        }
      }
    });

    console.log('ex add', angular.toJson(add_arr));
    console.log('ex update', angular.toJson(update_arr)); //do the adds first

    if (add_arr.length) {
      var dataAdd = {
        'exercises': add_arr
      };
      return $http.post(baseUrl + '/exercise/log', dataAdd)["catch"](function (err) {
        console.log(angular.toJson(err));
        throw err;
      });
    }

    if (update_arr.length) {
      //then the updates
      var dataUpdate = {
        'exercises': update_arr
      };
      return $http.put(baseUrl + '/exercise/log', dataUpdate)["catch"](function (err) {
        throw err;
      });
    }
  }

  function deleteExercise(exercise_id) {
    var request = {
      method: 'DELETE',
      url: baseUrl + '/exercise/log',
      data: {
        exercises: [{
          id: exercise_id
        }]
      }
    };
    return QueueService.queue(request).then(QueueService.clearQ)["catch"](function (err) {
      throw err;
    });
  }

  function addWeighIn(new_weight, editObj) {
    var data, method;

    if (editObj) {
      editObj.kg = new_weight;
      data = {
        'weights': [editObj]
      };
      method = 'PUT';
    } else {
      data = {
        'weights': [{
          'kg': new_weight,
          'timestamp': moment($rootScope.selected_day.date, 'ddd, MM/DD/YY').clone().hours(moment().hours()).minutes(moment().minutes()).format()
        }]
      };
      method = 'POST';
    }

    var request = {
      method: method,
      url: baseUrl + '/weight/log',
      data: data
    };
    return QueueService.queue(request).then(QueueService.clearQ)["catch"](function (err) {
      throw err;
    });
  }

  function addWater(water, date) {
    var formattedDate = date ? moment.utc(date, 'ddd, MM/DD/YY').format('YYYY-MM-DD') : moment.utc().format('YYYY-MM-DD');
    var data = {
      'logs': [{
        'consumed': water,
        'date': formattedDate
      }]
    };
    var request = {
      method: 'POST',
      url: baseUrl + '/water/log/add',
      data: data
    };
    return QueueService.queue(request).then(QueueService.clearQ)["catch"](function (err) {
      throw err;
    });
  }

  function deleteWater(date) {
    var formattedDate = date ? moment.utc(date, 'ddd, MM/DD/YY').format('YYYY-MM-DD') : moment.utc().format('YYYY-MM-DD');
    var data = {
      'logs': [{
        'consumed': 0,
        'date': formattedDate
      }]
    };
    var request = {
      method: 'PUT',
      url: baseUrl + '/water/log',
      data: data
    };
    return QueueService.queue(request).then(QueueService.clearQ)["catch"](function (err) {
      throw err;
    }); // hidden for now, because API throws error on delete
    // var formattedDate = date ? moment.utc(date).format('YYYY-MM-DD') : moment.utc().format('YYYY-MM-DD');
    // return $http.delete(baseUrl + '/water/log', {'log':[{'date': formattedDate}]})
    //   .catch(function(err) {
    //     throw err;
    //   });
  }

  function updateWater(water, date) {
    var formattedDate = date ? moment.utc(date, 'ddd, MM/DD/YY').format('YYYY-MM-DD') : moment.utc().format('YYYY-MM-DD');
    var data = {
      'logs': [{
        'consumed': water,
        'date': formattedDate
      }]
    };
    var request = {
      method: 'PUT',
      url: baseUrl + '/water/log',
      data: data
    };
    return QueueService.queue(request).then(QueueService.clearQ)["catch"](function (err) {
      throw err;
    });
  }

  function addHKWeighIn(hkWeights) {
    // hkWeights is formatted for api ingestion
    var data = {
      'weights': hkWeights
    };
    return $http.post(baseUrl + '/weight/log', data)["catch"](function (err) {
      throw err;
    });
  }

  function deleteWeighIn(weight_id) {
    var request = {
      method: 'DELETE',
      url: baseUrl + '/weight/log',
      data: {
        weights: [{
          id: weight_id
        }]
      }
    };
    return QueueService.queue(request).then(QueueService.clearQ)["catch"](function (err) {
      throw err;
    });
  }

  function sendBugReport(type, feedback, payload, metadata) {
    var data = {
      type: type,
      feedback: feedback
    };

    if (!!payload) {
      data.payload = payload;
    }

    if (!!metadata) {
      data.metadata = metadata;
    }

    return $http.post(baseUrl + '/feedback', data)["catch"](function (e) {
      console.log('there was an error sending feedback', angular.toJson(e));
      throw e;
    });
  }

  function checkConnection() {
    return $http.get('https://trackapi.nutritionix.com/')["catch"](function (err) {
      return Promise.reject(err);
    });
  }

  function setDayNote(date, note) {
    var data = {
      dates: [{
        date: moment(date, 'ddd, MM/DD/YY').format('YYYY-MM-DD'),
        notes: note || null
      }]
    };
    return $http({
      method: 'PUT',
      url: baseUrl + '/reports/totals',
      data: data
    });
  }

  function setDayCalorieLimit(date, newLimit) {
    if (!date || !newLimit) {
      return;
    }

    var data = {
      dates: [{
        date: moment(date, 'ddd, MM/DD/YY').format('YYYY-MM-DD'),
        daily_kcal_limit: newLimit
      }]
    };
    return $http({
      method: 'PUT',
      url: baseUrl + '/reports/totals',
      data: data
    });
  }

  function getUserTotals(offset, begin, end, timezone) {
    if (!offset) offset = 0;
    if (!begin) begin = moment.utc().subtract(7, 'days').format('YYYY-MM-DD');
    if (!end) end = moment.utc().add(1, 'days').format('YYYY-MM-DD');
    if (!timezone) timezone = 'US/Eastern';
    var userTotals = [];
    return $http({
      method: 'GET',
      url: baseUrl + '/reports/totals?begin=' + begin + '&end=' + end + '&timezone=' + timezone,
      headers: {
        'Content-Encoding': 'gzip'
      }
    }).then(function (response) {
      if (!response.data.dates) {
        return factory.getCachedUserTotals().then(function (res) {
          return res;
        });
      } else {
        userTotals = userTotals.concat(response.data.dates || []); // https://github.com/mattsilvllc/ionic-track/issues/728
        // show 7 days regardless to existing logs

        var targetDatesArray = getLastXDaysDates(7, offset);
        var result = {};

        _.forEach(targetDatesArray, function (date) {
          result[date] = {
            daily_carbs_pct: null,
            daily_fat_pct: null,
            daily_protein_pct: null,
            daily_kcal_limit: null,
            exercises_logged: null,
            foods_logged: null,
            notes: null,
            total_cal: null,
            total_cal_burned: null,
            water_consumed_liter: null,
            weights_logged: null
          };
        });

        userTotals.map(function (dayTotal) {
          var dayTotalDate = moment(dayTotal.date).format('ddd, MM/DD/YY');
          result[dayTotalDate] = dayTotal;
        });
        factory.setCachedUserTotals(result);
        return result;
      }
    }).then(function (totals) {
      $rootScope.userTotals = totals;
      return totals;
    })["catch"](function (err) {
      console.log(angular.toJson(err));
    });
  }

  function getCachedUserTotals() {
    var deferred = $q.defer();

    if (JSON.parse(window.localStorage.getItem('cachedUserTotals'))) {
      deferred.resolve(JSON.parse(window.localStorage.getItem('cachedUserTotals')));
    } else {
      deferred.reject(null);
      console.log('there was an error getting the cached user totals');
    }

    return deferred.promise;
  }

  function setCachedUserTotals(totals) {
    var deferred = $q.defer();

    if (totals) {
      window.localStorage.setItem('cachedUserTotals', angular.toJson(totals));
      deferred.resolve('we stored the user totals in localstorage');
    } else {
      deferred.reject('cannot set totals');
      console.log('there was an error storing the user totals in localstorage');
    }

    return deferred.promise;
  }

  function submitAccessCode(code) {
    var data = {
      access_code: code
    };
    return $http.post(baseUrl + '/iap/accessCode', data).then(function (resp) {
      return resp;
    })["catch"](function (err) {
      throw err;
    });
  }

  function validatePurchase(receipt, signature, platform) {
    var data = {
      'receipt': receipt,
      'platform': platform,
      'signature': signature
    };
    return $http.post(baseUrl + '/iap/validateReceipt', data).then(function (resp) {
      return resp;
    })["catch"](function (err) {
      throw err;
    });
  }

  function requestUpdatePassword(email) {
    return $http.get(baseUrl + '/auth/updatePassword?email=' + email).then(function (resp) {
      return resp;
    })["catch"](function (err) {
      throw err;
    });
  }

  function setNewPassword(options) {
    var deferred = $q.defer();

    if (!options || !options.link_hash.length || !options.password.length) {
      deferred.reject(null);
    } else {
      var data = {
        'link_hash': options.link_hash,
        'password': options.password
      };
      $http.post(baseUrl + '/auth/updatePassword', data).then(function (resp) {
        deferred.resolve(resp);
      })["catch"](function (err) {
        deferred.reject(err);
      });
    }

    return deferred.promise;
  }

  function requestEmailChange(email) {
    return $http.get(baseUrl + '/auth/email/verify/request?email=' + email).then(function (resp) {
      console.log(resp);
      return resp;
    })["catch"](function (err) {
      throw err;
    });
  }

  function getCountriesList() {
    return $http.get('https://d1gvlspmcma3iu.cloudfront.net/country-codes.json').then(function (resp) {
      return resp;
    })["catch"](function (err) {
      throw err;
    });
  }

  var factory = {
    getLastXDaysDates: getLastXDaysDates,
    getUserFoodLog: getUserFoodLog,
    getUserExerciseLog: getUserExerciseLog,
    getUserWeighIns: getUserWeighIns,
    getFoodHistory: getFoodHistory,
    getFoodById: getFoodById,
    getUsers: getUsers,
    addFood: addFood,
    postFoodObj: postFoodObj,
    getFoodViaBarcode: getFoodViaBarcode,
    postFoodViaBarcode: postFoodViaBarcode,
    updateFood: updateFood,
    deleteFood: deleteFood,
    requestUserPermissionByPhoneNumber: requestUserPermissionByPhoneNumber,
    getCurrentFood: getCurrentFood,
    setCurrentFood: setCurrentFood,
    getCachedFoodLog: getCachedFoodLog,
    getCachedExerciseLog: getCachedExerciseLog,
    getCachedWeightLog: getCachedWeightLog,
    setCachedFoodLog: setCachedFoodLog,
    setCachedExerciseLog: setCachedExerciseLog,
    setCachedWeightLog: setCachedWeightLog,
    getFoodNutrients: getFoodNutrients,
    findFoodViaBarcode: findFoodViaBarcode,
    setCurrentDayTotal: setCurrentDayTotal,
    getCurrentDayTotal: getCurrentDayTotal,
    updatePreferences: updatePreferences,
    fitbitSign: fitbitSign,
    fitbitUnlink: fitbitUnlink,
    unlinkPhoneNumber: unlinkPhoneNumber,
    linkPhoneNumber: linkPhoneNumber,
    confirmCodeSMS: confirmCodeSMS,
    getUserData: getUserData,
    shareMeal: shareMeal,
    // getUserReport: getUserReport,
    getSuggestedFoods: getSuggestedFoods,
    getAutocompleteFoods: getAutocompleteFoods,
    findRestaurantFoods: findRestaurantFoods,
    getBrandedFood: getBrandedFood,
    shareFoodLog: shareFoodLog,
    logAutocompleteStats: logAutocompleteStats,
    addExercise: addExercise,
    addOrUpdateHKExercise: addOrUpdateHKExercise,
    addWeighIn: addWeighIn,
    addHKWeighIn: addHKWeighIn,
    deleteExercise: deleteExercise,
    deleteWeighIn: deleteWeighIn,
    sendBugReport: sendBugReport,
    checkConnection: checkConnection,
    getUserWaterLog: getUserWaterLog,
    setCachedWaterLog: setCachedWaterLog,
    getCachedWaterLog: getCachedWaterLog,
    addWater: addWater,
    deleteWater: deleteWater,
    updateWater: updateWater,
    setDayNote: setDayNote,
    setDayCalorieLimit: setDayCalorieLimit,
    getUserTotals: getUserTotals,
    setCachedUserTotals: setCachedUserTotals,
    getCachedUserTotals: getCachedUserTotals,
    submitAccessCode: submitAccessCode,
    validatePurchase: validatePurchase,
    requestUpdatePassword: requestUpdatePassword,
    setNewPassword: setNewPassword,
    requestEmailChange: requestEmailChange,
    getCountriesList: getCountriesList
  };
  return factory;
}]);
'use strict';

angular.module('Track').service('AwsService', ["ConfigurationService", function (ConfigurationService) {
  var self = this; // AWS config

  window.AWS.config.credentials = new window.AWS.Credentials(ConfigurationService.aws_config.aws_access_key_id, ConfigurationService.aws_config.aws_secret_access_key);
  window.AWS.config.region = ConfigurationService.aws_config.region;
  self.bucket = new window.AWS.S3({
    params: {
      Bucket: ConfigurationService.aws_config.bucket
    }
  });
  return this;
}]);
'use strict';

angular.module('Track').service('BarcodeScannerService', ["$cordovaBarcodeScanner", "$cordovaDevice", "$ionicPopup", "$log", "$q", function ($cordovaBarcodeScanner, $cordovaDevice, $ionicPopup, $log, $q) {
  var self = this;

  self.scanBarcode = function () {
    // if ('Android' === $cordovaDevice.getPlatform()) {
    return $cordovaBarcodeScanner.scan({
      'orientation': 'portrait'
    }).then(function (barcodeData) {
      if (barcodeData.cancelled) {
        return null;
      } else {
        if (barcodeData.format !== 'QR_CODE' || barcodeData.text.includes('nutritionix.com')) {
          return barcodeData.text;
        } else {
          console.log('show warning');
          $ionicPopup.alert({
            title: 'Error',
            template: 'We scanned an unrecognized QR code, if you are trying to scan a food product barcode, please try to avoid scanning the QR code near the barcode and try scanning this product again',
            buttons: [{
              text: 'Ok',
              type: 'button-balanced'
            }]
          });
          return null;
        }
      }
    }); // } else {
    //   var deferred = $q.defer();
    //   var errorCallback = function(error) {
    //     $log.error(error);
    //     deferred.reject(error);
    //   };
    //   var requestCameraAuthorizationSuccessCallback = function() {
    //     var isCameraAuthorizedSuccessCallback = function(authorized) {
    //       if (!authorized) {
    //         deferred.reject(new Error('The application does not have permission to access the camera.'));
    //       } else {
    //         var scanSuccessCallback = function(barcode) {
    //           deferred.resolve(barcode);
    //         };
    //         var scanErrorCallback = function(error) {
    //           'cancelled' === error ? deferred.resolve() : deferred.reject(error);
    //         };
    //         var params = {
    //           camera: 'back', // defaults to 'back'
    //           flash: 'off', // defaults to 'auto'. See Quirks
    //           drawSight: true //defaults to true, create a red sight/line in the center of the scanner view.
    //         };
    //         cloudSky.zBar.scan(params, scanSuccessCallback, scanErrorCallback);
    //       }
    //     };
    //     cordova.plugins.diagnostic.isCameraAuthorized(isCameraAuthorizedSuccessCallback, errorCallback);
    //   };
    //   cordova.plugins.diagnostic.requestCameraAuthorization(requestCameraAuthorizationSuccessCallback, errorCallback);
    //   return deferred.promise;
    // }
  };

  return this;
}]);
'use strict';

angular.module('Track').factory('CacheFactory', ["$q", "$cordovaSQLite", function ($q, $cordovaSQLite) {
  var factory = {
    getMealBuilderFoods: getMealBuilderFoods,
    setMealBuilderFoods: setMealBuilderFoods,
    getDefaultGroceryFoods: getDefaultGroceryFoods,
    setDefaultGroceryFoods: setDefaultGroceryFoods,
    getRestaurants: getRestaurants,
    setRestaurants: setRestaurants,
    getRestaurantsWithCalc: getRestaurantsWithCalc,
    setRestaurantsWithCalc: setRestaurantsWithCalc,
    addRecentExercise: addRecentExercise,
    getRecentExercises: getRecentExercises,
    getFoodHistory: getFoodHistory,
    clearFoods: clearFoods
  };

  function setMealBuilderFoods(mealBuilderArray) {
    var deferred = $q.defer();

    if (mealBuilderArray) {
      window.localStorage.setItem('mealBuilderArray', angular.toJson(mealBuilderArray));
      deferred.resolve('success');
    } else deferred.reject('failure');

    return deferred.promise;
  }

  function getMealBuilderFoods() {
    var deferred = $q.defer();
    var foodExists = JSON.parse(window.localStorage.getItem('mealBuilderArray'));

    if (foodExists) {
      deferred.resolve(foodExists);
    } else {
      window.localStorage.setItem('mealBuilderArray', '[]');
      deferred.resolve([]);
    }

    return deferred.promise;
  }

  function getDefaultGroceryFoods() {
    var deferred = $q.defer();
    var foodExists = JSON.parse(window.localStorage.getItem('defaultGroceryFoods'));

    if (foodExists) {
      deferred.resolve(foodExists);
    } else {
      window.localStorage.setItem('defaultGroceryFoods', '[]');
      deferred.resolve(null);
    }

    return deferred.promise;
  }

  function setDefaultGroceryFoods(defaultGroceryFoods) {
    var deferred = $q.defer();

    if (defaultGroceryFoods) {
      window.localStorage.setItem('defaultGroceryFoods', angular.toJson(defaultGroceryFoods));
      deferred.resolve('success');
    } else deferred.reject('failure');

    return deferred.promise;
  }

  function getRestaurants() {
    var deferred = $q.defer();
    var restaurants = window.localStorage.getItem('restaurants');

    if (restaurants) {
      deferred.resolve(JSON.parse(restaurants));
    } else {
      deferred.reject(null);
    }

    return deferred.promise;
  }

  function setRestaurants(restaurants) {
    var deferred = $q.defer();

    if (restaurants) {
      window.localStorage.setItem('restaurants', angular.toJson(restaurants));
      deferred.resolve('success');
    } else deferred.reject('failure');

    return deferred.promise;
  }

  function getRestaurantsWithCalc() {
    var deferred = $q.defer();
    var restaurants = window.localStorage.getItem('restaurantsWithCalc');

    if (restaurants) {
      deferred.resolve(JSON.parse(restaurants));
    } else {
      deferred.reject(null);
    }

    return deferred.promise;
  }

  function setRestaurantsWithCalc(restaurants) {
    var deferred = $q.defer();

    if (restaurants) {
      window.localStorage.setItem('restaurantsWithCalc', angular.toJson(restaurants));
      deferred.resolve('success');
    } else deferred.reject('failure');

    return deferred.promise;
  }

  function addRecentExercise(exercise) {
    var recentExercises = getRecentExercises() || [];
    var exerciseToAdd = {
      name: exercise.duration_min + ' min ' + exercise.name,
      timestamp: exercise.timestamp
    };

    var index = _.findIndex(recentExercises, ['name', exerciseToAdd.name]);

    if (index < 0) {
      recentExercises.push(exerciseToAdd);
    } else {
      if (moment(recentExercises[index].timestamp).isBefore(exerciseToAdd.timestamp)) {
        recentExercises.splice(index, 1);
        recentExercises.push(exerciseToAdd);
      }
    }

    recentExercises = recentExercises.splice(-5, 5);
    window.localStorage.setItem('recentExercises', angular.toJson(recentExercises));
  }

  function getRecentExercises() {
    var result = JSON.parse(window.localStorage.getItem('recentExercises'));
    return result || [];
  }

  function getFoodHistory() {
    var query = 'SELECT * FROM history;';
    return $cordovaSQLite.execute(window.db, query).then(function (sqlResponse) {
      var output = [];

      for (var i = 0; i < sqlResponse.rows.length; i++) {
        output.push(sqlResponse.rows.item(i));
      }

      return output[0];
    })["catch"](function (err) {
      console.log(angular.toJson(err));
      throw err;
    });
  }

  function clearFoods() {
    var deferred = $q.defer();
    window.localStorage.setItem('mealBuilderArray', '[]');
    deferred.resolve();
    return deferred.promise;
  }

  return factory;
}]);
'use strict';

angular.module('Track').service('CameraService', ["$cordovaCamera", function ($cordovaCamera) {
  var self = this;

  self.takePhoto = function (options) {
    var destinationType = null;

    switch (options.destinationType) {
      case 'NATIVE_URI':
        destinationType = window.Camera.DestinationType.NATIVE_URI;
        break;

      case 'FILE_URI':
        destinationType = window.Camera.DestinationType.FILE_URI;
        break;

      default:
        destinationType = window.Camera.DestinationType.DATA_URL;
    }

    var cameraOptions = {
      quality: 100,
      sourceType: window.Camera.PictureSourceType.CAMERA,
      destinationType: destinationType,
      encodingType: window.Camera.EncodingType.JPEG,
      popoverOptions: window.CameraPopoverOptions,
      saveToPhotoAlbum: false,
      correctOrientation: true,
      allowEdit: false
    };
    return $cordovaCamera.getPicture(cameraOptions);
  };

  return this;
}]);
'use strict';
/**
 * @ngdoc service
 * @name Track.CoachService
 * @description
 * # CoachService should always make an API call to the /coach or /coaches endpoints
 */

angular.module('Track').factory('CoachService', ["$rootScope", "$http", "ApiService", "UserService", function ($rootScope, $http, ApiService, UserService) {
  var baseUrl = 'https://trackapi.nutritionix.com/v2';

  function becomeCoach() {
    return $http.post(baseUrl + '/me/coach').then(function (response) {
      console.log(response);
      ApiService.getUserData().then(function (user) {
        UserService.setUser(user.data);
      });
      return response;
    })["catch"](function (e) {
      console.log('there was an error becoming a coach', angular.toJson(e));
      return Promise.reject(e);
    });
  }

  function stopBeingCoach() {
    return $http["delete"](baseUrl + '/me/coach').then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error removing coaching', angular.toJson(e));
      return Promise.reject(e);
    });
  }

  function getClients() {
    return $http.get(baseUrl + '/share/patients').then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error getting list of clients', angular.toJson(e));
      return Promise.reject(e);
    });
  }

  function getClientTotals(options) {
    if (_.isEmpty(options)) {
      options = {};
    }

    if (!options.begin) options.begin = moment().startOf('month').format('YYYY-MM-DD');
    if (!options.end) options.end = moment().endOf('month').format('YYYY-MM-DD');
    if (!options.timezone) options.timezone = 'US/Eastern';
    return $http.get(baseUrl + '/reports/totals/' + options.clientId + '?begin=' + options.begin + '&end=' + options.end + '&timezone=' + options.timezone).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error getting client\'s totals', angular.toJson(e));
      return Promise.reject(e);
    });
  }

  function getClientFoodLog(options) {
    if (_.isEmpty(options)) {
      options = {};
    }

    if (!options.begin) options.begin = moment().startOf('month').format('YYYY-MM-DD');
    if (!options.end) options.end = moment().endOf('month').add(1, 'day').format('YYYY-MM-DD');
    if (!options.timezone) options.timezone = 'US/Eastern';
    return $http.get(baseUrl + '/log/' + options.clientId + '?begin=' + options.begin + '&end=' + options.end + '&timezone=' + options.timezone + '&limit=500&offset=0').then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error getting client\'s log', angular.toJson(e));
      return Promise.reject(e);
    });
  }

  function getClientExerciseLog(options) {
    if (_.isEmpty(options)) {
      options = {};
    }

    if (!options.begin) options.begin = moment().startOf('month').format('YYYY-MM-DD');
    if (!options.end) options.end = moment().endOf('month').add(1, 'day').format('YYYY-MM-DD');
    if (!options.timezone) options.timezone = 'US/Eastern';
    return $http.get(baseUrl + '/exercise/log/' + options.clientId + '?begin=' + options.begin + '&end=' + options.end + '&timezone=' + options.timezone + '&limit=500&offset=0').then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error getting client\'s log', angular.toJson(e));
      return Promise.reject(e);
    });
  }

  function getCoaches() {
    return $http.get(baseUrl + '/share/coaches').then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error getting coaches list', angular.toJson(e));
      return Promise.reject(e);
    });
  }

  function addCoach(coachId) {
    var data = {
      coach_code: coachId
    };
    return $http.post(baseUrl + '/share/coaches', data).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error sharing with coach', angular.toJson(e));
      return Promise.reject(e);
    });
  }

  function removeCoach(coachId) {
    var request = {
      method: 'DELETE',
      url: baseUrl + '/share/coaches',
      data: {
        coach_code: coachId
      }
    };
    return $http(request).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error stopping share with coach', angular.toJson(e));
      return Promise.reject(e);
    });
  }

  var factory = {
    becomeCoach: becomeCoach,
    stopBeingCoach: stopBeingCoach,
    getClients: getClients,
    getClientTotals: getClientTotals,
    getClientFoodLog: getClientFoodLog,
    getClientExerciseLog: getClientExerciseLog,
    getCoaches: getCoaches,
    addCoach: addCoach,
    removeCoach: removeCoach
  };
  return factory;
}]);
'use strict';

angular.module('Track').service('ConfigurationService', function () {
  return {
    environment: 'production',
    application_store_ids: {
      ios: '1061691342',
      android: 'com.nutritionix.nixtrack'
    },
    aws_config: {
      aws_access_key_id: 'AKIAICGAVNR5YBUYKE4A',
      aws_secret_access_key: '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',
      bucket: 'nix-ios-upload',
      region: 'us-east-1'
    },
    grocery_photo_upload: {
      max_photo_width: '1600',
      upc_list: 'http://d1gvlspmcma3iu.cloudfront.net/upc_list.json.gz',
      food_update_time: {
        unit: 'months',
        quantity: '24'
      },
      user_volunteering_multiplicator: '6'
    }
  };
});
'use strict';
/**
* @ngdoc service
* @name Track.RecipeService
* @description
* # RecipeService should always make an API call
*/

angular.module('Track').factory('CustomFoodService', ["$http", function ($http) {
  var factory = {
    getCustomFoods: getCustomFoods,
    addFood: addFood,
    getFoodById: getFoodById,
    updateFood: updateFood,
    deleteFood: deleteFood,
    getCachedFoods: getCachedFoods,
    setCachedFoods: setCachedFoods
  };
  var baseUrl = 'https://trackapi.nutritionix.com/v2';

  function getCustomFoods() {
    return $http.get(baseUrl + '/custom_foods').then(function (response) {
      setCachedFoods(response.data.custom_foods);
      return response;
    })["catch"](function (e) {
      console.log('there was an error getting custom foods', angular.toJson(e));
    });
  }

  function addFood(custom_food) {
    var data = {
      custom_food: custom_food
    };
    var request = {
      url: baseUrl + '/custom_foods/',
      method: 'POST',
      data: data
    };
    return $http(request).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error adding custom food', angular.toJson(e));
      return Promise.reject(e);
    });
  }

  function getFoodById(id) {
    return $http.get(baseUrl + '/custom_foods/' + id).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error getting custom food by id', angular.toJson(e));
    });
  }

  function updateFood(custom_food) {
    var data = {
      custom_food: custom_food
    };
    return $http.put(baseUrl + '/custom_foods/' + custom_food.id, data).then(function (response) {
      var CachedFoods = getCachedFoods();

      var deletedFoodIndex = _.findIndex(CachedFoods, {
        id: response.data.id
      });

      CachedFoods[deletedFoodIndex] = response.data;
      setCachedFoods(CachedFoods);
      return response;
    })["catch"](function (e) {
      console.log('there was an error updating custom food', angular.toJson(e));
    });
  }

  function deleteFood(food_id) {
    var CachedFoods = getCachedFoods();

    var deletedFoodIndex = _.findIndex(CachedFoods, {
      id: food_id
    });

    CachedFoods.splice(deletedFoodIndex, 1);
    setCachedFoods(CachedFoods);
    return $http["delete"](baseUrl + '/custom_foods/' + food_id)["catch"](function (e) {
      console.log('there was an error deleting a custom food', angular.toJson(e));
    });
  }

  function setCachedFoods(foodsArray) {
    if (!!foodsArray && !!foodsArray.length) {
      window.localStorage.setItem('foodsList', angular.toJson(foodsArray));
    }
  }

  function getCachedFoods() {
    var result = window.localStorage.getItem('foodsList');

    if (!!result) {
      return JSON.parse(result);
    }

    return [];
  }

  return factory;
}]);
'use strict';

angular.module('Track').factory('$exceptionHandler', ["$injector", "$window", "ConfigurationService", "StackTrace", function ($injector, $window, ConfigurationService, StackTrace) {
  return function (exception, cause) {
    if (!!window.Sentry) {
      window.Sentry.captureException(exception);
    } else if ('production' === ConfigurationService.environment) {
      var reportToGoogleAnalytics = function reportToGoogleAnalytics(exceptionReport) {
        var ga = $injector.get('AnalyticsService');

        if ($window.cordova && ga) {
          ga.trackEvent('exception', angular.toJson(exceptionReport));
        }
      };

      StackTrace.fromError(exception) //get the exception stack
      .then(function (stackframes) {
        var message = exception.toString();
        var stack = stackframes.map(function (sf, index) {
          return index + '->' + sf.toString();
        }).join('|');
        return {
          message: message,
          stack: stack,
          cause: cause
        };
      }).then(function (exceptionReport) {
        reportToGoogleAnalytics(exceptionReport);
      })["catch"](function (error) {
        reportToGoogleAnalytics(error);
      });
    }

    console.log(exception);
  };
}]);
'use strict';
/**
 * @ngdoc service
 * @name Track.ExternalURLService
 * @description
 * # Handles scanned QR codes as well as deep links
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

angular.module('Track').factory('ExternalURLService', ["$rootScope", "$state", "$cordovaDevice", "ApiService", "CacheFactory", "SQLiteService", "UserService", function ($rootScope, $state, $cordovaDevice, ApiService, CacheFactory, SQLiteService, UserService) {
  var factory = {
    handleUrl: handleUrl,
    externalLinkV1: externalLinkV1,
    externalLinkV2: externalLinkV2,
    externalLinkV3: externalLinkV3
  };

  function handleUrl(url) {
    var getUser = null;
    UserService.getUser().then(function (result) {
      var user = result;

      if (user === null) {
        $state.go('login');
      } else {
        if (url.path) {
          if (url.path === '/q3') {
            externalLinkV3(url);
          } else if (url.path === '/q1') {
            return externalLinkV1(url);
          } else if (url.path === '/calculate') {
            // Calculate Daily Calories
            $state.go('app.calculateDailyCalories');
          } else if (url.path === '/connected-apps') {
            // Connected Apps
            $state.go('app.connectedApps');
          } else if (url.path === '/account/forgot-password/reset') {
            // Forgot Password
            $state.go('app.resetPassword', {
              key: url.params.key
            });
          }
        } else {
          $state.go('app.foodlog');
        }
      }
    })["catch"](function (err) {
      console.log('Error getting user from DB:', err);
      $state.go('login');
    });
  }

  function externalLinkV1(url) {
    var nutrMap = {
      203: 'nf_protein',
      204: 'nf_total_fat',
      205: 'nf_total_carbohydrate',
      208: 'nf_calories',
      269: 'nf_sugars',
      291: 'nf_dietary_fiber',
      305: 'nf_p',
      306: 'nf_potassium',
      307: 'nf_sodium',
      601: 'nf_cholesterol',
      606: 'nf_saturated_fat'
    };
    var qrInfo = {};

    if (_typeof(url) === 'object') {
      qrInfo.q = url.q;
      qrInfo.b = url.b;
      qrInfo.u = url.u;
      qrInfo.n = url.n;
      qrInfo.a = {};
      url.a.split(',').forEach(function (kv) {
        var nutrItem = kv.split(':');
        qrInfo.a[parseInt(nutrItem[0])] = nutrItem[1];
      });
    } else {
      url = decodeURIComponent(url); // like url, certain info is after ?

      var qrSplit = url.split('?')[1];
      qrSplit.split('&').forEach(function (part) {
        var item = part.split('=');

        if (item[0] === 'a') {
          qrInfo[item[0]] = {};
          item[1].split(',').forEach(function (kv) {
            var nutrItem = kv.split(':');
            qrInfo[item[0]][nutrItem[0]] = nutrItem[1];
          });
        } else {
          qrInfo[item[0]] = item[1];
        }
      });
    }

    var request = {
      'food_name': qrInfo.n,
      'brand_name': qrInfo.b,
      'serving_qty': parseInt(qrInfo.q),
      'serving_unit': qrInfo.u,
      'serving_weight_grams': null
    };

    for (var key in qrInfo.a) {
      request[nutrMap[key]] = parseFloat(qrInfo.a[key]) || null;
    }

    $rootScope.$broadcast('mealBuilder: addFood', {
      foodArray: [request]
    });
    $state.go('app.reviewFoods', {}, {
      reload: true
    });
  }

  function externalLinkV2(url) {
    url = decodeURIComponent(url);
    var qrSplit = url.split('?')[1];
    var qrInfo = {};
    qrSplit.split('&').forEach(function (part) {
      var item = part.split('=');
      qrInfo[item[0]] = item[1];
    });
    ApiService.getFoodNutrients(qrInfo.i).then(function (results) {
      CacheFactory.clearFoods();
      return results;
    }).then(function (results) {
      $rootScope.$broadcast('clearFoods');
      return results.data.foods.forEach(function (food) {
        return $rootScope.itemsInBuilder.push(food);
      });
    }).then(function () {
      //the the user requested measure/defaul measure to alt_measures so it is part of drop down in review foods
      _.forEach($rootScope.itemsInBuilder, function (foodObj) {
        if (foodObj.alt_measures) {
          var temp = {
            'serving_weight': foodObj.serving_weight_grams,
            'seq': null,
            'measure': foodObj.serving_unit,
            'qty': foodObj.serving_qty
          };
          foodObj.alt_measures.unshift(temp);
        }
      });

      CacheFactory.setMealBuilderFoods($rootScope.itemsInBuilder);
      return $state.go('app.reviewFoods', {
        type: 'singleFood',
        name: qrInfo.n || null,
        servings: qrInfo.s || 1,
        recipeBrand: qrInfo.b || null
      });
    })["catch"](function (err) {
      console.log('there was an err', angular.toJson(err)); // errorMessage(err);
    });
  }

  function externalLinkV3(url) {
    var qrInfo = {};

    if (_typeof(url) === 'object') {
      qrInfo.ufl = url.params.ufl;
      qrInfo.s = url.params.s;
    } else {
      url = decodeURIComponent(url);
      var qrSplit = url.split('?')[1];
      qrSplit.split('&').forEach(function (part) {
        var item = part.split('=');
        qrInfo[item[0]] = item[1];
      });
    }

    ApiService.shareMeal(qrInfo.ufl, qrInfo.s).then(function (foodObj) {
      foodObj.data.foods[0].consumed_at = new Date();

      if (foodObj.data.foods[0].ingredients) {
        foodObj.data.foods[0].ingredients.map(function (ingredient) {
          ingredient.consumed_at = new Date();
        });
        $rootScope.$broadcast('mealBuilder: addFood', {
          foodArray: foodObj.data.foods[0].ingredients
        });
      } else {
        $rootScope.$broadcast('mealBuilder: addFood', {
          foodArray: foodObj.data.foods
        });
      }

      $state.go('app.reviewFoods', {
        type: foodObj.data.foods[0].ingredients ? 'singleFood' : 'multipleFoods',
        name: foodObj.data.foods[0].ingredients ? foodObj.data.foods[0].food_name : null,
        recipeBrand: foodObj.data.foods[0].ingredients ? foodObj.data.foods[0].brand_name : null,
        servings: foodObj.data.foods[0].serving_qty
      });
    });
  }

  return factory;
}]);
'use strict';

angular.module('Track').service('ForceTouchService', ["$q", "$rootScope", "$state", "$ionicPlatform", "$cordovaNetwork", "UserService", function ($q, $rootScope, $state, $ionicPlatform, $cordovaNetwork, UserService) {
  var service = {
    configure: configure
  };
  return service;

  function check3DTouchAvailability() {
    return $q(function (resolve, reject) {
      if (window.ThreeDeeTouch) {
        window.ThreeDeeTouch.isAvailable(function (available) {
          resolve(available);
        });
      } else {
        reject();
      }
    });
  }

  function configure() {
    check3DTouchAvailability().then(function (available) {
      if (available) {
        window.ThreeDeeTouch.configureQuickActions([{
          type: 'logFood',
          title: 'Log Food',
          iconTemplate: '/www/images/LogFood.png'
        }, {
          type: 'scanBarcode',
          title: 'Scan Barcode',
          iconTemplate: '/www/images/ScanBarcode.png'
        }]);

        window.ThreeDeeTouch.onHomeIconPressed = function (payload) {
          $ionicPlatform.ready(function () {
            if ($cordovaNetwork.isOnline()) {
              $rootScope.noInternet = false;
            } else {
              $rootScope.noInternet = true;
            }
          });
          var getUser = null;
          UserService.getUser().then(function (result) {
            var user = result;

            if (user === null) {
              $state.go('login');
            }

            if (payload.type == 'logFood') {
              $state.go('app.addfoodsmart');
            } else if (payload.type == 'scanBarcode') {
              $rootScope.$broadcast('scanBarcodeAction');
            }
          });
        };
      }
    });
  }
}]);
'use strict';

angular.module('Track').service('GroceryAgentService', ["$q", "UserService", function ($q, UserService) {
  var self = this;

  self.initGroceyAgentInfo = function () {
    var userGroceyAgentInfo = JSON.parse(window.localStorage.getItem('userGroceyAgentInfo'));
    return !userGroceyAgentInfo || needToUpdateUserGroceyAgentInfo(userGroceyAgentInfo) ? setUserGroceyAgentInfo() : $q.when(userGroceyAgentInfo);
  };

  var setUserGroceyAgentInfo = function setUserGroceyAgentInfo() {
    return UserService.getUser().then(function (userData) {
      var timestamp = new Date().getTime();
      var grocery_agent = userData.grocery_agent ? userData.grocery_agent : null;
      var userGroceyAgentInfo = {
        grocery_agent: grocery_agent,
        lastCheckedTimestamp: timestamp
      };
      window.localStorage.setItem('userGroceyAgentInfo', angular.toJson(userGroceyAgentInfo));
      return userGroceyAgentInfo;
    });
  };

  var needToUpdateUserGroceyAgentInfo = function needToUpdateUserGroceyAgentInfo(userGroceyAgentInfo) {
    var lastCheckedTimestamp = userGroceyAgentInfo.lastCheckedTimestamp || 0;
    var timestamp = new Date().getTime();
    var timestampDifference = timestamp - lastCheckedTimestamp;
    var oneDayInMilliseconds = 24 * 60 * 60 * 1000;
    return timestampDifference > oneDayInMilliseconds;
  };

  self.initGroceyAgentPreferences = function () {
    var groceryAgentPreferences = JSON.parse(window.localStorage.getItem('groceryAgentPreferences'));
    return $q.when(!groceryAgentPreferences ? self.setGroceryAgentPreferences() : groceryAgentPreferences);
  };

  self.setGroceryAgentPreferences = function (groceryAgentPreferences) {
    groceryAgentPreferences = groceryAgentPreferences || {
      volunteer: false
    };
    window.localStorage.setItem('groceryAgentPreferences', angular.toJson(groceryAgentPreferences));
    return groceryAgentPreferences;
  };

  return this;
}]);
'use strict';
/**
 * @ngdoc service
 * @name Track.HelperService
 * @description
 * # HelperService are service / factories that do not make an API call.
 */

angular.module('Track').factory('HelperService', function () {
  var factory = {
    formatV1FoodObjToTrackFoodObj: formatV1FoodObjToTrackFoodObj,
    multiply: multiply,
    calculateMealTypeByTime: calculateMealTypeByTime,
    addGramsToAltMeasures: addGramsToAltMeasures,
    setBasketWhenModuleState: setBasketWhenModuleState,
    getBasketWhenModuleState: getBasketWhenModuleState,
    resetBasketWhenModuleState: resetBasketWhenModuleState,
    setBasketRecipeData: setBasketRecipeData,
    getBasketRecipeData: getBasketRecipeData,
    resetBasketRecipeData: resetBasketRecipeData,
    instructionVersion: '1'
  };

  function calculateMealTypeByTime(hour) {
    if (!hour) hour = 0;

    if (hour >= 4 && hour < 10) {
      return 1;
    } else if (hour >= 10 && hour < 12) {
      return 2;
    } else if (hour >= 12 && hour < 15) {
      return 3;
    } else if (hour >= 15 && hour < 17) {
      return 4;
    } else if (hour >= 17 && hour < 21) {
      return 5;
    } else {
      return 6;
    }
  } //FoodArray should be an array of foodObjects


  function formatV1FoodObjToTrackFoodObj(foodArray, method, barcode) {
    //this assumes the food's ratio will stay constant.
    var newFoodArray = [];

    _.forEach(foodArray, function (food) {
      var tempFoodObj = {
        consumed_at: food.consumed_at,
        food_name: food.item_name || food.food_name,
        brand_name: food.brand_name,
        serving_unit: food.nf_serving_size_unit || food.serving_unit,
        nf_calories: food.nf_calories,
        serving_qty: food.nf_serving_size_qty || food.serving_qty,
        nf_total_fat: food.nf_total_fat,
        nf_saturated_fat: food.nf_saturated_fat,
        nf_cholesterol: food.nf_cholesterol,
        nf_sodium: food.nf_sodium,
        nf_total_carbohydrate: food.nf_total_carbohydrate,
        nf_dietary_fiber: food.nf_dietary_fiber,
        nf_sugars: food.nf_sugars,
        nf_protein: food.nf_protein,
        nf_potassium: food.nf_potassium,
        nf_p: food.nf_p,
        full_nutrients: food.full_nutrients || [],
        nix_brand_name: food.nix_brand_name,
        nix_brand_id: food.brand_id,
        nix_item_name: food.nix_item_name,
        nix_item_id: food.item_id,
        upc: food.upc || barcode,
        serving_weight_grams: food.serving_weight_grams || food.nf_serving_weight_grams,
        source: method,
        edit_count: food.edit_count,
        ndb_no: food.ndb_no,
        natural_query_id: food.natural_query_id,
        tags: food.tags || null
      };
      newFoodArray.push(tempFoodObj);
    });

    return newFoodArray;
  }

  function multiply(foodObj, multiplier, newQty) {
    if (!multiplier) return;
    return _.extend(foodObj, {
      nf_calories: foodObj.nf_calories * multiplier,
      serving_qty: newQty,
      full_nutrients: nutrientMultiply(foodObj.full_nutrients) || [],
      nf_total_fat: foodObj.nf_total_fat * multiplier,
      nf_saturated_fat: foodObj.nf_saturated_fat * multiplier,
      nf_cholesterol: foodObj.nf_cholesterol * multiplier,
      nf_sodium: foodObj.nf_sodium * multiplier,
      nf_total_carbohydrate: foodObj.nf_total_carbohydrate * multiplier,
      nf_dietary_fiber: foodObj.nf_dietary_fiber * multiplier,
      nf_sugars: foodObj.nf_sugars * multiplier,
      nf_protein: foodObj.nf_protein * multiplier,
      nf_potassium: foodObj.nf_potassium * multiplier,
      consumed_at: foodObj.consumed_at,
      serving_weight_grams: (foodObj.serving_weight_grams || foodObj.nf_serving_weight_grams) * multiplier,
      tags: foodObj.tags || null,
      nf_p: foodObj.nf_p * multiplier
    });

    function nutrientMultiply(fullNutrientArray) {
      if (fullNutrientArray.length < 1 || !fullNutrientArray) {
        return [];
      } else {
        return _.forEach(fullNutrientArray, function (nutrient) {
          nutrient.value = nutrient.value * multiplier;
          return nutrient.value;
        });
      }
    }
  }

  function addGramsToAltMeasures(foodObj) {
    if (!foodObj.serving_weight_grams) {
      return foodObj;
    }

    var cloneFoodObj = _.cloneDeep(foodObj),
        gMeasure; // Check if the alt_measures present


    if (cloneFoodObj.alt_measures) {
      // Check if the 'grams' present in alt_measures
      gMeasure = _.find(cloneFoodObj.alt_measures, {
        measure: 'g'
      });
    } else {
      cloneFoodObj.alt_measures = [];
      var temp = {
        'serving_weight': cloneFoodObj.serving_weight_grams,
        'seq': null,
        'measure': cloneFoodObj.serving_unit,
        'qty': cloneFoodObj.serving_qty
      };
      cloneFoodObj.alt_measures.unshift(temp);
      gMeasure = false;
    }

    if (!gMeasure && cloneFoodObj.serving_weight_grams) {
      cloneFoodObj.alt_measures.push({
        'measure': 'g',
        'qty': 1,
        'seq': 104,
        'serving_weight': 1
      });
    }

    return cloneFoodObj;
  }

  function setBasketWhenModuleState(state) {
    if (state) {
      window.localStorage.setItem('basketWhenState', angular.toJson(state));
    }
  }

  function getBasketWhenModuleState() {
    var result = JSON.parse(window.localStorage.getItem('basketWhenState'));

    if (result) {
      return result;
    }
  }

  function resetBasketWhenModuleState() {
    window.localStorage.removeItem('basketWhenState');
  }

  function setBasketRecipeData(data) {
    if (data) {
      window.localStorage.setItem('basketRecipeData', angular.toJson(data));
    }
  }

  function getBasketRecipeData() {
    var result = JSON.parse(window.localStorage.getItem('basketRecipeData'));

    if (result) {
      return result;
    }
  }

  function resetBasketRecipeData() {
    window.localStorage.removeItem('basketRecipeData');
  }

  return factory;
});
'use strict';
/**
 * @ngdoc function
 * @name Track.serive:ExampleService
 * @description
 * # ExampleService
 */

angular.module('Track') // use factory for services
.factory('LoginService', ["$rootScope", "$http", "$cordovaFacebook", "$state", "$q", "SQLiteService", "UserService", function ($rootScope, $http, $cordovaFacebook, $state, $q, SQLiteService, UserService) {
  var factory = {
    loginViaFacebook: loginViaFacebook,
    loginViaAppleID: loginViaAppleID,
    manualSignUp: manualSignUp,
    manualSignIn: manualSignIn,
    sendEmailVerification: sendEmailVerification
  };
  var baseUrl = 'https://trackapi.nutritionix.com/v2';

  function loginViaFacebook(referrer) {
    /**
     * Run getLoginStatus method to avoid 4201 error: "User cancelled dialog"
     */
    $cordovaFacebook.getLoginStatus().then(function onLoginStatus(status) {
      console.log('facebookLoginStatus: ', angular.toJson(status));
    })["catch"](function onFailLogin(failure) {
      console.log('facebookLoginStatusFail: ', failure);
    }); // END
    // plugin caches old user if switching fb profiles... need to logout first.

    $cordovaFacebook.logout();
    return $cordovaFacebook.login(['public_profile', 'email']).then(function (fbToken) {
      var postObj = {
        access_token: fbToken.authResponse.accessToken
      };
      if (referrer) postObj.ref_token = referrer;
      return $http.post(baseUrl + '/oauth/facebook/signin', postObj).then(function (trackResponse) {
        UserService.setUser(trackResponse.user);
        UserService.setJwt(trackResponse["x-user-jwt"]);
        $rootScope.$broadcast('user login', trackResponse); // hack: check created at TS to determine if signin or signup

        if (moment().diff(trackResponse.data.user.created_at, 'seconds') <= 90) {
          return $state.go('completeRegistration', {
            email: trackResponse.data.user.email
          });
        } else {
          return $state.go('app.foodlog');
        }
      })["catch"](function (err) {
        console.log('there was an error logging in facebook', err);
      });
    })["catch"](function (e) {
      console.log('could not login with facebook', e);
    });
  }

  function loginViaAppleID() {
    return window.SignInWithApple.request({
      requestedScopes: [SignInWithApple.Scope.Email, SignInWithApple.Scope.FullName],
      requestedOperation: SignInWithApple.Operation.Login,
      user: 'userId',
      state: 'state',
      nonce: 'nonce'
    }).then(function (apple_user_data) {
      return $http.post(baseUrl + '/oauth/apple/signin', apple_user_data).then(function (trackResponse) {
        UserService.setUser(trackResponse.user);
        UserService.setJwt(trackResponse["x-user-jwt"]);
        $rootScope.$broadcast('user login', trackResponse); // hack: check created at TS to determine if signin or signup

        if (moment().diff(trackResponse.data.user.created_at, 'seconds') <= 90) {
          return $state.go('completeRegistration', {
            email: trackResponse.data.user.email
          });
        } else {
          return $state.go('app.foodlog');
        }
      })["catch"](function (err) {
        console.log('there was an error logging in with appleID', err);
      });
    })["catch"](function (e) {
      console.log('could not login with AppleID', e);
    });
  }

  function manualSignUp(signupObj, country_code) {
    return $http({
      method: 'POST',
      url: baseUrl + '/auth/signup',
      data: signupObj
    }).then(function (response) {
      UserService.setUser(response.user);
      UserService.setJwt(response["x-user-jwt"]);
      $rootScope.$broadcast('user login', response);
    }).then(function () {
      return $state.go('completeRegistration', {
        email: signupObj.email,
        country_code: country_code
      });
    })["catch"](function (error) {
      return Promise.reject(error);
    });
  }

  function manualSignIn(emailOrPhone, password) {
    var signinObj = {
      password: password
    };

    if (!!emailOrPhone && emailOrPhone.indexOf('@') > -1) {
      signinObj.email = emailOrPhone;
    } else {
      signinObj.mobile_number = emailOrPhone;
    }

    return $http.post(baseUrl + '/auth/signin', signinObj).then(function (response) {
      $rootScope.$broadcast('user login', response);
      return response;
    })["catch"](function (err) {
      console.log('[LoginService] something went wrong in manualSignIn', angular.toJson(err));

      if (!!err.data && err.data.message !== 'There is no existing account that matches provided information') {
        throw err;
      } else {
        return Promise.reject(err);
      }
    });
  } // helper function to send verification email to user given email address


  function sendEmailVerification(email) {
    return $http.get(baseUrl + '/auth/email/verify/request', {
      params: {
        'email': email
      }
    })["catch"](function (err) {
      console.log('[LoginService] error in sendEmailVerification', angular.toJson(err));
      throw err;
    });
  }

  return factory;
}]);
'use strict';
/**
 * @ngdoc service
 * @name Track.NixService
 * @description
 * # NixService should always make an API call
 */

angular.module('Track').factory('NixService', ["$http", "CacheFactory", function ($http, CacheFactory) {
  var factory = {
    getRestaurants: getRestaurants,
    getRestaurantFoods: getRestaurantFoods,
    getRestaurantsWithCalc: getRestaurantsWithCalc,
    getGroceryFoods: getGroceryFoods,
    getBrandedFoods: getBrandedFoods,
    getWeightInGrams: getWeightInGrams,
    nix_id: '906641bd',
    android_api_key: '6f9ab12f0eadc5a6f115d6fb9e204613',
    ios_api_key: '59bcfe12c0e9965162798a31ff38ec1f'
  };

  function getRestaurants() {
    return $http({
      method: 'GET',
      url: 'http://nix-export.s3.amazonaws.com/brands-restaurant.json.gz',
      headers: {
        'x-3scale-bypass': undefined,
        'x-user-jwt': undefined
      }
    }).then(function (response) {
      CacheFactory.setRestaurants(response.data);
      return response.data;
    })["catch"](function (err) {
      throw err;
    });
  }

  function getRestaurantsWithCalc() {
    return $http({
      method: 'GET',
      url: 'https://d1gvlspmcma3iu.cloudfront.net/restaurant-calculators.json.gz',
      headers: {
        'x-3scale-bypass': undefined,
        'x-user-jwt': undefined
      }
    }).then(function (response) {
      CacheFactory.setRestaurantsWithCalc(response.data);
      return response.data;
    })["catch"](function (err) {
      throw err;
    });
  }

  function getGroceryFoods(params, start, end) {
    start = start || 0;
    end = end || 20;
    var data = {
      'appId': factory.nix_id,
      'appKey': device.platform === 'Android' ? factory.android_api_key : factory.ios_api_key,
      'query': params,
      'fields': ['*'],
      'offset': start,
      'limit': end,
      'sort': {
        'field': '_score',
        'order': 'desc'
      },
      'filters': {
        'item_type': 2
      }
    };
    var request = {
      method: 'POST',
      url: 'https://api.nutritionix.com/v1_1/search',
      headers: {
        'Content-Type': 'application/json',
        'x-3scale-bypass': undefined,
        'x-user-jwt': undefined
      },
      data: data,
      timeout: 3000
    };
    return $http(request).then(function (results) {
      return results;
    })["catch"](function (err) {
      console.log('there was an error getting grocery foods', angular.toJson(err));
      throw err;
    });
  }

  function getRestaurantFoods(query, brand_id, start, step) {
    start = start || 0;
    step = step || 20;
    query = query || '*';
    var data = {
      'offset': start,
      'limit': step,
      'sort': {
        'field': 'item_name.sortable_na',
        'order': 'asc'
      },
      'filters': {
        'brand_id': brand_id
      },
      'query': query,
      'fields': ['*'],
      'appId': '906641bd',
      'appKey': device.platform === 'Android' ? factory.android_api_key : factory.ios_api_key
    };
    return $http({
      method: 'POST',
      url: 'https://api.nutritionix.com/v1_1/search',
      headers: {
        'Content-Type': 'application/json',
        'x-3scale-bypass': undefined,
        'x-user-jwt': undefined
      },
      data: data
    }).then(function (response) {
      return response.data;
    })["catch"](function (err) {
      console.log(angular.toJson(arguments));
      console.log('this was the restaurant food search error,', angular.toJson(err));
      return err;
    });
  }

  function getBrandedFoods(query, start, end) {
    var data = {
      'appId': factory.nix_id,
      'appKey': device.platform === 'Android' ? factory.android_api_key : factory.ios_api_key,
      'query': query,
      'fields': ['*'],
      'offset': start,
      'limit': end,
      'sort': {
        'field': '_score',
        'order': 'desc'
      },
      'filters': {
        'not': {
          'item_type': 3
        }
      }
    };
    var request = {
      method: 'POST',
      url: 'https://api.nutritionix.com/v1_1/search',
      headers: {
        'Content-Type': 'application/json',
        'x-3scale-bypass': undefined,
        'x-user-jwt': undefined
      },
      data: data,
      timeout: 3000
    };
    return $http(request).then(function (results) {
      return results;
    })["catch"](function (err) {
      console.log('there was an error getting branded foods', angular.toJson(err));
      throw err;
    });
  }

  function getWeightInGrams(nix_id) {
    var request = {
      method: 'GET',
      url: 'https://www.nutritionix.com/nixapi/items/' + nix_id,
      headers: {
        'Content-Type': 'application/json',
        'x-3scale-bypass': undefined,
        'x-user-jwt': undefined
      },
      timeout: 3000
    };
    return $http(request).then(function (result) {
      var response = {
        'metric_qty': result.data.metric_qty,
        'metric_unit': result.data.metric_unit
      };
      return response;
    })["catch"](function (err) {
      console.log('Error getting weight in grams:', err);
    });
  }

  return factory;
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.serive:PushNotification
 * @description
 * # PushNotificationService
 */

angular.module('Track') // use factory for services
.factory('PushNotificationService', ["$q", function ($q) {
  var pushwoosh = false;
  var factory = {
    preparePushwoosh: preparePushwoosh,
    initPushwoosh: initPushwoosh,
    mergeTagsToUser: mergeTagsToUser,
    scheduleNotifications: scheduleNotifications
  };

  function gatePushwoosh(reject) {
    if (!pushwoosh) {
      console.log('Pw gate reject');
      reject(new Error('must call "preparePushwoosh" before this'));
    }
  } // function getHWIDAsync() {
  //   return $q(function(resolve, reject) {
  //     gatePushwoosh(reject)
  //     try {
  //       pushwoosh.getPushwooshHWID(resolve, reject);
  //     } catch (e) {
  //       reject(e);
  //     }
  //   });
  // }
  // function getTagsAsync() {
  //   return $q(function (resolve, reject) {
  //     gatePushwoosh(reject)
  //     pushwoosh.getTags(resolve, reject);
  //   })
  // }


  function setTagsAsync(args) {
    return $q(function (resolve, reject) {
      gatePushwoosh(reject);
      console.log('setting tags');
      pushwoosh.setTags(args, resolve, reject);
    });
  }

  function preparePushwoosh(callback) {
    pushwoosh = pushwoosh || cordova.require('pushwoosh-cordova-plugin.PushNotification'); // Initialize Pushwoosh. This will trigger all pending push notifications on start.

    pushwoosh.onDeviceReady({
      // appid: '55842-EFB06', //prod
      appid: 'E9AA1-C7F3A',
      //dev
      // projectid: '915637315046',
      projectid: '410036658585',
      //dev
      serviceName: ''
    });
    console.log('pushwoosh prepared'); // Should be called before pushwoosh.onDeviceReady

    document.addEventListener('push-notification', function (event) {
      var notification = event.notification; // handle push open here

      console.log('push message opened', angular.toJson(notification));

      if (notification.ios && notification.ios.l) {
        callback(notification.ios.l);
      } else if (notification.android && notification.android.l) {
        callback(notification.android.l);
      }
    });
  }

  function initPushwoosh() {
    return $q(function (resolve, reject) {
      gatePushwoosh(reject);
      pushwoosh.registerDevice(function (status) {
        console.log('Pushwoosh registerDevice success');
        window.sessionStorage.setItem('PW_register', true);
        resolve(status);
      }, function (status) {
        console.log('pushwoosh registration not successful', angular.toJson(status)); // handle registration error here

        window.sessionStorage.setItem('PW_register', false);
        reject(status);
      });
    });
  }

  function mergeTagsToUser(userId, action) {
    var registrationSuccess = window.sessionStorage.getItem('PW_register');
    var procedure = $q.resolve();

    if (!registrationSuccess && action) {
      procedure.then(initPushwoosh);
    }

    return procedure.then(function () {
      var args = {
        user_id: action ? userId : null
      };
      return setTagsAsync(args);
    });
  } // function smartInitPushwoosh(userPrefs) {
  //   if (userPrefs.enable_weekday_sms) {
  //     initPushwoosh()
  //       .then(mergeTagsToUser.bind(null, userPrefs.id, true))
  //   }
  // }
  ////////////// LOCAL NOTIFICATIONS NEW LOGIC


  function scheduleSingleNotification(weekday) {
    var scheduleDate = moment('21:00 ' + moment().isoWeekday(weekday).format('DD/MM/YYYY'), 'HH:mm DD/MM/YYYY');
    var triggerDate;

    if (moment().isoWeekday() < weekday) {
      triggerDate = new Date(scheduleDate.format());
    } else {
      triggerDate = new Date(scheduleDate.add(1, 'weeks').format());
    }

    window.cordova.plugins.notification.local.schedule({
      title: 'Nutritionix Track',
      text: 'Your food log looks a bit empty. Tap here to log what you ate today.',
      foreground: true,
      trigger: {
        at: triggerDate
      },
      smallIcon: 'res://drawable/gray_nix_apple_small',
      id: weekday
    });
  }

  function scheduleNotifications(weekday, weekend) {
    // need to cancel all notifications before scheduling new.
    cordova.plugins.notification.local.cancelAll(function () {
      for (var i = 1; i < 8; i++) {
        if (!!weekday && i < 6) {
          scheduleSingleNotification(i);
        }

        if (!!weekend && i > 5) {
          scheduleSingleNotification(i);
        }
      }
    });
  }

  return factory;
}]);
'use strict';
/**
 * @ngdoc service
 * @name Track.QueueService
 * @description
 * # QueueService will store every API request on the queue
 */

angular.module('Track').factory('QueueService', ["$cordovaSQLite", "$http", "$q", "$rootScope", function ($cordovaSQLite, $http, $q, $rootScope) {
  var factory = {
    selectQuery: selectQuery,
    queue: queue,
    requeue: requeue,
    dequeue: dequeue,
    runQueries: runQueries,
    getAllFromQ: getAllFromQ,
    clearQ: clearQ,
    setCachedQLength: setCachedQLength,
    getCachedQLength: getCachedQLength
  };

  function selectQuery() {
    var query = 'SELECT * FROM queries ORDER BY updated_at ASC LIMIT 1;';
    return $cordovaSQLite.execute(window.db, query).then(function (response) {
      return response;
    })["catch"](function (err) {
      throw err;
    });
  }

  function queue(request) {
    var query = 'INSERT INTO queries (query) VALUES (?);';
    return $cordovaSQLite.execute(window.db, query, [angular.toJson(request)]).then(function (response) {
      var cachedResponse = response;
      $rootScope.updatePendingLength++;
      factory.getCachedQLength().then(function (response) {
        response = response + 1;
        factory.setCachedQLength(response);
      }).then(function () {
        return cachedResponse;
      });
    })["catch"](function (err) {
      console.log('could not queue');
      throw err;
    });
  }

  function requeue(id) {
    var query = 'UPDATE queries set updated_at = CURRENT_TIMESTAMP WHERE id = ?;';
    return $cordovaSQLite.execute(window.db, query, [id]).then(function (response) {
      return response;
    })["catch"](function (err) {
      throw err;
    });
  }

  function dequeue(id) {
    var query = 'DELETE FROM queries where id = ?;';
    return $cordovaSQLite.execute(window.db, query, [id]).then(function (response) {
      factory.getCachedQLength().then(function (response) {
        response = response - 1;
        factory.setCachedQLength(response);
      });
      return response;
    })["catch"](function (err) {
      throw err;
    });
  }

  function clearQ() {
    if ($rootScope.noInternet) {
      console.log('[QueueService] No Internet, clearQuere cancelled');
      return Promise.reject('No internet');
    }

    return getAllFromQ().then(runQueries);
  }

  function runQueries(queue, errs) {
    errs = errs || [];

    function handleQErr(err) {
      errs.push(err);
    }

    $rootScope.showSpinner = true;

    if (!queue.length) {
      $rootScope.updatePendingLength = 0;
      return errs;
    } // process recursively, 1 item @ a time


    $rootScope.updatePendingLength = queue.length;
    var first = queue.pop();
    return $http(JSON.parse(first.query)) //process successful requests
    .then(function (response) {
      // this check was implemented to force-refresh the food log after logging any food.
      if (response.config.url == 'https://trackapi.nutritionix.com/v2/log') {
        $rootScope.$broadcast('refresh foodlog');
      } // clearTimeout(timeout);


      return dequeue(first.id)["catch"](handleQErr);
    }) //process errored requests
    ["catch"](function (err) {
      console.log('there was an err', angular.toJson(err)); // window.Sentry.captureException(angular.toJson(err));

      var retryCodes = [504, 0]; // console.log('Queue service error',err.status);

      errs.push(err);

      if (retryCodes.indexOf(err.status) !== -1) {
        return requeue(first.id)["catch"](handleQErr);
      } else {
        return dequeue(first.id)["catch"](handleQErr);
      }
    }).then(function () {
      return runQueries(queue, errs);
    });
  }

  function getAllFromQ() {
    var query = 'SELECT * FROM Queries ORDER BY updated_at desc';
    return $cordovaSQLite.execute(window.db, query, []).then(function (res) {
      var arr = [];
      var ln = res.rows.length;

      for (var c = 0; c < ln; c++) {
        arr.push(res.rows.item(c));
      }

      return arr;
    });
  }

  function setCachedQLength(qLength) {
    var deferred = $q.defer();
    deferred.resolve(window.localStorage.setItem('qLength', angular.toJson(qLength)));
    return deferred.promise;
  }

  function getCachedQLength() {
    var deferred = $q.defer();
    var qLength = window.localStorage.getItem('qLength');

    if (qLength === null) {
      window.localStorage.setItem('qLength', '0');
      deferred.resolve(0);
    } else {
      deferred.resolve(JSON.parse(qLength));
    }

    return deferred.promise;
  }

  return factory;
}]);
'use strict';
/**
 * @ngdoc service
 * @name Track.Recipe2Service
 * @description
 * # Recipe2Service should always make an API call
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

angular.module('Track').factory('Recipe2Service', ["$http", function ($http) {
  var factory = {
    getMyRecipes: getMyRecipes,
    addRecipe: addRecipe,
    getRecipeById: getRecipeById,
    updateRecipe: updateRecipe,
    deleteRecipe: deleteRecipe,
    getCachedRecipes: getCachedRecipes,
    setCachedRecipes: setCachedRecipes
  };
  var baseUrl = 'https://trackapi.nutritionix.com/v2';

  function getMyRecipes(options) {
    if (!options || _typeof(options) !== 'object') {
      options = {};
    }

    var limit = options.limit || 300,
        offset = options.offset || 0;
    return $http.get(baseUrl + '/recipe?limit=' + limit + '&offset=' + offset).then(function (response) {
      setCachedRecipes(response.data.recipes);
      return response;
    })["catch"](function (e) {
      console.log('there was an error getting my foods', angular.toJson(e));
    });
  }

  function addRecipe(recipe) {
    var data = {
      recipe: recipe
    };
    var request = {
      url: baseUrl + '/recipe',
      method: 'POST',
      data: data
    };
    return $http(request).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error adding recipe', angular.toJson(e));
      return Promise.reject(e);
    });
  }

  function getRecipeById(id) {
    return $http.get(baseUrl + '/recipe/' + id).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error getting recipe by id', angular.toJson(e));
    });
  }

  function updateRecipe(recipe) {
    var data = {
      recipe: recipe
    };
    return $http.put(baseUrl + '/recipe/' + recipe.id, data).then(function (response) {
      var CachedRecipes = getCachedRecipes();

      var deletedRecipeIndex = _.findIndex(CachedRecipes, {
        id: response.data.id
      });

      CachedRecipes[deletedRecipeIndex] = response.data;
      setCachedRecipes(CachedRecipes);
      return response;
    })["catch"](function (e) {
      console.log('there was an error updating recipe', angular.toJson(e));
    });
  }

  function deleteRecipe(recipe_id) {
    var CachedRecipes = getCachedRecipes();

    var deletedRecipeIndex = _.findIndex(CachedRecipes, {
      id: recipe_id
    });

    CachedRecipes.splice(deletedRecipeIndex, 1);
    setCachedRecipes(CachedRecipes);
    return $http["delete"](baseUrl + '/recipe/' + recipe_id)["catch"](function (e) {
      console.log('there was an error deleting a recipe', angular.toJson(e));
    });
  }

  function setCachedRecipes(recipesArray) {
    if (!!recipesArray && !!recipesArray.length) {
      window.localStorage.setItem('recipesList', angular.toJson(recipesArray));
    }
  }

  function getCachedRecipes() {
    var result = window.localStorage.getItem('recipesList');

    if (!!result) {
      return JSON.parse(result);
    }

    return [];
  }

  return factory;
}]);
'use strict';
/**
 * @ngdoc service
 * @name Track.RecipeService
 * @description
 * # RecipeService should always make an API call
 */

angular.module('Track').factory('RecipeService', ["$http", "$timeout", function ($http, $timeout) {
  var factory = {
    getMyFoods: getMyFoods,
    getRecipeById: getRecipeById,
    addRecipe: addRecipe,
    updateRecipe: updateRecipe,
    updateRecipeIngredient: updateRecipeIngredient,
    deleteRecipeIngredient: deleteRecipeIngredient,
    updateRecipeServingQty: updateRecipeServingQty,
    deleteRecipe: deleteRecipe,
    addRecipeIngredient: addRecipeIngredient,
    addRecipeInstructions: addRecipeInstructions
  };
  var baseUrl = 'https://trackapi.nutritionix.com/v2';

  function getMyFoods() {
    var limit = 300,
        offset = 0,
        result = [];

    function getCustomFoods() {
      return $http.get(baseUrl + '/recipes?limit=' + limit + '&offset=' + offset).then(function (response) {
        result = result.concat(response.data.recipes);

        if (result.length == limit + offset) {
          offset += limit;
          return $timeout(getCustomFoods, 0);
        } else {
          return result;
        }
      }).then(function (result) {
        if (result) {
          return result;
        }
      })["catch"](function (e) {
        console.log('there was an error getting my foods', angular.toJson(e));
      });
    }

    return $timeout(getCustomFoods, 0);
  }

  function addRecipe(recipe) {
    var data = {
      recipe: recipe
    };
    var request = {
      url: baseUrl + '/recipes/',
      method: 'POST',
      data: data
    };
    return $http(request).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error adding recipe', angular.toJson(e));
      throw e;
    });
  }

  function getRecipeById(id) {
    return $http.get(baseUrl + '/recipes/' + id).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error getting recipe by id', angular.toJson(e));
    });
  }

  function updateRecipeIngredient(id, ingredient_array) {
    var data = {
      ingredients: ingredient_array
    };
    return $http.put(baseUrl + '/recipes/' + id + '/ingredients', data).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error updating recipe ingredient', angular.toJson(e));
    });
  }

  function deleteRecipeIngredient(recipe_id, ingredient_id) {
    var request = {
      url: baseUrl + '/recipes/' + recipe_id + '/ingredients',
      method: 'DELETE',
      data: {
        ingredients: [{
          id: ingredient_id
        }]
      }
    };
    return $http(request).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error deleting recipe ingredient', angular.toJson(e));
    });
  }

  function updateRecipeServingQty(recipe_id, new_qty) {
    var data = {
      recipe: {
        serving_qty: new_qty
      }
    };
    return $http.put(baseUrl + '/recipes/' + recipe_id, data).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error updating recipe serving qty', angular.toJson(e));
    });
  }

  function updateRecipe(recipe) {
    var data = {
      recipe: recipe
    };
    return $http.put(baseUrl + '/recipes/' + recipe.id, data).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error updating recipe', angular.toJson(e));
    });
  }

  function deleteRecipe(recipe_id) {
    return $http["delete"](baseUrl + '/recipes/' + recipe_id)["catch"](function (e) {
      console.log('there was an error deleting a recipe', angular.toJson(e));
    });
  }

  function addRecipeIngredient(recipe_id, query) {
    var data = {
      query: query
    };
    return $http.post(baseUrl + '/recipes/' + recipe_id + '/ingredients', data).then(function (response) {
      return response;
    })["catch"](function (e) {
      console.log('there was an error adding recipe ingredients');
      throw e;
    });
  }

  function addRecipeInstructions(recipe_id, instructions) {
    var data = {
      recipe: {
        directions: instructions
      }
    };
    return $http.put(baseUrl + '/recipes/' + recipe_id, data).then(function (response) {
      return response;
    })["catch"](function (err) {
      console.log('there was an error adding recipe instructions', angular.toJson(err));
    });
  }

  return factory;
}]);
'use strict';
/**
 * @ngdoc service
 * @name Track.SQLiteService
 * @description
 * # SQLiteService are service / factories that helps to work with cordova SQLite plugin.
 */

angular.module('Track').factory('SQLiteService', ["$cordovaSQLite", "$q", "$ionicPlatform", function ($cordovaSQLite, $q, $ionicPlatform) {
  var factory = {
    query: query,
    getAll: getAll,
    getById: getById
  }; // Handle query's and potential errors

  function query(db, query, parameters) {
    parameters = parameters || [];
    var q = $q.defer();
    $ionicPlatform.ready(function () {
      $cordovaSQLite.execute(db, query, parameters).then(function (result) {
        q.resolve(result);
      }, function (error) {
        console.log('There was an error:', angular.toJson(error));
        q.reject(error);
      });
    });
    return q.promise;
  } // Proces a result set


  function getAll(result) {
    var output = [];

    for (var i = 0; i < result.rows.length; i++) {
      output.push(result.rows.item(i));
    }

    return output;
  } // Proces a single result


  function getById(result) {
    var output = null;

    if (result.rows.length > 0) {
      output = angular.copy(result.rows.item(0));
    }

    return output;
  }

  return factory;
}]);
'use strict';

angular.module('Track').service('UploadPhotoAgentService', ["$cordovaDevice", "$cordovaFile", "$cordovaSQLite", "$http", "$log", "$q", "ConfigurationService", "UploadPhotoUtilityService", "_", function ($cordovaDevice, $cordovaFile, $cordovaSQLite, $http, $log, $q, ConfigurationService, UploadPhotoUtilityService, _) {
  var existingBarcodesTableName = 'existing_barcodes';
  var recordsForSyncTableName = 'records_for_sync';
  var self = this;
  self.currentSession = {
    barcode: null,
    canSave: false
  };
  self.photoTemplates = angular.copy(UploadPhotoUtilityService.photoTemplates);
  /*********************************** Existing Barcodes Table ***********************************/

  self.dropExistingBarcodesTable = function () {
    var query = 'DROP TABLE IF EXISTS ' + existingBarcodesTableName;
    return $cordovaSQLite.execute(window.db, query, []);
  };

  self.checkExistingBarcodesTableExists = function () {
    var query = 'SELECT name FROM sqlite_master WHERE type="table" AND name="' + existingBarcodesTableName + '"';
    return $cordovaSQLite.execute(window.db, query).then(function (selectResult) {
      return 0 !== selectResult.rows.length;
    });
  };

  self.createExistingBarcodesTable = function () {
    var query = 'CREATE TABLE ' + existingBarcodesTableName + ' (id INTEGER PRIMARY KEY, barcode TEXT)';
    return $cordovaSQLite.execute(window.db, query, []);
  };

  self.countExistingBarcodes = function () {
    var query = 'SELECT COUNT(id) AS count FROM ' + existingBarcodesTableName;
    return $cordovaSQLite.execute(window.db, query, []).then(function (selectResult) {
      return selectResult.rows.item(0).count;
    });
  };

  self.insertExistingBarcodes = function (chunk) {
    var deferred = $q.defer();
    var temp = '';
    var data = [];
    chunk.map(function (barcode, index) {
      data.push(barcode);
      if (index !== 0) temp += ',';
      temp += '(?)';
    });
    window.db.sqlBatch([['INSERT INTO ' + existingBarcodesTableName + ' (barcode) VALUES ' + temp, data]], function () {
      self.countExistingBarcodes().then(function (count) {
        var timestamp = new Date().getTime();
        window.localStorage.setItem('existingBarcodesUpdateTimestamp', timestamp);
        deferred.resolve(count);
      });
    }, function (error) {
      $log.error(error);
      deferred.reject(error);
    });
    return deferred.promise;
  };

  self.deleteExistingBarcodes = function () {
    var query = 'DELETE FROM ' + existingBarcodesTableName;
    return $cordovaSQLite.execute(window.db, query, []);
  };

  var barcodeExistsInExistingBarcodes = function barcodeExistsInExistingBarcodes(barcode) {
    var query = 'SELECT id FROM ' + existingBarcodesTableName + ' WHERE barcode = ?';
    return $cordovaSQLite.execute(window.db, query, [barcode]).then(function (selectResult) {
      return 0 !== selectResult.rows.length;
    });
  };
  /*********************************** Records For Sync Table ***********************************/


  self.dropRecordsForSyncTable = function () {
    var query = 'DROP TABLE IF EXISTS ' + recordsForSyncTableName;
    return $cordovaSQLite.execute(window.db, query, []);
  };

  self.checkRecordsForSyncTableExists = function () {
    var query = 'SELECT name FROM sqlite_master WHERE type="table" AND name="' + recordsForSyncTableName + '"';
    return $cordovaSQLite.execute(window.db, query).then(function (selectResult) {
      return 0 !== selectResult.rows.length;
    });
  };

  self.createRecordsForSyncTable = function () {
    var query = 'CREATE TABLE ' + recordsForSyncTableName + ' (' + 'id INTEGER PRIMARY KEY, ' + 'user_id TEXT, ' + 'barcode TEXT, ' + 'photo_type INTEGER, ' + 'photo_name TEXT' + ')';
    return $cordovaSQLite.execute(window.db, query, []);
  };

  self.countRecordsForSync = function () {
    var query = 'SELECT COUNT(id) AS count FROM ' + recordsForSyncTableName;
    return $cordovaSQLite.execute(window.db, query, []).then(function (selectResult) {
      return selectResult.rows.item(0).count;
    });
  };

  self.countRecordsForSyncBarcodes = function () {
    var query = 'SELECT COUNT(DISTINCT barcode) AS count FROM ' + recordsForSyncTableName;
    return $cordovaSQLite.execute(window.db, query, []).then(function (selectResult) {
      return selectResult.rows.item(0).count;
    });
  };

  self.getRecordsForSync = function () {
    var query = 'SELECT * FROM ' + recordsForSyncTableName;
    return $cordovaSQLite.execute(window.db, query, []).then(function (selectResult) {
      var recordsForSync = [];

      if (selectResult.rows.length > 0) {
        var i = 0;

        while (i < selectResult.rows.length) {
          recordsForSync.push({
            id: selectResult.rows.item(i).id,
            user_id: selectResult.rows.item(i).user_id,
            barcode: selectResult.rows.item(i).barcode,
            photo_type: selectResult.rows.item(i).photo_type,
            photo_name: selectResult.rows.item(i).photo_name
          });
          i++;
        }
      }

      return recordsForSync;
    });
  };

  var insertRecordForSync = function insertRecordForSync(record) {
    var values = [record.userId, record.barcode, record.photo_type, record.photo_name];
    var query = 'INSERT INTO ' + recordsForSyncTableName + ' (user_id, barcode, photo_type, photo_name) VALUES (?, ?, ?, ?);';
    return $cordovaSQLite.execute(window.db, query, values);
  };

  var deleteRecordForSync = function deleteRecordForSync(id) {
    var query = 'DELETE FROM ' + recordsForSyncTableName + ' WHERE id = ?';
    return $cordovaSQLite.execute(window.db, query, [id]);
  };

  var checkBarcodeExistsInRecordForSync = function checkBarcodeExistsInRecordForSync(barcode) {
    var query = 'SELECT id FROM ' + recordsForSyncTableName + ' WHERE barcode = ?';
    return $cordovaSQLite.execute(window.db, query, [barcode]).then(function (selectResult) {
      return 0 !== selectResult.rows.length;
    });
  };
  /*********************************** Service ***********************************/


  self.requestExistingBarcodes = function () {
    return $http.get(ConfigurationService.grocery_photo_upload.upc_list).then(function (response) {
      return _.pull(response.data, null);
    });
  };

  var existingBarcodesUpdateTimestampIsUpToDate = function existingBarcodesUpdateTimestampIsUpToDate() {
    var existingBarcodesUpdateTimestamp = window.localStorage.getItem('existingBarcodesUpdateTimestamp') || 0;
    var timestamp = new Date().getTime();
    var timestampDifference = timestamp - existingBarcodesUpdateTimestamp;
    var oneDayInMilliseconds = 24 * 60 * 60 * 1000;
    return timestampDifference < oneDayInMilliseconds;
  };

  self.needToUpdateExistingBarcodes = function () {
    return self.checkExistingBarcodesTableExists().then(function (existingBarcodesTableExists) {
      return !existingBarcodesTableExists || !existingBarcodesUpdateTimestampIsUpToDate();
    });
  };

  self.scanBarcode = function (payload) {
    return UploadPhotoUtilityService.scanBarcode().then(function (barcode) {
      var promises = {
        barcode: $q.when(barcode),
        barcodeExistsInExistingBarcodes: barcodeExistsInExistingBarcodes(barcode),
        checkBarcodeExistsInRecordForSync: checkBarcodeExistsInRecordForSync(barcode)
      };
      return $q.all(promises);
    }).then(function (promisesArray) {
      var barcodeExists = promisesArray.barcodeExistsInExistingBarcodes || promisesArray.checkBarcodeExistsInRecordForSync;

      if (!barcodeExists) {
        self.currentSession.barcode = promisesArray.barcode;
        self.currentSession.userId = payload.userId;
        self.currentSession.photos = angular.copy(self.photoTemplates);
        return true;
      } else {
        return false;
      }
    });
  };

  var canSave = function canSave() {
    var canSave = true;

    for (var key in self.currentSession.photos) {
      if (!self.currentSession.photos[key].photo_name && self.currentSession.photos[key].show) {
        canSave = false;
        break;
      }
    }

    self.currentSession.canSave = canSave;
  };

  var generatePhotoFileName = function generatePhotoFileName(photoType) {
    var timestamp = new Date().getTime();
    var name = self.currentSession.barcode + '-' + self.photoTemplates[photoType].photo_type + '-' + 'TRACK' + self.currentSession.userId + '-' + timestamp;
    return {
      "default": name,
      platformSpecific: 'iOS' === $cordovaDevice.getPlatform() ? name + '.jpg' : name
    };
  };

  self.takePhoto = function (photoType) {
    self.currentSession.photos[photoType].loading = true;
    var name = !!self.currentSession.photos[photoType].name ? self.currentSession.photos[photoType].name : generatePhotoFileName(photoType);
    return UploadPhotoUtilityService.takePhoto({
      destinationType: 'FILE_URI'
    }).then(function (fileURI) {
      self.currentSession.photos[photoType].photo_src = self.currentSession.photos[photoType].photo_file_uri = fileURI;
      self.currentSession.photos[photoType].name = name;
      self.currentSession.photos[photoType].photo_name = name.platformSpecific;
      self.currentSession.photos[photoType].loading = false;
      return UploadPhotoUtilityService.processImage(fileURI, cordova.file.dataDirectory, name["default"]);
    }).then(function (processedImage) {
      var ts = new Date().getTime();
      self.currentSession.photos[photoType].photo_src = cordova.file.dataDirectory + name.platformSpecific + '?' + ts;
      canSave();
      return UploadPhotoUtilityService.removeOriginalImage(self.currentSession.photos[photoType].photo_file_uri);
    });
  };

  self.saveRecordsForSync = function () {
    var promises = [];

    for (var key in self.currentSession.photos) {
      if (self.currentSession.photos[key].photo_name) {
        var record = {
          userId: self.currentSession.userId,
          barcode: self.currentSession.barcode,
          photo_type: self.currentSession.photos[key].photo_type,
          photo_name: self.currentSession.photos[key].photo_name
        };
        promises.push(insertRecordForSync(record));
      }
    }

    return $q.all(promises);
  };

  self.resetCurrentSession = function () {
    self.currentSession = {};
    self.currentSession.barcode = null;
    self.currentSession.canSave = false;
    return self.currentSession;
  };

  self.syncRecord = function (record) {
    return UploadPhotoUtilityService.getDataURL(cordova.file.dataDirectory + record.photo_name, 'image/jpeg', 0.7).then(function (dataURL) {
      return UploadPhotoUtilityService.getBlob(dataURL);
    }).then(function (blob) {
      record.blob = blob;
      return record;
    }).then(function (record) {
      return UploadPhotoUtilityService.uploadToS3(record);
    }).then(function () {
      return deleteRecordForSync(record.id);
    }).then(function () {
      return UploadPhotoUtilityService.deleteRecordPhoto(record.photo_name);
    });
  };

  self.sync = function () {
    return self.getRecordsForSync().then(function (recordsForSync) {
      var promises = [];
      recordsForSync.map(function (record, index) {
        var promise = $cordovaFile.readAsText(cordova.file.dataDirectory, record.photo_name).then(function (dataURL) {
          return UploadPhotoUtilityService.getBlob(dataURL);
        }).then(function (blob) {
          record.blob = blob;
          return record;
        }).then(function (record) {
          return UploadPhotoUtilityService.uploadToS3(record);
        }).then(function () {
          return deleteRecordForSync(record.id);
        }).then(function () {
          return UploadPhotoUtilityService.deleteRecordPhoto(record.photo_name);
        });
        promises.push(promise);
      });
      return $q.all(promises);
    });
  };

  return self;
}]);
'use strict';

angular.module('Track').service('UploadPhotoUserService', ["$cordovaDevice", "$cordovaFile", "$q", "$rootScope", "$window", "ConfigurationService", "UploadPhotoUtilityService", function ($cordovaDevice, $cordovaFile, $q, $rootScope, $window, ConfigurationService, UploadPhotoUtilityService) {
  var self = this;
  self.photos = angular.copy(UploadPhotoUtilityService.photoTemplates);

  var generatePhotoFileName = function generatePhotoFileName(payload) {
    var timestamp = new Date().getTime();
    var name = payload.barcode + '-' + self.photos[payload.photoType].photo_type + '-' + 'TRACK' + payload.user.id + '-' + timestamp;
    return {
      "default": name,
      platformSpecific: 'iOS' === $cordovaDevice.getPlatform() ? name + '.jpg' : name
    };
  };

  self.takePhoto = function (payload) {
    self.photos[payload.photoType].loading = true;
    var name = !!self.photos[payload.photoType].name ? self.photos[payload.photoType].name : generatePhotoFileName(payload);
    return UploadPhotoUtilityService.takePhoto({
      destinationType: 'FILE_URI'
    }).then(function (fileURI) {
      self.photos[payload.photoType].photo_src = self.photos[payload.photoType].photo_file_uri = fileURI;
      self.photos[payload.photoType].name = name;
      self.photos[payload.photoType].photo_name = name.platformSpecific;
      self.photos[payload.photoType].loading = false;
      self.photos[payload.photoType].notUploaded = payload.barcode.search(/[^0-9]/) > -1 ? false : true;
      return UploadPhotoUtilityService.processImage(fileURI, cordova.file.dataDirectory, name["default"]);
    }).then(function (processedImage) {
      var ts = new Date().getTime();
      self.photos[payload.photoType].photo_src = cordova.file.dataDirectory + name.platformSpecific + '?' + ts;

      if ('iOS' === $cordovaDevice.getPlatform()) {
        self.photos[payload.photoType].photo_src = window.Ionic.WebView.convertFileSrc(self.photos[payload.photoType].photo_src);
      }

      return UploadPhotoUtilityService.removeOriginalImage(self.photos[payload.photoType].photo_file_uri);
    }).then(function () {
      $rootScope.$broadcast('photos changed');
    });
  };

  self.canUpload = function () {
    for (var key in self.photos) {
      if (!self.photos[key].photo_src && self.photos[key].show) {
        return false;
      }
    }

    return true;
  };

  self.upload = function () {
    var promises = [];
    angular.forEach(self.photos, function (photo, key) {
      if (photo.show && photo.notUploaded && !!photo.photo_src) {
        var promise = UploadPhotoUtilityService.getDataURL(photo.photo_src, 'image/jpeg', 0.7).then(function (dataURL) {
          return UploadPhotoUtilityService.getBlob(dataURL);
        }).then(function (blob) {
          photo.blob = blob;
          return UploadPhotoUtilityService.uploadToS3(photo).then(function () {
            photo.notUploaded = false;
          });
        }).then(function (location) {
          return UploadPhotoUtilityService.deleteRecordPhoto(photo.photo_name);
        });
        promises.push(promise);
      }
    });
    return $q.all(promises).then(function () {
      $rootScope.$broadcast('photos changed');
    });
  };

  self.resetPhotos = function () {
    var promises = [];
    angular.forEach(self.photos, function (photo, key) {
      if (photo.show && photo.photo_name && photo.notUploaded) {
        promises.push(UploadPhotoUtilityService.deleteRecordPhoto(photo.photo_name));
      }
    });
    return $q.all(promises).then(function (resolvedPromises) {
      delete self.photos;
      self.photos = angular.copy(UploadPhotoUtilityService.photoTemplates);
    }).then(function () {
      $rootScope.$broadcast('photos changed');
    });
  };

  return this;
}]);
'use strict';

angular.module('Track').service('UploadPhotoUtilityService', ["$cordovaCamera", "$cordovaFile", "$log", "$q", "AwsService", "BarcodeScannerService", "CameraService", "ConfigurationService", "_", function ($cordovaCamera, $cordovaFile, $log, $q, AwsService, BarcodeScannerService, CameraService, ConfigurationService, _) {
  var self = this;
  self.maxPhotoWidth = ConfigurationService.grocery_photo_upload.max_photo_width;
  self.photoTemplates = {
    front: {
      photo_name: null,
      photo_src: null,
      photo_type: 1,
      show: true,
      title: 'Front Package',
      loading: false,
      notUploaded: true
    },
    nutrition: {
      photo_name: null,
      photo_src: null,
      photo_type: 2,
      show: true,
      title: 'Nutrition Label',
      loading: false,
      notUploaded: true
    },
    ingredient: {
      photo_name: null,
      photo_src: null,
      photo_type: 3,
      show: false,
      title: 'Ingredient Statement',
      loading: false,
      notUploaded: true
    }
  };

  self.scanBarcode = function () {
    return BarcodeScannerService.scanBarcode().then(function (barcode) {
      return _.trimStart(barcode, 0);
    });
  };

  self.takePhoto = function (options) {
    return CameraService.takePhoto(options);
  };
  /** ---------------------------------------------------------------------
   *
   * images and file system processing
   *
   --------------------------------------------------------------------- */


  var getFileRef = function getFileRef(fileURI) {
    var deferred = $q.defer();
    window.resolveLocalFileSystemURL(fileURI, onSuccess, onError);

    function onSuccess(fileRef) {
      deferred.resolve(fileRef);
    }

    function onError(error) {
      deferred.reject(error);
    }

    return deferred.promise;
  };

  var deleteFileByRef = function deleteFileByRef(fileRef) {
    var deferred = $q.defer();
    fileRef.remove(onSuccess, onError);

    function onSuccess(fileRef) {
      deferred.resolve(fileRef);
    }

    function onError(error) {
      deferred.reject(error);
    }

    return deferred.promise;
  };

  var getImageSize = function getImageSize(fileURI) {
    var deferred = $q.defer();
    window.imageResizer.getImageSize(onSuccess, onError, fileURI);

    function onSuccess(success) {
      deferred.resolve(success);
    }

    function onError(error) {
      deferred.reject(error);
    }

    return deferred.promise;
  };

  var resizeImage = function resizeImage(fileURI, path, name, width, height) {
    var deferred = $q.defer();
    var options = {
      imageDataType: window.ImageResizer.IMAGE_DATA_TYPE_URL,
      resizeType: window.ImageResizer.RESIZE_TYPE_MIN_PIXEL,
      pixelDensity: false,
      storeImage: true,
      directory: path,
      filename: name,
      photoAlbum: false,
      format: 'jpg',
      quality: 100
    };
    window.imageResizer.resizeImage(onSuccess, onError, fileURI, width, height, options);

    function onSuccess(success) {
      deferred.resolve(success);
    }

    function onError(error) {
      deferred.reject(error);
    }

    return deferred.promise;
  };

  self.removeOriginalImage = function (fileURI) {
    return getFileRef(fileURI).then(deleteFileByRef);
  };

  self.processImage = function (fileURI, path, name) {
    return getImageSize(fileURI).then(function (size) {
      var width, height;
      height = parseInt(size.height * (self.maxPhotoWidth / size.width));
      width = parseInt(self.maxPhotoWidth);
      return resizeImage(fileURI, path, name, width, height);
    });
  };

  self.deleteRecordPhoto = function (name) {
    return $cordovaFile.removeFile(cordova.file.dataDirectory, name);
  };
  /** ---------------------------------------------------------------------
   *
   * upload image processing
   *
   --------------------------------------------------------------------- */


  self.getDataURL = function (src, type, quality) {
    return window.blobUtil.imgSrcToDataURL(src, type, undefined, quality);
  };

  self.getBlob = function (src) {
    if (_.startsWith(src, 'data:image')) {
      return window.blobUtil.dataURLToBlob(src);
    } else {
      return window.blobUtil.imgSrcToBlob(src);
    }
  };

  self.uploadToS3 = function (record) {
    var deferred = $q.defer();
    var params = {
      Key: record.photo_name + '.jpg',
      ContentType: 'image/jpeg',
      Body: record.blob
    };

    if (_.includes(params.Key, '.jpg.jpg')) {
      params.Key = _.replace(params.Key, '.jpg.jpg', '.jpg');
    }

    AwsService.bucket.upload(params, function (err, data) {
      if (!err) {
        deferred.resolve(data.Location);
      } else {
        deferred.reject(err);
      }
    });
    return deferred.promise;
  };

  return this;
}]);
'use strict';

angular.module('Track').service('UserDefaultsService', function () {
  var factory = {
    setValue: setValue,
    getValue: getValue
  };
  var isIOS = window.ionic.Platform.platform() === 'android' ? false : true;

  function setValue(key, value) {
    if (!isIOS) {
      return;
    }

    if (window.AppGroupsUserDefaults) {
      var userOptions = {
        key: key,
        value: value,
        suite: 'group.nutritionix.nixtrack'
      };
      window.AppGroupsUserDefaults.save(userOptions, function () {
        console.log('added to NSUserDefaults', userOptions);
      }, function () {
        console.log('failed to save to NSUserDefaults', userOptions);
      });
    }
  }

  function getValue(key) {
    if (window.AppGroupsUserDefaults) {
      var userOptions = {
        key: key,
        suite: 'group.nutritionix.nixtrack'
      };
      window.AppGroupsUserDefaults.load(userOptions, function (result) {
        console.log('loaded from NSUserDefaults', userOptions);
        return result;
      }, function () {
        console.log('failed to save to NSUserDefaults', userOptions);
      });
    }
  }

  return factory;
});
'use strict';
/**
 * @ngdoc function
 * @name Track.serive:ExampleService
 * @description
 * # ExampleService
 */

angular.module('Track') // use factory for services
.factory('UserService', ["$rootScope", "$state", "$q", "$http", "SQLiteService", function ($rootScope, $state, $q, $http, SQLiteService) {
  var baseUrl = "https://trackapi.nutritionix.com/v2";

  var updateSentryContext = function updateSentryContext() {
    window.Sentry.configureScope(function (scope) {
      scope.setUser({
        userData: !!factory.user ? factory.user : 'Empty',
        email: !!factory.user ? factory.user.email : '',
        id: !!factory.user ? factory.user.id : '',
        jwtLength: !!factory.jwt ? factory.jwt.length : 0
      });
    });
  };

  var setJwt = function setJwt(newJwt) {
    if (!newJwt && typeof newJwt !== 'string') {
      return;
    }

    factory.jwt = newJwt;
    console.log('[UserService] Setting JWT in DB:', newJwt);
    return SQLiteService.query(window.db, 'INSERT INTO localdata (dataName, value) VALUES (?1, ?2) ON CONFLICT(dataName) DO UPDATE SET dataName=?1, value=?2', ['jwt', newJwt]);
  };

  var getJwt = function getJwt() {
    var deferred = $q.defer();

    if (!!factory.jwt) {
      deferred.resolve(factory.jwt);
    } else {
      SQLiteService.query(window.db, 'SELECT value FROM localdata WHERE dataName=?', ['jwt']).then(function (result) {
        var jwt = SQLiteService.getById(result);

        if (!!jwt) {
          deferred.resolve(jwt.value);
        } else {
          deferred.resolve(null);
        }
      })["catch"](function (err) {
        console.log('[UserService] Error getting JWT from DB:', err);
        deferred.reject(err);
      });
    }

    return deferred.promise;
  };

  var removeJwt = function removeJwt() {
    factory.jwt = ''; //No need to clear data in DB, because on logout DB will be completely cleared
  };

  var setUser = function setUser(userData) {
    factory.user = userData;
    var stringifiedUser = angular.toJson(userData);
    console.log('[UserService] Setting new user data:', stringifiedUser);
    return SQLiteService.query(window.db, 'INSERT INTO localdata (dataName, value) VALUES (?1, ?2) ON CONFLICT(dataName) DO UPDATE SET dataName=?1, value=?2', ['user', stringifiedUser]);
  };

  var getUser = function getUser() {
    var deferred = $q.defer();

    if (!_.isEmpty(factory.user)) {
      // console.log('[UserService] Getting user stored in memory:', angular.toJson(factory.user));
      deferred.resolve(factory.user);
    } else {
      SQLiteService.query(window.db, 'SELECT value FROM localdata WHERE dataName = ?', ['user']).then(function (result) {
        var userValue = SQLiteService.getById(result);
        var user = !_.isEmpty(userValue) && !!JSON.parse(userValue.value) ? JSON.parse(userValue.value) : null;

        if (!_.isEmpty(user)) {
          factory.user = user;
          console.log('[UserService] Getting user from DB:', angular.toJson(factory.user));
          updateSentryContext();
          deferred.resolve(factory.user);
        } else {
          factory.getJwt().then(function (jwt) {
            if (!!jwt && jwt.length) {
              $http.get(baseUrl + '/me').then(function (response) {
                factory.user = response.data;
                var stringifiedUser = angular.toJson(response.data);
                SQLiteService.query(window.db, 'INSERT INTO localdata (dataName, value) VALUES (?1, ?2) ON CONFLICT(dataName) DO UPDATE SET dataName=?1, value=?2', ['user', stringifiedUser]);
                deferred.resolve(response.data);
              })["catch"](function (err) {
                console.log('[UserService] there was an error getting user from API', angular.toJson(err));
              });
            } else {
              updateSentryContext();
              deferred.reject('[UserService] No user stored in local DB');
            }
          });
        }
      })["catch"](function (err) {
        deferred.reject(err);
      });
    }

    return deferred.promise;
  };

  var updateUser = function updateUser(preferences) {
    //receive object with preferences and merge them into current user obj.
    var newPreferences = _.cloneDeep(preferences);

    delete newPreferences.id;
    delete newPreferences.username;
    delete newPreferences.ref;
    delete newPreferences.coach;
    delete newPreferences.mobile_number;
    delete newPreferences.is_activated;
    delete newPreferences.country_code;
    delete newPreferences.created_at;
    delete newPreferences.show_meal_type;
    delete newPreferences.nutrPrefs;
    delete newPreferences.grocery_agent;
    delete newPreferences.remote_ids;
    delete newPreferences.premium_user;
    newPreferences.enable_review_foods = newPreferences.enable_review_foods || 0; //must be a number

    console.log(newPreferences);

    if (newPreferences.nutrition_topics) {
      var topics_ids = [];
      newPreferences.nutrition_topics.map(function (topic) {
        if (!topic.id) {
          return;
        }

        return topics_ids.push(topic.id);
      });
      newPreferences.nutrition_topics = topics_ids;
    }

    return $http.put(baseUrl + '/me/preferences', newPreferences).then(function (response) {
      factory.user = response.data;
      var stringifiedUser = angular.toJson(response.data);
      SQLiteService.query(window.db, 'INSERT INTO localdata (dataName, value) VALUES (?1, ?2) ON CONFLICT(dataName) DO UPDATE SET dataName=?1, value=?2', ['user', stringifiedUser]);
      return response;
    })["catch"](function (err) {
      console.log('[UserService] error in updateUser', angular.toJson(err));
      Promise.reject(err);
    });
  };

  var removeUser = function removeUser() {
    factory.user = {}; //No need to clear data in DB, because on logout DB will be completely cleared
  };

  var setDailyCalories = function setDailyCalories(daily_kcal) {
    var data = {
      'daily_kcal': daily_kcal
    };
    return factory.updateUser(data);
  };

  var togglePN = function togglePN(time, shouldEnable) {
    var enable = 0;

    if (shouldEnable) {
      enable = 1;
    }

    var data = {
      push_enabled: enable
    };

    if (time === 0) {
      data.weekday_reminders_enabled = enable;
    } else {
      data.weekend_reminders_enabled = enable;
    }

    return factory.updateUser(data);
  };

  var factory = {
    setJwt: setJwt,
    getJwt: getJwt,
    removeJwt: removeJwt,
    setUser: setUser,
    getUser: getUser,
    updateUser: updateUser,
    removeUser: removeUser,
    setDailyCalories: setDailyCalories,
    togglePN: togglePN,
    user: {},
    jwt: ''
  };
  return factory;
}]);
'use strict';

angular.module('Track').factory('VoiceRecognitionService', ["$ionicPlatform", "$q", function ($ionicPlatform, $q) {
  var factory = {
    startVoiceRecognition: startVoiceRecognition,
    stopVoiceRecognition: stopVoiceRecognition,
    isRecognitionAvailable: false,
    hasPermission: false
  };
  var speechRecognition;
  $ionicPlatform.ready(function () {
    speechRecognition = window.plugins.speechRecognition;
    speechRecognition.isRecognitionAvailable(function (isAvailable) {
      factory.isRecognitionAvailable = isAvailable;
    }, function (e) {
      console.log('error:', e);
    });
    speechRecognition.hasPermission(function (hasPermission) {
      factory.hasPermission = hasPermission;
    }, function (e) {
      console.log('error:', e);
    });
  });
  var recognitionInProgress = false;

  function startVoiceRecognition(options) {
    var deferred = $q.defer();

    if (!factory.isRecognitionAvailable) {
      speechRecognition.isRecognitionAvailable(function (isAvailable) {
        factory.isRecognitionAvailable = isAvailable;

        if (!factory.isRecognitionAvailable) {
          deferred.reject('Not available');
        }
      }, function (e) {
        console.log('error:', e);
      });
    }

    if (!factory.hasPermission) {
      speechRecognition.requestPermission(function () {
        factory.hasPermission = true;
      }, function (e) {
        factory.hasPermission = false;
        deferred.reject('No permissions granted');
      });
    }

    recognitionInProgress = true;
    speechRecognition.startListening(function (result) {
      if (recognitionInProgress && window.ionic.Platform.isIOS()) {
        deferred.notify(result[0]);
      } else {
        deferred.resolve(result[0]);
      }
    }, function (err) {
      if (err == 0) {
        deferred.reject('Cancelled');
      }

      console.log('error starting speech recognition:', err);
      deferred.reject(err);
    }, options);
    return deferred.promise;
  }

  function stopVoiceRecognition() {
    speechRecognition.stopListening();
    recognitionInProgress = false;
  }

  return factory;
}]);
'use strict';
/**
 * @ngdoc service
 * @name Track.WalkthroughService
 * @description
 * # WalkthroughService setting new data to the native widget
 */

angular.module('Track').factory('WalkthroughService', function () {
  var storedEvents = JSON.parse(window.localStorage.getItem('walkthroughEventsList')) || {};
  var factory = {
    runWalkthrough: runWalkthrough,
    setEventFlag: setEventFlag,
    eventsList: storedEvents
  };
  var eventsToCheck = ['firstLogin', 'firstFoodAddedToFoodLog', 'firstFoodAddedToBasket', 'firstMultipleFoodsInBasket', 'firstEnterInTrackTab', 'firstOfflineMode'];
  eventsToCheck.map(function (eventName) {
    if (factory.eventsList[eventName] === undefined) {
      setEventFlag(eventName, true);
    }
  });

  function setEventFlag(name, value) {
    factory.eventsList[name] = value;
    window.localStorage.setItem('walkthroughEventsList', angular.toJson(factory.eventsList));
  }

  var walkthroughList = [[// sequence #0
  {
    'id': '0-1',
    'title': 'Smart Search',
    'content': 'Search all foods here.',
    'state': 'app.foodlog',
    'fixed': true,
    'focusOffset': {
      'top': 3,
      'bottom': 3,
      'left': 3,
      'right': 3
    }
  }, {
    'id': '0-2',
    'title': 'Barcode Scanner',
    'content': 'Use the barcode scanner to quickly log packaged foods.',
    'state': 'app.foodlog',
    'fixed': true,
    'focusOffset': {
      'top': 3,
      'bottom': 3,
      'left': -3,
      'right': -3
    }
  }, {
    'id': '0-3',
    'title': 'Basket',
    'content': 'Review foods in your basket before logging.',
    'state': 'app.foodlog',
    'fixed': true,
    'focusOffset': {
      'top': 3,
      'bottom': 3,
      'left': 3,
      'right': 3
    }
  }, {
    'id': 'a.main-tab.tab-item[icon=\'fa fa-plus\']',
    'title': 'Log by Voice',
    'content': 'Click the +Track button to log by voice.',
    'state': 'app.foodlog',
    'isIdSelector': true,
    'fixed': true,
    'lastSlide': true // set to true to set it as last slide.

  }], [// sequence #1
  {
    'id': '1-1',
    'title': 'Daily Summary',
    'content': 'Keep track of your daily totals by tapping on the calorie bar to view your Daily Summary.',
    'state': 'app.foodlog',
    'focusOffset': {
      'top': 3,
      'bottom': 23,
      'left': 0,
      'right': 0
    }
  }, {
    'id': '1-2',
    'title': 'Meal Summary',
    'content': 'Or view summaries by meal.',
    'state': 'app.foodlog',
    'fixed': true,
    'focusOffset': {
      'top': 3,
      'bottom': 3,
      'left': 3,
      'right': 3
    }
  }, {
    'id': '1-3',
    'title': 'Delete or Copy a Food',
    'content': 'Swipe left to quickly delete or copy a food.',
    'state': 'app.foodlog',
    'fixed': true,
    'focusOffset': {
      'top': 3,
      'bottom': 3,
      'left': 3,
      'right': 3
    }
  }, {
    'id': '1-4',
    'title': 'Delete or Copy a Meal',
    'content': 'Or swipe left on a meal to quickly delete or copy a whole meal.',
    'state': 'app.foodlog',
    'fixed': true,
    'lastSlide': true // set to true to set it as last slide.

  }], [// sequence #2
  {
    'id': '2-1',
    'title': 'Edit Quantity',
    'content': 'Easily change the serving size or serving unit.',
    'state': 'app.reviewFoods',
    'focusOffset': {
      'top': 3,
      'bottom': -12,
      'left': 3,
      'right': 3
    }
  }, {
    'id': '2-2',
    'title': 'Nutrition Data Preview',
    'content': 'Click here to view an item\'s nutrition information before logging.',
    'state': 'app.reviewFoods',
    'fixed': true,
    'focusOffset': {
      'top': -10,
      'bottom': -10,
      'left': 0,
      'right': -45
    }
  }], [// sequence #3 (#2 extended)
  {
    'id': '2-1',
    'title': 'Edit Quantity',
    'content': 'Easily change the serving size or serving unit.',
    'state': 'app.reviewFoods',
    'focusOffset': {
      'top': 3,
      'bottom': -12,
      'left': 3,
      'right': 3
    }
  }, {
    'id': '2-2',
    'title': 'Nutrition Data Preview',
    'content': 'Click here to view an item\'s nutrition information before logging.',
    'state': 'app.reviewFoods',
    'fixed': true,
    'focusOffset': {
      'top': -10,
      'bottom': -10,
      'left': 0,
      'right': -45
    }
  }, {
    'id': '3-1',
    'title': 'Log as a Single Food',
    'content': 'Use this option to combine your Basket contents into a recipe or single meal.',
    'state': 'app.reviewFoods',
    'fixed': true,
    'focusOffset': {
      'top': 3,
      'bottom': 3,
      'left': 3,
      'right': 3
    }
  }], [// sequence #4 (#3 step 3 only)
  {
    'id': '3-1',
    'title': 'Log as a Single Food',
    'content': 'Use this option to combine your Basket contents into a recipe or single meal.',
    'state': 'app.reviewFoods',
    'fixed': true,
    'focusOffset': {
      'top': 3,
      'bottom': 3,
      'left': 3,
      'right': 3
    }
  }], [// sequence #5
  {
    'id': '4-1',
    'title': 'Freeform',
    'content': 'Click into the box to pull up your keyboard. Type freeform text or click the microphone button to speak your foods.',
    'state': 'app.reviewFoods',
    'fixed': true,
    'focusOffset': {
      'top': 3,
      'bottom': 3,
      'left': 3,
      'right': 3
    }
  }, {
    'id': '4-2',
    'title': 'Specific Searches',
    'content': 'Search specifically within a restaurant menu, for a packaged food, or for previously logged foods in your History.',
    'state': 'app.reviewFoods',
    'fixed': true,
    'focusOffset': {
      'top': 3,
      'bottom': 3,
      'left': 3,
      'right': 3
    }
  }], [// sequence #6
  {
    'id': '6-1',
    'title': 'Offline Mode',
    'content': 'The Track app relies on a steady internet connection in order to pull the most up-to-date nutrition information directly from the Nutritionix verified database. When the app enters offline mode, you will need to connect to a more reliable internet source in order to look up and/or log new foods.',
    'state': 'app.foodlog',
    'fixed': true,
    'focusOffset': {
      'top': 3,
      'bottom': 3,
      'left': 3,
      'right': 3
    }
  }]];

  function runWalkthrough(wtIndex) {
    angular.element('.wt-wrapper').scope().startWalkthrough(walkthroughList[wtIndex]);
  }

  return factory;
});
'use strict';
/**
 * @ngdoc service
 * @name Track.WidgetService
 * @description
 * # WidgetService setting new data to the native widget
 */

angular.module('Track').factory('WidgetService', ["$cordovaDevice", "UserDefaultsService", function ($cordovaDevice, UserDefaultsService) {
  var factory = {
    setCaloriesLimit: setCaloriesLimit,
    setBurnedCalories: setBurnedCalories,
    setConsumedCalories: setConsumedCalories,
    caloriesLimit: 2000,
    todayConsumed: 0,
    todayBurned: 0
  };
  window.widgetServiceGlobal = factory;
  var platform;
  document.addEventListener('deviceready', getPlatform, false);

  function getPlatform() {
    platform = $cordovaDevice.getPlatform();
  }

  function setCaloriesLimit(calLimit) {
    if (calLimit !== undefined, calLimit !== null) {
      factory.caloriesLimit = parseInt(calLimit);
      updateWidgetData();
    } else {
      return;
    }
  }

  function setBurnedCalories(calBurned) {
    if (calBurned !== undefined, calBurned !== null) {
      factory.todayBurned = parseInt(calBurned);
      updateWidgetData();
    } else {
      return;
    }
  }

  function setConsumedCalories(calConsumed) {
    if (calConsumed !== undefined, calConsumed !== null) {
      factory.todayConsumed = parseInt(calConsumed);
      updateWidgetData();
    } else {
      return;
    }
  }

  function updateWidgetData() {
    if (!platform) {
      return;
    }

    var updateDate = moment.utc().format('MM-DD-YYYY');

    if (platform === 'Android') {
      window.nutritionixWidget.updateData({
        todayConsumed: factory.todayConsumed,
        todayBurned: factory.todayBurned,
        caloriesLimit: factory.caloriesLimit,
        updateDate: updateDate
      });
    } else if (platform === 'iOS') {
      UserDefaultsService.setValue('caloriesConsumed', factory.todayConsumed.toString());
      UserDefaultsService.setValue('caloriesBurned', factory.todayBurned.toString());
      UserDefaultsService.setValue('caloriesLimit', factory.caloriesLimit.toString());
      UserDefaultsService.setValue('caloriesUpdateDate', updateDate);
    } else {
      return; //console.log ('platform is not supported');
    }
  }

  return factory;
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.util:lodash
 * @description
 * # Lo-Dash
 * Expose Lo-Dash through injectable factory, so we don't pollute / rely on global namespace
 * just inject lodash as _
 */

angular.module('Track').factory('_', ["$window", function ($window) {
  return $window._;
}]);
'use strict';
/**
 * @ngdoc function
 * @name Track.util:stacktrace
 * @description
 * # StackTrace
 * Framework-agnostic, micro-library for getting stack traces in all web browsers
 * just inject lodash as StackTrace
 */

angular.module('Track').factory('StackTrace', ["$window", function ($window) {
  return $window.StackTrace;
}]);
"use strict";

(function () {
  'use strict';

  angular.module('Track').filter('caloriesFilter', function () {
    return function (calories) {
      if (calories < 0) {
        return 0;
      }

      return Math.round(calories);
    };
  });
})();
"use strict";

(function () {
  'use strict';

  angular.module('Track').filter('capitalizeFirstWord', function () {
    return function (input, all) {
      var reg = all ? /([^\W_]+[^\s-]*) */g : /([^\W_]+[^\s-]*)/;
      return !!input ? input.replace(reg, function (txt) {
        return txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase();
      }) : '';
    };
  });
})();
"use strict";

(function () {
  'use strict';

  angular.module('Track').filter('coachCodeFilter', function () {
    return function (coachCode) {
      if (!coachCode) {
        return;
      }

      var result = coachCode.replace(/(.{3})/, '$1-');
      return result;
    };
  });
})();
"use strict";

(function () {
  'use strict';

  angular.module('Track').filter('cut', function () {
    return function (value, wordwise, max, tail) {
      if (!value) return '';
      max = parseInt(max, 10);
      if (!max) return value;
      if (value.length <= max) return value;
      value = value.substr(0, max);

      if (wordwise) {
        var lastspace = value.lastIndexOf(' ');

        if (lastspace != -1) {
          value = value.substr(0, lastspace);
        }
      }

      return value + (tail || ' …');
    };
  });
})();
"use strict";

(function () {
  'use strict';

  angular.module('Track').filter('kgToUserUnits', ["UserService", function (UserService) {
    return function (kg) {
      var measureSystem = '';
      return UserService.getUser().then(function (user) {
        measureSystem = user.measure_system;

        if (measureSystem === 1) {
          return kg;
        }

        return kg * 2.20462;
      })["catch"](function (err) {
        console.log('Error getting active user from local DB:', err);
      });
    };
  }]);
})();
"use strict";

(function () {
  'use strict';

  angular.module('Track').filter('nutrient', function () {
    return function nutrient(nutrients, id, attribute) {
      var i;
      id = parseInt(id);

      if (id && angular.isArray(nutrients)) {
        for (i in nutrients) {
          if (nutrients.hasOwnProperty(i)) {
            if (parseInt(nutrients[i].attr_id) === id) {
              return attribute ? nutrients[i][attribute] : nutrients[i];
            }
          }
        }
      }

      return null;
    };
  });
})();
"use strict";

(function () {
  'use strict';

  angular.module('Track').filter('objectLimitTo', function () {
    return function (obj, limitFrom, limitTo) {
      var newObj = {},
          i = 0;

      for (var p in obj) {
        if (i >= limitFrom) newObj[p] = obj[p];
        if (++i === limitTo) break;
      }

      return newObj;
    };
  });
})();
"use strict";

(function () {
  'use strict';

  angular.module('Track').filter('ucfirst', function () {
    return function (input) {
      input = input || '';
      return input.replace(/\w\S*/g, function (txt) {
        return txt.charAt(0).toUpperCase() + txt.substr(1);
      });
    };
  });
})();
'use strict';

angular.module('Track').service('HealthKitExerciseService', ["$rootScope", "$q", "SQLiteService", "ApiService", function ($rootScope, $q, SQLiteService, ApiService) {
  var factory = {
    syncExercise: syncExercise,
    pullExerciseFromHK: pullExerciseFromHK
  };

  function syncExercise() {
    var syncDates = ApiService.getLastXDaysDates(7); //do not sync days outside the last 7 days

    var should_sync = _.difference(Object.keys($rootScope.foodlog), syncDates).length;

    if (should_sync == syncDates.length) {
      console.log('dont sync');
      return;
    }

    getLastExerciseSync().then(function (result) {
      // if result set is empty, push all to hk; else determine what to push
      if (!result) {
        console.log('adding all exercise');
        deleteExerciseFromHK(syncDates).then(function (value) {
          console.log('Delete all exercise sample success');
          addExerciseToHK(syncDates).then(function (result) {
            console.log('updating hk exercise sqlite');
            SQLiteService.query(window.db, 'INSERT INTO hkdata_exercise (response) VALUES (?)', [angular.toJson($rootScope.exerciseLog)])["catch"](function (err) {
              console.log('there was an error adding hk exercise data to db', angular.toJson(err));
            });
          });
        });
      } else {
        reconcileHKExercise(result.resp, result.id);
      }
    })["catch"](function (err) {
      console.log(angular.toJson(err));
    });
  } //should always only be one row in table


  function getLastExerciseSync() {
    var deferred = $q.defer();
    SQLiteService.query(window.db, 'SELECT * FROM hkdata_exercise').then(function (result) {
      if (result.rows.length == 1) {
        var res = SQLiteService.getById(result);
        deferred.resolve({
          'resp': JSON.parse(res.response),
          'id': res.id
        });
      } else {
        deferred.resolve('');
      }
    })["catch"](function (err) {
      console.log('there was an error getting hk exercise data from db', angular.toJson(err));
      deferred.reject(err);
    });
    return deferred.promise;
  }

  function reconcileHKExercise(exercise_data, id) {
    // These are the last 7 days we want to match
    var syncDates = ApiService.getLastXDaysDates(7);
    var daysToSync = [];

    var day_difference = _.difference(syncDates, Object.keys(exercise_data));

    _.forEach(day_difference, function (day) {
      daysToSync.push(day);
    });

    _.forEach(exercise_data, function (dayObj, day) {
      //outside the scope of 7 days
      var match_arr;

      if (syncDates.indexOf(day) === -1) {
        return;
      } else {
        var hkExercises = dayObj.exercises;
        var apiExercises = $rootScope.exerciseLog[day].exercises; // used to determine deletes. bit arr to store which indices in hk array are matched.
        // ones that are not matched need to be deleted from hk

        match_arr = new Array(hkExercises.length); //first check for exercises in api exercises that are not in hk

        _.forEach(apiExercises, function (api_exercise) {
          //index of matched exercise in hkexercises
          var match = _.findIndex(hkExercises, function (exercise) {
            return api_exercise.id == exercise.id;
          }); //id no match found, then need to add


          if (match === -1) {
            console.log('adding exercise day', day);
            daysToSync.push(day);
            return;
          } else {
            match_arr[match] = 1; //check if the exercise has been updated by comparing the calories burned values

            if (api_exercise.nf_calories !== hkExercises[match].nf_calories) {
              console.log('updating exercise', day);
              daysToSync.push(day);
              return;
            }
          }
        });
      }

      if (_.includes(daysToSync, day)) {
        return;
      } //iterate through the matched arr to determine deletes


      for (var i = 0; i < match_arr.length; i++) {
        if (!match_arr[i]) {
          console.log('deleting', day);
          daysToSync.push(day);
        }
      }
    });

    daysToSync = Array.from(new Set(daysToSync));
    deleteExerciseFromHK(daysToSync).then(function (value) {
      addExerciseToHK(daysToSync).then(function () {
        // if we need to do a sync, then update, otherwise its already synced
        if (daysToSync.length) {
          console.log('updating exercise sqlite');
          SQLiteService.query(window.db, 'UPDATE hkdata_exercise SET response=? where id=?', [angular.toJson($rootScope.exerciseLog), id])["catch"](function (err) {
            console.log('there was error updating hk data to db', angular.toJson(err));
          });
        }
      });
    });
  }

  function addExerciseToHK(days) {
    var promises = [];

    _.forEach(days, function (day) {
      _.map($rootScope.exerciseLog[day].exercises, function (exercise) {
        var deferred = $q.defer();
        promises.push(deferred.promise);
        var sample = {
          'sampleType': 'HKQuantityTypeIdentifierActiveEnergyBurned',
          'startDate': new Date(exercise.timestamp),
          'endDate': new Date(new Date(day).setHours(23, 59, 59)),
          'amount': exercise.nf_calories,
          'unit': 'kcal'
        };
        window.plugins.healthkit.saveQuantitySample(sample, function (value) {
          deferred.resolve('success');
        }, function (err) {
          console.log('add exercise sample err', angular.toJson(err));
          deferred.reject(err);
        });
      });
    });

    return $q.all(promises);
  }

  function deleteExerciseFromHK(days) {
    var promises = [];

    _.forEach(days, function (day) {
      var deferred = $q.defer();
      promises.push(deferred.promise);
      var sample = {
        'sampleType': 'HKQuantityTypeIdentifierActiveEnergyBurned',
        'startDate': new Date(day),
        'endDate': new Date(new Date(day).setHours(23, 59, 59)) //end of day

      };
      window.plugins.healthkit.deleteSamples(sample, function (value) {
        deferred.resolve('success');
      }, function (err) {
        console.log('Delete exercise sample err', angular.toJson(err));
        deferred.reject(err);
      });
    });

    return $q.all(promises);
  }

  function pullExerciseFromHK() {
    window.plugins.healthkit.querySampleTypeAggregated({
      startDate: new Date(new Date().getTime() - 7 * 24 * 60 * 60 * 1000),
      endDate: new Date(),
      aggregation: 'day',
      sampleType: 'HKQuantityTypeIdentifierActiveEnergyBurned',
      unit: 'kcal'
    }, function (value) {
      var add_update_map = {};

      _.forEach(value, function (record) {
        var day_formatted = moment(record.startDate).format('ddd, MM/DD/YY');

        if (day_formatted in add_update_map) {
          add_update_map[day_formatted] += record.quantity;
        } else {
          if (record.quantity !== 0) {
            add_update_map[day_formatted] = record.quantity;
          }
        }
      });

      ApiService.addOrUpdateHKExercise(add_update_map);
    }, function (err) {
      console.log('err', angular.toJson(err));
    });
  }

  return factory;
}]);
'use strict';

angular.module('Track').service('HealthKitService', ["$rootScope", "$q", "SQLiteService", "ApiService", function ($rootScope, $q, SQLiteService, ApiService) {
  var factory = {
    sync: sync,
    syncInProgress: false
  }; // attr ids we want to pull and sum
  //value is hk identified and unit array

  var atr_ids = {
    262: ['HKQuantityTypeIdentifierDietaryCaffeine', 'mg'],
    301: ['HKQuantityTypeIdentifierDietaryCalcium', 'mg'],
    205: ['HKQuantityTypeIdentifierDietaryCarbohydrates', 'g'],
    601: ['HKQuantityTypeIdentifierDietaryCholesterol', 'mg'],
    312: ['HKQuantityTypeIdentifierDietaryCopper', 'mg'],
    208: ['HKQuantityTypeIdentifierDietaryEnergyConsumed', 'kcal'],
    645: ['HKQuantityTypeIdentifierDietaryFatMonounsaturated', 'g'],
    646: ['HKQuantityTypeIdentifierDietaryFatPolyunsaturated', 'g'],
    606: ['HKQuantityTypeIdentifierDietaryFatSaturated', 'g'],
    204: ['HKQuantityTypeIdentifierDietaryFatTotal', 'g'],
    291: ['HKQuantityTypeIdentifierDietaryFiber', 'g'],
    303: ['HKQuantityTypeIdentifierDietaryIron', 'mg'],
    304: ['HKQuantityTypeIdentifierDietaryMagnesium', 'mg'],
    315: ['HKQuantityTypeIdentifierDietaryManganese', 'mg'],
    406: ['HKQuantityTypeIdentifierDietaryNiacin', 'mg'],
    410: ['HKQuantityTypeIdentifierDietaryPantothenicAcid', 'mg'],
    305: ['HKQuantityTypeIdentifierDietaryPhosphorus', 'mg'],
    306: ['HKQuantityTypeIdentifierDietaryPotassium', 'mg'],
    203: ['HKQuantityTypeIdentifierDietaryProtein', 'g'],
    405: ['HKQuantityTypeIdentifierDietaryRiboflavin', 'mg'],
    307: ['HKQuantityTypeIdentifierDietarySodium', 'mg'],
    269: ['HKQuantityTypeIdentifierDietarySugar', 'g'],
    404: ['HKQuantityTypeIdentifierDietaryThiamin', 'mg'],
    415: ['HKQuantityTypeIdentifierDietaryVitaminB6', 'mg'],
    320: ['HKQuantityTypeIdentifierDietaryVitaminA', 'mcg'],
    401: ['HKQuantityTypeIdentifierDietaryVitaminC', 'mg'],
    328: ['HKQuantityTypeIdentifierDietaryVitaminD', 'mcg'],
    323: ['HKQuantityTypeIdentifierDietaryVitaminE', 'mg'],
    309: ['HKQuantityTypeIdentifierDietaryZinc', 'mg']
  };

  function sync() {
    if (factory.syncInProgress) {
      return;
    }

    factory.syncInProgress = true;
    var syncDates = ApiService.getLastXDaysDates(7); //do not sync days outside the last 7 days

    var should_sync = _.difference(Object.keys($rootScope.foodlog), syncDates).length;

    if (should_sync == syncDates.length) {
      console.log('dont sync');
      return;
    }

    getLastHKSync().then(function (result) {
      // if result set is empty, push all to hk; else determine what to push
      if (!result) {
        console.log('adding all nutrients');
        deleteFromHK(syncDates).then(function (value) {
          console.log('Delete all samples success');
          addToHK(syncDates).then(function (result) {
            //update the db with the current foodlog
            console.log('updating hk sqlite');
            SQLiteService.query(window.db, 'INSERT INTO hkdata (response) VALUES (?)', [angular.toJson($rootScope.foodlog)])["catch"](function (err) {
              console.log('there was error adding hk data to db', angular.toJson(err));
            });
          });
        });
      } else {
        reconcileHK(result.resp, result.id);
        factory.syncInProgress = false;
      }
    })["catch"](function (err) {
      console.log(angular.toJson(err));
      factory.syncInProgress = false;
    });
  } // should always only be one row in table


  function getLastHKSync() {
    var deferred = $q.defer();
    SQLiteService.query(window.db, 'SELECT * FROM hkdata').then(function (result) {
      if (result.rows.length == 1) {
        var res = SQLiteService.getById(result);
        deferred.resolve({
          'resp': JSON.parse(res.response),
          'id': res.id
        });
      } else {
        deferred.resolve('');
      }
    })["catch"](function (err) {
      console.log('there was error getting hk data from db');
      deferred.reject(err);
    });
    return deferred.promise;
  }

  function reconcileHK(hk_data, id) {
    // These are the last 7 days we want to match
    var syncDates = ApiService.getLastXDaysDates(7);
    var daysToSync = [];

    var day_difference = _.difference(syncDates, Object.keys(hk_data));

    _.forEach(day_difference, function (day) {
      daysToSync.push(day);
    });

    _.forEach(hk_data, function (dayObj, day) {
      // outside the scope of the last 7 days
      var match_arr;

      if (syncDates.indexOf(day) === -1) {
        return;
      } else {
        var hkFoods = dayObj.foods;
        var apiFoods = $rootScope.foodlog[day].foods; // used to determine deletes. bit arr to store which indices in hk array are matched.
        // ones that are not matched need to be deleted from hk

        match_arr = new Array(hkFoods.length); // first check for foods in api foods that are not in hk

        _.forEach(apiFoods, function (api_food) {
          //index of matched food in hkfoods
          var match = _.findIndex(hkFoods, function (food) {
            return api_food.id == food.id;
          }); // matching id was not found, so needs to be added to HK


          if (match === -1) {
            console.log('adding', day);
            daysToSync.push(day);
            return;
          } else {
            match_arr[match] = 1; // check if the food has been updated by matching the serving weight grams

            if (api_food.serving_weight_grams !== hkFoods[match].serving_weight_grams) {
              console.log('updating', day);
              daysToSync.push(day);
              return;
            }
          }
        });
      }

      if (_.includes(daysToSync, day)) {
        return;
      } // iterate through the matched arr and "delete" ones that are not matched


      for (var i = 0; i < match_arr.length; i++) {
        if (!match_arr[i]) {
          console.log('delete', day);
          daysToSync.push(day);
        }
      }
    });

    daysToSync = Array.from(new Set(daysToSync));
    deleteFromHK(daysToSync).then(function (value) {
      addToHK(daysToSync).then(function () {
        // if we need to do a sync, then update, otherwise its already synced
        if (daysToSync.length) {
          console.log('updating sqlite');
          SQLiteService.query(window.db, 'UPDATE hkdata SET response=? where id=?', [angular.toJson($rootScope.foodlog), id])["catch"](function (err) {
            console.log('there was error updating hk data to db', angular.toJson(err));
          });
        }
      });
    });
  }

  function createSample(day) {
    //object to store samples and aggregate values over all foods for a day
    var sample_dict = {}; //all foods for a day that needs to be updated

    var day_foods = $rootScope.foodlog[day].foods;

    _.forEach(day_foods, function (food) {
      _.map(food.full_nutrients, function (nutr_obj) {
        if (atr_ids[nutr_obj.attr_id]) {
          // increment the value
          if (sample_dict[nutr_obj.attr_id]) {
            sample_dict[nutr_obj.attr_id].value += nutr_obj.value;
          } else {
            sample_dict[nutr_obj.attr_id] = {
              'hk': atr_ids[nutr_obj.attr_id][0],
              'value': nutr_obj.value,
              'unit': atr_ids[nutr_obj.attr_id][1]
            };
          }
        }
      });
    }); // convert sample dict into hksample formatted array


    var hkSample = [];

    _.forEach(sample_dict, function (id_dict, attr_id) {
      var sample = {
        'startDate': new Date(day),
        //beginning of day
        'endDate': new Date(new Date(day).setHours(23, 59, 59)),
        //end of day
        'sampleType': id_dict.hk,
        'unit': id_dict.unit,
        'amount': id_dict.value
      };
      hkSample.push(sample);
    });

    return hkSample;
  }

  function addToHK(days) {
    var promises = [];

    if (days.length === 0) {
      var deferred = $q.defer();
      deferred.resolve('success');
      return deferred.promise;
    }

    _.forEach(days, function (day) {
      var deferred = $q.defer();
      promises.push(deferred.promise);
      var samples = createSample(day);

      if (samples.length === 0) {
        deferred.resolve('success');
        return deferred.promise;
      }

      var correlation = {
        'startDate': new Date(day),
        //beginning of day
        'endDate': new Date(new Date(day).setHours(23, 59, 59)),
        //end of day
        'metadata': {
          'day': day
        },
        'correlationType': 'HKCorrelationTypeIdentifierFood',
        'samples': samples
      };
      window.plugins.healthkit.saveCorrelation(correlation, function (value) {
        console.log('correlation save success!', day);
        deferred.resolve('success');
      }, function (err) {
        console.log('correlation save err', angular.toJson(err));
        deferred.reject(err);
      });
    });

    return $q.all(promises);
  }

  function deleteFromHK(days) {
    var delete_samples = [];
    var promises = [];

    _.forEach(days, function (day) {
      _.map(atr_ids, function (arr, key) {
        var sample = {
          'startDate': new Date(day),
          'endDate': new Date(new Date(day).setHours(23, 59, 59)),
          //end of day
          'sampleType': arr[0]
        };
        delete_samples.push(sample);
      });
    });

    _.forEach(delete_samples, function (sample) {
      var deferred = $q.defer();
      promises.push(deferred.promise);
      window.plugins.healthkit.deleteSamples(sample, function (value) {
        deferred.resolve('success');
      }, function (err) {
        console.log('Delete Sample err', angular.toJson(err));
        deferred.reject(err);
      });
    });

    return $q.all(promises);
  }

  return factory;
}]);
'use strict';

angular.module('Track').service('HealthKitWeightService', ["$rootScope", "$q", "SQLiteService", "ApiService", function ($rootScope, $q, SQLiteService, ApiService) {
  var factory = {
    syncWeight: syncWeight,
    pullWeightsFromHK: pullWeightsFromHK
  };
  var unit = 'metric';

  function syncWeight(weight_units) {
    var syncDates = ApiService.getLastXDaysDates(7); // do not sync days outside the last 7 days

    var should_sync = _.difference(Object.keys($rootScope.weightLog), syncDates).length;

    if (should_sync == syncDates.length) {
      console.log('dont sync');
      return;
    }

    unit = weight_units;
    getLastWeightSync().then(function (result) {
      // if result set is empty, push all to hk; else determine what to push
      if (!result) {
        var allWeights = [];

        _.map($rootScope.weightLog, function (dayObj, day) {
          allWeights.push.apply(allWeights, dayObj.weights);
        });

        console.log('adding all weight');
        addWeightToHK(allWeights).then(function (result) {
          console.log('updating hk weight sqlite');
          SQLiteService.query(window.db, 'INSERT INTO hkdata_weight (response) VALUES (?)', [angular.toJson($rootScope.weightLog)])["catch"](function (err) {
            console.log('there was an error adding hk weight data to db', angular.toJson(err));
          });
        });
      } else {
        reconcileHKWeight(result.resp, result.id);
      }
    })["catch"](function (err) {
      console.log(angular.toJson(err));
    });
  } //should always only be one row in table


  function getLastWeightSync() {
    var deferred = $q.defer();
    SQLiteService.query(window.db, 'SELECT * FROM hkdata_weight').then(function (result) {
      if (result.rows.length == 1) {
        var res = SQLiteService.getById(result);
        deferred.resolve({
          'resp': JSON.parse(res.response),
          'id': res.id
        });
      } else {
        deferred.resolve('');
      }
    })["catch"](function (err) {
      console.log('there was an error getting hk weight data from db', angular.toJson(err));
      deferred.reject(err);
    });
    return deferred.promise;
  }

  function reconcileHKWeight(weight_data, id) {
    // These are the last 7 days we want to match
    var syncDates = ApiService.getLastXDaysDates(7);
    var addArr = [];
    var deleteArr = [];
    var updateArr = [];

    var day_difference = _.difference(syncDates, Object.keys(weight_data));

    _.forEach(day_difference, function (day) {
      addArr.push.apply(addArr, $rootScope.weightLog[day].weights);
    });

    _.forEach(weight_data, function (dayObj, day) {
      //outside the scope of 7 days
      var match_arr, hkWeights;

      if (syncDates.indexOf(day) === -1) {
        return;
      } else {
        hkWeights = dayObj.weights;
        var apiWeights = $rootScope.weightLog[day].weights; // used to determine deletes. bit arr to store which indices in hk array are matched.
        // ones that are not matched need to be deleted from hk

        match_arr = new Array(hkWeights.length); //first check for weights in api weights that are not in hk

        _.forEach(apiWeights, function (api_weight) {
          //index of matched weight in hkweights
          var match = _.findIndex(hkWeights, function (weight) {
            return api_weight.id == weight.id;
          }); //id no match found, then need to add


          if (match === -1) {
            console.log('adding weight', api_weight.kg);
            addArr.push(api_weight);
          } else {
            match_arr[match] = 1; //check if the weight has been updated by comparing the kg values

            if (api_weight.kg !== hkWeights[match].kg) {
              console.log('updating', api_weight.kg);
              updateArr.push([api_weight, hkWeights[match]]);
            }
          }
        });
      } //iterate through the matched arr to determine deletes


      for (var i = 0; i < match_arr.length; i++) {
        if (!match_arr[i]) {
          console.log('deleting', hkWeights[i].kg);
          deleteArr.push(hkWeights[i]);
        }
      }
    });

    deleteWeightFromHK(deleteArr);
    addWeightToHK(addArr); // for updated weight

    if (updateArr.length) {
      var weights_to_delete = [];
      var weights_to_add = [];

      _.map(updateArr, function (weightarr) {
        weights_to_delete.push(weightarr[1]);
        weights_to_add.push(weightarr[0]);
      });

      deleteWeightFromHK(weights_to_delete).then(function (value) {
        'delete update samples success';

        addWeightToHK(weights_to_add);
      });
    }

    if (deleteArr.length || addArr.length || updateArr.length) {
      console.log('updating hk weight sqlite');
      SQLiteService.query(window.db, 'UPDATE hkdata_weight SET response=? where id=?', [angular.toJson($rootScope.weightLog), id])["catch"](function (err) {
        console.log('there was an error adding hk weight data to db', angular.toJson(err));
      });
    }
  }

  function addWeightToHK(weights) {
    var promises = [];

    _.forEach(weights, function (weight) {
      var deferred = $q.defer();
      promises.push(deferred.promise);
      var sample = {
        'unit': unit === 'metric' ? 'kg' : 'lb',
        'amount': unit === 'metric' ? weight.kg : _.round(weight.kg * 2.20462, 2),
        'date': new Date(weight.timestamp)
      };
      window.plugins.healthkit.saveWeight(sample, function (value) {
        deferred.resolve('success');
      }, function (err) {
        console.log('add weight sample err', angular.toJson(err));
        deferred.reject(err);
      });
    });

    return $q.all(promises);
  }

  function deleteWeightFromHK(weights) {
    var promises = [];

    _.forEach(weights, function (weight) {
      var deferred = $q.defer();
      promises.push(deferred.promise);
      var sample = {
        'startDate': new Date(new Date(weight.timestamp).getTime() - 1000),
        'endDate': new Date(new Date(weight.timestamp).getTime() + 1000),
        'sampleType': 'HKQuantityTypeIdentifierBodyMass'
      };
      window.plugins.healthkit.deleteSamples(sample, function (value) {
        console.log('val', angular.toJson(value));
        deferred.resolve('success');
      }, function (err) {
        console.log('Delete weight sample err', angular.toJson(err));
        deferred.reject(err);
      });
    });

    return $q.all(promises);
  }

  function pullWeightsFromHK(e, val) {
    window.plugins.healthkit.querySampleType({
      'startDate': new Date(new Date().getTime() - 7 * 24 * 60 * 60 * 1000),
      // 7 days ago
      'endDate': new Date(),
      // now
      'sampleType': 'HKQuantityTypeIdentifierBodyMass',
      'unit': 'kg'
    }, function (value) {
      var api_timestamps = [];

      _.forEach($rootScope.weightLog, function (day) {
        _.forEach(day.weights, function (weightObj) {
          api_timestamps.push(moment.utc(weightObj.timestamp).format());
        });
      });

      var hk_weights_to_add = [];

      _.forEach(value, function (hkObj) {
        if (api_timestamps.indexOf(moment.utc(hkObj.startDate).format()) === -1) {
          hk_weights_to_add.push({
            'kg': hkObj.quantity,
            'timestamp': hkObj.startDate
          });
        }
      });

      console.log('weight add', angular.toJson(hk_weights_to_add));
      ApiService.addHKWeighIn(hk_weights_to_add);
    }, function (err) {
      console.log('err', angular.toJson(err));
    });
  }

  return factory;
}]);
"use strict";

angular.module('Track').run(['$templateCache', function ($templateCache) {
  $templateCache.put('templates/main.html', '<ion-side-menus drag-content="false" enable-menu-with-back-views="true" class="app-main-view" ng-class="{\'footer-visible\': $root.showFooter && !$root.showAutocomplete}">\n    <!-- Center content -->\n    <ion-side-menu-content>\n        <ion-nav-view name="viewContent">\n        </ion-nav-view>\n    </ion-side-menu-content>\n\n    <!-- Left menu -->\n    <ion-side-menu side="left" class="side-menu">\n\n        <ion-header-bar align-title="center" class="bar-balanced">\n            <h1 class="title">Track {{version}}</h1>\n        </ion-header-bar>\n\n        <ion-content class="has-header">\n            <div class="list">\n                <li menu-close class="item item-icon-left menu-selection" ui-sref="app.foodlog">\n                    <i class="icon ion-home"></i>\n                    Home\n                </li>\n                <!-- <li ng-show="showSwitchUsers" menu-close class="item item-icon-left menu-selection ng-hide" ui-sref="app.users">\n                    <i class="icon ion-ios-people"></i>\n                    Switch Users\n                </li>  -->\n                <li menu-close class="item item-icon-left menu-selection" ui-sref="app.myRecipes2">\n                     <i class="icon fa fa-list"> </i>\n                     My Recipes\n                </li>\n\n                <li menu-close class="item item-icon-left menu-selection" ui-sref="app.customFoods">\n                     <i class="icon fa fa-cutlery"> </i>\n                     Custom Foods\n                </li>\n\n                <li menu-close class="item item-icon-left menu-selection" ui-sref="app.betaFeatures"\n                ng-if=\'userGroceyAgentInfo.grocery_agent\'>\n                <i class="icon ion-wrench"> </i>\n                    Beta\n                </li>\n\n                <li menu-close class="item item-icon-left menu-selection" ui-sref="app.preferences">\n                    <i class="icon ion-gear-b"> </i>\n                    Preferences\n                </li>\n\n                <li menu-close class="item item-icon-left menu-selection" ui-sref="app.dailygoals">\n                    <i class="icon fa fa-bullseye"> </i>\n                    Daily Goals\n                </li>\n\n                <li menu-close class="item item-icon-left menu-selection" ui-sref="app.myCoach">\n                    <i class="icon fa fa-thumbs-o-up"></i>\n                    My Coach\n                </li>\n                <li menu-close class="item item-icon-left menu-selection" ui-sref="app.coachPortal" ng-if="!!$root.isCoach">\n                    <i class="icon fa fa-play"></i>\n                    Coach Portal\n                </li>\n\n                <li menu-close class="item item-icon-left menu-selection" ui-sref="app.help">\n                <i class="icon ion-help"> </i>\n                    Help\n                </li>\n\n                <li menu-close class="item item-icon-left menu-selection" ui-sref="app.UploadPhotoAgent"\n                ng-if=\'userGroceyAgentInfo.grocery_agent\'>\n                <i class="icon ion-camera"> </i>\n                    Grocery Agent Mode\n                </li>\n\n                <li menu-close class="item item-icon-left menu-selection" style="z-index: 9999;" ng-click="signout()">\n                    <i class="icon ion-log-out"></i>\n                    Signout\n                </li>\n            </div>\n            <div class="like-this-app-container">\n              <div class="like-this-app-text">Like This app?</div>\n              <div>\n                <button ng-click="promptForRating()" class="button button-block button-small button-balanced">\n                  <span class="menu-selection">\n                    <i class="fa fa-star" aria-hidden="true"></i>\n                    Rate us on {{textForButtons.storeName}}\n                  </span>\n                </button>\n                <button ng-click="promptToShare()" class="button button-block button-small button-balanced">\n                  <span class="menu-selection">\n                    <i class="fa fa-share-square-o" aria-hidden="true"></i>\n                    Send Track to a friend\n                  </span>\n                </button>\n                <button ng-click="openFb()" class="button button-block button-small button-balanced">\n                  <span class="menu-selection">\n                    <i class="fa fa-thumbs-up" aria-hidden="true"></i>\n                    Like us on Facebook\n                  </span>\n                </button>\n              </div>\n              <div class="like-this-app-logo">\n                <a class="menu-selection" ng-click=\'goToWebSite()\'>\n                  <img src="images/logo2.svg" width="180" alt="Nutritionix">\n                </a>\n              </div>\n            </div>\n        </ion-content>\n    </ion-side-menu>\n</ion-side-menus>\n');
  $templateCache.put('templates/views/addFoodSmart.html', '<ion-nav-view cache-view="false" hide-back-button="true">\n\n  <main-header></main-header>\n\n  <add-Food-Tabs ng-if="!showAutocomplete" state="state"> </add-Food-Tabs>\n\n  <ion-content class="has-subheader" ng-class="$root.mealBuilderClass">\n    <div class="clearfix"></div>\n    <ion-list type="list-inset">\n      <div class="item item-input" wt-step="4-1">\n        <textarea id="addFoodTextArea" rows="3" ng-model="vm.query" placeholder=\'{{vm.exampleText}}\'></textarea>\n      </div>\n      <a class="button button-balanced" ng-click="vm.startRecognition()" style="font-size:24px;min-width: 40px;min-height: 40px;height: 40px;line-height:40px;position: absolute;bottom:5px;right:5px;-webkit-border-radius:20px;border-radius:20px;z-index: 10;">\n        <i class="ion-android-microphone">\n        </i>\n        <span ng-if="recordingMessage.length !== 0" style="display:inline-block; margin-top:-4px; font-size: 12px; vertical-align: middle;">{{ recordingMessage }}</span>\n      </a>\n    </ion-list>\n\n    <div class="button-bar" style="padding-left: 10px; padding-right: 10px; margin-top: 8px; ">\n        <a class="button button-balanced" ng-click="vm.getNutrients()">\n          <i class="ion-ios-plus-outline">\n            <span> Add to Basket</span>\n          </i>\n        </a>\n    </div>\n    <div class="padding" ng-if="vm.isDisclaimerVisible">\n      <div class="disclaimer-panel" >\n        * If you are experiencing trouble with the Google Voice recognition service, please uninstall the Google Voice Search app and <a ng-click="goToGooglePlayMarket()" style="text-decoration:underline;">click here</a> to download the latest version from the Play Store.\n\n        <div style="display:flex; align-items:center; justify-content:space-between">\n          <label style="display:flex; align-items:center; font-size:inherit;"><input type="checkbox" ng-model="vm.doNotShowDisclaimer">&nbsp;&nbsp;Do not show this message again.</label>\n          <div style="color:red;" ng-click="hideDisclaimer()">Close</div>\n        </div>\n      </div>\n    </div>\n    <br>\n    <div style="margin-left: 10px">\n      <h4 style="padding-left: .5em; padding-right: .5em"><b> How does Freeform work?</b></h4>\n      <p style="padding-left: .5em; padding-right: .5em"> Type or speak freeform text in the box above.</p>\n      <p style="padding-left: .5em; padding-right: .5em"> Freeform is fueled by our state-of-the-art Natural Language Processing technology to accurately determine what you ate.</p>\n      <p style="padding-left: .5em; padding-right: .5em"> After you add foods to the Basket, you will have a chance to review the foods, change the time you ate them, and change serving sizes before adding to your food log.\n    </div>\n\n  </ion-content>\n  <meal-Builder ng-show="$root.itemsInBuilder.length > 0 && !showAutocomplete" class="ng-hide"> </meal-Builder>\n\n</ion-nav-view>\n');
  $templateCache.put('templates/views/betaFeatures.html', '<ion-view>\n    <ion-header-bar align-title="center" class="bar-balanced">\n        <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n        <h1 class="title">Beta Features</h1>\n    </ion-header-bar>\n    <ion-content has-header>\n        <!-- <ion-item item-icon-left ui-sref="app.myRecipes2">\n            <i class="icon fa fa-list"></i>\n            My Recipes 2.0\n        </ion-item> -->\n        <ion-item class=\'text-center\'>There are no Beta features at the moment.</ion-item>\n    </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/calculateDailyCalories.html', '<ion-nav-view hide-back-button="true">\n  <ion-header-bar align-title="center" class="bar-balanced">\n      <button class="button button-icon icon ion-ios-arrow-left" ng-click="vm.goBack()"></button>\n      <h1 class="title">Calculate Daily Calories</h1>\n      <i class="icon ion-help" style="position: absolute; right: 15px; bottom:10px; font-size: 25px;" on-touch="vm.goToCalcFAQ()"></i>\n  </ion-header-bar>\n  <ion-content>\n      <form action="" novalidate name="userPreferencesForm">\n        <div class="list list-inset">\n            <label class="item item-input item-select">\n                <div class="input-label dailyCaloriesLabel">\n                    Units\n                </div>\n                <select ng-model="vm.unitSystem" ng-change="vm.changeUnitSystem()">\n                    <option selected value="imperial">Imperial (US)</option>\n                    <option value="metric">Metric</option>\n                </select>\n            </label>\n             <div class="item item-input item-select">\n                <div class="input-label dailyCaloriesLabel">\n                    Sex\n                    <i class="fa fa-info-circle pull-right" ng-click="vm.showDisclaimer()"></i>\n                </div>\n                <select ng-model="vm.gender">\n                    <option value="male">Male</option>\n                    <option selected value="female">Female</option>\n                </select>\n            </div>\n            <label class="item item-input">\n              <span class="input-label dailyCaloriesLabel">Weight</span>\n              <input  ng-if="vm.unitSystem == \'metric\'"\n                      name="userWeight"\n                      type="number"\n                      valid-number\n                      decimal="true"\n                      select-on-click\n                      ng-model="vm.weightView.kg"\n                      placeholder="kg"\n                      class="dailyCaloriesInput"\n                      hide-keyboard-on-go>\n              <span ng-if="vm.unitSystem == \'metric\'"> kg </span>\n              <input  ng-if="vm.unitSystem == \'imperial\'"\n                      name="userWeight"\n                      type="number"\n                      valid-number\n                      decimal="true"\n                      select-on-click\n                      ng-model="vm.weightView.lb"\n                      placeholder="lbs."\n                      class="dailyCaloriesInput"\n                      hide-keyboard-on-go>\n              <span ng-if="vm.unitSystem == \'imperial\'"> lbs </span>\n              <i class="fa fa-edit" style="position: absolute; top:15px; right:10px; font-size:20px; color:#777;"></i>\n            </label>\n            <div ng-show="userPreferencesForm.userWeight.$dirty" style="border-bottom:1px solid black#ddd" class="userPrefsErrorText ng-hide">\n              <div ng-show="userPreferencesForm.userWeight.$invalid && userPreferencesForm.userWeight.$modelValue !== 0" class="red ng-hide">Invalid value</div>\n            </div>\n\n            <label ng-if="vm.unitSystem == \'metric\'" class="item item-input">\n              <span class="input-label dailyCaloriesLabel">Height</span>\n              <input  type="number"\n                      valid-number\n                      decimal="false"\n                      name="userHeightCm"\n                      ng-model="vm.heightView.cm"\n                      select-on-click\n                      id="height"\n                      placeholder="cm"\n                      class="dailyCaloriesInput"\n                      hide-keyboard-on-go>\n              <span ng-if="vm.unitSystem == \'metric\'"> cm </span>\n              <i class="fa fa-edit" style="position: absolute; top:15px; right:10px; font-size:20px; color:#777;"></i>\n            </label>\n            <div ng-show="userPreferencesForm.userHeightCm.$dirty" style="border-bottom:1px solid black#ddd" class="userPrefsErrorText ng-hide">\n              <div\n                ng-show="userPreferencesForm.userHeightCm.$invalid &&\n                userPreferencesForm.userHeightCm.$modelValue !== 0"\n                class="red ng-hide">Invalid value</div>\n            </div>\n            <label ng-if="vm.unitSystem == \'imperial\'" class="item item-input">\n              <span class="input-label dailyCaloriesLabel">Height</span>\n              <input  type="number"\n                      valid-number\n                      decimal="false"\n                      name="userHeightFt"\n                      select-on-click\n                      ng-model="vm.heightView.ft"\n                      name="feet"\n                      id="feet"\n                      placeholder="ft."\n                      class="dailyCaloriesInput"\n                      hide-keyboard-on-go>\n              <span ng-if="vm.unitSystem == \'imperial\'"> ft </span>\n              <i class="fa fa-edit" style="position: absolute; top:15px; right:10px; font-size:20px; color:#777;"></i>\n            </label>\n            <div ng-show="userPreferencesForm.userHeightFt.$dirty" style="border-bottom:1px solid black#ddd" class="userPrefsErrorText ng-hide">\n              <div\n                ng-show="userPreferencesForm.userHeightFt.$invalid &&\n                userPreferencesForm.userHeightFt.$modelValue !== 0"\n                class="red ng-hide">Invalid value</div>\n            </div>\n            <label ng-if="vm.unitSystem == \'imperial\'" class="item item-input">\n              <span class="input-label dailyCaloriesLabel">&nbsp;</span>\n              <input  type="number"\n                      valid-number\n                      decimal="false"\n                      name="userHeightIn"\n                      ng-model="vm.heightView.inch"\n                      select-on-click\n                      name="inch"\n                      id="inch"\n                      placeholder="in."\n                      class="dailyCaloriesInput"\n                      hide-keyboard-on-go>\n              <span ng-if="vm.unitSystem == \'imperial\'"> in </span>\n              <i class="fa fa-edit" style="position: absolute; top:15px; right:10px; font-size:20px; color:#777;"></i>\n            </label>\n            <div ng-show="userPreferencesForm.userHeightIn.$dirty" style="border-bottom:1px solid black#ddd" class="userPrefsErrorText ng-hide">\n              <div\n                ng-show="userPreferencesForm.userHeightIn.$invalid &&\n                userPreferencesForm.userHeightIn.$modelValue !== 0"\n                class="red ng-hide">Invalid value</div>\n            </div>\n\n            <label class="item item-input">\n              <span class="input-label dailyCaloriesLabel">Age</span>\n              <input  type="number"\n                      valid-number\n                      decimal="false"\n                      name="userAge"\n                      placeholder=""\n                      ng-model="vm.age"\n                      select-on-click\n                      class="dailyCaloriesInput"\n                      hide-keyboard-on-go>\n              <span > years </span>\n              <i class="fa fa-edit" style="position: absolute; top:15px; right:10px; font-size:20px; color:#777;"></i>\n            </label>\n            <div ng-show="userPreferencesForm.userAge.$dirty" style="border-bottom:1px solid #ddd" class="userPrefsErrorText ng-hide">\n              <div ng-show="userPreferencesForm.userAge.$invalid && userPreferencesForm.userAge.$modelValue !== 0" class="red ng-hide">Invalid value</div>\n            </div>\n        </div>\n\n        <div class="card" ng-show="vm.getRecommendedCalories()">\n          <div class="item item-divider">\n            Recommended Calorie Values\n          </div>\n          <div class="item item-text-wrap ">\n            <div class="row">\n              <div class="col text-center"><strong>{{vm.getRecommendedCalories() | fdaRound: \'calories\'}}</strong></div>\n              <div class="col col-75">Maintain current weight</div>\n            </div>\n            <div class="row">\n              <div class="col text-center"><strong>{{vm.getRecommendedCalories() - 500 | fdaRound: \'calories\'}}</strong></div>\n              <div class="col col-75">Lose\n                <span ng-if="vm.unitSystem === \'metric\'">~0.5 kg</span>\n                <span ng-if="vm.unitSystem === \'imperial\'">~1 lb</span>\n                per week\n              </div>\n            </div>\n            <div class="row">\n              <div class="col text-center"><strong>{{vm.getRecommendedCalories() + 500 | fdaRound: \'calories\'}}</strong></div>\n              <div class="col col-75">Gain\n                <span ng-if="vm.unitSystem === \'metric\'">~0.5 kg</span>\n                <span ng-if="vm.unitSystem === \'imperial\'">~1 lb</span>\n                per week\n              </div>\n            </div>\n          </div>\n        </div>\n      </form>\n\n      <div class="card card-with-button">\n        <div class="item item-divider">\n          Enter Daily Calorie Limit\n        </div>\n        <form ng-submit="vm.hideKeyboard()" name="userDailyCaloriesLimit" novalidate>\n          <div class="list">\n            <label class="item item-input" style="padding-right:16px;">\n              <span class="input-label dailyCaloriesLabel">My Daily Calorie Limit:</span>\n              <input  class="myCalorie-limit"\n                      type="number"\n                      step="1"\n                      decimal="false"\n                      name="dailyCaloriesLimit"\n                      ng-model="vm.myCalorieLimit"\n                      select-on-click\n                      required\n                      hide-keyboard-on-go/>\n            </label>\n            <div ng-show="vm.showErrorMessage" class="userPrefsErrorText no-borders ng-hide">\n              <div ng-show="userDailyCaloriesLimit.dailyCaloriesLimit.$error.required" class="red ng-hide">Please, set Calorie Limit</div>\n              <div ng-show="userDailyCaloriesLimit.dailyCaloriesLimit.$modelValue == 0" class="red ng-hide">Calorie Limit can\'t be 0</div>\n              <div ng-show="userDailyCaloriesLimit.dailyCaloriesLimit.$invalid && !userDailyCaloriesLimit.dailyCaloriesLimit.$error.required" class="red ng-hide">Please set valid number</div>\n            </div>\n          </div>\n        </form>\n        <div class="item text-center item-button">\n          <p ng-show="!!vm.showMessage" class="calorie-limit-message ng-hide"> {{vm.updateCalorieMessage}} </p>\n        </div>\n      </div>\n\n      <div class="padding disclaimer">\n        <p>\n          <strong>Disclaimer:</strong> This information is for use in adults defined as individuals 18 years of age or older and not by younger people, or pregnant or breastfeeding women. This information is not intended to provide medical advice. A health care provider who has examined you and knows your medical history is the best person to diagnose and treat your health problem. If you have specific health questions, please consult your health care provider. Calorie calculations are based on the Harris Benedict equation, and corrected MET values are provided as referenced at these sources:<br/>\n          <a ng-click="vm.openDisclaimerLink(\'https://sites.google.com/site/compendiumofphysicalactivities/corrected-mets\')" href="">Compendium of Physical Activities</a><br/>\n          <a ng-click="vm.openDisclaimerPDF(\'http://www.umass.edu/physicalactivity/newsite/publications/Sarah%20Keadle/papers/1.pdf\')" href="">Corrected Metabolic Equivalents</a>\n        </p>\n        <div style="padding-bottom:70px;" ng-if="vm.isDataChanged()"></div>\n      </div>\n  </ion-content>\n  <div class="floating-button-container" ng-class="{\'slide-in\': vm.isDataChanged()}" ng-style="{\'bottom\':iosFloatingButtonAdjustment+25+\'px\'}">\n    <button class="button button-balanced" ng-class="{\'shake\': vm.preferencesNotSaved}" ng-click="vm.savePreferences(vm.myCalorieLimit)">Save</button>\n  </div>\n</ion-nav-view>\n');
  $templateCache.put('templates/views/coachPortal.html', '<ion-view>\n  <ion-header-bar align-title="center" class="bar-balanced">\n    <button class="button button-icon icon ion-navicon" menu-toggle="left"></button>\n    <h1 class="title">Coach Portal</h1>\n  </ion-header-bar>\n  <div class="bar bar-subheader" style="background:#eee;padding:0;display: flex;align-items: center;">\n    <div style="position: relative;width: 100%;padding-right:60px;">\n      <div ng-click="copyCodeToClipboard()" style="width: 100%;padding:10px 15px;border-right:1px solid #444;">\n        Coach ID: <strong>{{user.coach.code | coachCodeFilter}}</strong>\n        <div class="disclaimer" style="position: absolute;left: 15px;bottom:3px;line-height:1;font-size:10px;color:#28a54c;">Tap to copy your ID</div>\n      </div>\n      <i class="fa fa-share-square-o" ng-click="shareCode()" style="position: absolute;right:0;top:50%;transform:translateY(-50%);font-size:23px;width:60px;color:#444;text-align: center;">\n        <span style="font-size:12px;display: block;">Share ID</span>\n      </i>\n    </div>\n  </div>\n  <ion-content class="has-header has-subheader">\n    <ion-list>\n      <ion-item class="item-input-inset">\n        <label class="item-input-wrapper">\n          <input type="text" placeholder="Search my clients" ng-model="data.search" />\n        </label>\n        <span on-touch="clearSearch()" style="margin-left:10px;">Cancel</span>\n      </ion-item>\n      <ion-item class="item-icon-right" ng-if="clientsList.length" ng-repeat="client in clientsList | filter: data.search" ng-click="viewClient(client)">\n        {{(client.last_name ? client.last_name+\', \' : \'\')+client.first_name}}\n        <i class="icon fa fa-angle-right"></i>\n      </ion-item>\n    </ion-list>\n    <p class="padding" style="margin:50px 0 0;">\n      <button class="button button-positive button-block" ng-if="user.grocery_agent" ng-click="stopBeingCoach()">Stop being a coach</button>\n    </p>\n  </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/connectedApps.html', '<ion-view>\n    <ion-header-bar align-title="center" class="bar-balanced">\n   <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n        <h1 class="title">Connected Apps</h1>\n    </ion-header-bar>\n    <ion-content>\n    <div class="clearfix"></div>\n      <ul class="card list">\n\n          <li class="item item-icon-left item-icon-right" ng-click="goToManageAppSync(\'Fitbit\')">\n            <img class="icon padding" src="images/fitbit.png"/>\n            <div class="padding-left"> Fitbit  </div>\n            <i class=\'icon padding ion-ios-arrow-forward\'> </i>\n          </li>\n\n          <li ng-if="platform == \'iOS\'" class="item item-icon-left item-icon-right" ng-click="goToManageAppSync(\'HealthKit\')">\n            <i class=\'icon padding ion-ios-medical-outline\'> </i>\n            <div class="padding-left"> HealthKit  </div>\n            <i class=\'icon padding ion-ios-arrow-forward\'> </i>\n          </li>\n\n      </ul>\n\n      <p class="text-center" style="color:#666">More integrations coming soon.</p>\n\n    </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/createFood.html', '<ion-view>\n    <ion-header-bar align-title="center" class="bar-balanced">\n        <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n        <h1 class="title">Create Food</h1>\n        <button class="button button-clear" ng-click="goBack()">Cancel</button>\n    </ion-header-bar>\n    <ion-content>\n        <div class="list">\n            <div class="item item-divider ">\n                I want to create a...\n            </div>\n            <div class="item item-icon-left item-icon-right item-text-wrap" ng-click="goToRecipe()">\n                <i class="icon ion-clipboard"></i>\n                <h2>Recipe</h2>\n                <p>\n                    Build a recipe using your favorite foods or ingredients. Our system calculates all of the nutritional information for you.\n                </p>\n                <i class="icon ion-chevron-right"></i>\n            </div>\n            <div class="item item-icon-left item-icon-right item-text-wrap" ng-click="goToCustomFood()">\n                <i class="icon ion-compose"></i>\n                <h2>Custom Food</h2>\n                <p>\n                    Manually enter the nutrition information for a food.\n                </p>\n                <i class="icon ion-chevron-right"></i>\n            </div>\n        </div>\n    </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/customFood.html', '<ion-view>\n    <ion-header-bar align-title="center" class="bar-balanced">\n        <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n        <h1 class="title">Create Custom Food</h1>\n        <button class="button button-clear" ng-click="goBack()">Cancel</button>\n    </ion-header-bar>\n    <div class="overlay" ng-if="loadingFood" style="position:absolute;top: 0;bottom: 0;left: 0;right: 0;background:rgba(0,0,0,0.5);z-index: 8;color:#fff;display: flex;justify-content: center;align-items: center;">Loading. Please wait.</div>\n    <ion-content>\n      <div class="list form-outline">\n        <label class="item item-input">\n            <span class="input-label">Food Name<span class="required">*</span></span>\n            <input select-on-click ng-model="customFood.food_name" type="text" placeholder="Food Name">\n        </label>\n        <label class="item item-input">\n            <span class="input-label">Serving Info<span class="required">*</span></span>\n            <input select-on-click ng-model="customFood.serving_qty" type="number" placeholder="Quantity">\n        </label>\n        <label class="item item-input">\n            <span class="input-label"></span>\n            <input select-on-click ng-model="customFood.serving_unit" type="text" placeholder="Serving Unit">\n        </label>\n        <label class="item item-input">\n            <span class="input-label">Calories<span class="required">*</span></span>\n            <input select-on-click ng-model="customFood.nf_calories" type="number" placeholder="0" class="input-nutrition">\n            <span class="placeholder">kcal</span>\n        </label>\n        <label class="item item-input">\n            <span class="input-label">Total Fat</span>\n            <input select-on-click ng-model="customFood.nf_total_fat" type="number" placeholder="0" class="input-nutrition">\n            <span class="placeholder">g</span>\n        </label>\n        <label class="item item-input">\n            <span class="input-label">Saturated Fat</span>\n            <input select-on-click ng-model="customFood.nf_saturated_fat" type="number" placeholder="0" class="input-nutrition">\n        </label>\n        <label class="item item-input">\n            <span class="input-label">Cholesterol</span>\n            <input select-on-click ng-model="customFood.nf_cholesterol" type="number" placeholder="0" class="input-nutrition">\n            <span class="placeholder">mg</span>\n        </label>\n        <label class="item item-input">\n            <span class="input-label">Sodium</span>\n            <input select-on-click ng-model="customFood.nf_sodium" type="number" placeholder="0" class="input-nutrition">\n            <span class="placeholder">mg</span>\n        </label>\n        <label class="item item-input">\n            <span class="input-label">Total Carbohydrate</span>\n            <input select-on-click ng-model="customFood.nf_total_carbohydrate" type="number" placeholder="0" class="input-nutrition">\n            <span class="placeholder">g</span>\n        </label>\n        <label class="item item-input">\n            <span class="input-label">Dietary Fiber</span>\n            <input select-on-click ng-model="customFood.nf_dietary_fiber" type="number" placeholder="0" class="input-nutrition">\n            <span class="placeholder">g</span>\n        </label>\n        <label class="item item-input">\n            <span class="input-label">Sugars</span>\n            <input select-on-click ng-model="customFood.nf_sugars" type="number" placeholder="0" class="input-nutrition">\n            <span class="placeholder">g</span>\n        </label>\n        <label class="item item-input">\n            <span class="input-label">Protein</span>\n            <input select-on-click ng-model="customFood.nf_protein" type="number" placeholder="0" class="input-nutrition">\n            <span class="placeholder">g</span>\n        </label>\n        <label class="item item-input">\n            <span class="input-label">Vitamin A</span>\n            <input select-on-click ng-model="customFood.nf_vitamin_a_dv" type="number" placeholder="0" class="input-nutrition">\n            <span class="placeholder">%dv</span>\n        </label>\n        <label class="item item-input">\n            <span class="input-label">Vitamin C</span>\n            <input select-on-click ng-model="customFood.nf_vitamin_c_dv" type="number" placeholder="0" class="input-nutrition">\n            <span class="placeholder">%dv</span>\n        </label>\n        <label class="item item-input">\n            <span class="input-label">Vitamin D</span>\n            <input select-on-click ng-model="customFood.nf_vitamin_d_dv" type="number" placeholder="0" class="input-nutrition">\n            <span class="placeholder">%dv</span>\n        </label>\n        <label class="item item-input">\n            <span class="input-label">Calcium</span>\n            <input select-on-click ng-model="customFood.nf_calcium_dv" type="number" placeholder="0" class="input-nutrition">\n            <span class="placeholder">%dv</span>\n        </label>\n        <label class="item item-input">\n            <span class="input-label">Iron</span>\n            <input select-on-click ng-model="customFood.nf_iron_dv" type="number" placeholder="0" class="input-nutrition">\n            <span class="placeholder">%dv</span>\n        </label>\n        <label class="item item-input">\n            <span class="input-label">Phosphorus</span>\n            <input select-on-click ng-model="customFood.nf_p" type="number" placeholder="0" class="input-nutrition">\n            <span class="placeholder">mg</span>\n        </label>\n        <label class="item item-input">\n            <span class="input-label">Potassium</span>\n            <input select-on-click ng-model="customFood.nf_potassium" type="number" placeholder="0" class="input-nutrition">\n            <span class="placeholder">mg</span>\n        </label>\n      </div>\n      <div class="padding">\n        <p>\n          <span class="required">*</span> denotes required fields\n        </p>\n        <button class="button button-block button-balanced" ng-class="{\'shake\' : invalidForm}" ng-click="submitCustomFood()">{{editingFood ? \'Update\' : logAfterSubmit ? \'Save and add to Log\' : \'Submit\'}}</button>\n      </div>\n      <div ng-if="editingFood" class="padding">\n          <button class="button button-balanced button-block" ng-class="{\'shake\' : invalidForm && logAfterSubmit}" ng-click="logCustom()"><i class="ion-ios-plus-outline"></i> Log this food</button>\n      </div>\n\n    </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/customFoods.html', '<ion-view>\n    <ion-header-bar align-title="center" class="bar-balanced">\n        <button class="button button-icon icon ion-navicon" menu-toggle="left"></button>\n        <h1 class="title" style="text-transform:capitalize;">Custom Foods</h1>\n        <button class="button" style="font-size: 15px" ng-click="goToCreateFood()"><i class="fa fa-plus"></i></button>\n    </ion-header-bar>\n    <div class="bar bar-subheader flexible-subheader bar-header-search">\n        <div class="item-input-inset">\n            <label class="item-input-wrapper">\n                <input type="text" placeholder="Search custom foods" ng-model="search" />\n            </label>\n        </div>\n        <div ng-if="showSavedFoodMessage" class="recipeCreatedAlert">Food Saved</div>\n    </div>\n    <ion-content class="has-subheader" on-scroll="$root.hideKeyboard()">\n        <div style="padding: 3px; font-size: 12px; text-align: center; color: #999;"> swipe left to delete </div>\n        <ion-item ng-if="customFoods.length === 0" class="item-text-wrap  review-food-item" style="font-size: 12px; text-align: center;">\n          You have no saved custom foods.\n        </ion-item>\n        <ion-list>\n            <ion-item ng-repeat="food in customFoods | filter: search" ng-click="editFood(food)" nav-direction="forward" class="recipe-food-item item-icon-right item-select">\n                <ion-option-button class="button-assertive" style="background-color:#06a6ee;" ng-click="logFood(food.id)">Quick Log</ion-option-button>\n                <ion-option-button class="button-assertive" ng-click="deleteFood($index, food.id)">Delete</ion-option-button>\n                <div ng-if="food.photo.thumb" class="recipe-food-image">\n                  <img ng-src="{{food.photo.thumb}}" alt="">\n                </div>\n                <div ng-if="!food.photo.thumb" class="recipe-food-image">\n                  <img src="images/gray_nix_apple_small.png" alt="">\n                </div>\n                <div class="recipe-food-info">\n                    <div class="recipe-food-item-serving">1 {{food.serving_unit}}</div>\n                    <div class="recipe-food-item-name"> {{food.food_name | capitalizeFirstWord}}</div>\n                </div>\n                <div class="item-note item-calories">\n                  {{(food.full_nutrients | nutrient: 208: \'value\')/food.serving_qty | number: 0}} <span class="review-item-calory-label">Cal</span>\n                </div>\n            </ion-item>\n        </ion-list>\n    </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/dailygoals.html', '<ion-view>\n  <ion-header-bar align-title="center" class="bar-balanced has-tabs-top">\n    <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n    <div class="center-text">\n      <h1 class="title tab-title">Edit Daily Goals</h1>\n    </div>\n    <i class="fa fa-question shopping-basket-icon" aria-hidden="true" on-touch="showGoalsFaq()"></i>\n  </ion-header-bar>\n  <ion-content>\n    <form name="goalsForm" novalidate>\n      <div class="list">\n        <label class="item item-input">\n          <span class="input-label dailyCaloriesLabel" style="width:50%;text-align:right;">Daily Calories Goal:</span>\n          <input  type="number"\n                  name="userCalorieLimit"\n                  select-on-click\n                  ng-model="currentUser.daily_kcal"\n                  name="daily_kcal"\n                  id="daily_kcal"\n                  placeholder="2000"\n                  class="dailyCaloriesInput"\n                  hide-keyboard-on-go\n                  style="width:150px;border:1px solid #d7d7d7;padding:2px 5px;border-radius:4px;">\n          <span style="padding-left:10px;"> kcal </span>\n        </label>\n        <label class="item item-input">\n          <span class="input-label dailyCaloriesLabel" style="width:50%; white-space: normal;text-align:right;"><span style="font-size:12px;display: block;">% of Calories from</span> Carbohydrates:</span>\n          <input  type="number"\n                  min="0"\n                  max="100"\n                  name="userCarbsGoal"\n                  select-on-click\n                  ng-model="currentUser.daily_carbs_pct"\n                  name="daily_carbs_pct"\n                  id="daily_carbs_pct"\n                  class="dailyGoalsInput"\n                  hide-keyboard-on-go>\n          <span style="padding-left:10px;"> % </span>\n          <span class="grams-goal">{{(((currentUser.daily_kcal || 0) / 100 * currentUser.daily_carbs_pct) / 4) | number: 1}}g</span>\n        </label>\n        <label class="item item-input">\n          <span class="input-label dailyCaloriesLabel" style="width:50%; white-space: normal;text-align:right;"><span style="font-size:12px;display: block;">% of Calories from</span> Protein:</span>\n          <input  type="number"\n                  min="0"\n                  max="100"\n                  name="userProteinGoal"\n                  select-on-click\n                  ng-model="currentUser.daily_protein_pct"\n                  name="daily_protein_pct"\n                  id="daily_protein_pct"\n                  class="dailyGoalsInput"\n                  hide-keyboard-on-go>\n          <span style="padding-left:10px;"> % </span>\n          <span class="grams-goal">{{(((currentUser.daily_kcal || 0) / 100 * currentUser.daily_protein_pct) / 4) | number: 1}}g</span>\n        </label>\n        <label class="item item-input">\n          <span class="input-label dailyCaloriesLabel" style="width:50%; white-space: normal;text-align:right;"><span style="font-size:12px;display: block;">% of Calories from</span> Fat:</span>\n          <input  type="number"\n                  min="0"\n                  max="100"\n                  name="userFatGoal"\n                  select-on-click\n                  ng-model="currentUser.daily_fat_pct"\n                  name="daily_fat_pct"\n                  id="daily_fat_pct"\n                  class="dailyGoalsInput"\n                  hide-keyboard-on-go>\n          <span style="padding-left:10px;"> % </span>\n          <span class="grams-goal">{{(((currentUser.daily_kcal || 0) / 100 * currentUser.daily_fat_pct) / 9) | number: 1}}g</span>\n        </label>\n      </div>\n      <div class="padding red">{{saveError}}</div>\n      <div class="padding">\n        <button type="submit" class="button button-block button-balanced" ng-class="{\'shake\':shakeButton}" ng-click="saveGoals()" ng-disabled="goalsForm.$invalid">Save</button>\n      </div>\n    </form>\n  </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/developerSettings.html', '<ion-view>\n  <ion-header-bar align-title="center" class="bar-balanced">\n    <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n    <h1 class="title">Developer settings</h1>\n  </ion-header-bar>\n  <ion-content>\n    <ul class="list">\n      <li class="padding">\n        No developer options for now\n      </li>\n    </ul>\n  </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/editRecipe.html', '<ion-view>\n  <ion-header-bar align-title="center" class="bar-balanced">\n      <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n      <h1 class="title">Edit Recipe</h1>\n  </ion-header-bar>\n\n  <ion-content>\n    <label class="item item-divider">\n      <input type="text" class="recipeNameField" ng-model="recipe.food_name" ng-class="{\'editing\' : editingName}" ng-blur="saveFoodName()" ng-focus="editFoodName()"/>\n      <i class="editNameSwitch fa fa-edit"></i>\n    </label>\n    <div style="padding: 3px; font-size: 12px; text-align: center; color: #999;"> swipe left to delete </div>\n\n    <ion-list>\n\n      <ion-item ng-repeat="ingredient in recipe.ingredients" class="review-food-item item-icon-right item-select">\n        <ion-option-button class="button-assertive" ng-click="removeIngredient($index, ingredient)" >Remove</ion-option-button>\n        <div class="row review-foods-row">\n          <div class="review-food-image">\n            <img ng-src="{{ingredient.photo.thumb}}" src="images/gray_nix_apple_small.png" alt="">\n          </div>\n          <div style="flex-grow:1;">\n            <div style="display: flex; margin-bottom: 5px;">\n              <form>\n               <input type="number" ng-change="changeQty(ingredient, {{ingredient}})" ng-model="ingredient.serving_qty" ng-model-options="{ updateOn: \'blur\' }" id={{$index}} ng-click="selectText($index)" class="review-food-item-quantity">\n              </form>\n              <div ng-if="!ingredient.alt_measures" class="review-food-single-item-measure" style="margin:auto 0 auto 10px;"> {{ingredient.serving_unit}} </div>\n              <select ng-if="ingredient.alt_measures" ng-model="ingredient.serving_unit" class="review-food-item-measure" ng-change="changeMeasure(ingredient, {{ingredient}}, ingredient.serving_unit)">\n                <option class="review-foods-options" ng-repeat="alt_measure in ingredient.alt_measures | unique: \'measure\'" value="{{alt_measure.measure}}"> {{alt_measure.measure}} </option>\n              </select>\n              <i ng-if="ingredient.alt_measures" class="ion-arrow-down-b select-review-foods-arrow"> </i>\n            </div>\n            <p class="review-food-item-name"> {{ingredient.food_name | capitalizeFirstWord}} </p>\n            <p ng-if="ingredient.brand_name" class="review-food-item-brand">\n              {{ingredient.brand_name | capitalizeFirstWord}}\n            </p>\n          </div>\n          <div class="item-note item-calories" on-tap="showIngredientInfo(ingredient)">\n            <i style="left:20px" class="fa fa-info-circle"></i>\n            {{(ingredient.full_nutrients | nutrient: 208: \'value\' | number: 0) || 0}}\n            <span class="review-item-calory-label">Cal</span>\n          </div>\n        </div>\n      </ion-item>\n    </ion-list>\n\n    <div class="recipe-summary">\n        <a href ng-click="addRecipeIngredient()" class="add-ingredients"> + Add Ingredients</a>\n        <div class="item-note item-calories">\n          {{((recipe.full_nutrients | nutrient: 208: \'value\') / top_level.serving_qty) | number: 0}}\n          <span class="review-item-calory-label">Cal</span>\n        </div>\n        1 serving\n    </div>\n\n\n    <div class="padding">\n      <h4 ng-click="recipeInstructions = !recipeInstructions">\n        <span class="toggle">Edit\n          <span>\n            <i ng-show="!recipeInstructions" class="icon ion-chevron-right ng-hide"></i>\n            <i ng-show="recipeInstructions" class="icon ion-chevron-down ng-hide"></i>\n          </span>\n        </span>\n        Instructions:\n      </h4>\n      <p ng-show="recipeInstructions" class="ng-hide">\n        <textarea name="" cols="30" rows="6" multiline-placeholder ng-model="instruction.text" class="input-bordered textarea-recipe-instructions" placeholder="1. Prep all of the vegetables. \\n2. Bake at 375 degrees for 20 minutes. \\n3. Let cool for 5 minutes before serving."></textarea>\n      </p>\n\n      <div class="row" style="margin-left: -5px">\n        <span style="font-size:15px"> Recipe Makes: </span>\n        <input style="position: relative; margin-left: 10px; margin-top: -6px" type="number" ng-change="changeServingQty()" ng-model="top_level.serving_qty" ng-model-options="{ updateOn: \'blur\' }" class="review-food-item-quantity">\n        <div style="margin-top: 2px" ng-if="top_level.serving_qty <= 1" class="review-food-single-item-measure"> Serving\n        </div>\n        <div style="margin-top: 2px" ng-if="top_level.serving_qty > 1" class="review-food-single-item-measure"> Servings\n        </div>\n        <br>\n      </div>\n    </div>\n    <div class="button-bar padding">\n        <a class="button button-balanced" ng-click="saveRecipe()">\n          <i class="ion-android-done">\n            <span> Save and Close</span>\n          </i>\n        </a>\n    </div>\n    <br>\n    <div class="button-bar padding">\n        <a class="button button-balanced" ng-click="logRecipe()">\n          <i class="ion-ios-plus-outline">\n            <span> Log this food</span>\n          </i>\n        </a>\n    </div>\n\n  </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/editRecipe2.html', '<ion-view>\n  <ion-header-bar align-title="center" class="bar-balanced">\n    <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n    <h1 class="title">{{editingRecipe ? \'Edit Recipe\' : \'Create New Recipe\'}}</h1>\n    <button ng-if="editingRecipe" class="button button-clear" ng-click="goBack(\'discard\')">Cancel</button>\n    <button ng-if="!editingRecipe" class="button button-clear" ng-click="submitRecipe()">Save</button>\n  </ion-header-bar>\n  <div class="overlay" ng-if="showPreloader" style="position:absolute;top: 0;bottom: 0;left: 0;right: 0;background:rgba(0,0,0,0.5);z-index: 8;color:#fff;display: flex;justify-content: center;align-items: center;">Loading. Please wait.</div>\n  <ion-content>\n    <div ng-if="invalidForm" style="position: absolute;top: 5px;left: 50%;transform:translateX(-50%);background:rgba(255,122,122,1);border-radius: 5px;padding:5px 10px;z-index: 100;">Recipe not saved</div>\n    <form action="" name="vm.recipeForm" no-validate>\n      <div class="list form-outline">\n\n        <!-- Recipe info -->\n        <label class="item item-input" style="flex-wrap:wrap;">\n          <!-- <span class="input-label">Recipe Name<span class="required">*</span></span> -->\n          <input ng-model="recipe.name" ng-class="{\'error-required\':errorMessages.name.length}" type="text" placeholder="Recipe Name" required>\n          <span ng-if="errorMessages.name.length" class=\'error-message\' style="position:relative;width: 100%;left: 0;">{{errorMessages.name}}</span>\n        </label>\n        <label class="item item-input">\n          <span class="input-label">Recipe Makes<span class="required">*</span></span>\n          <input ng-min="1" ng-model="recipe.serving_qty" ng-class="{\'error-required\':errorMessages.serving_qty.length}" type="number" class="text-center" placeholder="1" required style="max-width:25%;" ng-change="changedQuantity()"><span style="width:25%;text-align: center;">{{recipe.serving_unit}}{{isMultiServing ? \'s\' : \'\'}}</span>\n          <!-- <input ng-model="recipe.serving_unit" ng-class="{\'error-required\':errorMessages.serving_unit.length}" type="text" class="text-center" placeholder="Serving" required> -->\n          <span ng-if="errorMessages.serving_qty.length || errorMessages.serving_unit.length" class=\'error-message\'>{{(errorMessages.serving_qty || errorMessages.serving_unit)}}</span>\n        </label>\n\n        <!-- Time -->\n        <div class="item item-input">\n          <span class="input-label">\n            <i class="fa fa-clock-o label-icon-clock"></i>\n            Total: {{calculateTotalTime()}} min\n          </span>\n          <span class="input-wrap">\n            <input ng-model="recipe.prep_time_min" type="number" valid-number step="1" class="prep-time text-center" placeholder="0 min">\n          </span>\n          <span class="input-wrap">\n            <input ng-model="recipe.cook_time_min" type="number" valid-number step="1" class="cook-time text-center" placeholder="0 min">\n          </span>\n        </div>\n      </div>\n    </form>\n    <!-- Ingredients -->\n    <div class="item item-divider">\n      Ingredients\n      <span ng-if="recipe.ingredients.length" class="col-calories" style="width:auto;">Calories per serving: {{calculateTotalCalories() | number: 0}}</span>\n    </div>\n    <ion-list class="list-ingredients" ng-if="recipe.ingredients.length">\n      <ion-item class="item-ingredient" ng-repeat="ingredient in ingredientsView">\n        <img style="max-width:45px; max-height:45px;" ng-src="{{ingredient.thumb}}" src="images/gray_nix_apple_small.png" alt="">\n        <form>\n          <input type="text" ng-model="ingredient.original_input" ng-model-options="{updateOn: \'blur submit\'}" ng-change="vm.changeIngredient($index)" ng-blur="vm.changeIngredient($index)">\n        </form>\n        <div class="cal">\n          {{(ingredient.totalCalories | number: 0) || 0}}\n          <span>kcal</span>\n        </div>\n        <!-- <ion-option-button class="ion-arrow-move"></ion-option-button> -->\n        <ion-option-button class="button-assertive ion-ios-trash" ng-click="removeIngredient($index)"></ion-option-button>\n      </ion-item>\n    </ion-list>\n    <div class="item">\n      <a ng-click="showIngredientsPopup()">+ Add Ingredients</a>\n    </div>\n\n    <!-- Directions -->\n    <div class="item item-divider">\n      Directions\n    </div>\n    <form action="" name="vm.recipeDirectionsForm" no-validate>\n      <label class="item item-input">\n        <textarea ng-model="recipe.directions" rows="10" placeholder="Type your recipe prep notes and cooking instructions here."></textarea>\n      </label>\n    </form>\n\n    <div class="padding red" ng-if="errorMessages.ingredients.length">\n      {{errorMessages.ingredients}}\n    </div>\n\n    <ion-item>\n      <div style="display:flex;justify-content: space-between;">\n        <span style="width:100%;" ng-click="showPhoto = !showPhoto">\n          <i class="fa fa-camera" aria-hidden="true"></i>\n            Photo\n          <i class="fa fa-chevron-right" ng-hide="showPhoto" style=""></i>\n          <i class="fa fa-chevron-down ng-hide" ng-show="showPhoto" style=""></i>\n        </span>\n        <div style="position: relative;">\n          <div style="position: absolute;top: -16px;bottom: -16px;left: -16px;right: -16px;" ng-if="!isPhotoPopupShown" ng-click="showPhotoPopup()"></div>\n          <div ngf-stop-propagation="true" ng-if="!uploadPhoto.file" ngf-accept="\'image/*\'" ngf-pattern="\'image/*\'" ngf-select="fileChanged($files)" style="padding:16px; margin:-16px -16px -16px 0;"><i class="fa fa-refresh" ng-if="!!recipe.photo && recipe.photo.is_user_uploaded"></i>{{(!!recipe.photo && recipe.photo.is_user_uploaded) ? \' Change Photo\' : \'+ Add Photo\'}} </div>\n        </div>\n      </div>\n      <div ng-show="showPhoto" class="ng-hide" style="margin-top: 10px;text-align:center;">\n        <div ng-if="uploadPhoto.noCustomPhoto" class="padding" style="white-space: normal;">This recipe has no photo.</div>\n        <div style="position: relative;">\n          <img ng-if="!uploadPhoto.isChanged && !uploadPhoto.noCustomPhoto" ng-src="{{recipe.photo.thumb}}" alt="" style="width:100%;border-radius: 4px;">\n          <img ng-if="!uploadPhoto.isChanged && !uploadPhoto.noCustomPhoto" ng-src="{{recipe.photo.highres}}" alt="" style="width:100%;border-radius: 4px;position: absolute;top: 0;bottom: 0;left: 0;right: 0;">\n        </div>\n        <div ng-if="!!uploadPhoto.isChanged && !uploadPhoto.noCustomPhoto" style="position: relative;">\n          <button ng-if="!uploadPhoto.isUploaded" class="button button-assertive" ng-click="clearCustomPhoto()" style="position: absolute;top:0;right:0;"><i class="fa fa-trash"></i></button>\n          <img ngf-src="uploadPhoto.file" alt="" style="width:100%;border-radius: 4px;">\n          <div class="preloader" ng-if="uploadPhoto.isUploading" style="position: absolute;top: 0;bottom: 0;left: 0;right: 0;background:rgba(255,255,255,0.5);display: flex;align-items: center;justify-content: center;">\n            <ion-spinner icon="ios" class="spinner-balanced"></ion-spinner>\n          </div>\n        </div>\n      </div>\n    </ion-item>\n\n    <div class="padding" style="display:flex; white-space: nowrap;" ng-if="editingRecipe">\n      <button ng-if="editingRecipe" style="width:100%; margin-right:10px;" class="button button-energized" ng-click="copyRecipe()">Copy</button>\n      <button class="button button-balanced" style="width:100%; background-color:#06a6ee" ng-click="logRecipe()">Log this recipe</button>\n    </div>\n    <div style="padding-bottom:70px;" ng-if="uploadPhoto.isChanged || !vm.recipeDirectionsForm.$pristine || !vm.recipeForm.$pristine || recipe.ingredients.length != initialIngredientsQty || changedIngredient"></div>\n  </ion-content>\n  \n  <div class="floating-button-container" ng-class="{\'slide-in\': uploadPhoto.isChanged || !vm.recipeDirectionsForm.$pristine || !vm.recipeForm.$pristine || recipe.ingredients.length != initialIngredientsQty || changedIngredient}" ng-style="{\'bottom\':iosFloatingButtonAdjustment+25+\'px\'}">\n    <button class="button button-block button-balanced" ng-click="submitRecipe()" ng-class="{\'shake\': invalidForm}">Save</button>\n  </div>\n\n</ion-view>');
  $templateCache.put('templates/views/food.html', '<ion-nav-view on-swipe-left="goback()">\n    <ion-header-bar align-title="center" class="bar-balanced">\n      <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n      <h1 class="title">{{readOnly ? \'View\' : \'Edit\'}} Food</h1>\n      <ion-spinner ng-if="$root.showSpinner" style="position: absolute; right: 15px; stroke: #FFFFFF!important; fill: #FFFFFF!important" icon="bubbles"></ion-spinner>\n      <i ng-if="showCheck" class="icon ion-checkmark" style="position: absolute; right: 15px; font-size: 25px;"></i>\n    </ion-header-bar>\n    <ion-content has-bouncing="false" class="has-header">\n      <ion-item class="review-food-item item-icon-right item-select" ng-class="{\'read-only\' : readOnly}">\n        <ion-option-button ng-if="!readOnly" class="button-assertive" ng-click="deleteFood()" >Remove</ion-option-button>\n        <div class="row review-foods-row">\n          <div class="review-food-image">\n            <img ng-src="{{food.photo.thumb}}" src="images/gray_nix_apple_small.png" alt="">\n          </div>\n          <div style="flex-grow:1;align-self:center;">\n            <div style="display: flex; margin-bottom: 5px;" ng-if="!readOnly">\n              <form novalidate ng-submit="cordova.plugins.Keyboard.close">\n                <input type="number" ng-enter="updateCachedFoodOnQtyChange" ng-model="updateForm.quantity" ng-model-options="{ updateOn: \'blur\' }" select-on-click class="review-food-item-quantity">\n              </form>\n              <div ng-if="!food.alt_measures" class="review-food-single-item-measure" style="margin:auto 0 auto 10px;"> {{updateForm.measure}} </div>\n              <select ng-if="food.alt_measures" ng-model="updateForm.measure" class="review-food-item-measure">\n                <option class="review-foods-options" ng-repeat="alt_measure in food.alt_measures | unique: \'measure\'" value="{{alt_measure.measure}}"> {{alt_measure.measure}} </option>\n              </select>\n              <i ng-if="food.alt_measures" class="ion-arrow-down-b select-review-foods-arrow"> </i>\n            </div>\n            <p class="review-food-item-name" style="font-size:16px; min-height:16px; margin:auto 0;">\n              {{food.food_name | ucfirst}}\n            </p>\n            <p ng-if="readOnly || food.brand_name" class="review-food-item-brand" style="margin:auto 0;">\n              <span ng-if="food.brand_name">{{food.brand_name | ucfirst}}</span>\n              <span ng-if="readOnly && food.brand_name">, </span>\n              <span ng-if="readOnly">{{food.serving_qty}} {{food.serving_unit}}</span>\n            </p>\n\n          </div>\n          <div class="item-note item-calories">\n            {{food.nf_calories | caloriesFilter | number: 0 }} <span class="review-item-calory-label">Cal</span>\n          </div>\n        </div>\n      </ion-item>\n\n      <ion-item ng-if="!readOnly">\n        <when-module state="food.consumed_at" mtype="food.meal_type"></when-module>\n      </ion-item>\n\n      <ion-item ng-if="!readOnly">\n        <div ng-click="showNotes = !showNotes">\n          <span>\n            <i class="fa fa-sticky-note-o" aria-hidden="true"></i>\n              Notes\n            <i class="fa fa-chevron-right" ng-hide="showNotes" style=""></i>\n            <i class="fa fa-chevron-down ng-hide" ng-show="showNotes" style=""></i>\n          </span>\n        </div>\n        <div ng-show="showNotes" class="ng-hide" style="margin-top: 10px;" >\n          <textarea ng-model="food.note" ng-model-options="{ updateOn: \'blur\' }" placeholder="Add notes to this food" style="width:100%;min-height:75px;border:1px solid #eee;padding:3px 7px;"></textarea>\n        </div>\n      </ion-item>\n\n      <ion-item ng-if="readOnly && !!food.note">\n        <div ng-click="showNotes = !showNotes">\n          <span>\n            <i class="fa fa-sticky-note-o" aria-hidden="true"></i>\n              Notes\n            <i class="fa fa-chevron-right" ng-hide="showNotes" style=""></i>\n            <i class="fa fa-chevron-down ng-hide" ng-show="showNotes" style=""></i>\n          </span>\n        </div>\n        <div ng-show="showNotes" class="ng-hide padding" style="margin-top: 10px;">\n          {{food.note}}\n        </div>\n      </ion-item>\n\n      <ion-item>\n        <div style="display:flex;justify-content: space-between;">\n          <span style="width:100%;" ng-click="showPhoto = !showPhoto">\n            <i class="fa fa-camera" aria-hidden="true"></i>\n              Photo\n            <i class="fa fa-chevron-right" ng-hide="showPhoto" style=""></i>\n            <i class="fa fa-chevron-down ng-hide" ng-show="showPhoto" style=""></i>\n          </span>\n          <div style="position: relative;">\n            <div style="position: absolute;top: -16px;bottom: -16px;left: -16px;right: -16px;" ng-if="!isPhotoPopupShown" ng-click="showPhotoPopup()"></div>\n            <div ngf-stop-propagation="true" ng-if="!uploadPhoto.file && !readOnly" ngf-accept="\'image/*\'" ngf-pattern="\'image/*\'" ngf-select="fileChanged($files)" style="padding:16px; margin:-16px -16px -16px 0;"><i class="fa fa-refresh" ng-if="!!food.photo && food.photo.is_user_uploaded"></i>{{(!!food.photo && food.photo.is_user_uploaded) ? \' Change Photo\' : \'+ Add Photo\'}} </div>\n          </div>\n        </div>\n        <div ng-show="showPhoto" class="ng-hide" style="margin-top: 10px;text-align:center;">\n          <div ng-if="uploadPhoto.noCustomPhoto" class="padding" style="white-space: normal;">This food has no photo.</div>\n          <div style="position: relative;">\n            <img ng-if="!uploadPhoto.isChanged && !uploadPhoto.noCustomPhoto" ng-src="{{food.photo.thumb}}" alt="" style="width:100%;border-radius: 4px;">\n            <img ng-if="!uploadPhoto.isChanged && !uploadPhoto.noCustomPhoto" ng-src="{{food.photo.highres}}" alt="" style="width:100%;border-radius: 4px;position: absolute;top: 0;bottom: 0;left: 0;right: 0;">\n          </div>\n          <div ng-if="!!uploadPhoto.isChanged && !uploadPhoto.noCustomPhoto" style="position: relative;">\n            <button ng-if="!uploadPhoto.isUploaded" class="button button-balanced" ng-click="submitPhoto()" style="position: absolute;top:0;left:0;">Upload</button>\n            <button ng-if="!uploadPhoto.isUploaded" class="button button-assertive" ng-click="clearCustomPhoto()" style="position: absolute;top:0;right:0;"><i class="fa fa-trash"></i></button>\n            <img ngf-src="uploadPhoto.file" alt="" style="width:100%;border-radius: 4px;">\n            <div class="preloader" ng-if="uploadPhoto.isUploading" style="position: absolute;top: 0;bottom: 0;left: 0;right: 0;background:rgba(255,255,255,0.5);display: flex;align-items: center;justify-content: center;">\n              <ion-spinner icon="ios" class="spinner-balanced"></ion-spinner>\n            </div>\n          </div>\n        </div>\n      </ion-item>\n\n      <div class="row" style="margin-top: -10px;" ng-if="!readOnly">\n          <button class="button button-block button-outline button-dark icon ion-ios-copy" style="width:150px; margin-left: auto;" ng-click="copyFood()">\n            Copy\n          </button>\n          <div style="width: 20px;"> </div>\n          <button class="button button-block button-outline button-dark icon ion-trash-a" style="width:150px; margin-right: auto" ng-click="deleteFood()">\n            Delete\n          </button>\n      </div>\n      <div  ng-if="!!labelData"\n            nutrition-label="labelData"\n            style="padding: 0 10px;"\n            nutrition-label-options="{showDisclaimer: false}"\n            hide-mode-switcher="true">\n      </div>\n      <div ng-if=\'labelData.nf_p || labelData.nf_potassium || labelData.caffeine || net_carbs\' class=\'nutrition-label-attr\'>\n        <ul>\n          <li ng-if=\'net_carbs\'>Net Carbs<span class="note">**</span> : {{net_carbs || 0 | number: 1}} g</li>\n          <li ng-if=\'labelData.vitamin_d\'>Vitamin D<span class="note">**</span> : {{labelData.vitamin_d || 0 | number: 1}} IU</li>\n          <li ng-if=\'labelData.nf_p\'>Phosphorus<span class="note">**</span> : {{labelData.nf_p || 0 | number: 1}} mg</li>\n          <li ng-if=\'labelData.nf_potassium\'>Potassium<span class="note">**</span> : {{labelData.nf_potassium || 0 | number: 1}} mg</li>\n          <li ng-if=\'labelData.caffeine\'>Caffeine<span class="note">**</span> : {{labelData.caffeine || 0 | number: 1}} mg</li>\n        </ul>\n      </div>\n      <div style="padding: 0 10px 10px 10px;" ng-if="!readOnly">\n        <b style="font-size: 1.5em;"> Share This Meal </b>\n        <i class="icon ion-share share-icon" ng-click=socialSharing()></i>\n        <p>\n          Have a friend use the Track barcode scanner to scan this code and instantly copy this meal to their food log. You can also tap the share icon to share this meal via SMS or email.\n        </p>\n        <p style="text-align: center;">\n          <qrcode version="5" error-correction-level="M" size="200" data={{qrText}}></qrcode>\n        </p>\n      </div>\n      <div class="padding text-center" ng-if="readOnly">\n        <button class="button button-positive" style="min-width: 120px;" ng-click="goBack()">Go Back</button>\n      </div>\n      <div ng-if=\'labelData.nf_p || labelData.nf_potassium || labelData.caffeine\' class=\'nutrition-label-attr\'>\n        <p class=\'note\'>\n          ** Please note that our restaurant and branded grocery food database does not have these attributes available, and if your food log contains restaurant or branded grocery foods, these totals may be incorrect. The data from these attributes is for reference purposes only, and should not be used for any chronic disease management.\n        </p>\n      </div>\n      <div style="padding-bottom:70px;" ng-if="isDataChanged()"></div>\n    </ion-content>\n    <div class="floating-button-container" ng-class="{\'slide-in\': isDataChanged()}" ng-style="{\'bottom\':iosFloatingButtonAdjustment+25+\'px\'}">\n      <button class="button button-balanced" ng-class="{\'shake\': foodNotSaved}" ng-click="updateFood()">Save</button>\n    </div>\n</ion-nav-view>\n');
  $templateCache.put('templates/views/foodlog.html', '<ion-nav-view nav-transition="none" hide-back-button="true">\n\n  <div class=\'badge badge-stable connection-message\' wt-step="6-1" ng-if="$root.noInternet" style="background: #e1e1e1;">\n    Offline Mode<span ng-if="$root.updatePendingLength > 0">, {{$root.updatePendingLength}} update<span ng-if="$root.updatePendingLength > 1">s</span> pending</span>\n  </div>\n\n  <main-header nav-transition="none"></main-header>\n  <ion-content>\n    <ion-refresher\n      spinner="bubbles"\n      on-refresh="doRefresh()"\n      >\n    </ion-refresher>\n\n    <div style="position: relative;">\n      <div ng-if="isNewLogLoading" class="foodlog-preloader">\n        <ion-spinner icon="ios" class="spinner-balanced"></ion-spinner>\n      </div>\n\n      <div class="day-title" on-swipe-left="changeOnDays(1)" on-swipe-right="changeOnDays(-1)">\n        <div class="day-controls">\n          <div on-touch="changeOnDays(-1)" class="change-day prev">\n            <i class="icon ion-chevron-left"></i>\n          </div>\n          <p class="food-day" ng-click="goToTotal($root.foodlog[$root.selected_day.date])"> {{getCurrentDayName()}}, <span class="food-date"> {{$root.selected_day.date | amParse : \'ddd, MM/DD/YY\' | amDateFormat : \'MM/DD\'}} </span> </p>\n          <div on-touch="changeOnDays(1)" class="change-day next">\n            <i class="icon ion-chevron-right"></i>\n          </div>\n        </div>\n\n        <div style="padding-top:10px" class="row" ng-click="goToTotal($root.foodlog[$root.selected_day.date])" wt-step="1-1">\n          <span class="col meter-calories-consumed">\n            <span class="cal-intake"> {{$root.selected_day.log.totalCalories | caloriesFilter | number: 0}}</span>\n            <span class="intake-label"> cal intake </span>\n          </span>\n          <span class="col meter-calories-burned">\n            <span class="cal-intake"> {{$root.exerciseLog[$root.selected_day.date].totalCaloriesBurned | caloriesFilter | number: 0}} </span>\n            <span class="intake-label"> cal burned </span>\n          </span>\n          <span class="col meter-calories-remaining">\n            <span class="intake-label"> {{ ($root.selected_day.meta.daily_kcal_limit - selected_day.log.totalCalories + $root.exerciseLog[$root.selected_day.date].totalCaloriesBurned) < 0 ? \'over\' : \'remaining\' }} </span>\n            <span class="cal-intake"> {{\n              ($root.selected_day.meta.daily_kcal_limit > $root.selected_day.log.totalCalories - $root.exerciseLog[$root.selected_day.date].totalCaloriesBurned ?\n              $root.selected_day.meta.daily_kcal_limit - $root.selected_day.log.totalCalories + $root.exerciseLog[$root.selected_day.date].totalCaloriesBurned :\n              $root.selected_day.log.totalCalories - $root.exerciseLog[$root.selected_day.date].totalCaloriesBurned - $root.selected_day.meta.daily_kcal_limit) | number: 0\n            }} </span>\n          </span>\n        </div>\n        <div class="meter">\n          <span class="progress-bar" style="width: {{progressWidth()}}%; transition: width 0.90s ease-in, background-color 0.90s ease-in; background-color:{{barColor($root.selected_day.log.totalCalories - $root.exerciseLog[$root.selected_day.date].totalCaloriesBurned)}}"></span>\n        </div>\n      </div>\n\n      <div class="card foodlog-card">\n        <div  ng-click="goToTotal($root.foodlog[$root.selected_day.date])" class="row macronutrients">\n          <div class="col protein">\n            {{$root.selected_day.log.totalProtein}}g\n            <span>Protein</span>\n          </div>\n          <div class="col carb">\n            {{$root.selected_day.log.totalCarbohydrate}}g\n            <span>Carb</span>\n          </div>\n          <div class="col fat">\n            {{$root.selected_day.log.totalFat}}g\n            <span>Fat</span>\n          </div>\n        </div>\n\n        <ion-list>\n          <ion-item class="item item-divider meal-time" style="padding:0;" wt-step="1-4">\n            <div style="display:flex;">\n              <div ng-click="toggleSuggestedFoods(1)" style="min-width:30%;">\n                Breakfast\n                <i class="icon ion-plus-circled"></i>\n              </div>\n              <div ng-click="goToTotal($root.foodlog[$root.selected_day.date], 1)" style="min-width:70%; text-align:right;">\n                <i class="icon ion-information-circled" wt-step="1-2" style="color:#aaa; margin-right:10px;"></i>\n                <span class="item-note">{{$root.selected_day.log.breakfast_calories | caloriesFilter | number: 0}}</span>\n              </div>\n            </div>\n            <ion-option-button ng-if="$root.selected_day.log.breakfast.length" class="button-energized" ng-click="swipeCopyFoodBulk($root.selected_day.log.breakfast)" style="min-height:20px;line-height: 20px;"> Copy</ion-option-button>\n            <ion-option-button ng-if="$root.selected_day.log.breakfast.length" class="button-assertive" ng-click="swipeDeleteFoodBulk($root.selected_day.log.breakfast, \'breakfast\')" style="min-height:20px;line-height: 20px;"> Delete</ion-option-button>\n          </ion-item>\n\n          <span ng-if="!$root.selected_day.log.breakfast.length" class="no-foods-logged">No foods logged yet.</span>\n\n          <ion-item ng-if="$root.selected_day.log.breakfast.length" ng-repeat="food in $root.selected_day.log.breakfast" ng-click="goToFood(food)" class="item item-button-right foodlog-food-item" wt-step="1-3">\n            <div class="foodlog-item-container">\n              <div class="foodlog-image">\n                <img ng-src="{{food.photo.thumb}}" alt="">\n              </div>\n              <div class="foodname_measure_container" style="width:calc(100% - 135px);margin: 0;">\n                <div class="foodlog-food-name">{{food.food_name | cut:true:cut:\'...\' | ucfirst}}</div>\n                <div class=\'foodlog-qty-measure\'>\n                  <span>\n                    <span ng-if="food.brand_name">{{food.brand_name}},</span>\n                    {{food.serving_qty || 1 }} {{food.serving_unit  | cut:true:32:\'...\' || food.food_name}}\n                  </span>\n                </div>\n              </div>\n              <div class="foodlog-custom-photo" ng-if="!!food.photo && food.photo.is_user_uploaded">\n                <i class="fa fa-camera"></i>\n              </div>\n              <div class="foodlog-calories" style="width:40px; text-align:right;">\n                <span> {{food.nf_calories | caloriesFilter | number: 0}} </span>\n              </div>\n                <span class="chevron-right">\n                  <i class="icon ion-chevron-right"></i>\n                </span>\n            </div>\n            <ion-option-button class="button-energized" ng-click="swipeCopyFood(food)"> Copy</ion-option-button>\n            <ion-option-button class="button-assertive" ng-click="swipeDeleteFood(food)"> Delete</ion-option-button>\n          </ion-item>\n\n          <div ng-if="$root.selected_day.log.am_snack.length">\n            <ion-item class="item item-divider meal-time" wt-step="1-4">\n              <div style="display:flex;">\n                <div ng-click="toggleSuggestedFoods(2)" style="min-width:30%;">\n                  AM Snack\n                  <i class="icon ion-plus-circled"></i>\n                </div>\n                <div ng-click="goToTotal($root.foodlog[$root.selected_day.date], 2)" style="min-width:70%; text-align:right;">\n                  <i class="icon ion-information-circled" style="color:#aaa; margin-right:10px;"></i>\n                  <span class="item-note">{{$root.selected_day.log.am_snack_calories | caloriesFilter | number: 0}}</span>\n                </div>\n              </div>\n              <ion-option-button ng-if="$root.selected_day.log.am_snack.length" class="button-energized" ng-click="swipeCopyFoodBulk($root.selected_day.log.am_snack)" style="min-height:20px;line-height: 20px;"> Copy</ion-option-button>\n              <ion-option-button ng-if="$root.selected_day.log.am_snack.length" class="button-assertive" ng-click="swipeDeleteFoodBulk($root.selected_day.log.am_snack, \'AM Snack\')" style="min-height:20px;line-height: 20px;"> Delete</ion-option-button>\n            </ion-item>\n            <span ng-if="!$root.selected_day.log.am_snack.length" class="no-foods-logged">No foods logged yet.</span>\n\n            <ion-item ng-if="$root.selected_day.log.am_snack.length" ng-repeat="food in $root.selected_day.log.am_snack" ng-click="goToFood(food)" class="item item-button-right foodlog-food-item" wt-step="1-3">\n              <div class="foodlog-item-container">\n                <div class="foodlog-image">\n                  <img ng-src="{{food.photo.thumb}}" alt="">\n                </div>\n                <div class="foodname_measure_container"  style="width:calc(100% - 135px);margin: 0;">\n                  <div class="foodlog-food-name">{{food.food_name | cut:true:cut:\'...\' | ucfirst}}</div>\n                  <div class=\'foodlog-qty-measure\'>\n                    <span>\n                      <span ng-if="food.brand_name">{{food.brand_name}},</span>\n                      {{food.serving_qty || 1 }} {{food.serving_unit  | cut:true:32:\'...\' || food.food_name}}\n                    </span>\n                  </div>\n                </div>\n                <div class="foodlog-custom-photo" ng-if="!!food.photo && food.photo.is_user_uploaded">\n                  <i class="fa fa-camera"></i>\n                </div>\n                <div class="foodlog-calories" style="width:40px; text-align:right;">\n                  <span> {{food.nf_calories | caloriesFilter | number: 0}} </span>\n                </div>\n                  <span class="chevron-right">\n                    <i class="icon ion-chevron-right"></i>\n                  </span>\n              </div>\n              <ion-option-button class="button-energized" ng-click="swipeCopyFood(food)"> Copy</ion-option-button>\n              <ion-option-button class="button-assertive" ng-click="swipeDeleteFood(food)"> Delete</ion-option-button>\n            </ion-item>\n          </div>\n\n          <ion-item class="item item-divider meal-time" wt-step="1-4">\n            <div style="display:flex;">\n              <div ng-click="toggleSuggestedFoods(3)" style="min-width:30%;">\n                Lunch\n                <i class="icon ion-plus-circled"></i>\n              </div>\n              <div ng-click="goToTotal($root.foodlog[$root.selected_day.date], 3)" style="min-width:70%; text-align:right;">\n                <i class="icon ion-information-circled" style="color:#aaa; margin-right:10px;"></i>\n                <span class="item-note">{{$root.selected_day.log.lunch_calories | caloriesFilter | number: 0}}</span>\n              </div>\n            </div>\n            <ion-option-button ng-if="$root.selected_day.log.lunch.length" class="button-energized" ng-click="swipeCopyFoodBulk($root.selected_day.log.lunch)" style="min-height:20px;line-height: 20px;"> Copy</ion-option-button>\n            <ion-option-button ng-if="$root.selected_day.log.lunch.length" class="button-assertive" ng-click="swipeDeleteFoodBulk($root.selected_day.log.lunch, \'lunch\')" style="min-height:20px;line-height: 20px;"> Delete</ion-option-button>\n          </ion-item>\n          <span ng-if="!$root.selected_day.log.lunch.length" class="no-foods-logged">No foods logged yet.</span>\n\n          <ion-item ng-if="$root.selected_day.log.lunch.length" ng-repeat="food in $root.selected_day.log.lunch" ng-click="goToFood(food)" class="item item-button-right foodlog-food-item" wt-step="1-3">\n            <div class="foodlog-item-container">\n              <div class="foodlog-image">\n                <img ng-src="{{food.photo.thumb}}" alt="">\n              </div>\n              <div class="foodname_measure_container"  style="width:calc(100% - 135px);margin: 0;">\n                <div class="foodlog-food-name">{{food.food_name | cut:true:cut:\'...\' | ucfirst}}</div>\n                <div class=\'foodlog-qty-measure\'>\n                  <span>\n                    <span ng-if="food.brand_name">{{food.brand_name}},</span>\n                    {{food.serving_qty || 1 }} {{food.serving_unit  | cut:true:32:\'...\' || food.food_name}}\n                  </span>\n                </div>\n              </div>\n              <div class="foodlog-custom-photo" ng-if="!!food.photo && food.photo.is_user_uploaded">\n                <i class="fa fa-camera"></i>\n              </div>\n              <div class="foodlog-calories" style="width:40px; text-align:right;">\n                <span> {{food.nf_calories | caloriesFilter | number: 0}} </span>\n              </div>\n                <span class="chevron-right">\n                  <i class="icon ion-chevron-right"></i>\n                </span>\n            </div>\n            <ion-option-button class="button-energized" ng-click="swipeCopyFood(food)"> Copy</ion-option-button>\n            <ion-option-button class="button-assertive" ng-click="swipeDeleteFood(food)"> Delete</ion-option-button>\n          </ion-item>\n\n          <div ng-if="$root.selected_day.log.pm_snack.length">\n            <ion-item class="item item-divider meal-time" wt-step="1-4">\n              <div style="display:flex;">\n                <div ng-click="toggleSuggestedFoods(4)" style="min-width:30%;">\n                  PM Snack\n                  <i class="icon ion-plus-circled"></i>\n                </div>\n                <div ng-click="goToTotal($root.foodlog[$root.selected_day.date], 4)" style="min-width:70%; text-align:right;">\n                  <i class="icon ion-information-circled" style="color:#aaa; margin-right:10px;"></i>\n                  <span class="item-note">{{$root.selected_day.log.pm_snack_calories | caloriesFilter | number: 0}}</span>\n                </div>\n              </div>\n              <ion-option-button ng-if="$root.selected_day.log.pm_snack.length" class="button-energized" ng-click="swipeCopyFoodBulk($root.selected_day.log.pm_snack)" style="min-height:20px;line-height: 20px;"> Copy</ion-option-button>\n              <ion-option-button ng-if="$root.selected_day.log.pm_snack.length" class="button-assertive" ng-click="swipeDeleteFoodBulk($root.selected_day.log.pm_snack, \'PM Snack\')" style="min-height:20px;line-height: 20px;"> Delete</ion-option-button>\n            </ion-item>\n            <span ng-if="!$root.selected_day.log.pm_snack.length" class="no-foods-logged">No foods logged yet.</span>\n\n            <ion-item ng-if="$root.selected_day.log.pm_snack.length" ng-repeat="food in $root.selected_day.log.pm_snack" ng-click="goToFood(food)" class="item item-button-right foodlog-food-item" wt-step="1-3">\n              <div class="foodlog-item-container">\n                <div class="foodlog-image">\n                  <img ng-src="{{food.photo.thumb}}" alt="">\n                </div>\n                <div class="foodname_measure_container"  style="width:calc(100% - 135px);margin: 0;">\n                  <div class="foodlog-food-name">{{food.food_name | cut:true:cut:\'...\' | ucfirst}}</div>\n                  <div class=\'foodlog-qty-measure\'>\n                    <span>\n                      <span ng-if="food.brand_name">{{food.brand_name}},</span>\n                      {{food.serving_qty || 1 }} {{food.serving_unit  | cut:true:32:\'...\' || food.food_name}}\n                    </span>\n                  </div>\n                </div>\n                <div class="foodlog-custom-photo" ng-if="!!food.photo && food.photo.is_user_uploaded">\n                  <i class="fa fa-camera"></i>\n                </div>\n                <div class="foodlog-calories" style="width:40px; text-align:right;">\n                  <span> {{food.nf_calories | caloriesFilter | number: 0}} </span>\n                </div>\n                  <span class="chevron-right">\n                    <i class="icon ion-chevron-right"></i>\n                  </span>\n              </div>\n              <ion-option-button class="button-energized" ng-click="swipeCopyFood(food)"> Copy</ion-option-button>\n              <ion-option-button class="button-assertive" ng-click="swipeDeleteFood(food)"> Delete</ion-option-button>\n            </ion-item>\n          </div>\n\n          <ion-item class="item item-divider meal-time" wt-step="1-4">\n            <div style="display:flex;">\n              <div ng-click="toggleSuggestedFoods(5)" style="min-width:30%;">\n                Dinner\n                <i class="icon ion-plus-circled"></i>\n              </div>\n              <div ng-click="goToTotal($root.foodlog[$root.selected_day.date], 5)" style="min-width:70%; text-align:right;">\n                <i class="icon ion-information-circled" style="color:#aaa; margin-right:10px;"></i>\n                <span class="item-note">{{$root.selected_day.log.dinner_calories | caloriesFilter | number: 0}}</span>\n              </div>\n            </div>\n            <ion-option-button ng-if="$root.selected_day.log.dinner.length" class="button-energized" ng-click="swipeCopyFoodBulk($root.selected_day.log.dinner)" style="min-height:20px;line-height: 20px;"> Copy</ion-option-button>\n            <ion-option-button ng-if="$root.selected_day.log.dinner.length" class="button-assertive" ng-click="swipeDeleteFoodBulk($root.selected_day.log.dinner, \'dinner\')" style="min-height:20px;line-height: 20px;"> Delete</ion-option-button>\n          </ion-item>\n          <span ng-if="!$root.selected_day.log.dinner.length" class="no-foods-logged">No foods logged yet.</span>\n\n          <ion-item ng-if="$root.selected_day.log.dinner.length" ng-repeat="food in $root.selected_day.log.dinner" ng-click="goToFood(food)" class="item item-button-right foodlog-food-item" wt-step="1-3">\n            <div class="foodlog-item-container">\n              <div class="foodlog-image">\n                <img ng-src="{{food.photo.thumb}}" alt="">\n              </div>\n              <div class="foodname_measure_container"  style="width:calc(100% - 135px);margin: 0;">\n                <div class="foodlog-food-name">{{food.food_name | cut:true:cut:\'...\' | ucfirst}}</div>\n                <div class=\'foodlog-qty-measure\'>\n                  <span>\n                    <span ng-if="food.brand_name">{{food.brand_name}},</span>\n                    {{food.serving_qty || 1 }} {{food.serving_unit  | cut:true:32:\'...\' || food.food_name}}\n                  </span>\n                </div>\n              </div>\n              <div class="foodlog-custom-photo" ng-if="!!food.photo && food.photo.is_user_uploaded">\n                <i class="fa fa-camera"></i>\n              </div>\n              <div class="foodlog-calories" style="width:40px; text-align:right;">\n                <span> {{food.nf_calories | caloriesFilter | number: 0}} </span>\n              </div>\n                <span class="chevron-right">\n                  <i class="icon ion-chevron-right"></i>\n                </span>\n            </div>\n            <ion-option-button class="button-energized" ng-click="swipeCopyFood(food)"> Copy</ion-option-button>\n            <ion-option-button class="button-assertive" ng-click="swipeDeleteFood(food)"> Delete</ion-option-button>\n          </ion-item>\n\n          <div ng-if="$root.selected_day.log.late_snack.length">\n            <ion-item class="item item-divider meal-time" wt-step="1-4">\n              <div style="display:flex;">\n                <div ng-click="toggleSuggestedFoods(6)" style="min-width:30%;"">\n                  Late Snack\n                  <i class="icon ion-plus-circled"></i>\n                </div>\n                <div ng-click="goToTotal($root.foodlog[$root.selected_day.date], 6)" style="min-width:70%; text-align:right;">\n                  <i class="icon ion-information-circled" style="color:#aaa; margin-right:10px;"></i>\n                  <span class="item-note">{{$root.selected_day.log.late_snack_calories | caloriesFilter | number: 0}}</span>\n                </div>\n              </div>\n              <ion-option-button ng-if="$root.selected_day.log.late_snack.length" class="button-energized" ng-click="swipeCopyFoodBulk($root.selected_day.log.late_snack)" style="min-height:20px;line-height: 20px;"> Copy</ion-option-button>\n              <ion-option-button ng-if="$root.selected_day.log.late_snack.length" class="button-assertive" ng-click="swipeDeleteFoodBulk($root.selected_day.log.late_snack, \'Late Snack\')" style="min-height:20px;line-height: 20px;"> Delete</ion-option-button>\n            </ion-item>\n            <span ng-if="!$root.selected_day.log.late_snack.length" class="no-foods-logged">No foods logged yet.</span>\n\n            <ion-item ng-if="$root.selected_day.log.late_snack.length" ng-repeat="food in $root.selected_day.log.late_snack" ng-click="goToFood(food)" class="item item-button-right foodlog-food-item" wt-step="1-3">\n              <div class="foodlog-item-container">\n                <div class="foodlog-image">\n                  <img ng-src="{{food.photo.thumb}}" alt="">\n                </div>\n                <div class="foodname_measure_container"  style="width:calc(100% - 135px);margin: 0;">\n                  <div class="foodlog-food-name">{{food.food_name | cut:true:cut:\'...\' | ucfirst}}</div>\n                  <div class=\'foodlog-qty-measure\'>\n                    <span>\n                      <span ng-if="food.brand_name">{{food.brand_name}},</span>\n                      {{food.serving_qty || 1 }} {{food.serving_unit  | cut:true:32:\'...\' || food.food_name}}\n                    </span>\n                  </div>\n                </div>\n                <div class="foodlog-custom-photo" ng-if="!!food.photo && food.photo.is_user_uploaded">\n                  <i class="fa fa-camera"></i>\n                </div>\n                <div class="foodlog-calories" style="width:40px; text-align:right;">\n                  <span> {{food.nf_calories | caloriesFilter | number: 0}} </span>\n                </div>\n                <span class="chevron-right">\n                  <i class="icon ion-chevron-right"></i>\n                </span>\n              </div>\n              <ion-option-button class="button-energized" ng-click="swipeCopyFood(food)"> Copy</ion-option-button>\n              <ion-option-button class="button-assertive" ng-click="swipeDeleteFood(food)"> Delete</ion-option-button>\n            </ion-item>\n          </div>\n\n          <div ng-if="!$root.selected_day.log.am_snack.length && !$root.selected_day.log.pm_snack.length && !$root.selected_day.log.late_snack.length">\n            <ion-item class="item item-divider food-log-no-ops" ng-click="toggleSuggestedFoods(guessSnackType())" wt-step="1-4">\n              Snack\n              <i class="icon ion-plus-circled"></i>\n            </ion-item>\n            <span class="no-foods-logged">No foods logged yet.</span>\n          </div>\n\n          <ion-item class="item item-divider food-log-no-ops" ng-click="logExercise()">\n            Exercise\n            <i class="icon ion-plus-circled"></i>\n          </ion-item>\n          <span ng-if="!$root.exerciseLog[$root.selected_day.date].exercises.length" class="no-foods-logged">No exercises logged yet.</span>\n\n          <ion-item ng-if="$root.exerciseLog[$root.selected_day.date].exercises.length" ng-repeat="exercise in $root.exerciseLog[$root.selected_day.date].exercises" ng-click="logExercise($index, exercise)">\n            <div class="foodlog-item-container">\n              <div class="foodlog-image">\n                <img ng-src="{{exercise.photo.thumb}}" alt="">\n              </div>\n              <div class="foodname_measure_container">\n                <div class="foodlog-food-name">{{exercise.name | cut:true:cut:\'...\' | ucfirst}}</div>\n                <div class=\'foodlog-qty-measure\'>\n                  <span ng-if="exercise.name !== \'HealthKit Exercise Total\'">\n                    {{exercise.duration_min}} min\n                  </span>\n                  <span ng-if="exercise.name === \'HealthKit Exercise Total\'">\n                    Daily Total\n                  </span>\n                </div>\n              </div>\n              <div class="foodlog-calories">\n                <span> -{{exercise.nf_calories | caloriesFilter | number: 0}} Cal</span>\n              </div>\n            </div>\n            <ion-option-button class="button-assertive" ng-click="swipeDeleteExercise($index, exercise)"> Delete</ion-option-button>\n          </ion-item>\n\n          <ion-item style="font-size:10px;padding-top:5px; padding-bottom:5px;font-style:italic;" ng-if="uncompletedProfile">\n            Complete your profile <a ui-sref="app.profile">here</a> for more accurate exercise tracking\n          </ion-item>\n\n          <ion-item class="item item-divider food-log-no-ops" ng-click="logWeighIn()">\n            Weigh-in\n            <i class="icon ion-plus-circled"></i>\n          </ion-item>\n          <span ng-if="!$root.weightLog[$root.selected_day.date].weights.length" class="no-foods-logged">No weights logged yet.</span>\n\n          <ion-item ng-if="$root.weightLog[$root.selected_day.date].weights.length" ng-repeat="weight in $root.weightLog[$root.selected_day.date].weights" ng-click="logWeighIn($index, weight)">\n            <div class="foodlog-weight-container">\n              {{weight.timestamp | amDateFormat: \'hh:mmA\'}} &nbsp;&nbsp;\n              {{user.measure_system ? weight.kg : weight.kg * 2.20462 | number: 1}}\n              {{user.measure_system ? \'kg\' : \'lb\'}}\n            </div>\n            <ion-option-button class="button-assertive" ng-click="swipeDeleteWeighIn($index, weight)"> Delete</ion-option-button>\n          </ion-item>\n\n          <ion-item class="item item-divider food-log-no-ops" ng-click="logWater()">\n            Water\n            <i class="icon ion-plus-circled"></i>\n          </ion-item>\n          <ion-item ng-if="$root.waterLog[$root.selected_day.date] === 0">\n            <div class="foodlog-weight-container" ng-click="logWater()">\n              0\n              {{user.measure_system ? \'L\' : \'oz\'}}\n            </div>\n          </ion-item>\n          <ion-item ng-if="$root.waterLog[$root.selected_day.date] !== 0">\n            <div class="foodlog-weight-container" ng-click="logWater()">\n              {{user.measure_system ? ($root.waterLog[$root.selected_day.date] | number: 2) : (($root.waterLog[$root.selected_day.date] * 33.814) | number: 0)}}\n              {{user.measure_system ? \'L\' : \'oz\'}}\n            </div>\n            <ion-option-button class="button-assertive" ng-click="swipeDeleteWater($root.selected_day.date)"> Delete</ion-option-button>\n          </ion-item>\n\n          <ion-item class="item daily-summary" ng-click="goToTotal($root.foodlog[$root.selected_day.date])">\n            <i class="fa fa-pie-chart" aria-hidden="true"></i>\n            View Daily Summary\n          </ion-item>\n\n\n        </ion-list>\n      </div>\n    </div>\n\n  </ion-content>\n\n</ion-nav-view>\n');
  $templateCache.put('templates/views/grocery.html', '<ion-nav-view cache-view="false" animation="no-animation" hide-back-button="true">\n  <ion-view>\n\n  <ion-header-bar align-title="center" class="bar-balanced">\n\n    <button class="button button-icon icon ion-ios-arrow-left" on-touch="goBack()"></button>\n    <div class="center-text">\n      <h1 class="title tab-title">Grocery brands</h1>\n    </div>\n    <i class="fa fa-shopping-basket shopping-basket-icon" aria-hidden="true" on-touch="goToReviewFoods()"></i>\n    <div on-touch="goToReviewFoods()" ng-if="$root.cartNumber !== 0" class="numberCircle">{{$root.cartNumber}}</div>\n  </ion-header-bar>\n\n  <add-Food-Tabs ng-if="!showAutocomplete" state="state"> </add-Food-Tabs>\n\n  <div ng-if="!showAutocomplete" class="bar bar-subheader flexible-subheader has-tabs-top track-tabs-search">\n     <div class="item-input-inset" style="margin-top: -10px;">\n       <label class="item-input-wrapper" style="border-bottom: none !important;">\n         <input type="text" autocomplete="off" autocorrect="off" autocapitalize="off" placeholder="Search Grocery Foods" ng-model="data.grocerySearch" style=" height: 32px; display: block; border-radius: 0px; border: none; width:100%;"/>\n       </label>\n     </div>\n   </div>\n\n    <ion-content class="has-subheader" ng-class="$root.mealBuilderClass" on-scroll="checkHintWasPresented()" on-scroll-complete="$root.hideKeyboard()" scroll-event-interval="500" delegate-handle="groceryScroll">\n\n        <ion-item ng-show="groceries" class="item-icon-left item-text-wrap ng-hide" collection-repeat="grocery in groceries" ng-click="addFood(grocery)" item-height="56">\n          <i class="icon fa fa-plus-circle" style="color: #888 !important;"> </i>\n          <div class="item-note item-calories">\n            {{grocery.nf_calories | caloriesFilter}} <span>Cal</span>\n          </div>\n          <div class="history-item-container">\n            <div style="font-family: Roboto, sans-serif; font-size: 12px;">\n              {{grocery.item_name}}\n            </div>\n            <div class="item-brand">\n              {{grocery.brand_name}}, {{grocery.nf_serving_size_qty || 1 }} {{grocery.nf_serving_size_unit | cut:true:32:\'...\' || grocery.food_name}}\n            </div>\n          </div>\n        </ion-item>\n    </ion-content>\n    <meal-Builder ng-show="$root.itemsInBuilder.length > 0 && !showAutocomplete" class="ng-hide"> </meal-Builder>\n\n  </ion-view>\n  </ion-nav-view>\n');
  $templateCache.put('templates/views/groceryAgentPreferences.html', '<ion-view>\n  <ion-header-bar align-title="center" class="bar-balanced">\n    <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n    <h1 class="title">Grocery Agent Preferences</h1>\n  </ion-header-bar>\n  <ion-content>\n    <ul class="list">\n      <li class="item item-toggle">\n        <h2>Volunteer to submit new photos</h2>\n        <p>if the product is out of date ({{refreshFoodPhotoTime.quantity}} {{refreshFoodPhotoTime.unit}})</p>\n        <label class="toggle toggle-balanced">\n          <input type="checkbox" ng-model=\'groceryAgentPreferences.volunteer\'>\n          <div class="track">\n            <div class="handle"></div>\n          </div>\n        </label>\n      </li>\n    </ul>\n  </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/help.html', '<ion-view>\n    <ion-header-bar align-title="center" class="bar-balanced">\n   <button class="button button-icon icon ion-ios-arrow-left" ng-click="vm.goBack()"></button>\n        <h1 class="title">Help</h1>\n    </ion-header-bar>\n    <ion-content>\n      <div class="list">\n        <li class="item item-icon-left menu-selection" ng-click="vm.goToInstruction()">\n            <i class="fa fa-mobile icon"> </i>\n            Walkthrough\n        </li>\n        <li menu-close class="item item-icon-left menu-selection" ng-click="vm.goToFAQ()">\n            <i class="fa fa-question-circle icon"></i>\n            FAQ\n        </li>\n        <!-- <li menu-close class="item item-icon-left menu-selection" ng-click="vm.goToSupport()">\n            <i class="icon ion-email"></i>\n            Email Us\n        </li> --> <!-- https://edgenetteam.atlassian.net/browse/WELL-993 --> \n      </div>\n      <div class="row">\n          <div class="col-50 text-center"><a on-tap="vm.openTOS()" style="color:#444; text-decoration: underline;">Terms and conditions</a></div>\n          <div class="col-50 text-center"><a on-tap="vm.openPrivacy()" style="color:#444; text-decoration: underline;">Privacy Policy</a></div>\n      </div>\n    </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/history.html', '\n<ion-nav-view hide-back-button="true">\n  <ion-view>\n\n  <main-header></main-header>\n\n  <add-Food-Tabs ng-if="!showAutocomplete" state="state"> </add-Food-Tabs>\n  <div ng-if="!showAutocomplete" class="bar bar-subheader flexible-subheader has-tabs-top track-tabs-search">\n    <div class="item-input-inset" style="margin-top: -10px;">\n      <label class="item-input-wrapper" style="border-bottom: none !important;position: relative;padding-right: 30px;">\n        <input type="text" id="historySearch" autocomplete="off" autocorrect="off" autocapitalize="off" placeholder="Search My Food History" ng-model="data.historySearch" style=" height: 32px; display: block; border-radius: 0px; border: none; width:100%;"/>\n        <button class="fa fa-times clear-search" ng-if="!hideClearItem" aria-hidden="true" on-touch="clearSearch()" style="right:0;padding:0 10px;"></button>\n      </label>\n    </div>\n  </div>\n    <ion-content on-drag="$root.hideKeyboard()" class="has-subheader" ng-class="$root.mealBuilderClass">\n      <ion-item class="item-text-wrap item-icon-left" ng-click="addFood(food)" collection-repeat="food in foods | orderBy: \'food_name\'" item-height="56">\n        <div class="foodlog-image" style="width:40px; position: absolute; top:10px; left:12px;">\n          <img ng-src="{{food.photo.thumb}}" src="images/gray_nix_apple_small.png" alt="" style="max-width:100%;">\n        </div>\n        <div class="item-note item-calories" >\n          {{getCalories(food) | caloriesFilter}} <span>Cal</span>\n        </div>\n        <div class="history-item-container">\n          <div style="font-family: Roboto, sans-serif; font-size: 12px; ">\n            {{food.food_name | capitalizeFirstWord}}\n          </div>\n          <div class="item-brand">\n            <span ng-if="food.brand_name"> {{food.brand_name}}, </span> <span ng-if="!food.brand_name"> Common Food, </span>{{food.serving_qty || 1 }} {{food.serving_unit | cut:true:32:\'...\' || food.food_name}}\n          </div>\n        </div>\n      </ion-item>\n    </ion-content>\n    <meal-Builder ng-show="$root.itemsInBuilder.length > 0 && !showAutocomplete" addedFoods="addedFoods"> </meal-Builder class="ng-hide">\n\n  </ion-view>\n</ion-nav-view>\n');
  $templateCache.put('templates/views/instruction.html', '<ion-view>\n\t<div class="carousel-wrap">\n\t\t<ul rn-carousel rn-carousel-buffered rn-carousel-index="sliderIndex">\n\t\t\t<li ng-repeat="slide in slides" ng-click="slideOnClick($index, $parent)" ng-swipe-left="swipeCloseAtEnd($index)">\n\t\t\t<!-- <h3>{{slide.title}}</h3> -->\n\t\t\t\t<div style="display:flex; flex-direction: column; height: 100vh;">\n\t\t\t\t\t<div ng-if="isIOS" style="height:16px; width:100%; background:#10421d;"></div>\n\t\t\t\t\t<img ng-src="images/instruction/instruction-{{$index+1}}.jpg" style="display:flex; width:100%; height:auto; margin:auto"/>\n\t\t\t\t\t<div class="greenbtn" style="color:#fff; font-size:24px; display:flex; background:#28a54c; flex-grow:5;">\n\t\t\t\t\t\t<div style="margin:auto;">\n\t\t\t\t\t\t\tStart Logging Now <i class="fa fa-arrow-right"></i>\n\t\t\t\t\t\t</div>\n\t\t\t\t\t</div>\n\t\t\t\t</div>\n\t\t\t</li>\n\t\t</ul>\n\t</div>\n</ion-view>\n');
  $templateCache.put('templates/views/manageAppSync.html', '<ion-nav-view nav-transition="none" hide-back-button="true">\n  <ion-header-bar align-title="center" class="bar-balanced">\n    <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n    <h1 class="title">{{managedApp}}</h1>\n  </ion-header-bar>\n  <ion-content>\n    <div class="clearfix"></div>\n    <div class="list list-inset">\n      <label class="item item-input item-select">\n        <div class="input-label dailyCaloriesLabel">\n          Nutrition\n        </div>\n        <select ng-model="syncOptions.fitbit" ng-if="managedApp === \'Fitbit\' && !!syncOptions.fitbit" ng-change="fitbit()">\n          <option value="push">Push</option>\n          <option value="off">Off</option>\n        </select>\n        <select ng-model="syncOptions.nutrition" ng-if="managedApp === \'HealthKit\'" ng-change="adjustSync(\'nutrition\')">\n          <option value="push">Push</option>\n          <option value="off">Off</option>\n        </select>\n      </label>\n      <label class="item item-input item-select" ng-if="managedApp === \'HealthKit\'">\n        <div class="input-label dailyCaloriesLabel">\n          Weight\n        </div>\n        <select ng-model="syncOptions.weight" ng-change="adjustSync(\'weight\')">\n          <option value="push">Push</option>\n          <option value="pull">Pull</option>\n          <option value="off">Off</option>\n        </select>\n      </label>\n      <label class="item item-input item-select" ng-if="managedApp === \'HealthKit\'">\n        <div class="input-label dailyCaloriesLabel">\n          Exercise Calories\n        </div>\n        <select ng-model="syncOptions.exercise" ng-change="adjustSync(\'exercise\')">\n          <option value="push">Push</option>\n          <option value="pull">Pull</option>\n          <option value="off">Off</option>\n        </select>\n      </label>\n    </div>\n\n    <div class="card card-with-button">\n      <div class="item item-divider">\n        About Push &amp; Pull\n      </div>\n      <div class="padding">\n        <strong>How does Push work?</strong>\n        <p>\n          Nutritionix sends data you enter into an approved 3rd party app.\n        </p>\n        <br/>\n        <strong>How does Pull work?</strong>\n        <p>\n          Nutritionix will pull-in the data you have stored in other services. Use this option when a 3rd party app is the summary source of this data.\n        </p>\n      </div>\n    </div>\n\n  </ion-content>\n</ion-nav-view>\n');
  $templateCache.put('templates/views/myCoach.html', '<ion-view class="page-coach">\n  <ion-header-bar align-title="center" class="bar-balanced">\n    <button class="button button-icon icon ion-navicon" menu-toggle="left"></button>\n    <h1 class="title">My Coach</h1>\n  </ion-header-bar>\n  <ion-content>\n    <div class="list form-outline form-coach-id">\n      <div class="item item-text-wrap">\n        Please enter the Coach ID you received from your coach:\n      </div>\n      <label class="item item-input" ng-class="{\'has-error\': noCoachError || alreadyInList}">\n        <span class="input-label">Coach ID:</span>\n        <input type="text" ng-model="data.coachCodeView" placeholder="code" id="coach_id">\n        <i class="icon ion-checkmark" ng-if="addSuccess"></i>\n        <button class=\'button button-positive\' on-tap="addCoach()">Submit</button>\n      </label>\n      <div class="text-center">\n        <span class="error" ng-if="noCoachError">No coach found.</span>\n        <span class="error" ng-if="alreadyInList">Already shared.</span>\n      </div>\n\n      <!-- My Coaches section -->\n      <ion-list class="list-my-coaches" ng-if="user.premium_user">\n        <ion-item class="item-divider">\n          <strong>My Coaches</strong>\n        </ion-item>\n        <!-- no coach -->\n        <ion-item class="note" ng-if="!coachesList.length">\n          You are not currently sharing with any coaches.\n        </ion-item>\n        <!-- coach list -->\n        <ion-item class="item-coach" ng-if="!!coachesList.length" ng-repeat="coach in coachesList">\n          <div class="coach-photo">\n            <i class="fa fa-user" ng-if="!coach.photo"></i>\n            <!-- <img src="https://s3.amazonaws.com/cdn4-nutritionix/images/matt.jpg" alt="Matt Silverman" ng-if="!!coach.photo"> -->\n          </div>\n          <h2 ng-if=coach.last_name>{{coach.first_name + " " + coach.last_name}}</h2>\n          <h2 ng-if=!coach.last_name>{{coach.first_name}}</h2>\n\n          <ion-option-button class="button-assertive ion-ios-trash" ng-click="removeCoach($index)"></ion-option-button>\n        </ion-item>\n      </ion-list>\n    </div>\n\n    <!-- orange alert bubble -->\n    <div class="alert-bubble" ng-if="!!user && !user.premium_user && showSubscribePrompt">\n      Get access to this feature and more with a TrackPro account! <a href="" ui-sref="app.subscribe" style="color:#fff; text-decoration: underline;">Upgrade now!</a>\n    </div>\n\n    <!-- subscribe now -->\n    <div class="subscribe-now" ng-if="!!user && !user.premium_user && showSubscribePrompt">\n      <h4 ng-if=coach.last_name>\n        To share with {{!!coachToAdd ? coachToAdd.first_name + \' \' + coachToAdd.last_name : \'your coach\'}},\n        subscribe to Pro now:\n      </h4>\n      <h4 ng-if=!coach.last_name>\n        To share with {{!!coachToAdd ? coachToAdd.first_name : \'your coach\'}},\n        subscribe to Pro now:\n      </h4>\n      <a href="" ui-sref="app.subscribe" class="button button-calm button-block">Subscribe</a>\n    </div>\n\n    <!-- are you a coach -->\n    <div class="alert alert-info" ng-if="!!user && !user.coach">\n      <h4 class="alert-heading">Are you a Coach?</h4>\n      <p>\n        Using a Coach ID, other Track users can share their food logs with you in real time.\n      </p>\n      <p>\n        Grab your Coach ID <a href="" ng-click="becomeCoach()">here</a>.\n      </p>\n    </div>\n\n    <div class="alert alert-info" ng-if="!!user && !!user.coach">\n      <h4 class="alert-heading">Hey there, coach!</h4>\n      <p>\n        View your Coach Portal:\n      </p>\n      <p>\n        <button class="button button-positive" ui-sref="app.coachPortal">View Coach Portal</button>\n      </p>\n    </div>\n\n  </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/myRecipes2.html', '<ion-view>\n    <ion-header-bar align-title="center" class="bar-balanced">\n        <button class="button button-icon icon ion-navicon" menu-toggle="left"></button>\n        <h1 class="title" style="text-transform:capitalize;">My Recipes 2.0</h1>\n        <button class="button" style="font-size: 15px" ng-click="goToCreateRecipe()"><i class="fa fa-plus"></i></button>\n    </ion-header-bar>\n    <div class="bar bar-subheader flexible-subheader bar-header-search">\n        <div class="item-input-inset">\n            <label class="item-input-wrapper">\n                <input type="text" placeholder="Search my recipes" ng-model="search" />\n            </label>\n        </div>\n        <div ng-if="showSavedRecipeMessage" class="recipeCreatedAlert">Recipe Saved</div>\n    </div>\n    <ion-content class="has-subheader" on-scroll="$root.hideKeyboard()">\n        <div style="padding: 3px; font-size: 12px; text-align: center; color: #999;"> swipe left to delete </div>\n        <ion-item ng-if="recipes.length === 0" class="item-text-wrap  review-food-item" style="font-size: 12px; text-align: center;">\n          {{loadingData ? \'Loading. Please wait.\' : \'You have no saved recipes.\'}}\n        </ion-item>\n\n        <ion-list>\n            <ion-item ng-repeat="recipe in recipes | filter: searchFilter" ng-click="editRecipe(recipe)" nav-direction="forward" class="recipe-food-item item-icon-right item-select">\n                <ion-option-button class="button-assertive" style="background-color:#06a6ee" ng-click="logRecipe(recipe.id)">Quick Log</ion-option-button>\n                <ion-option-button class="button-energized" ng-click="copyRecipe(recipe)">Copy</ion-option-button>\n                <ion-option-button class="button-assertive" ng-click="deleteRecipe($index, recipe.id)">Delete</ion-option-button>\n                <div ng-if="showNewRecipeTag(recipe.created_at)" class="new-recipe-tag">NEW</div>\n                <div class="recipe-food-image">\n                  <img ng-src="{{recipe.photo.thumb}}" src="images/gray_nix_apple_small.png" alt="">\n                </div>\n                <div class="recipe-food-info">\n                    <div class="recipe-food-item-serving">1 Serving</div>\n                    <div class="recipe-food-item-name"> {{recipe.name | capitalizeFirstWord}}</div>\n                </div>\n                <div class="item-note item-calories">\n                  {{((recipe.full_nutrients | nutrient: 208: \'value\') / recipe.serving_qty) | number: 0}} <span class="review-item-calory-label">Cal</span>\n                </div>\n            </ion-item>\n        </ion-list>\n        <ion-infinite-scroll\n          immediate-check="false"\n          ng-if="recipes.length == recipesOffset+recipesLimit"\n          icon="ion-loading-c"\n          on-infinite="loadMoreRecipes()">\n        </ion-infinite-scroll>\n    </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/myrecipes.html', '<ion-view>\n    <ion-header-bar align-title="center" class="bar-balanced">\n        <button class="button button-icon icon ion-navicon" menu-toggle="left"></button>\n        <h1 class="title" style="text-transform:capitalize;">{{searchTitle}}</h1>\n        <button class="button" style="font-size: 15px" ng-click="goToCreateFood()"><i class="fa fa-plus"></i></button>\n    </ion-header-bar>\n    <div class="bar bar-subheader flexible-subheader bar-header-search">\n        <div class="item-input-inset">\n            <label class="item-input-wrapper">\n                <input type="text" placeholder="Search {{searchTitle}}" ng-model="search" />\n            </label>\n        </div>\n        <div ng-if="showSavedRecipeMessage && selectedFilter === \'recipes\'" class="recipeCreatedAlert">Recipe Added</div>\n        <div ng-if="showSavedRecipeMessage && selectedFilter === \'custom\'" class="recipeCreatedAlert">Food Added</div>\n    </div>\n    <ion-content class="has-subheader" on-scroll="$root.hideKeyboard()">\n        <div style="padding: 3px; font-size: 12px; text-align: center; color: #999;"> swipe left to delete </div>\n        <ion-item ng-if="filteredFoods.length === 0" class="item-text-wrap  review-food-item" style="font-size: 12px; text-align: center;">\n          You have no saved {{selectedFilter === \'recipes\' ? \'recipes\' : selectedFilter === \'custom\' ? \'custom foods\': \'foods\'}}.\n        </ion-item>\n\n        <ion-list>\n            <ion-item ng-repeat="recipe in filteredFoods | filter: search" ng-click="editRecipe(recipe)" nav-direction="forward" class="recipe-food-item item-icon-right item-select">\n                <ion-option-button class="button-assertive" style="background-color:#06a6ee" ng-click="logRecipe(recipe.id)">Quick Log</ion-option-button>\n                <ion-option-button class="button-assertive" ng-click="deleteRecipe($index, recipe.id)">Delete</ion-option-button>\n                <div ng-if="food.photo.thumb" class="recipe-food-image">\n                  <img ng-src="{{food.photo.thumb}}" alt="">\n                </div>\n                <div ng-if="!food.photo.thumb" class="recipe-food-image">\n                  <img src="images/gray_nix_apple_small.png" alt="">\n                </div>\n                <div class="recipe-food-info">\n                    <div class="recipe-food-item-serving">1 Serving</div>\n                    <div class="recipe-food-item-name"> {{recipe.food_name | capitalizeFirstWord}}</div>\n                </div>\n                <div class="item-note item-calories">\n                  {{((recipe.full_nutrients | nutrient: 208: \'value\') / recipe.serving_qty) | number: 0}} <span class="review-item-calory-label">Cal</span>\n                </div>\n            </ion-item>\n        </ion-list>\n    </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/newRecipe.html', '<ion-view>\n    <ion-header-bar align-title="center" class="bar-balanced">\n        <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n        <h1 class="title">Create New Recipe</h1>\n        <button class="button button-clear" ng-click="goBack()">Cancel</button>\n    </ion-header-bar>\n    <ion-content>\n      <div class="list form-outline">\n        <label class="item item-input">\n            <span class="input-label">Recipe Name<span class="required">*</span></span>\n            <input type="text" ng-model="food.food_name" placeholder="Food Name">\n        </label>\n        <label class="item item-input" style="flex-wrap:wrap;">\n            <span class="input-label">Ingredients<span class="required">*</span></span>\n            <textarea name="ingredients" id="ingredients" cols="30" rows="10" multiline-placeholder ng-model="food.ingredients" placeholder="2 cups flour\\n1 tsp salt\\n2 sticks butter" style="resize: vertical;"></textarea>\n            <div style="font-style: italic; white-space: normal; font-size: 12px;">*For best results, please limit one ingredient per line.</div>\n        </label>\n        <label class="item item-input">\n            <span class="input-label">Recipe Makes<span class="required">*</span></span>\n        </label>\n        <label class="item item-input" style="border-top:0;">\n            <input type="number" ng-model="food.serving_qty" style="max-width:20%;" placeholder="1">\n            <input type="text" ng-model="food.serving_unit" placeholder="Serving">\n        </label>\n      </div>\n      <div class="padding">\n        <button class="button button-block button-balanced" ng-class="{\'shake\' : invalidForm}" ng-click="submitRecipe()">Submit</button>\n      </div>\n\n    </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/notifications.html', '<ion-view>\n    <ion-header-bar align-title="center" class="bar-balanced">\n    <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n      <h1 class="title"> Notifications </h1>\n    </ion-header-bar>\n    <ion-content>\n      <div class="list">\n        <div class="item item-text-wrap">\n          <label class="toggle toggle-balance">\n            <input ng-model="options.toggle_weekday" ng-click="toggleReminderWeekday()" type="checkbox">\n            <div class="track">\n              <div class="handle"></div>\n            </div>\n          </label>\n          <h2>\n            Weekday Push Notifications\n          </h2>\n          <p>\n            If enabled, we send a push alert at 9PM on any weekday (M-F) when you forget to log your foods.\n          </p>\n        </div>\n        <div class="item item-text-wrap">\n          <label class="toggle toggle-balance">\n            <input ng-model="options.toggle_weekend" ng-click="toggleReminderWeekend()" type="checkbox">\n            <div class="track">\n              <div class="handle"></div>\n            </div>\n          </label>\n          <h2>\n            Weekend Push Notifications\n          </h2>\n          <p>\n            If enabled, we send a push alert at 9PM on any weekend (Sat-Sun) when you forget to log your foods.\n          </p>\n        </div>\n      </div>\n    </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/onboarding.html', '<!-- FILE IS DEPRECATED -->\n\n <ion-view>\n  <ion-content>\n    <div class="padding" style="padding-top: 1.5cm; padding-bottom: 2cm">\n      <h4> Welcome to Nutritionix Track! </h4>\n      <p>\n        Track was developed by a team of registered dietitians to make tracking your food as easy as humanly possible.\n      </p>\n        <h4> {{user.first_name}}\'s To-Do List </h4>\n        <ion-list class="onboarding-todo-list">\n          <ion-item class="item item-icon-left item-icon-right item-text-wrap">\n            <a ui-sref="app.calculateDailyCalories"><i class="icon fa " ng-class="{\'fa-check-square-o\': user.daily_kcal, \'fa-square-o\': !user.daily_kcal}"></i>\n              Calculate and save your daily calorie goal.\n            <i class="icon ion-chevron-right"></i></a>\n          </ion-item>\n          <ion-item class="item item-icon-left item-icon-right item-text-wrap">\n            <a ui-sref="app.connectedApps">\n              <i class="icon fa " ng-class="{\'fa-check-square-o\': user.fitbit, \'fa-square-o\': !user.fitbit}"></i>\n              Consider connecting your Fitbit account to Track.\n              <i class="icon ion-chevron-right"></i>\n            </a>\n          </ion-item>\n          <ion-item class="item item-icon-left item-icon-right item-text-wrap">\n            <a ui-sref="app.smsReminders">\n              <i class="icon fa " ng-class="{\'fa-check-square-o\': user.sms, \'fa-square-o\': !user.sms}"></i>\n              Consider enabling weekday SMS reminders.\n              <i class="icon ion-chevron-right"></i>\n            </a>\n          </ion-item>\n          <ion-item class="item item-icon-left item-icon-right item-text-wrap">\n            <a ui-sref="app.addfoodsmart">\n              <i class="icon fa " ng-class="{\'fa-check-square-o\': false, \'fa-square-o\': true}"></i>\n              Log your first food by tapping the + button below!\n              <i class="icon ion-chevron-right"></i>\n            </a>\n          </ion-item>\n        </ion-list>\n    </div>\n  </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/preferences.html', '<ion-view>\n    <ion-header-bar align-title="center" class="bar-balanced">\n    <button class="button button-icon icon ion-ios-arrow-left" ng-click="vm.goBack()"></button>\n        <h1 class="title">Preferences</h1>\n    </ion-header-bar>\n    <ion-content>\n      <div class="list">\n        <div class="item" ui-sref=\'app.profile\'>\n          My Profile\n        </div>\n        <div class="item" ng-click="vm.goToCalculateDailyCalories()">\n          Daily Calorie Preferences\n          <div class="badge badge-balanced foodlog-calories">\n            <div style="position: relative; right: 0px; margin: 0 auto; "> {{vm.user.daily_kcal}} </div>\n          </div>\n        </div>\n        <div class="item" ng-click="vm.goToConnectedApps()">\n          Connected Apps\n        </div>\n        <div class="item" ng-click="vm.goToPushNotifications()">\n          Notifications\n        </div>\n        <div class="item" ui-sref=\'app.groceryAgentPreferences\' ng-if=\'userGroceyAgentInfo.grocery_agent\'>\n          Grocery Agent Preferences\n        </div>\n        <div class="item" ui-sref=\'app.developerSettings\' ng-if=\'userGroceyAgentInfo.grocery_agent && !vm.hideDevOptions\'>\n          Developer settings\n        </div>\n      </div>\n      <div style="text-align: center; color: #e1e1e1;" ng-show="versionNumber" class="ng-hide">\n        Version: {{versionNumber}}<span ng-show="buildIdentifier" class="ng-hide">({{buildIdentifier}})</span>\n      </div>\n    </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/productRecommendations.html', '<ion-view>\n  <ion-header-bar align-title="center" class="bar-balanced">\n    <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n    <h1 class="title">Product Suggestions</h1>\n  </ion-header-bar>\n  <ion-content>\n    <div class="banner">\n      <div class="banner-icon">\n        <svg style="width:100%; height:60px; fill:#fff; background:transparent;" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" version="1.1" x="0px" y="0px" viewBox="0 0 10 16" enable-background="new 0 0 10 16" height="29px">\n          <path fill-rule="evenodd" d="M9 0H1C.27 0 0 .27 0 1v15l5-3.09L10 16V1c0-.73-.27-1-1-1zm-.78 4.25L6.36 5.61l.72 2.16c.06.22-.02.28-.2.17L5 6.6 3.12 7.94c-.19.11-.25.05-.2-.17l.72-2.16-1.86-1.36c-.17-.16-.14-.23.09-.23l2.3-.03.7-2.16h.25l.7 2.16 2.3.03c.23 02 .27.08.09.23h.01z"></path>\n        </svg>\n      </div>\n      <p>\n        Our team of registered dietitians scours the web to pick out products that could help you stay on track to leading a healthier lifestyle.\n      </p>\n    </div>\n    <ul ng-if="!$root.noInternet" class="list list-product-recommendation">\n      <li class="item item-text-wrap item-thumbnail-left item-icon-right" ng-click="openProductLink(product)" ng-repeat="product in products">\n        <div class="recommended-product-image">\n          <img src="" ng-src="{{product.image_thumb}}">\n        </div>\n        <h2><strong>{{product.item_name}}</strong></h2>\n        <p class="note">{{product.brand_name}}</p>\n        <p class="padding-top">\n          {{product.description}}\n        </p>\n        <i class="icon ion-chevron-right"></i>\n      </li>\n      <li>\n        <div class=\'disclaimer padding text-center\'>We hope you enjoy our product recommendations! Nutritionix may collect a share of sales or other compensation from the links on this page.</div>\n      </li>\n    </ul>\n\n    <div class="padding text-center" ng-if="$root.noInternet">\n      This feature is not available in offline mode.\n    </div>\n  </ion-content>\n</ion-view>');
  $templateCache.put('templates/views/profile.html', '<ion-view>\n  <ion-header-bar align-title="center" class="bar-balanced has-tabs-top">\n    <button class="button button-icon icon ion-ios-arrow-left" ng-click="vm.goBack()"></button>\n    <h1 class="title">My Track Profile</h1>\n  </ion-header-bar>\n  <ion-content>\n    <form name="form" novalidate>\n      <div class="list">\n        <label class="item item-input item-floating-label">\n          <span class="input-label">First Name</span>\n          <input type="text" ng-model="vm.firstName" name="firstName" placeholder="First Name" required>\n          <div ng-show="form.$submitted || form.firstName.$touched" class="ng-hide">\n            <div ng-show="form.firstName.$error.required" class="red ng-hide">First Name is required</div>\n          </div>\n        </label>\n        <label class="item item-input item-floating-label">\n          <span class="input-label">Last Name</span>\n          <input type="text" ng-model="vm.lastName" name="lastName" placeholder="Last Name" required>\n        </label>\n        <label class="item item-input item-select">\n          <div class="input-label">Timezone</div>\n          <select name="timezone" id="timezone" ng-model="vm.timezone" ng-options="timezone as timezone for timezone in vm.timezones">\n          </select>\n        </label>\n        <label class="item item-input item-select">\n          <div class="input-label dailyCaloriesLabel">\n            Units\n          </div>\n          <select ng-model="vm.unitSystem" ng-change="vm.changeUnitSystem()">\n            <option selected value="imperial">Imperial (US)</option>\n            <option value="metric">Metric</option>\n          </select>\n        </label>\n        <!-- <label class="item item-input item-select">\n          <div class="input-label dailyCaloriesLabel">\n            Gender\n          </div>\n          <select ng-model="vm.gender">\n            <option value="male">Male</option>\n            <option value="female">Female</option>\n          </select>\n        </label> -->\n        <label class="item item-input">\n          <span class="input-label dailyCaloriesLabel">Weight</span>\n          <input ng-if="vm.unitSystem == \'metric\'" name="userWeight" type="number" valid-number decimal="true" select-on-click ng-model="vm.weightView.kg" placeholder="kg" class="dailyCaloriesInput" hide-keyboard-on-go>\n          <span ng-if="vm.unitSystem == \'metric\'"> kg </span>\n          <input ng-if="vm.unitSystem == \'imperial\'" name="userWeight" type="number" valid-number decimal="true" select-on-click ng-model="vm.weightView.lb" placeholder="lbs." class="dailyCaloriesInput" hide-keyboard-on-go>\n          <span ng-if="vm.unitSystem == \'imperial\'"> lbs </span>\n          <i class="fa fa-edit" style="position: absolute; top:15px; right:10px; font-size:20px; color:#777;"></i>\n        </label>\n        <div ng-show="form.userWeight.$dirty" style="border-bottom:1px solid black#ddd" class="userPrefsErrorText ng-hide">\n          <div ng-show="form.userWeight.$invalid && form.userWeight.$modelValue !== 0" class="red ng-hide">Invalid value</div>\n        </div>\n        <label ng-if="vm.unitSystem == \'metric\'" class="item item-input">\n          <span class="input-label dailyCaloriesLabel">Height</span>\n          <input type="number" valid-number decimal="false" name="userHeightCm" ng-model="vm.heightView.cm" select-on-click id="height" placeholder="cm" class="dailyCaloriesInput" hide-keyboard-on-go>\n          <span ng-if="vm.unitSystem == \'metric\'"> cm </span>\n          <i class="fa fa-edit" style="position: absolute; top:15px; right:10px; font-size:20px; color:#777;"></i>\n        </label>\n        <div ng-show="form.userHeightCm.$dirty" style="border-bottom:1px solid black#ddd" class="userPrefsErrorText ng-hide">\n          <div ng-show="form.userHeightCm.$invalid &&\n            form.userHeightCm.$modelValue !== 0" class="red ng-hide">Invalid value</div>\n        </div>\n        <label ng-if="vm.unitSystem == \'imperial\'" class="item item-input">\n          <span class="input-label dailyCaloriesLabel">Height</span>\n          <input type="number" valid-number decimal="false" name="userHeightFt" select-on-click ng-model="vm.heightView.ft" name="feet" id="feet" placeholder="ft." class="dailyCaloriesInput" hide-keyboard-on-go>\n          <span ng-if="vm.unitSystem == \'imperial\'"> ft </span>\n          <i class="fa fa-edit" style="position: absolute; top:15px; right:10px; font-size:20px; color:#777;"></i>\n        </label>\n        <div ng-show="form.userHeightFt.$dirty" style="border-bottom:1px solid black#ddd" class="userPrefsErrorText ng-hide">\n          <div ng-show="form.userHeightFt.$invalid &&\n            form.userHeightFt.$modelValue !== 0" class="red ng-hide">Invalid value</div>\n        </div>\n        <label ng-if="vm.unitSystem == \'imperial\'" class="item item-input">\n          <span class="input-label dailyCaloriesLabel">&nbsp;</span>\n          <input type="number" valid-number decimal="false" name="userHeightIn" ng-model="vm.heightView.inch" select-on-click name="inch" id="inch" placeholder="in." class="dailyCaloriesInput" hide-keyboard-on-go>\n          <span ng-if="vm.unitSystem == \'imperial\'"> in </span>\n          <i class="fa fa-edit" style="position: absolute; top:15px; right:10px; font-size:20px; color:#777;"></i>\n        </label>\n        <div ng-show="form.userHeightIn.$dirty" style="border-bottom:1px solid black#ddd" class="userPrefsErrorText ng-hide">\n          <div ng-show="form.userHeightIn.$invalid &&\n            form.userHeightIn.$modelValue !== 0" class="red ng-hide">Invalid value</div>\n        </div>\n        <label class="item item-input">\n          <span class="input-label dailyCaloriesLabel">Age</span>\n          <input type="number" valid-number decimal="false" name="userAge" placeholder="" ng-model="vm.age" select-on-click class="dailyCaloriesInput" hide-keyboard-on-go>\n          <span> years </span>\n          <i class="fa fa-edit" style="position: absolute; top:15px; right:10px; font-size:20px; color:#777;"></i>\n        </label>\n        <div ng-show="form.userAge.$dirty" style="border-bottom:1px solid #ddd" class="userPrefsErrorText ng-hide">\n          <div ng-show="form.userAge.$invalid && form.userAge.$modelValue !== 0" class="red ng-hide">Invalid value</div>\n        </div>\n      </div>\n    </form>\n    <div style="padding-bottom:70px;" ng-if="vm.isDataChanged()"></div>\n    <div class="row">\n      <div class="col text-center"><button class="button button-block button-outline button-dark icon ion-key" ng-click="vm.requestPasswordUpdate()"> Reset password</button></div>\n      <div style="width:20px;"></div>\n      <div class="col text-center"><button class="button button-block button-outline button-dark icon ion-android-mail" ng-click="vm.requestEmailChange()"> Change email</button></div>\n    </div>\n  </ion-content>\n  <div class="floating-button-container" ng-class="{\'slide-in\': vm.isDataChanged()}" ng-style="{\'bottom\':iosFloatingButtonAdjustment+25+\'px\'}">\n    <button class="button button-balanced" ng-class="{\'shake\': vm.preferencesNotSaved}" ng-click="vm.changeProfile()">Save</button>\n  </div>\n</ion-view>\n');
  $templateCache.put('templates/views/resetPassword.html', '<ion-view>\n  <ion-header-bar align-title="center" class="bar-balanced has-tabs-top">\n    <button class="button button-icon icon ion-ios-arrow-left" ng-click="vm.goBack()"></button>\n    <h1 class="title">Reset Password</h1>\n  </ion-header-bar>\n  <ion-content>\n    <div class="text-center" style="padding:50px 0 20px;">\n      <img src="images/logo2.svg" width="180" alt="Nutritionix">\n    </div>\n    <h4 class="text-center" style="margin:0 0 20px;">Reset Password</h4>\n    <div class="list">\n      <label class="item item-input item-floating-label">\n        <span class="input-label">New Password</span>\n        <input type="password" ng-model="vm.newPassword" placeholder="New Password">\n      </label>\n      <label class="item item-input item-floating-label">\n        <span class="input-label">Confirm New Password</span>\n        <input type="password" ng-model="vm.newPasswordConfirmation" ng-change="vm.comparePasswords()" placeholder="Confirm New Password">\n      </label>\n    </div>\n    <div class="padding">\n      <div class="red text-center">{{vm.errorMessage}}</div>\n      <button class="button button-block button-balanced" ng-click="vm.setNewPassword()">Reset</button>\n    </div>\n  </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/restaurantCalculator.html', '<ion-nav-view nav-transition="none" hide-back-button="true">\n  <ion-header-bar align-title="center" class="bar-balanced">\n    <button class="button button-icon icon ion-close" ng-click="goBack()"></button>\n    <div class="center-text">\n      <h1 class="title tab-title">{{brandName}}</h1>\n    </div>\n    <i class="fa fa-shopping-basket shopping-basket-icon" aria-hidden="true" on-touch="goToReviewFoods()"></i>\n    <div on-touch="goToReviewFoods()" ng-if="$root.cartNumber !== 0" class="numberCircle">{{$root.cartNumber}}</div>\n  </ion-header-bar>\n  <ion-content scroll="true" overflow-scroll="true" ng-class="{\'mealbuilder-visible\': $root.itemsInBuilder.length > 0 && !showAutocomplete}">\n    <span class="calc-preloader" ng-if="showPreloader">\n      <i class="fa fa-spinner" aria-hidden="true"></i>\n    </span>\n    <div class="restaurant-calculator-wrapper">\n      <iframe data-tap-disabled="true" style="width:100%;" ng-if="calculatorUrl" ng-src="{{calculatorUrl}}"></iframe>\n    </div>\n  </ion-content>\n  <meal-Builder ng-show="$root.itemsInBuilder.length > 0 && !showAutocomplete" class="ng-hide"> </meal-Builder>\n</ion-nav-view>\n');
  $templateCache.put('templates/views/restaurantFoods.html', '<ion-nav-view cache-view="false" nav-transition="none" hide-back-button="true">\n\n  <ion-header-bar align-title="center" class="bar-balanced">\n\n    <button class="button button-icon icon ion-ios-arrow-left" on-touch="goToRestaurantBrands()"></button>\n    <div class="center-text">\n       <label class="item-input-wrapper" style="max-width: 100%;border-bottom: none !important; position: relative;background:#fff;">\n         <input type="text" autocomplete="off" autocorrect="off" autocapitalize="off" placeholder="Search {{brandName}}" ng-model="data.restFoodSearch" style=" height: 32px; display: block; border-radius: 0px; border: none; width:100%;"/>\n         <button class="fa fa-times clear-search" ng-if="!hideClearItem" aria-hidden="true" on-touch="clearSearch()"></button>\n       </label>\n    </div>\n    <i class="fa fa-shopping-basket shopping-basket-icon" aria-hidden="true" on-touch="goToReviewFoods()"></i>\n    <div on-touch="goToReviewFoods()" ng-if="$root.cartNumber !== 0" class="numberCircle">{{$root.cartNumber}}</div>\n  </ion-header-bar>\n\n  <add-Food-Tabs ng-if="!showAutocomplete" state="state"> </add-Food-Tabs>\n\n  <ion-content on-drag="$root.hideKeyboard()" class="has-subheader" ng-class="$root.mealBuilderClass">\n\n    <div ng-if=\'showCalcButton()\' ng-click="openCalc()" style="padding-top: 8px; padding-bottom: 8px;border:0 none;margin:10px 10px -10px; display:flex;align-items: center;">\n      <div class="item-brand" style="width: 100%;padding:0 10px;display: flex;align-items: center;">\n        <img class="brand-image" ng-src="{{restaurantLogoUrl || \'images/gray_nix_apple_small.png\'}}" style="max-width:100%;max-height:50px;"/>\n      </div>\n      <div style="display: flex;justify-content: flex-end;align-items: center;">\n        <div style="padding:0;text-align: right;color:#6ca6e8;font-weight: 600;line-height: 1;width: 100%;padding-right: 10px;font-size:12px;">\n          Launch<br/>\n          Nutrition<br/>\n          Calculator\n        </div>\n        <i class="icon fa fa-calculator" style="color:#6ca6e8;font-size: 35px;padding-right: 5px;"></i>\n        <i class="icon fa fa-chevron-right" style="color:#52a256;left:auto;right:11px;font-size: 30px;padding-right: 5px;"></i>\n      </div>\n    </div>\n\n    <div class="card" ng-if="foods.length">\n      <div class="list">\n        <a class="item item-icon-left" ng-repeat="food in foods" ng-click="addFood(food)" style="padding-top: 8px; padding-bottom: 8px;">\n          <i class="icon fa fa-plus-circle" style="color: #888 !important;"> </i>\n            <div class="item-note item-calories">\n              {{food.nf_calories | caloriesFilter}} <span>Cal</span>\n            </div>\n            <div class="restaurant-item-name">\n              {{food.item_name || food.food_name}}\n            </div>\n            <div class="item-brand">\n              {{food.brand_name}}, {{food.nf_serving_size_qty || food.serving_qty || 1 }} {{(food.nf_serving_size_unit || food.serving_unit) | cut:true:32:\'...\' || food.food_name}}\n            </div>\n        </a>\n      </div>\n      <ion-infinite-scroll\n         ng-if="!data.restFoodSearch && (offset+step) < maxHits"\n         on-infinite="loadMoreFoods()"\n         distance="1%">\n      </ion-infinite-scroll>\n    </div>\n    <div class="card padding" ng-if="!foods.length">\n      <div class="text-center padding">Nothing found.</div>\n      <button class="button button-block button-balanced" style="line-height: 1.4; padding:10px;" ng-click="requestItem()">Request a missing item for <span style="display:inline-block;">{{brandName}}</span></button>\n    </div>\n  </ion-content>\n\n  <meal-Builder ng-show="$root.itemsInBuilder.length > 0 && !showAutocomplete" class="ng-hide"> </meal-Builder>\n\n\n</ion-nav-view>\n');
  $templateCache.put('templates/views/restaurants.html', '<ion-nav-view cache-view="false" hide-back-button="true">\n\n  <ion-header-bar align-title="center" class="bar-balanced">\n\n    <button class="button button-icon icon ion-ios-arrow-left" on-touch="goBack()"></button>\n    <div class="center-text">\n      <h1 class="title tab-title">Restaurants</h1>\n    </div>\n    <i class="fa fa-shopping-basket shopping-basket-icon" aria-hidden="true" on-touch="goToReviewFoods()"></i>\n    <div on-touch="goToReviewFoods()" ng-if="$root.cartNumber !== 0" class="numberCircle">{{$root.cartNumber}}</div>\n  </ion-header-bar>\n\n  <add-Food-Tabs ng-if="!showAutocomplete" state="state"> </add-Food-Tabs>\n\n   <div ng-if="!showAutocomplete" class="bar bar-subheader flexible-subheader has-tabs-top track-tabs-search">\n     <div class="item-input-inset" style="width:100%;margin-top: -10px;">\n       <label class="item-input-wrapper" style="border-bottom: none !important;">\n         <input type="text" autocomplete="off" autocorrect="off" autocapitalize="off" placeholder="Search All Restaurants" ng-model="data.items" style=" height: 32px; display: block; border-radius: 0px; border: none; width:100%;"/>\n       </label>\n     </div>\n   </div>\n\n  <ion-content on-scroll-complete="$root.hideKeyboard()" class="has-subheader" ng-class=\'$root.mealBuilderClass\'>\n\n    <div ng-if="restaurantsWithCalcView.length" class="padding" style="font-style: italic;">Restaurants with Nutrition Calculator available:</div>\n\n    <ion-item class="item item-button-right brand-item item-text-wrap" nav-transition="none" ng-click="goToRestaurantFoods(brand)"\n         ng-repeat="brand in restaurantsWithCalcView"\n         >\n      <div class="image-container">\n        <img class="brand-image" ng-src="{{brand.logo || \'images/gray_nix_apple_small.png\'}}"/>\n      </div>\n      <div class="brand-name-title" style="font-family: Roboto, sans-serif; color: #555; "> {{brand.name}} </div>\n      <div class="buttons">\n        <button class="button button-icon fa fa-calculator" style="opacity:1;color:#6ca6e8;"></button>\n        <button class="button button-icon ion-ios-arrow-right" style="opacity:1; color: #a1a1a1 !important; font-size: 26px; margin-top: 1px;"></button>\n      </div>\n    </ion-item>\n\n    <div ng-if="restaurants.length" class="padding" style="font-style: italic;">Additional restaurants:</div>\n\n    <ion-item class="item item-icon-right brand-item item-text-wrap" nav-transition="none" ng-click="goToRestaurantFoods(brand)"\n         collection-repeat="brand in restaurants | limitTo: limit"\n         >\n      <div class="image-container">\n        <img class="brand-image" ng-src="{{brand.logo || \'images/gray_nix_apple_small.png\'}}"/>\n      </div>\n      <div class="brand-name-title" style="font-family: Roboto, sans-serif; color: #555; "> {{brand.name}} </div>\n      <i class="icon ion-ios-arrow-right" style="color: #a1a1a1 !important; font-size: 26px; margin-top: 1px;"></i>\n    </ion-item>\n    <ion-infinite-scroll\n      ng-if="moreToLoad()"\n      on-infinite="loadMore()"\n      distance="1%">\n    </ion-infinite-scroll>\n\n    <div class="card padding" ng-if="!restaurants.length">\n      <div class="text-center padding">Nothing found.</div>\n      <button class="button button-block button-balanced" style="line-height: 1.4; padding:10px;" ng-click="requestRestaurant()">Submit a missing restaurant</button>\n    </div>\n  </ion-content>\n  <meal-Builder ng-show="$root.itemsInBuilder.length > 0 && !showAutocomplete" class="ng-hide"> </meal-Builder>\n\n</ion-nav-view>\n');
  $templateCache.put('templates/views/reviewFoods.html', '<ion-nav-view animation="no-animation">\n\n    <main-header></main-header>\n\n    <ion-content class="has-header" on-drag="hideKeyboard()">\n        <div style="padding: 3px; font-size: 12px; text-align: center; color: #999;" ng-if="$root.itemsInBuilder.length !== 0"> swipe left to delete </div>\n\n          <ion-item ng-if="$root.itemsInBuilder.length === 0 && !logging.meal_type" class="item-text-wrap  review-food-item" style="font-size: 12px; text-align: center;">\n            <p class="text-center" style="font-size:16px; color:#aaa; padding-bottom:10px;">\n              <i class="fa fa-arrow-up" aria-hidden="true"></i>\n            </p>\n            Your basket is empty! Please use the search box above to add a food to your basket.\n          </ion-item>\n          <ion-item ng-if="$root.itemsInBuilder.length === 0 && logging.meal_type" class="item-text-wrap  review-food-item" style="font-size: 12px; text-align: center; min-height:1px;">\n            <p class="text-center" style="font-size:16px; color:#aaa; padding-bottom:10px;">\n              <i class="fa fa-arrow-up" aria-hidden="true"></i>\n            </p>\n            Please use the search box above to search foods for {{getMealTimeName()}}.\n          </ion-item>\n\n          <ion-list>\n            <ion-item ng-repeat="food in $root.itemsInBuilder" class="review-food-item item-icon-right item-select">\n              <ion-option-button class="button-assertive" ng-click="swipeRemoveFood($index)" >Remove</ion-option-button>\n              <div class="row review-foods-row">\n                <div class="review-food-image">\n                  <img ng-src="{{food.photo.thumb}}" src="images/gray_nix_apple_small.png" alt="">\n                </div>\n                <div style="flex-grow:1;" wt-step="2-1">\n                  <div style="display: flex; margin-bottom: 5px;">\n                    <form ng-submit="hideKeyboard()" novalidate>\n                      <input type="number" autocorrect="off" autocapitalize="off" spellcheck="false" ng-change="changeQty(food, {{food}})" ng-model="food.serving_qty" ng-model-options="{ updateOn: \'blur\' }" select-on-click class="review-food-item-quantity" style="">\n                    </form>\n                    <div ng-if="!food.alt_measures" class="review-food-single-item-measure" style="margin:auto 0 auto 10px;"> {{food.serving_unit}} </div>\n                    <select ng-if="food.alt_measures" ng-change="changeMeasure(food, {{food}}, food.serving_unit)" ng-model="food.serving_unit" class="review-food-item-measure">\n                      <option class="review-foods-options" ng-repeat="alt_measure in food.alt_measures | unique: \'measure\'" value="{{alt_measure.measure}}"> {{alt_measure.measure}} </option>\n                    </select>\n                    <i ng-if="food.alt_measures" class="ion-arrow-down-b select-review-foods-arrow"> </i>\n                  </div>\n                  <p class="review-food-item-name"> {{food.food_name | capitalizeFirstWord}} </p>\n                  <p class="review-food-item-brand">\n                    {{food.brand_name | capitalizeFirstWord}}\n                  </p>\n                </div>\n                <div class="item-note item-calories" on-tap="showFoodInfo(food)" wt-step="2-2">\n                  <i class="fa fa-info-circle"></i>\n                  {{(food.nf_calories | caloriesFilter  | number: 0) || 0}} <span class="review-item-calory-label">Cal</span>\n                </div>\n              </div>\n            </ion-item>\n          </ion-list>\n          <ion-item ng-if="$root.itemsInBuilder.length > 0" style="background: #eee; padding: 8px 15px; ">\n            Total Calories <span class=\'pull-right green\' style="font-size: 18px;" count-up="{{totals.calories | caloriesFilter}}" duration="0.2"> </span>\n          </ion-item>\n          <ion-item ng-if="logging.type === \'singleFood\' " style="background: #eee; padding: 8px 15px; ">\n            Calories Per Serving <span class=\'pull-right green\' count-up="{{totals.calories/logging.servings | caloriesFilter}}" duration="0.2"> </span>\n          </ion-item>\n          <div ng-if="$root.itemsInBuilder.length > 0" class="row macronutrients">\n            <div class="col protein">\n              {{totals.protein}}g\n              <span>Protein</span>\n            </div>\n            <div class="col carb">\n              {{totals.carbs}}g\n              <span>Carb</span>\n            </div>\n            <div class="col fat">\n              {{totals.fat}}g\n              <span>Fat</span>\n            </div>\n          </div>\n\n        <div class="logging-options" ng-if="$root.itemsInBuilder.length > 1">\n          <div class="item">\n            <p>Appear on food log as:</p>\n            <div class="row">\n              <div class="col" style="margin: 0px;  padding: 0px;">\n              <label style="padding: 5px;">\n                <input type="radio" ng-change="heightChanged()" ng-model="logging.type" value="multipleFoods">\n                Multiple Foods\n              </label>\n              </div>\n              <div class="col" style="margin: 0px; padding: 0px;">\n                <label style="padding: 5px;" wt-step="3-1">\n                  <input type="radio" ng-change="heightChanged()" ng-model="logging.type" value="singleFood">\n                    Single Food (Recipe)\n                </label>\n              </div>\n            </div>\n          </div>\n          <ion-input ng-if="logging.type === \'singleFood\'" class="item item-input review-foods-input">\n            <ion-label> Meal Name</ion-label>\n            <form ng-submit="hideKeyboard()">\n              <input type="text" ng-model="logging.name" placeholder="E.g: After workout meal">\n            </form>\n          </ion-input>\n          <ion-input ng-if="logging.type === \'singleFood\'" class="item item-input">\n            <ion-label> Servings</ion-label>\n            <input type="tel" ng-model="logging.servings">\n          </ion-input>\n        </div>\n        <span style="padding: 10px 15px;" ng-if="errorMessage" class="item red"> {{errorMessage}} </span>\n        <ion-item>\n          <when-module ng-if="$root.itemsInBuilder.length > 0" state="logging.consumed_at" mtype="logging.meal_type"></when-module>\n        </ion-item>\n\n        <ion-item ng-if="$root.itemsInBuilder.length > 0">\n          <div style="display:flex;justify-content: space-between;">\n            <span ng-click="togglePhotoDropdown()">\n              <i class="fa fa-camera" aria-hidden="true"></i>\n                Photo\n              <span ng-if="!uploadPhoto.isChanged && !customPhotoUrl && !($root.itemsInBuilder.length > 1)">\n                <i class="fa fa-chevron-right" ng-hide="showPhoto"></i>\n                <i class="fa fa-chevron-down ng-hide" ng-show="showPhoto"></i>\n              </span>\n            </span>\n            <div style="position: relative; display: flex;">\n              <div style="position: absolute;top: -16px;bottom: -16px;left: -16px;right: -16px;" ng-if="!isPhotoPopupShown" ng-click="showPhotoPopup()"></div>\n\n              <div ngf-stop-propagation="true" ng-if="!uploadPhoto.file && !customPhotoUrl && !isAndroid" ngf-accept="\'image/*\'" ngf-pattern="\'image/*\'" ngf-select="fileChanged($files)" ngf-capture="camera" style="padding:16px; margin:-16px -16px -16px 0;">+ Add Photo</div> <!-- Show only for ios -->\n\n              <div ng-if="!uploadPhoto.file && !customPhotoUrl && isAndroid" style="padding:16px; margin:-16px -16px -16px 0;">Add Photo:</div>\n              <div ng-if="!uploadPhoto.file && !customPhotoUrl && isAndroid" style="padding:16px; margin:-16px 0 -16px 0;" ng-click="takePhoto()">\n                <i class="fa fa-camera"></i>\n              </div>\n              <div ng-if="!uploadPhoto.file && !customPhotoUrl && isAndroid" style="padding:16px; margin:-16px -16px -16px 0;" ngf-stop-propagation="true" ng-if="!uploadPhoto.file && !customPhotoUrl" ngf-accept="\'image/*\'" ngf-pattern="\'image/*\'" ngf-select="fileChanged($files)" ngf-capture="camera">\n                <i class="fa fa-image"></i>\n              </div>\n            </div>\n          </div>\n          <div ng-show="showPhoto" class="ng-hide" style="margin-top: 10px;text-align:center;">\n            <div ng-if="uploadPhoto.isChanged" style="position: relative;">\n              <button ng-if="uploadPhoto.isChanged" class="button button-assertive" ng-click="clearCustomPhoto()" style="position: absolute;top:0;right:0;"><i class="fa fa-trash"></i></button>\n              <img ngf-src="uploadPhoto.file" alt="" style="width:100%;border-radius: 4px;">\n              <div class="preloader" ng-if="uploadPhoto.isUploading" style="position: absolute;top: 0;bottom: 0;left: 0;right: 0;background:rgba(255,255,255,0.5);display: flex;align-items: center;justify-content: center;">\n                <ion-spinner icon="ios" class="spinner-balanced"></ion-spinner>\n              </div>\n            </div>\n            <div ng-if="!uploadPhoto.isChanged && !!customPhotoUrl" style="position: relative;">\n              <button class="button button-assertive" ng-click="clearCustomPhoto()" style="position: absolute;top:0;right:0;"><i class="fa fa-trash"></i></button>\n              <img ng-src="{{customPhotoUrl.full || customPhotoUrl.thumb}}" alt="" style="width:100%;border-radius: 4px;">\n            </div>\n            <div ng-if="!uploadPhoto.isChanged && !customPhotoUrl && $root.itemsInBuilder.length === 1" style="position: relative;">\n              <img ng-if="!!$root.itemsInBuilder[0].photo && !!$root.itemsInBuilder[0].photo.highres" ng-src="{{$root.itemsInBuilder[0].photo.highres}}" alt="" style="width:100%;border-radius: 4px;">\n              <div ng-if="!$root.itemsInBuilder[0].photo || !$root.itemsInBuilder[0].photo.highres" class="text-center">This food has no photo.</div>\n            </div>\n          </div>\n        </ion-item>\n\n        <button class="button button-full button-balanced" ng-click="logFoods()" style="margin-top: 0px; margin-bottom: -1px;">\n          <span ng-if="$root.itemsInBuilder.length === 0"> Back to Food Log </span>\n          <span ng-if="logging.type === \'singleFood\'"> Log 1 Serving </span>\n          <span ng-if="!(logging.type === \'singleFood\') && $root.itemsInBuilder.length > 1"> Log {{$root.itemsInBuilder.length}} Foods </span>\n          <span ng-if="!(logging.type === \'singleFood\') && $root.itemsInBuilder.length === 1"> Log {{$root.itemsInBuilder.length}} Food </span>\n        </button>\n        <br>\n\n        <div class="padding" style="text-align: left;">\n          <span on-touch="sendBugReport()" style="color: #999; font-size: 12px;"> Report a problem </span>\n          <span on-touch="shopNutritionDiscrepancyPopup()" style="float:right; color: #999; font-size: 12px;"> Report nutrition discrepancy </span>\n        </div>\n\n        <div class="padding" ng-if="$root.itemsInBuilder.length > 0" style="text-align: center">\n          <span on-touch="deleteAllFoods()" style="color: red; text-decoration: underline; font-size: 16px"> Clear Basket </span>\n        </div>\n\n    </ion-content>\n\n</ion-nav-view>\n');
  $templateCache.put('templates/views/settings.html', '<ion-view>\n    <ion-header-bar align-title="center" class="bar-positive">\n    <button class="button button-icon icon ion-navicon" menu-toggle="left"></button>\n        <h1 class="title">Settings</h1>\n    </ion-header-bar>\n\n    <ion-content>\n        <div class="list">\n\n            <!-- connect toggles to controller using ng-model -->\n\n            <ion-toggle>\n                <span class="settings-item__text">\n                    Allow Push Notifications\n                </span>\n            </ion-toggle>\n\n            <ion-toggle>\n                <span class="settings-item__text">\n                    Allow cookies\n                </span>\n            </ion-toggle>\n\n        </div>\n    </ion-content>\n\n</ion-view>\n');
  $templateCache.put('templates/views/share.html', '<ion-nav-view>\n  <ion-header-bar align-title="center" class="bar-balanced">\n    <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n    <h1 class="title">Share Food Log</h1>\n  </ion-header-bar>\n  <ion-content>\n    <div class="item">\n      <div class="item-text-wrap">\n        <p> Send a snapshot of your food log to your nutrition coach, medical professional, or anyone else.  This one-time snapshot will include all of the foods you have logged, along with the nutritional information of those foods for up to 10 days. </p>\n      </div>\n    </div>\n    <div class="list" style="margin-bottom:10px;">\n      <div class="item item-divider">\n        Email food log to:\n      </div>\n      <label class="item item-input">\n        <span class="input-label">Email</span>\n        <input ng-model="share.email" type="email" placeholder="example@domain.com">\n      </label>\n      <div class="item item-divider">\n        Select date range (max 10 days):\n      </div>\n      <label ng-click="showDatePicker(\'start\')" class="item item-input item-icon-right" >\n        <span class="input-label">Start</span>\n        <span>{{share.start | amDateFormat: \'MM/DD/YYYY\'}}</span>\n        <i class="icon ion-calendar"></i>\n      </label>\n      <label ng-click="showDatePicker(\'end\')" class="item item-input item-icon-right">\n        <span class="input-label">End</span>\n        <span> {{share.end | amDateFormat: \'MM/DD/YYYY\'}}</span>\n        <i class="icon ion-calendar"></i>\n      </label>\n    </div>\n\n    <div class="padding">\n    <button class="button button-block button-balanced" ng-click="sendEmail()">\n      Send Email\n    </button>\n    </div>\n  </ion-content>\n</ion-nav-view>\n');
  $templateCache.put('templates/views/smsReminders.html', '<!-- FILE IS DEPRECATED -->\n<ion-view>\n    <ion-header-bar align-title="center" class="bar-balanced">\n    <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n      <h1 class="title"> SMS Reminders </h1>\n    </ion-header-bar>\n    <ion-content>\n      <ul class="card list">\n        <li class="item item-toggle">\n          <div class="padding-left"> SMS Reminders </div>\n            <label class="toggle">\n              <input type="checkbox" ng-model="options.toggle" ng-change="toggleReminder()">\n              <div class="track">\n                <div class="handle"></div>\n              </div>\n            </label>\n        </li>\n        <div class="item">\n          <div class="item-text-wrap">\n            <p class="sms-line-break">\n              When enabled, Track will send you a reminder text message at 9PM on any weekday(M-F) in which you have not logged 50% of your daily calorie limit by 9PM.\n            </p>\n            <p class="sms-line-break">\n              Simply reply to the text message with the foods you have eaten to log them!\n            </p>\n            <p>\n              To disable SMS reminders, turn this switch off OR reply to any reminder text message with STOP.\n            </p>\n          </div>\n        </div>\n        <!-- Verified  -->\n        <li style="padding: 10px !important" class="list-group-item" ng-if="options.verification">\n          <p>\n            Mobile Number\n          </p>\n          <p>\n            <span class="pull-right sms-badge sms-badge-success">\n              Verified\n            </span>\n            {{options.mobileNumber}}\n          </p>\n          <p class="sms-note">\n            <a href ng-click="unlinkConfirm()">Delete mobile number</a>\n          </p>\n        </li>\n\n        <!-- Unverified -->\n        <li class="list-group-item mobile-number-verification" style="padding: 10px;" ng-if="!options.verification && options.toggle">\n          <p>\n            Mobile Number\n          </p>\n          <div class="sms-note">\n            <p>\n              To use SMS reminders, please verify your mobile number below.\n              We will send a 6-digit verification code.\n            </p>\n            <p>\n              SMS in only available to users in the US at this time.\n            </p>\n          </div>\n          <div class="sms-center">\n            <div>\n              <form>\n                <div class="verification-field-wrapper">\n                  <div class="input-prefix">+1</div>\n                  <input type="tel" class="sms-tel-no" placeholder="555-555-5555"\n                         ng-model="options.phoneNumber"/>\n                </div>\n                 <button type="button" class="button button-block button-balanced sms-send-code"\n                         ng-class="{\n                           \'btn-default\': !options.initiated,\n                           \'btn-success\': options.initiated,\n                         }"\n                         ng-disabled="!options.phoneNumber || options.initiated"\n                         ng-click="link()">\n                   <span ng-if="!options.initiated">Send Verification Code</span>\n                   <span ng-if="options.initiated">Verification Code Sent</span>\n                 </button>\n                <br>\n                <div class="sms-verification">\n                  <h5>\n                    Enter Verification Code\n                  </h5>\n                </div>\n                <div class="verification-field-wrapper">\n                  <div class="sms-mobile">\n                    <input type="tel" class="sms-code"\n                            ng-model="options.confirmCode">\n                  </div>\n                </div>\n                <div>\n                  <button type="button" class="button button-block button-balanced sms-submit-code"\n                          ng-class="{\n                            \'btn-default\': !options.completed,\n                            \'btn-success\': options.completed,\n                          }"\n                          ng-disabled="!options.confirmCode || options.completed"\n                          ng-click="codeConfirmation()"\n                  >\n                    <span ng-if="!options.completed">Submit</span>\n                    <span ng-if="options.completed">Confirmed</span>\n                  </button>\n                </div>\n              </form>\n            </div>\n          </div>\n        </li>\n      </ul>\n    </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/stats.html', '<ion-view>\n    <ion-header-bar align-title="center" class="bar-balanced">\n        <button class="button button-icon icon ion-ios-arrow-left" ng-click="vm.goBack()"></button>\n        <h1 class="title">Stats</h1>\n    </ion-header-bar>\n    <ion-content class="padding has-header">\n      <div ng-if="vm.user">\n        <!-- Diet Logging Graph -->\n        <diet-graph title="Food Logging Calendar" api="vm.dietGraphApi" target="vm.user.daily_kcal" on-click-handler="vm.changeDayToDate" initial-display-date="initialDisplayDate" show-missed="vm.showMissedDays"></diet-graph>\n        <!-- End Diet Logging Graph -->\n        <p class="note text-center">\n          Tap on any date on the calendar to review or add foods.\n        </p>\n      </div>\n      <br>\n      <!-- weight logging graph -->\n      <weight-graph ng-if="vm.user"></weight-graph>\n      <!-- /weight logging graph -->\n    </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/subscribe.html', '<ion-view class="page-subscribe">\n  <ion-header-bar align-title="center" class="bar-balanced">\n    <button class="button button-icon icon ion-navicon" menu-toggle="left"></button>\n    <h1 class="title">Subscribe</h1>\n  </ion-header-bar>\n  <ion-content class="has-header padding">\n    <div ng-if="!user.premium_user">\n      <h2>\n          Track Pro\n      </h2>\n      <p class="intro">\n        Subscribe to Pro and begin sharing with your coach today!\n      </p>\n      <div class="list">\n        <div class="item item-text-wrap item-subscription">\n            <span class="item-subscription-price">\n              <sup>$</sup>5.99\n              <sub>/mo</sub>\n            </span>\n            <span class="item-subscription-term">\n              Monthly Subscription\n            </span>\n            <span class="item-subscription-info">\n              1/10 the cost of gym membership!\n            </span>\n            <button class="button button-block button-calm" ng-click="purchaseSubscription(\'Track_Pro_Automatic_Renewal\')">\n                <strong>Subscribe</strong>\n            </button>\n            <div ng-if="showTrial" style="text-align: center;display: block;margin: 10px 0 20px;">\n              Start your 2 month free trial, then $5.99/month\n            </div>\n        </div>\n        <div class="item item-text-wrap item-subscription">\n            <span class="item-subscription-price">\n              <sup>$</sup>29\n              <sub>/year</sub>\n            </span>\n            <span class="item-subscription-term">\n              Annual Subscription\n            </span>\n            <span class="item-subscription-info">\n              Discounted rate of $29/year\n            </span>\n            <button class="button button-block button-calm" ng-click="purchaseSubscription(\'Track_Pro_Renewal_Yearly\')">\n              <strong>Subscribe</strong>\n            </button>\n            <div ng-if="showTrial" style="text-align: center;display: block;margin: 10px 0 20px;">\n              Start your 2 month free trial, then $29/year\n            </div>\n        </div>\n      </div>\n      <p class="padding">\n        <button class="button button-small button-block button-restore-purchase" ng-click="restorePurchases()">\n          Restore previous purchase\n        </button>\n      </p>\n      <div class="list list-license" style="padding-bottom:10px;">\n        <p ng-if="platform.store === \'ios\'" style="padding: 17px 15px" class="note">\n        <b> Subscription Details </b><br>\n        If you choose to purchase a subscription, payment will be charged to your iTunes account, and your account will be charged within 24-hours prior to the end of the 2-month trial period. Auto-renewal may be turned off at any time by going to your settings in the iTunes store after purchase. For more information, please visit our <a on-tap="openTOS()">terms of service</a> and <a href="" on-tap="openPrivacy()"> Privacy Policy </a>\n        </p>\n        <p ng-if="platform.store === \'android\'" style="padding: 17px 15px" class="note">\n        <b> Subscription Details </b><br>\n        If you choose to purchase a subscription, payment will be charged to your Google Play account, and your account will be charged within 24-hours prior to the end of the 2-month trial period. Auto-renewal may be turned off at any time by going to your subscription settings in the Google Play Store app. For more information, please visit our <a on-tap="openTOS()">terms of service</a> and <a href="" on-tap="openPrivacy()"> Privacy Policy </a>\n        </p>\n        <div class="item">\n          <p class="note">\n            Need help? Email <a href="mailto:support@nutritionix.com">support@nutritionix.com</a>\n          </p>\n        </div>\n      </div>\n    </div>\n    <div ng-if="user.premium_user">\n      <h2 class="welcome">\n        You\'re a <span class="dark">Track</span> <span class="pro">Pro</span> user!\n      </h2>\n      <p class="intro padding-bottom">\n        Ready to track like a pro? You have now access to awesome features like:\n      </p>\n      <div class="list list-pro-features">\n        <a href="" class="item item-text-wrap item-icon-right" style="white-space:nowrap;" ui-sref="app.myCoach">\n          <i class="icon ion-chevron-right"></i>\n          Coach Portal <sup>Share your log with a coach now!</sup>\n        </a>\n        <!-- <a href="" class="item item-text-wrap item-icon-right" ui-sref="app.connectedApps">\n          <i class="icon ion-chevron-right"></i>\n          Fitbit Integration\n        </a>\n        <a href="" class="item item-text-wrap item-icon-right" ui-sref="app.connectedApps">\n          <i class="icon ion-chevron-right"></i>\n          iOS Health App Integration\n        </a>\n        <a href="" class="item item-text-wrap item-icon-right">\n          <i class="icon ion-chevron-right"></i>\n          Export Your Data\n        </a> -->\n      </div>\n\n      <div ng-if=\'user.grocery_agent\' class=\'text-center\'>\n        <a href="" class="button button-positive" ng-click="unsubscribeFromPro()" style="background: transparent;border: 2px solid #5bc0de;color: #5bc0de;min-height: 40px;height: 40px;line-height: 40px;">Unsubscribe from Pro</a>\n      </div>\n    </div>\n  </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/total.html', '<ion-nav-view>\n  <ion-header-bar align-title="center" class="bar-balanced">\n    <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n    <h1 class="title" style="font-size:16px;">{{mealTypeTitle}}</h1>\n    <!-- <button class="button button-icon icon ion-ios-help-outline"> </button> -->\n  </ion-header-bar>\n  <ion-content>\n    <div ng-if="!!labelData" nutrition-label="labelData" nutrition-label-options="{showDisclaimer: false}" hide-mode-switcher="true"></div>\n\n    <div class="card" ng-if="!vm.readOnly && mealTypeName == \'Daily\'">\n      <div class="item item-input">\n        <span class="input-label dailyCaloriesLabel">Daily Calorie Limit:</span>\n        <input  type="number"\n                step="1"\n                decimal="false"\n                name="dailyCaloriesLimit"\n                ng-model="labelData.calorieIntake"\n                ng-model-options="{ updateOn: \'blur\' }"\n                select-on-click\n                required\n                hide-keyboard-on-go\n                style="border:1px solid #bebebe;min-width: 1px;max-width: 60px;padding-right:4px;padding-left:4px;"/>\n        <button style="line-height: 30px;min-height: 30px;margin:auto;" ng-click="updateCalorieLimit()" class="button button-balanced">Save</button>\n      </div>\n    </div>\n    <div ng-if="showCalorieError" class="red text-center" style="position:relative; top:-15px;">Calorie limit is required</div>\n\n    <div class="card ng-hide" ng-show="vm.total.calories">\n      <div class="item item-divider">\n        Source of calories\n      </div>\n      <div class="item item-text-wrap">\n        <div ng-if="!!dailyGoals && (!!dailyGoals.protein_pct || !!dailyGoals.carbohydrate_pct || !!dailyGoals.fat_pct)" style="font-size:12px;margin-bottom: 25px;">\n          <div class="text-right" style="margin-bottom: 5px;color:#666;">Actual / Goal</div>\n          <div class="progressbar-wrapper" ng-class="{\'progress-red\' : pieChart.data[0] > dailyGoals.protein_pct}" ng-if="dailyGoals.protein_pct !== null">\n            <div class="pull-right"><span class="current-percent">{{pieChart.data[0]}}%</span> / {{dailyGoals.protein_pct}}%</div>\n            <div class="goal-label">Protein</div>\n            <div class="progressbar">\n              <div class="progress" style="background-color:#1aa6b7;width:{{dailyGoals.protein_progress < 100 ? dailyGoals.protein_progress : 100}}%"></div>\n            </div>\n          </div>\n          <div class="progressbar-wrapper" ng-class="{\'progress-red\' : pieChart.data[1] > dailyGoals.carbohydrate_pct}" ng-if="dailyGoals.carbohydrate_pct !== null">\n            <div class="pull-right"><span class="current-percent">{{pieChart.data[1]}}%</span> / {{dailyGoals.carbohydrate_pct}}%</div>\n            <div class="goal-label">Carbohydrate</div>\n            <div class="progressbar">\n              <div class="progress" style="background-color:#f0ab00;width:{{dailyGoals.carbohydrate_progress < 100 ? dailyGoals.carbohydrate_progress : 100}}%"></div>\n            </div>\n          </div>\n          <div class="progressbar-wrapper" ng-class="{\'progress-red\' : pieChart.data[2] > dailyGoals.fat_pct}" ng-if="dailyGoals.fat_pct !== null">\n            <div class="pull-right"><span class="current-percent">{{pieChart.data[2]}}%</span> / {{dailyGoals.fat_pct}}%</div>\n            <div class="goal-label">Fat</div>\n            <div class="progressbar">\n              <div class="progress" style="background-color:#b3217c;width:{{dailyGoals.fat_progress < 100 ? dailyGoals.fat_progress : 100}}%"></div>\n            </div>\n          </div>\n        </div>\n        <div class="row">\n          <canvas class="chart chart-pie"\n                  width="220"\n                  height="110"\n                  chart-data="pieChart.data"\n                  chart-labels="pieChart.labels"\n                  chart-legend="true"\n                  chart-colors="[\'#1aa6b7\', \'#f0ab00\', \'#b3217c\', \'#808080\']"\n                  chart-options="{\n                        responsive: true,\n                        maintainAspectRatio: false,\n                        legend: {\n                            display: true,\n                            position: \'right\',\n                            fullWidth: true,\n                            labels: {\n                              generateLabels: pieChart.generateLabels,\n                              boxWidth: 15\n                            },\n                            onClick: null\n                        },\n                        tooltips: {\n                          callbacks: {\n                            label: pieChart.label\n                          }\n                        }\n                      }"\n          >\n          </canvas>\n        </div>\n      </div>\n    </div>\n\n    <ul class=\'nutrition-label-attr\'>\n      <li>Net Carbs<span class="note">**</span> : {{vm.total.net_carbs || 0 | number: 1}} g</li>\n      <li>Phosphorus<span class="note">**</span> : {{vm.total.nf_p || 0 | number: 1}} mg</li>\n      <li>Potassium<span class="note">**</span> : {{vm.total.nf_potassium || 0 | number: 1}} mg</li>\n      <li>Caffeine<span class="note">**</span> : {{vm.total.caffeine || 0 | number: 1}} mg</li>\n    </ul>\n    <div>\n      <div ng-click="vm.showAdditionalMicroDropdown = !vm.showAdditionalMicroDropdown" class="padding">\n        <span>\n          <i class="fa fa-chevron-right" ng-hide="vm.showAdditionalMicroDropdown"></i>\n          <i class="fa fa-chevron-down ng-hide" ng-show="vm.showAdditionalMicroDropdown"></i>\n          View more micronutrients\n        </span>\n      </div>\n      <ul ng-show="vm.showAdditionalMicroDropdown" class="ng-hide nutrition-label-attr">\n        <li>Vitamin D**: {{vm.total.vitamin_d | number: 1}} IU</li>\n        <li>Vitamin E**: {{vm.total.vitamin_e | number: 1}} IU</li>\n        <li>Vitamin K**: {{vm.total.vitamin_k | number: 1}} \xB5g</li>\n        <li>Thiamine**: {{vm.total.thiamine | number: 1}} mg</li>\n        <li>Riboflavin**: {{vm.total.riboflavin | number: 1}} mg</li>\n        <li>Niacin**: {{vm.total.niacin | number: 1}} mg</li>\n        <li>Pantothenic Acid**: {{vm.total.pantothenic_acid | number: 1}} mg</li>\n        <li>Vitamin B-6**: {{vm.total.vitamin_b6 | number: 1}} mg</li>\n        <li>Folate**: {{vm.total.folate | number: 1}} \xB5g</li>\n        <li>Vitamin B-12**: {{vm.total.vitamin_b12 | number: 1}} \xB5g</li>\n        <li>Folic Acid**: {{vm.total.folic_acid | number: 1}} \xB5g</li>\n        <li>Zinc**: {{vm.total.zinc | number: 1}} mg</li>\n        <li>Magnesium**: {{vm.total.magnesium | number: 1}} mg</li>\n      </ul>\n    </div>\n    <div ng-if="!vm.readOnly && mealTypeName == \'Daily\'" class="padding">\n      <div ng-click="vm.showNotes = !vm.showNotes">\n        <span>\n          <i class="fa fa-sticky-note-o" aria-hidden="true"></i>\n            Notes\n          <i class="fa fa-chevron-right" ng-hide="vm.showNotes" style=""></i>\n          <i class="fa fa-chevron-down ng-hide" ng-show="vm.showNotes" style=""></i>\n        </span>\n      </div>\n      <div ng-show="vm.showNotes" class="ng-hide" style="margin-top: 10px;" >\n        <textarea ng-model="vm.dayNote" ng-model-options="{ updateOn: \'blur\' }" placeholder="Add notes to this day" style="width:100%;min-height:75px;border:1px solid #eee;padding:3px 7px;"></textarea>\n      </div>\n    </div>\n    <div class=\'nutrition-label-attr\'>\n      <p class=\'note\'>\n        ** Please note that our restaurant and branded grocery food database does not have these attributes available, and if your food log contains restaurant or branded grocery foods, these totals may be incorrect. The data from these these attributes is for reference purpose only, and should not be used for any chronic disease management.</p>\n    </div>\n    <div ng-if="vm.showMealControls" class="padding row">\n      <div class="col">\n        <button class="button-energized button button-block" ng-click="vm.copyFoodBulk()">Copy Meal</button>\n      </div>\n      <div class="col">\n        <button class="button-assertive button button-block" ng-click="vm.deleteFoodBulk()">Clear Meal</button>\n      </div>\n    </div>\n  </ion-content>\n</ion-nav-view>\n');
  $templateCache.put('templates/views/uploadPhotoAgent.html', '<ion-view>\n  <ion-header-bar align-title="center" class="bar-balanced has-tabs-top">\n    <!-- <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button> -->\n    <button class="button button-icon icon ion-navicon" menu-toggle="left"></button>\n    <h1 class="title">Grocery Agent Mode</h1>\n  </ion-header-bar>\n  <ion-content padding=\'true\'>\n    <div ng-if=\'!currentSession.barcode\'>\n      <div style=\'text-align: center;\'>\n        <p>\n          To upload your photos, please connect to wifi!\n        </p>\n        <p>\n          <span>{{barcodesForSyncCount}}</span> Barcodes Waiting to Sync ({{barcodesForSyncCount * 2}} photos)\n        </p>\n      </div>\n      <div class=\'row\'>\n        <div class=\'col\'>\n          <button class=\'button button-block button-stable icon ion-android-sync\' ng-disabled=\'!barcodesForSyncCount || !WiFiNetworkIsInUse\' ng-click=\'sequentialSync()\'>\n            Sync Photos to Cloud\n          </button>\n          <!-- <button class=\'button button-block button-stable icon ion-android-sync\' ng-disabled=\'!barcodesForSyncCount || !WiFiNetworkIsInUse\' ng-click=\'parallelSync()\'>\n            Parallel Sync\n          </button> -->\n        </div>\n      </div>\n      <div class=\'row\'>\n        <div class=\'col\'>\n          <p>\n            Remember, for every product your scan follow this order:\n            <br/>1. Take front of package photo\n            <br/>2. Take nutrition label photo\n          </p>\n        </div>\n      </div>\n      <div class=\'row\'>\n        <div class=\'col\'>\n          <button class=\'button button-block button-stable\' ng-click=\'scanBarcode()\'>\n            <i class=\'icon fa fa-barcode\'></i> Start Scanning\n          </button>\n          <p style=\'text-align: center;\'>\n            to stop scanning mode, hit "cancel" button to return to this screen.\n          </p>\n        </div>\n      </div>\n      <div class=\'row\'>\n        <div class=\'col\'>\n          <p>\n            Tips:\n            <br/>- Align products parallel to the shelf to avoid glare from ceiling lights\n          </p>\n        </div>\n      </div>\n      <div ng-if=\'existingBarcodesCount\' class=\'row\'>\n        <div class=\'col\'>\n          <p>\n            Barcode Database: {{existingBarcodesCount | number}}\n          </p>\n        </div>\n      </div>\n    </div>\n    <div ng-if=\'currentSession.barcode\'>\n      <div class=\'row\'>\n        <div class=\'col\'>\n          UPC: {{currentSession.barcode}}\n        </div>\n      </div>\n      <div ng-repeat=\'(key, prop) in photoTemplates track by key\' ng-if=\'photoTemplates[key].show\'>\n        <div class=\'row\'>\n          <div class=\'col\'>\n            <p>{{$index+1}}. {{photoTemplates[key].title}} Photo: <i ng-if=\'currentSession.photos[key].photo_src\' class="icon ion-checkmark"></i></p>\n          </div>\n        </div>\n        <div class=\'row\'>\n          <div class=\'col\' ng-if=\'currentSession.photos[key].photo_src\' ng-style="currentSession.photos[key].loading && {\'margin\':\'auto\', \'text-align\':\'center\'}">\n            <ion-spinner ng-if=\'currentSession.photos[key].loading\' icon="dots"></ion-spinner>\n            <img style=\'width:50%;\' ng-if=\'!currentSession.photos[key].loading\' ng-src=\'{{currentSession.photos[key].photo_src}}\'>\n          </div>\n          <div class=\'col\' style=\'margin:auto;\'>\n            <button ng-if=\'!currentSession.photos[key].photo_src\' class=\'button button-block button-stable icon ion-camera\' ng-click=\'takePhoto(key)\'>\n              <span>Take {{photos[key].title}} Photo</span>\n            </button>\n            <button ng-if=\'currentSession.photos[key].photo_src\' class=\'button button-block button-stable icon ion-refresh\' ng-click=\'takePhoto(key)\'>\n              <span ng-if=\'currentSession.photos[key].photo_src\'>Retake</span>\n            </button>\n          </div>\n        </div>\n      </div>\n      <div class=\'row\'>\n        <div class=\'col\'>\n          <button class="button button-block button-stable" ng-disabled=\'!currentSession.canSave\' ng-click=\'saveRecordsForSync()\'>\n            Save\n          </button>\n        </div>\n      </div>\n      <div class=\'row\'>\n        <div class=\'col\'>\n          <button class="button button-block button-stable" ng-click=\'cancel()\'>\n            Cancel\n          </button>\n        </div>\n      </div>\n    </div>\n  </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/uploadPhotoUser.html', '<ion-view cache-view="false">\n  <ion-header-bar align-title="center" class="bar-balanced has-tabs-top">\n    <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n    <h1 class="title">User Photo Upload</h1>\n  </ion-header-bar>\n  <ion-content padding=\'true\'>\n    <div class=\'row\'>\n      <div class=\'col\'>\n        <p>{{message}}</p>\n      </div>\n    </div>\n    <div ng-repeat=\'(key, prop) in photos track by key\' ng-if=\'photos[key].show\'>\n      <div class="row">\n        <div class="col">\n          <p>{{$index+1}}. {{photos[key].title}} Photo: <i ng-if=\'photos[key].photo_src\' class="icon ion-checkmark"></i></p>\n        </div>\n      </div>\n      <div class=\'row\'>\n        <div class=\'col\' ng-if=\'photos[key].photo_src\' ng-style="photos[key].loading && {\'margin\':\'auto\', \'text-align\':\'center\'}">\n          <ion-spinner ng-if=\'photos[key].loading\' icon="dots"></ion-spinner>\n          <img style=\'width:50%;\' ng-if=\'!photos[key].loading\' ng-src=\'{{photos[key].photo_src}}\'>\n        </div>\n        <div class=\'col\' style=\'margin:auto;\'>\n          <button ng-if=\'!photos[key].photo_src\' class=\'button button-block button-stable icon ion-camera\' ng-click=\'takePhoto(key)\'>\n            <span>Take {{photos[key].title}} Photo</span>\n          </button>\n          <button ng-if=\'photos[key].photo_src\' class=\'button button-block button-stable icon ion-refresh\' ng-click=\'takePhoto(key)\'>\n            <span ng-if=\'photos[key].photo_src\'>Retake</span>\n          </button>\n        </div>\n      </div>\n    </div>\n    <div class="row">\n      <div class="col">\n        <p>Barcode Scanned: {{barcode}}</p>\n        <small>By submitting photos, you accept the <a ng-click=\'goToPrivacyPolicy()\'>Nutritionix Privacy Policy</a></small>\n      </div>\n    </div>\n    <div class=\'row\'>\n      <div class=\'col\'>\n        <button class="button button-block button-stable" ng-disabled=\'!canUpload\' ng-click=\'upload()\'>\n          Submit Photos to Nutritionix\n        </button>\n      </div>\n    </div>\n  </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/users.html', '<ion-view>\n    <ion-header-bar align-title="center" class="bar-balanced">\n    <button class="button button-icon icon ion-navicon" menu-toggle="left"></button>\n        <h1 class="title">User Profiles</h1>\n    </ion-header-bar>\n    <ion-content>\n      <div class="list">\n        <ion-item ng-repeat="user in usersObj" style="z-index: 9999;" ng-click="changeActiveUser(user)">\n          {{user.first_name}} {{user.last_name}}\n        </ion-item>\n      </div>\n    </ion-content>\n</ion-view>\n\n');
  $templateCache.put('templates/views/viewClient.html', '<ion-view>\n  <ion-header-bar align-title="center" class="bar-balanced">\n    <button class="button button-icon icon ion-ios-arrow-left" ng-click="goBack()"></button>\n    <h1 class="title">View Client</h1>\n  </ion-header-bar>\n  <ion-content class="has-header">\n    <div class="padding" ng-if="!!data && !!data.client" style="position: relative;">\n      <p style="font-size:16px; font-weight: bold;margin-bottom:10px;">{{(data.client.last_name ? data.client.last_name+\', \' : \'\')}}{{data.client.first_name}}&nbsp;&nbsp;{{data.age}}{{!!data.age ? \', \' : \'\'}}{{data.client.gender === \'male\' ? \'M\' : \'F\'}}</p>\n      <i class="fa fa-envelope-o" style="    position: absolute;top: 10px;right: 10px;width: 40px;height: 40px;color: #444;border: 3px solid;font-size: 19px;border-radius: 50%;text-align: center;line-height: 34px;" ng-if="data.client && data.client.email" ng-click="emailToClient()"></i>\n      <p>Days tracked in {{data.currentMonth | amDateFormat : \'MMMM\'}}: {{data.totals.length}}</p>\n    </div>\n    <div style="display: flex;justify-content: flex-end; padding:0 15px;">\n      <div class="faded-month" style="display: flex; color:#bbb;" ng-click="changeMonth(-1)">\n        {{data.prevMonth | amDateFormat : \'MMM\'}}\n        <i class="fa fa-angle-left" style="text-align:center;font-size:20px;width:40px;color:#888;"></i>\n      </div>\n      {{data.currentMonth | amDateFormat : \'MMMM\'}}\n      <div class="nextMonth" style="display: flex; color:#bbb;" ng-click="changeMonth(1)">\n        <i class="fa fa-angle-right" style="text-align:center;font-size:20px;width:40px;color:#888;"></i>\n        {{data.nextMonth | amDateFormat : \'MMM\'}}\n      </div>\n    </div>\n    <ion-item ng-if="!data || !data.totals" class="text-center" style="margin-top:20px;text-align: center;">\n      Loading\n    </ion-item>\n    <ion-list ng-if="!!data && !!data.totals">\n      <ion-item ng-if="data.showPreloader" class="text-center" style="margin-top:20px;text-align: center;">\n        Loading\n      </ion-item>\n      <ion-item ng-if="!data.totals.length && !data.showPreloader" class="text-center" style="margin-top:20px;">\n        No logged data this month.\n      </ion-item>\n      <ion-item ng-repeat="dayTotals in data.totals" ng-if="data.totals.length" style="padding:0;border:0 none;" ng-click="goToDayLog(dayTotals.date)">\n        <p style="color:#000;padding:15px 10px 0;background:#fff;" > {{dayTotals.date | amDateFormat : \'dddd\'}}, {{dayTotals.date | amDateFormat : \'MMMM Do\'}} {{dayTotals.date | amDateFormat : \'YYYY\'}}</p>\n        <div style="position: relative;padding:0 30px 0 0;border:0 none;border-top:1px solid #ddd;">\n          <div class="day-title">\n            <div style="padding-top:10px" class="row">\n              <span class="col meter-calories-consumed">\n                <span class="cal-intake"> {{dayTotals.total_cal | caloriesFilter | number: 0}}</span>\n                <span class="intake-label"> cal intake </span>\n              </span>\n              <span class="col meter-calories-burned">\n                <span class="cal-intake"> {{dayTotals.total_cal_burned | caloriesFilter | number: 0}} </span>\n                <span class="intake-label"> cal burned </span>\n              </span>\n              <span class="col meter-calories-remaining">\n                <span class="intake-label"> {{ (dayTotals.daily_kcal_limit + dayTotals.total_cal_burned - dayTotals.total_cal) < 0 ? \'over\' : \'remaining\' }} </span>\n                <span class="cal-intake"> {{\n                  (dayTotals.daily_kcal_limit > dayTotals.total_cal - dayTotals.total_cal_burned ?\n                  dayTotals.daily_kcal_limit - dayTotals.total_cal + dayTotals.total_cal_burned :\n                  dayTotals.total_cal - dayTotals.total_cal_burned - dayTotals.daily_kcal_limit) | number: 0\n                }} </span>\n              </span>\n            </div>\n            <div class="meter">\n              <span class="progress-bar" style="width: {{ !dayTotals.total_cal ? 0 : ((((dayTotals.total_cal - dayTotals.total_cal_burned) < dayTotals.daily_kcal_limit ) ? (dayTotals.total_cal / (dayTotals.daily_kcal_limit + dayTotals.total_cal_burned) ).toFixed(2) : 1) * 100)}}%; transition: width 0.90s ease-in, background-color 0.90s ease-in; background-color:{{barColor(dayTotals.total_cal - dayTotals.total_cal_burned, dayTotals.daily_kcal_limit)}}"></span>\n            </div>\n          </div>\n          <div class="card foodlog-card" style="margin:0;">\n            <div class="row macronutrients" style="margin:0;">\n              <div class="col protein">\n                {{(dayTotals.totalProtein | number: 0) + \'g\'}}\n                <span>Protein</span>\n              </div>\n              <div class="col carb">\n                {{(dayTotals.totalCarbohydrate | number: 0) + \'g\'}}\n                <span>Carb</span>\n              </div>\n              <div class="col fat">\n                {{(dayTotals.totalFat | number: 0) + \'g\'}}\n                <span>Fat</span>\n              </div>\n            </div>\n          </div>\n          <div style="position: absolute;right:0;bottom: 1px;top: 0;width: 31px;display:flex;align-items: center;justify-content: center;background:#eee;border-left: 1px solid #ddd;border-bottom:1px solid #ddd;font-size:30px;color:#888;">\n            <i class="fa fa-angle-right"></i>\n          </div>\n        </div>\n      </ion-item>\n    </ion-list>\n  </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/viewClientDayLog.html', '<ion-nav-view nav-transition="none" hide-back-button="true">\n\n  <ion-header-bar align-title="center" class="bar-balanced">\n    <button class="button button-icon icon ion-ios-arrow-left" on-touch="goBack()"></button>\n    <div class="center-text">\n      <h1 class="title tab-title">Client Daily Log</h1>\n    </div>\n    <i class="fa fa-home shopping-basket-icon" aria-hidden="true" ui-sref="app.foodlog"></i>\n  </ion-header-bar>\n\n  <ion-content>\n    <!-- <ion-refresher\n      spinner="bubbles"\n      on-refresh="doRefresh()"\n      >\n    </ion-refresher> -->\n\n    <div style="position: relative;">\n      <div ng-if="isNewLogLoading" class="foodlog-preloader">\n        <ion-spinner icon="ios" class="spinner-balanced"></ion-spinner>\n      </div>\n\n      <div class="day-title" on-swipe-left="changeOnDays(1)" on-swipe-right="changeOnDays(-1)">\n        <div class="day-controls" style="padding:7px 0;">\n          <div on-touch="changeOnDays(-1)" class="change-day prev">\n            <i class="icon ion-chevron-left"></i>\n          </div>\n          <p style="margin:0;text-align: center;line-height: 1.2;">{{user.first_name}}{{(!!user.last_name ? \' \'+user.last_name : \'\')}}</p>\n          <p style="padding:0;font-size: 14px;line-height: 1.2;" class="food-day" ng-click="goToTotal(foodLog[selected_day.date])"> {{getCurrentDayName()}}, <span class="food-date"> {{selected_day.date | amParse : \'ddd, MM/DD/YY\' | amDateFormat : \'MM/DD\'}} </span> </p>\n          <div on-touch="changeOnDays(1)" class="change-day next">\n            <i class="icon ion-chevron-right"></i>\n          </div>\n        </div>\n\n        <div style="padding-top:10px" class="row" ng-click="goToTotal(foodLog[selected_day.date])">\n          <span class="col meter-calories-consumed">\n            <span class="cal-intake"> {{clientTotals[selected_day.date].total_cal | caloriesFilter | number: 0}}</span>\n            <span class="intake-label"> cal intake </span>\n          </span>\n          <span class="col meter-calories-burned">\n            <span class="cal-intake"> {{clientTotals[selected_day.date].total_cal_burned || 0 | caloriesFilter | number: 0}} </span>\n            <span class="intake-label"> cal burned </span>\n          </span>\n          <span class="col meter-calories-remaining">\n            <span class="intake-label"> {{ (clientTotals[selected_day.date].daily_kcal_limit - clientTotals[selected_day.date].total_cal + clientTotals[selected_day.date].total_cal_burned) < 0 ? \'over\' : \'remaining\' }} </span>\n            <span class="cal-intake"> {{\n              (clientTotals[selected_day.date].daily_kcal_limit > clientTotals[selected_day.date].total_cal - clientTotals[selected_day.date].total_cal_burned ?\n              clientTotals[selected_day.date].daily_kcal_limit - clientTotals[selected_day.date].total_cal + clientTotals[selected_day.date].total_cal_burned :\n              clientTotals[selected_day.date].total_cal - clientTotals[selected_day.date].total_cal_burned - clientTotals[selected_day.date].daily_kcal_limit) | number: 0\n            }} </span>\n          </span>\n        </div>\n        <div class="meter">\n          <span class="progress-bar" style="width: {{ !clientTotals[selected_day.date].total_cal ? 0 : ((((clientTotals[selected_day.date].total_cal - clientTotals[selected_day.date].total_cal_burned) < clientTotals[selected_day.date].daily_kcal_limit ) ? (clientTotals[selected_day.date].total_cal / (clientTotals[selected_day.date].daily_kcal_limit + clientTotals[selected_day.date].total_cal_burned) ).toFixed(2) : 1) * 100)}}%; transition: width 0.90s ease-in, background-color 0.90s ease-in; background-color:{{barColor(clientTotals[selected_day.date].total_cal - clientTotals[selected_day.date].total_cal_burned, clientTotals[selected_day.date].daily_kcal_limit)}}"></span>\n        </div>\n      </div>\n\n      <div class="card foodlog-card">\n        <div  ng-click="goToTotal(foodLog[selected_day.date])" class="row macronutrients">\n          <div class="col protein">\n            {{selected_day.log.totalProtein | number: 0}}g\n            <span>Protein</span>\n          </div>\n          <div class="col carb">\n            {{selected_day.log.totalCarbohydrate | number: 0}}g\n            <span>Carb</span>\n          </div>\n          <div class="col fat">\n            {{selected_day.log.totalFat | number: 0}}g\n            <span>Fat</span>\n          </div>\n        </div>\n\n        <ion-list>\n          <ion-item class="item item-divider food-log-no-ops">\n            <div style="display:flex;" ng-click="goToTotal(foodLog[selected_day.date], 1)">\n              <div style="min-width:30%;align-self:center;">\n                Breakfast\n              </div>\n              <div style="min-width:70%; text-align:right;">\n                <i class="icon ion-information-circled" style="color:#aaa; margin-right:10px;"></i>\n                <span class="item-note">{{selected_day.log.breakfast_calories | caloriesFilter | number: 0}}</span>\n              </div>\n            </div>\n          </ion-item>\n\n          <span ng-if="!selected_day.log.breakfast.length" class="no-foods-logged">No foods logged yet.</span>\n\n          <ion-item ng-if="selected_day.log.breakfast.length" ng-repeat="food in selected_day.log.breakfast" ng-click="goToFood(food)" class="item item-button-right foodlog-food-item">\n            <div class="item-content">\n              <div class="foodlog-item-container">\n                <div class="foodlog-image">\n                  <img ng-src="{{food.photo.thumb}}" alt="">\n                </div>\n                <div class="foodname_measure_container" style="width:calc(100% - 135px);margin: 0;">\n                  <div class="foodlog-food-name">{{food.food_name | cut:true:cut:\'...\' | ucfirst}}</div>\n                  <div class=\'foodlog-qty-measure\'>\n                    <span>\n                      <span ng-if="food.brand_name">{{food.brand_name}},</span>\n                      {{food.serving_qty || 1 }} {{food.serving_unit  | cut:true:32:\'...\' || food.food_name}}\n                    </span>\n                  </div>\n                </div>\n                <div class="foodlog-custom-photo" ng-if="!!food.photo && food.photo.is_user_uploaded">\n                  <i class="fa fa-camera"></i>\n                </div>\n                <div class="foodlog-calories" style="width:40px; text-align:right;">\n                  <span> {{food.nf_calories | caloriesFilter | number: 0}} </span>\n                </div>\n                  <span class="chevron-right">\n                    <i class="icon ion-chevron-right"></i>\n                  </span>\n              </div>\n            </div>\n          </ion-item>\n\n          <div ng-if="selected_day.log.am_snack.length">\n            <ion-item class="item item-divider food-log-no-ops">\n              <div style="display:flex;" ng-click="goToTotal(foodLog[selected_day.date], 2)">\n                <div style="min-width:30%;align-self:center;">\n                  AM Snack\n                </div>\n                <div style="min-width:70%; text-align:right;">\n                  <i class="icon ion-information-circled" style="color:#aaa; margin-right:10px;"></i>\n                  <span class="item-note">{{selected_day.log.am_snack_calories | caloriesFilter | number: 0}}</span>\n                </div>\n              </div>\n            </ion-item>\n            <span ng-if="!selected_day.log.am_snack.length" class="no-foods-logged">No foods logged yet.</span>\n\n            <ion-item ng-if="selected_day.log.am_snack.length" ng-repeat="food in selected_day.log.am_snack" ng-click="goToFood(food)" class="item item-button-right foodlog-food-item">\n              <div class="item-content">\n                <div class="foodlog-item-container">\n                  <div class="foodlog-image">\n                    <img ng-src="{{food.photo.thumb}}" alt="">\n                  </div>\n                  <div class="foodname_measure_container" style="width:calc(100% - 135px);margin: 0;">\n                    <div class="foodlog-food-name">{{food.food_name | cut:true:cut:\'...\' | ucfirst}}</div>\n                    <div class=\'foodlog-qty-measure\'>\n                      <span>\n                        <span ng-if="food.brand_name">{{food.brand_name}},</span>\n                        {{food.serving_qty || 1 }} {{food.serving_unit  | cut:true:32:\'...\' || food.food_name}}\n                      </span>\n                    </div>\n                  </div>\n                  <div class="foodlog-custom-photo" ng-if="!!food.photo && food.photo.is_user_uploaded">\n                <i class="fa fa-camera"></i>\n              </div>\n                  <div class="foodlog-calories" style="width:40px; text-align:right;">\n                    <span> {{food.nf_calories | caloriesFilter | number: 0}} </span>\n                  </div>\n                    <span class="chevron-right">\n                      <i class="icon ion-chevron-right"></i>\n                    </span>\n                </div>\n              </div>\n            </ion-item>\n          </div>\n\n          <ion-item class="item item-divider food-log-no-ops">\n            <div style="display:flex;" ng-click="goToTotal(foodLog[selected_day.date], 3)">\n              <div style="min-width:30%;align-self:center;">\n                Lunch\n              </div>\n              <div style="min-width:70%; text-align:right;">\n                <i class="icon ion-information-circled" style="color:#aaa; margin-right:10px;"></i>\n                <span class="item-note">{{selected_day.log.lunch_calories | caloriesFilter | number: 0}}</span>\n              </div>\n            </div>\n          </ion-item>\n          <span ng-if="!selected_day.log.lunch.length" class="no-foods-logged">No foods logged yet.</span>\n\n          <ion-item ng-if="selected_day.log.lunch.length" ng-repeat="food in selected_day.log.lunch" ng-click="goToFood(food)" class="item item-button-right foodlog-food-item">\n            <div class="item-content">\n              <div class="foodlog-item-container">\n                <div class="foodlog-image">\n                  <img ng-src="{{food.photo.thumb}}" alt="">\n                </div>\n                <div class="foodname_measure_container" style="width:calc(100% - 135px);margin: 0;">\n                  <div class="foodlog-food-name">{{food.food_name | cut:true:cut:\'...\' | ucfirst}}</div>\n                  <div class=\'foodlog-qty-measure\'>\n                    <span>\n                      <span ng-if="food.brand_name">{{food.brand_name}},</span>\n                      {{food.serving_qty || 1 }} {{food.serving_unit  | cut:true:32:\'...\' || food.food_name}}\n                    </span>\n                  </div>\n                </div>\n                <div class="foodlog-custom-photo" ng-if="!!food.photo && food.photo.is_user_uploaded">\n                <i class="fa fa-camera"></i>\n              </div>\n                <div class="foodlog-calories" style="width:40px; text-align:right;">\n                  <span> {{food.nf_calories | caloriesFilter | number: 0}} </span>\n                </div>\n                  <span class="chevron-right">\n                    <i class="icon ion-chevron-right"></i>\n                  </span>\n              </div>\n            </div>\n          </ion-item>\n\n          <div ng-if="selected_day.log.pm_snack.length">\n            <ion-item class="item item-divider food-log-no-ops">\n              <div style="display:flex;" ng-click="goToTotal(foodLog[selected_day.date], 4)">\n                <div style="min-width:30%;align-self:center;">\n                  PM Snack\n                </div>\n                <div style="min-width:70%; text-align:right;">\n                  <i class="icon ion-information-circled" style="color:#aaa; margin-right:10px;"></i>\n                  <span class="item-note">{{selected_day.log.pm_snack_calories | caloriesFilter | number: 0}}</span>\n                </div>\n              </div>\n            </ion-item>\n            <span ng-if="!selected_day.log.pm_snack.length" class="no-foods-logged">No foods logged yet.</span>\n\n            <ion-item ng-if="selected_day.log.pm_snack.length" ng-repeat="food in selected_day.log.pm_snack" ng-click="goToFood(food)" class="item item-button-right foodlog-food-item">\n              <div class="item-content">\n                <div class="foodlog-item-container">\n                  <div class="foodlog-image">\n                    <img ng-src="{{food.photo.thumb}}" alt="">\n                  </div>\n                  <div class="foodname_measure_container" style="width:calc(100% - 135px);margin: 0;">\n                    <div class="foodlog-food-name">{{food.food_name | cut:true:cut:\'...\' | ucfirst}}</div>\n                    <div class=\'foodlog-qty-measure\'>\n                      <span>\n                        <span ng-if="food.brand_name">{{food.brand_name}},</span>\n                        {{food.serving_qty || 1 }} {{food.serving_unit  | cut:true:32:\'...\' || food.food_name}}\n                      </span>\n                    </div>\n                  </div>\n                  <div class="foodlog-custom-photo" ng-if="!!food.photo && food.photo.is_user_uploaded">\n                <i class="fa fa-camera"></i>\n              </div>\n                  <div class="foodlog-calories" style="width:40px; text-align:right;">\n                    <span> {{food.nf_calories | caloriesFilter | number: 0}} </span>\n                  </div>\n                    <span class="chevron-right">\n                      <i class="icon ion-chevron-right"></i>\n                    </span>\n                </div>\n              </div>\n            </ion-item>\n          </div>\n\n          <ion-item class="item item-divider food-log-no-ops">\n            <div style="display:flex;" ng-click="goToTotal(foodLog[selected_day.date], 5)">\n              <div style="min-width:30%;align-self:center;">\n                Dinner\n              </div>\n              <div style="min-width:70%; text-align:right;">\n                <i class="icon ion-information-circled" style="color:#aaa; margin-right:10px;"></i>\n                <span class="item-note">{{selected_day.log.dinner_calories | caloriesFilter | number: 0}}</span>\n              </div>\n            </div>\n          </ion-item>\n          <span ng-if="!selected_day.log.dinner.length" class="no-foods-logged">No foods logged yet.</span>\n\n          <ion-item ng-if="selected_day.log.dinner.length" ng-repeat="food in selected_day.log.dinner" ng-click="goToFood(food)" class="item item-button-right foodlog-food-item">\n            <div class="item-content">\n              <div class="foodlog-item-container">\n                <div class="foodlog-image">\n                  <img ng-src="{{food.photo.thumb}}" alt="">\n                </div>\n                <div class="foodname_measure_container" style="width:calc(100% - 135px);margin: 0;">\n                  <div class="foodlog-food-name">{{food.food_name | cut:true:cut:\'...\' | ucfirst}}</div>\n                  <div class=\'foodlog-qty-measure\'>\n                    <span>\n                      <span ng-if="food.brand_name">{{food.brand_name}},</span>\n                      {{food.serving_qty || 1 }} {{food.serving_unit  | cut:true:32:\'...\' || food.food_name}}\n                    </span>\n                  </div>\n                </div>\n                <div class="foodlog-custom-photo" ng-if="!!food.photo && food.photo.is_user_uploaded">\n                <i class="fa fa-camera"></i>\n              </div>\n                <div class="foodlog-calories" style="width:40px; text-align:right;">\n                  <span> {{food.nf_calories | caloriesFilter | number: 0}} </span>\n                </div>\n                  <span class="chevron-right">\n                    <i class="icon ion-chevron-right"></i>\n                  </span>\n              </div>\n            </div>\n          </ion-item>\n\n          <div ng-if="selected_day.log.late_snack.length">\n            <ion-item class="item item-divider food-log-no-ops">\n              <div style="display:flex;" ng-click="goToTotal(foodLog[selected_day.date], 6)">\n                <div style="min-width:30%;align-self:center;">\n                  Late Snack\n                </div>\n                <div style="min-width:70%; text-align:right;">\n                  <i class="icon ion-information-circled" style="color:#aaa; margin-right:10px;"></i>\n                  <span class="item-note">{{selected_day.log.late_snack_calories | caloriesFilter | number: 0}}</span>\n                </div>\n              </div>\n            </ion-item>\n            <span ng-if="!selected_day.log.late_snack.length" class="no-foods-logged">No foods logged yet.</span>\n\n            <ion-item ng-if="selected_day.log.late_snack.length" ng-repeat="food in selected_day.log.late_snack" ng-click="goToFood(food)" class="item item-button-right foodlog-food-item">\n              <div class="item-content">\n                <div class="foodlog-item-container">\n                  <div class="foodlog-image">\n                    <img ng-src="{{food.photo.thumb}}" alt="">\n                  </div>\n                  <div class="foodname_measure_container" style="width:calc(100% - 135px);margin: 0;">\n                    <div class="foodlog-food-name">{{food.food_name | cut:true:cut:\'...\' | ucfirst}}</div>\n                    <div class=\'foodlog-qty-measure\'>\n                      <span>\n                        <span ng-if="food.brand_name">{{food.brand_name}},</span>\n                        {{food.serving_qty || 1 }} {{food.serving_unit  | cut:true:32:\'...\' || food.food_name}}\n                      </span>\n                    </div>\n                  </div>\n                  <div class="foodlog-custom-photo" ng-if="!!food.photo && food.photo.is_user_uploaded">\n                <i class="fa fa-camera"></i>\n              </div>\n                  <div class="foodlog-calories" style="width:40px; text-align:right;">\n                    <span> {{food.nf_calories | caloriesFilter | number: 0}} </span>\n                  </div>\n                  <span class="chevron-right">\n                    <i class="icon ion-chevron-right"></i>\n                  </span>\n                </div>\n              </div>\n            </ion-item>\n          </div>\n\n          <ion-item class="item item-divider food-log-no-ops">\n            Exercise\n          </ion-item>\n          <span ng-if="!exerciseLog[selected_day.date].length" class="no-foods-logged">No exercises logged yet.</span>\n\n          <ion-item ng-if="exerciseLog[selected_day.date].length" ng-repeat="exercise in exerciseLog[selected_day.date]">\n            <div class="foodlog-item-container">\n              <div class="foodlog-image">\n                <img ng-src="{{exercise.photo.thumb}}" alt="">\n              </div>\n              <div class="foodname_measure_container">\n                <div class="foodlog-food-name">{{exercise.name | cut:true:cut:\'...\' | ucfirst}}</div>\n                <div class=\'foodlog-qty-measure\'>\n                  <span ng-if="exercise.name !== \'HealthKit Exercise Total\'">\n                    {{exercise.duration_min}} min\n                  </span>\n                  <span ng-if="exercise.name === \'HealthKit Exercise Total\'">\n                    Daily Total\n                  </span>\n                </div>\n              </div>\n              <div class="foodlog-custom-photo" ng-if="!!food.photo && food.photo.is_user_uploaded">\n                <i class="fa fa-camera"></i>\n              </div>\n              <div class="foodlog-calories">\n                <span> -{{exercise.nf_calories | caloriesFilter | number: 0}} Cal</span>\n              </div>\n            </div>\n          </ion-item>\n\n          <ion-item class="item item-divider food-log-no-ops">\n            Water\n          </ion-item>\n          <ion-item ng-if="!clientTotals[selected_day.date].water_consumed_liter || clientTotals[selected_day.date].water_consumed_liter === 0">\n            <div class="foodlog-weight-container">\n              0\n              {{coach.measure_system ? \'L\' : \'oz\'}}\n            </div>\n          </ion-item>\n          <ion-item ng-if="!!clientTotals[selected_day.date].water_consumed_liter && clientTotals[selected_day.date].water_consumed_liter !== 0">\n            <div class="foodlog-weight-container">\n              {{coach.measure_system ? (clientTotals[selected_day.date].water_consumed_liter | number: 2) : ((clientTotals[selected_day.date].water_consumed_liter * 33.814) | number: 0)}}\n              {{coach.measure_system ? \'L\' : \'oz\'}}\n            </div>\n          </ion-item>\n        </ion-list>\n      </div>\n    </div>\n\n  </ion-content>\n\n</ion-nav-view>\n');
  $templateCache.put('templates/views/auth/completeRegistration.html', '<ion-view>\n  <div class="padding" style="margin-top: 85px">\n    <h3 class="text-center">Finish Setup</h3>\n    <p class="text-center">\n      Finish your account setup\n    </p>\n    <form name="formFields" ng-submit="createAccount()">\n      <div ng-if="!fields.email">\n        <label class="item item-input" ng-class="{\'has-error\': formFields.email.$invalid && !formFields.email.$pristine && formFields.email.$blur}">\n          <span class="input-label">Email</span>\n          <input type="email" class="form-control" name="email" ng-model="registration.email" ng-focus="formFieldsForm.email.$blur = false" ng-blur="formFields.email.$blur = true" placeholder="somebody@example.com" required>\n        </label>\n        <p ng-show="formFields.email.$error.required && !formFields.email.$pristine" class="ng-hide">Email is required</p>\n        <p ng-show="formFields.email.$invalid && !formFields.email.$error.required && formFields.email.$blur" class="ng-hide">This is not a valid email</p>\n      </div>\n\n      <div class=\'text-center\'>\n        <label class="item item-input" ng-class="{\'has-error\': formFields.calorieLimit.$invalid && !formFields.calorieLimit.$pristine}">\n          <span class="input-label">Your daily calorie limit</span>\n          <input type="number" name="calorieLimit" class="form-control text-center" ng-model="registration.daily_kcal" ng-init="registration.daily_kcal=2000"required>\n        </label>\n        <p ng-show="formFields.calorieLimit.$error.required && !formFields.calorieLimit.$pristine" class="ng-hide">Calorie limit value is required</p>\n      </div>\n\n\n    <button type="submit" class="button button-block button-balanced" ng-disabled="formFields.$invalid"> Submit </button>\n    </form>\n  </div>\n</ion-view>\n');
  $templateCache.put('templates/views/auth/login.html', '<ion-view>\n    <ion-content>\n        <div class="padding padding-top-40">\n            <div class="brand">\n                <img src="images/logo.svg" width="150" height="177" alt="Nutritionix">\n                <h1>\n                    Track <i class="fa fa-bar"> </i>\n                </h1>\n                <h4>\n                    Food Tracker by Nutritionix\n                </h4>\n            </div>\n            <div class="buttons-wrap" style="padding-top: 10px;">\n                <p class="padding-bottom-2x" ng-if="showAppleLogin">\n                    <button class="button button-block button-positive" style="background-color:#000;display:flex;min-height: 24px;height:40px;line-height:38px; padding: 0 7px; color:#fff;" ng-click="loginApple()">\n                        <i class="fa fa-apple" style="line-height: 38px; font-size: 18px; padding: 0 5px; position: absolute;"></i>\n                        <span style="margin: 0 auto;">Sign in with Apple</span>\n                    </button>\n                </p>\n\n                <p class="padding-bottom-2x">\n                    <button class="button button-block button-positive" style="background-color:#4267b2;display:flex;min-height: 24px;height:40px;line-height:38px; padding: 0 7px;" ng-click="loginFacebook()">\n                        <svg class="icon" style="height:24px;margin-top:7px;position: absolute;" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 216 216" class="_5h0m" color="#FFFFFF"><path fill="#FFFFFF" d="\n                          M204.1 0H11.9C5.3 0 0 5.3 0 11.9v192.2c0 6.6 5.3 11.9 11.9\n                          11.9h103.5v-83.6H87.2V99.8h28.1v-24c0-27.9 17-43.1 41.9-43.1\n                          11.9 0 22.2.9 25.2 1.3v29.2h-17.3c-13.5 0-16.2 6.4-16.2\n                          15.9v20.8h32.3l-4.2 32.6h-28V216h55c6.6 0 11.9-5.3\n                          11.9-11.9V11.9C216 5.3 210.7 0 204.1 0z"></path></svg> <span style="margin: 0 auto;">Log in With Facebook</span>\n                    </button>\n                </p>\n                <p class="note" style="margin-top: -15px;">\n                    This app does not post to Facebook.\n                </p>\n\n\n                <button class="button button-block button-default" ng-click="goToManualSignIn()">\n                    <i class="icon padding-right"> </i> Login Via Email\n                </button>\n\n                <button class="button button-block button-default" ng-click="goToCreateAccount()">\n                    <i class="icon padding-right"> </i> Create Account\n                </button>\n            </div>\n            <div class="support-data">\n                Need help?<br/>\n                Contact us at <a href="mailto:support@nutritionix.com">support@nutritionix.com</a>.\n            </div>\n        </div>\n    </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/auth/manualLogin.html', '<ion-nav-bar>\n  <ion-nav-buttons side="primary">\n        <button class="button" ng-click="goBack()">\n          <i class="ion-chevron-left"> Back </i>\n        </button>\n   </ion-nav-buttons>\n</ion-nav-bar>\n<ion-nav-view>\n    <ion-view>\n        <ion-content class="padding padding-top-80">\n            <div class="brand">\n                <img src="images/logo.svg" width="125" height="147" alt="Nutritionix">\n                <h1>\n                    Track\n                </h1>\n                <h4>\n                    Food Logging by Nutritionix\n                </h4>\n            </div>\n            <div class="buttons-wrap" style="margin-top: -40px;">\n              <label class="item item-input">\n                 <span class="input-label">Email</span>\n                 <input type="email" ng-model=\'email\' placeholder="Email" autocapitalize="off" autocorrect="off" required="required">\n               </label>\n               <label class="item item-input">\n                 <span class="input-label">Password</span>\n                 <input type="password" ng-model="password" placeholder="Password" autocapitalize="off" autocorrect="off">\n               </label>\n               <div style="text-align: right; " >\n                   <a href="#" onClick="cordova.InAppBrowser.open(\'https://www.nutritionix.com/account/forgot-password\',\'_blank\',\'location=no\');return false;" style="color: #111; font-size: 12px;"> Forgot Password?</a>\n\n               </div>\n              <button class="button button-block button-balanced" ng-click="manualLogin(email, password)">\n                  Login\n              </button>\n               <button class="button button-block button-default" ng-click="goToSignUp()">\n                  Create Account\n              </button>\n            </div>\n        </ion-content>\n    </ion-view>\n</ion-nav-view>\n');
  $templateCache.put('templates/views/auth/signup2.html', '<ion-view>\n    <ion-header-bar align-title="center" class="bar-balanced">\n      <h1 class="title">Signup</h1>\n    </ion-header-bar>\n    <ion-content>\n      <div class="list">\n        <form name="signupForm" novalidate>\n          <div ng-if="!fields.email">\n            <label class="item item-input" ng-class="{\'has-error\': signupForm.email.$invalid && !signupForm.email.$pristine && signupForm.email.$blur}">\n              <span class="input-label">Email</span>\n              <input type="email" class="form-control" name="email" ng-model="signup.email" ng-focus="signupForm.email.$blur = false" ng-blur="signupForm.email.$blur = true" placeholder="somebody@example.com" required>\n            </label>\n            <p style="color:red" ng-show="signupForm.email.$error.required && !signupForm.email.$pristine" class="ng-hide">Email is required</p>\n            <p style="color:red" ng-show="signupForm.email.$invalid && !signupForm.email.$error.required && signupForm.email.$blur" class="ng-hide">This is not a valid email</p>\n          </div>\n        </form>\n        <!--\n        <div class="item">\n          <h2>Choose a unique username</h2>\n          <div class="item-input-inset item-username">\n            <label class="item-input-wrapper">\n              <input type="text" placeholder="Enter Username">\n            </label>\n            <button class="button button-small">\n              Check\n            </button>\n          </div>\n          <p class="message-success">Username available!</p>\n        </div>\n        <label class="item item-input item-select">\n          <div class="input-label">\n            What type of diet you <br> are most interested in?\n          </div>\n          <select>\n            <option>Calorie Counting</option>\n          </select>\n        </label>\n        -->\n        <div class="item item-divider">\n          Optional Settings\n        </div>\n        <div class="item item-text-wrap">\n          <label class="toggle toggle-balance">\n            <input type="checkbox" ng-model="registration.pushNotificationsWeekday">\n            <div class="track">\n              <div class="handle"></div>\n            </div>\n          </label>\n          <h2>\n            Weekday Push Notifications\n          </h2>\n          <p>\n            If enabled, we send a push alert at 9PM on any weekday (M-F) when you forget to log your foods.\n          </p>\n        </div>\n        <div class="item item-text-wrap">\n          <label class="toggle toggle-balance">\n            <input type="checkbox" ng-model="registration.pushNotificationsWeekend">\n            <div class="track">\n              <div class="handle"></div>\n            </div>\n          </label>\n          <h2>\n            Weekend Push Notifications\n          </h2>\n          <p>\n            If enabled, we send a push alert at 9PM on any weekend (Sat-Sun) when you forget to log your foods.\n          </p>\n        </div>\n        <div class="item item-text-wrap">\n          Which nutrition topics do you follow?\n          <div class="button button-block button-positive" ng-click="shopTopicsPopup()">Pick Topics</div> <!-- Need to use some element other than button to avoid form submit on tap -->\n          <div><button style="margin:0 10px 10px 0;" ng-click="topic.is_selected = false" ng-repeat="topic in topics | filter: {\'is_selected\' : true}">{{topic.name}} <i class="fa fa-close"></i></button>\n          </div>\n        </div>\n        <!--\n        <div class="item item-text-wrap">\n          <label class="toggle toggle-balance">\n            <input type="checkbox">\n            <div class="track">\n              <div class="handle"></div>\n            </div>\n          </label>\n          <h2>\n            Location Services\n          </h2>\n          <p>\n            If enabled, we store your current location each time you log a food. Over time, this let\'s us more\n            accurately suggest what foods you are about to log and even create cool visualization on a map!\n          </p>\n        </div>\n        -->\n        <div class="row">\n          <div class="checkbox col-20">\n             <input type="checkbox" ng-model="registration.track" />\n          </div>\n          <div class="col-80">\n             I agree to Nutritionix Track\n             <a on-tap="openTOS()">terms of service</a> and <a href="" on-tap="openPrivacy()"> Privacy Policy </a>\n          </div>\n        </div>\n\n        <div class="row">\n            <div class="checkbox col-20">\n                <input type="checkbox" ng-model="registration.thirteenConfirm" />\n            </div>\n            <div class="col-80" style="display: flex; align-items:center;">\n                I confirm that I am at least 13 years of age.\n            </div>\n        </div>\n\n      </div>\n      <p class="text-center">\n      <button ng-click="createAccount()" ng-disabled="signupForm.$invalid||!registration.track || !registration.thirteenConfirm" class="button button-balanced">\n        Start Logging Foods!\n      </button></p>\n    </ion-content>\n</ion-view>\n');
  $templateCache.put('templates/views/auth/signupViaEmail.html', '<ion-view>\n  <ion-nav-bar>\n    <ion-nav-buttons side="primary">\n          <button class="button" ng-click="goBack()">\n            <i class="ion-chevron-left"> Back </i>\n          </button>\n     </ion-nav-buttons>\n  </ion-nav-bar>\n  <ion-nav-view>\n    <ion-view>\n      <ion-content class="padding padding-top-80">\n          <div class="brand">\n             <img src="images/logo.svg" width="75" height="85" alt="Nutritionix">\n            <h3 class="text-center"><strong>Signup</strong></h1>\n            <h5 class="">\n              Create your free Track Account\n            </h4>\n          </div>\n          <form name="signupForm" ng-submit="createAccount()" novalidate>\n            <div class="list-group">\n                <label class="item item-input" ng-class="{\'has-error\': signupForm.first_name.$invalid && !signupForm.first_name.$pristine}">\n                  <span class="input-label">First Name</span>\n                  <input type="text" class="form-control" name="first_name" ng-model="signup.first_name" placeholder="e.g. Sam" required>\n                </label>\n\n                <p style="color:red" ng-show="signupForm.first_name.$invalid && !signupForm.first_name.$pristine" class="ng-hide">First name is required</p>\n\n                <label class="item item-input" ng-class="{\'has-error\': signupForm.email.$invalid && !signupForm.email.$pristine && signupForm.email.$blur}">\n                  <span class="input-label">Email</span>\n                  <input type="email" class="form-control" name="email" ng-model="signup.email" ng-focus="signupForm.email.$blur = false" ng-blur="signupForm.email.$blur = true" placeholder="somebody@example.com" required>\n                </label>\n                <label class="item item-input" ng-class="{\'has-error\': signupForm.emailConfirm.$invalid && !signupForm.emailConfirm.$pristine && signupForm.emailConfirm.$blur}">\n                  <span class="input-label">Confirm Email</span>\n                  <input type="email" class="form-control" name="emailConfirm" ng-model="emailConfirm" ng-focus="signupForm.emailConfirm.$blur = false" ng-blur="signupForm.emailConfirm.$blur = true" placeholder="somebody@example.com" required>\n                </label>\n\n                <p style="color:red" ng-show="!signupForm.email.$pristine && !signupForm.emailConfirm.$pristine && signupForm.emailConfirm.$blur && signup.email !== emailConfirm" class="ng-hide">Email address doesn\'t match</p>\n                <p style="color:red" ng-show="signupForm.email.$error.required && !signupForm.email.$pristine" class="ng-hide">Email is required</p>\n                <p style="color:red" ng-show="signupForm.email.$invalid && !signupForm.email.$error.required && signupForm.email.$blur" class="ng-hide">This is not a valid email</p>\n\n                <label class="item item-input" ng-class="{\'has-error\': signupForm.password.$invalid && !signupForm.password.$pristine && signupForm.password.$blur}">\n                  <span class="input-label">Password</span>\n                  <input type="password" class="form-control" name="password" ng-model="signup.password" ng-focus="signupForm.password.$blur = false" ng-blur="signupForm.password.$blur = true" placeholder="Password" ng-minlength="6"required>\n                </label>\n\n                <label class="item item-input">\n                  <span class="input-label">Country</span>\n                  <input ion-autocomplete type="text" readonly="readonly" class="ion-autocomplete" autocomplete="on" ng-model="location.selected" items-method="filterCountries(query)" placeholder="Select your location" max-selected-items="1" item-view-value-key="official_name_en" required/>\n                </label>\n\n                <div class="row">\n                    <div class="checkbox col-20">\n                        <input type="checkbox" ng-model="registration.track" />\n                    </div>\n                    <div class="col-80">\n                        I agree to Nutritionix Track\n                        <a on-tap="openTOS()">terms of service</a> and <a href="" on-tap="openPrivacy()"> Privacy Policy </a>\n                    </div>\n                </div>\n                <div class="row">\n                    <div class="checkbox col-20">\n                        <input type="checkbox" ng-model="registration.thirteenConfirm" />\n                    </div>\n                    <div class="col-80" style="display: flex; align-items:center;">\n                        I confirm that I am at least 13 years of age.\n                    </div>\n                </div>\n                <p style="color:red" ng-show="signupForm.password.$error.required && !signupForm.password.$pristine" class="ng-hide">Password is required</p>\n                <p style="color:red" ng-show="signupForm.password.$invalid && !signupForm.password.$error.required && signupForm.password.$blur" class="ng-hide"> Password must be a minimum of 6 characters</p>\n\n              <button type="submit" class="button button-block button-balanced" ng-disabled="signupForm.$invalid || !registration.track || !registration.thirteenConfirm || signup.email !== emailConfirm">Create Account</button>\n\n            </div>\n          </form>\n      </ion-content>\n    </ion-view>\n  </ion-nav-view>\n\n</ion-view>\n\n');
  $templateCache.put('templates/views/autocomplete/brands.html', '<!-- <div class="ion-autocomplete-container \' + ionAutocompleteController.randomCssClass + \' modal" style="display: none;">\n<div class="bar bar-header item-input-inset">\n<label class="item-input-wrapper">\n<i class="icon ion-search placeholder-icon"></i>,\n<input type="search" id="ion-autocomplete-search" class="ion-autocomplete-search" ng-model="viewModel.searchQuery" ng-model-options="viewModel.ngModelOptions" placeholder="{{viewModel.placeholder}}"/>\n</label>\n<div class="ion-autocomplete-loading-icon" ng-if="viewModel.showLoadingIcon && viewModel.loadingIcon"><ion-spinner icon="{{viewModel.loadingIcon}}"></ion-pinner></div>\n<button class="ion-autocomplete-cancel button button-clear" ng-click="viewModel.cancelClick()">{{viewModel.cancelLabel}}</button>\n</div>\n<ion-content class="has-header" on-touch="viewModel.lostFocus()">\n<ion-list>\n<ion-item class="item-divider" ng-show="viewModel.selectedItems.length > 0">{{viewModel.selectedItemsLabel}}</ion-item>\n<ion-item ng-repeat="selectedItem in viewModel.selectedItems track by $index" class="item-icon-left item-icon-right item-text-wrap">\n<i class="icon ion-checkmark"></i>\n{{viewModel.getItemValue(selectedItem, viewModel.itemViewValueKey)}}\n<i class="icon ion-trash-a" style="cursor:pointer" ng-click="viewModel.removeItem($index)"></i>\n</ion-item>\n<ion-item class="item-divider" ng-show="viewModel.searchItems.length > 0">{{viewModel.selectItemsLabel}}</ion-item>\n<ion-item collection-repeat="item in viewModel.searchItems" item-height="48px" item-width="100%" ng-click="viewModel.selectItem(item)" class="item-text-wrap">\n{{viewModel.getItemValue(item, viewModel.itemViewValueKey)}}\n<div class="">{{item.fields.nf_serving_size_qty}} {{item.fields.nf_serving_size_unit}}</div>\n</ion-item>\n</ion-list>\n</ion-content>\n</div>\n -->\n\n<div> {{templateData.testData}} </div>\n');
  $templateCache.put('templates/views/autocomplete/items.html', '');
  $templateCache.put('templates/views/directives/addFoodTabs.html', '  <div class="tabs-striped tabs-top tabs-color-balanced tabs-color-light">\n    <div class="tabs" wt-step="4-2">\n      <a class="tab-item large-tab-title" ng-class="smartClass" nav-transition="none"  ui-sref="app.addfoodsmart">\n        Freeform\n      </a>\n      <a class="tab-item large-tab-title" ng-class="restaurantClass" nav-transition="none" ui-sref="app.restaurants">\n        Restaurants\n      </a>\n      <a class="tab-item large-tab-title" ng-class="groceryClass" nav-transition="none" ui-sref="app.grocery">\n        Grocery\n      </a>\n      <a class="tab-item large-tab-title" ng-class="historyClass" nav-transition="none" ui-sref="app.history">\n        History\n      </a>\n    </div>\n  </div>\n');
  $templateCache.put('templates/views/directives/barcodeScanner.html', '<button class="button button-icon icon fa fa-barcode" style="color:black" ng-click="scanBarcode($parent.logging.meal_type)"> </button>\n');
  $templateCache.put('templates/views/directives/footer.html', '<ion-tabs class="tabs-icon-top tabs-dark" delegate-handle="test-handle">\n\n  <ion-tab title="Dashboard" ui-sref="app.foodlog" class="track-tab" icon="fa fa-home">\n  </ion-tab>\n\n  <ion-tab title="Stats" ui-sref="app.stats" class="track-tab" icon="fa fa-bar-chart">\n  </ion-tab>\n\n  <ion-tab wt-step="0-4" title="Track" ui-sref="app.addfoodsmart" class="main-tab" icon="fa fa-plus">\n  </ion-tab>\n\n  <ion-tab title="Suggested" ng-if="isAndroid" ui-sref="app.productRecommendations" class="track-tab" icon="fa fa-custom-recommended-badge">\n  </ion-tab>\n  <ion-tab title="Recipes" ng-if="!isAndroid" ui-sref="app.myRecipes2" class="track-tab" icon="fa fa-list">\n  </ion-tab>\n\n  <ion-tab title="Preferences" ng-if="isAndroid !== undefined" ui-sref="app.preferences" class="track-tab" icon="fa fa-gear">\n  </ion-tab>\n\n  <ion-tab title="Recipes" ng-if="isAndroid" ui-sref="app.myRecipes2" class="track-tab" icon="fa fa-list" hidden="true">\n  </ion-tab><!-- hidden tab for proper footer tabs highlighting -->\n\n</ion-tabs>');
  $templateCache.put('templates/views/directives/header.html', '<ion-header-bar align-title="center" class="bar-balanced has-tabs-top">\n  <button class="button button-icon icon universal-header-left-button" ng-class="{\'ion-ios-arrow-left\': (showCloseAutocomplete || showBack), \'ion-navicon\': (!showCloseAutocomplete && !showBack)}" on-tap="universalHeaderLeftButton()"></button>\n  <div class="center-text">\n\n    <div class="searchWrapper">\n      <form ng-submit="hideKeyboard()">\n\n      <input type="text" wt-step="0-1" id="autocompleteSearch" class="header-search-bar" placeholder="Search foods to log" autocomplete="off" autocorrect="on" autocapitalize="off" spellcheck="false" ng-model="data.search" ng-change="search()" ng-model-options="{ debounce: 350 }" ng-focus="showDropdown()" ng-class="{\'searchField-android\': currentPlatform == \'android\'}" />\n\n      </form>\n      <barcode-scanner wt-step="0-2" ng-if="$root.basketLog || !showAutocomplete" class="barcode-scanner"> </barcode-scanner>\n      <button class="fa fa-times clear-search" ng-if="showAutocomplete && !$root.basketLog" aria-hidden="true" on-touch="hideDropdown()"></button>\n    </div>\n\n  </div>\n  <i class="fa fa-shopping-basket shopping-basket-icon" aria-hidden="true" on-touch="goToReviewFoods()" wt-step="0-3"></i>\n  <div on-touch="goToReviewFoods()" ng-if="cartNumber !== 0" class="numberCircle">{{cartNumber}}</div>\n  </div>\n</ion-header-bar>\n\n<ion-subheader class="bar bar-subheader has-autocomplete-tabs" style="padding:0; height: auto;" ng-if="data.search.length">\n  <div class="autocomplete-tabs">\n    <a class="autocomplete-tab" ng-click="switchFilter(0)" ng-class="{\'active\' : !selectedFilter}">\n      All\n    </a>\n    <a class="autocomplete-tab" ng-click="switchFilter(\'users_foods\')" ng-class="{\'active\' : selectedFilter == \'users_foods\'}">\n      Your foods\n    </a>\n    <a class="autocomplete-tab" ng-click="switchFilter(\'Common\')" ng-class="{\'active\' : selectedFilter == \'Common\'}">\n      Common\n    </a>\n    <a class="autocomplete-tab" ng-click="switchFilter(\'Branded\')" ng-class="{\'active\' : selectedFilter == \'Branded\'}">\n      Branded\n    </a>\n    <!-- <a class="autocomplete-tab" ng-click="switchFilter(\'Freeform\')" ng-class="{\'active\' : selectedFilter == \'Freeform\'}">\n      Freeform\n    </a> -->\n  </div>\n</ion-subheader>\n\n<ion-content delegate-handle="autocompleteContent" class="has-header header-droprown ng-hide" on-drag="hideKeyboard()" has-bouncing="false" ng-show="showAutocomplete" ng-class="{\'has-subheader\': data.search.length}">\n  <div ng-if="$root.noInternet" class="item text-center" style="padding-top:45px; padding-bottom:25px;">\n    <p>You must connect to the internet to use this feature</p>\n  </div>\n\n  <div ng-if="!$root.noInternet">\n    <div ng-if="loading" class="search-results-preloader">\n\n      <ion-spinner icon="ios" class="spinner-balanced"></ion-spinner>\n    </div>\n\n    <div ng-if="showHint && showAutocomplete" class="search-tip">\n      <i class="fa fa-arrow-up" aria-hidden="true"></i>\n      <p> Use the search box above to search for foods to add to your log. </p>\n    </div>\n\n    <div ng-if="!showHint">\n      <ion-list class="list-autocomplete">\n        <ion-item class="item-divider" ng-if="data.suggested.length">\n          Foods eaten {{mealPrefix}} {{hourNow}}\n        </ion-item>\n        <ion-item ng-if="data.suggested.length" ng-repeat="item in data.suggested" ng-click="addSuggestedFood(item)">\n          <div class="foodlog-item-container">\n            <div ng-if="item.photo.thumb" class="foodlog-image">\n              <img ng-src="{{item.photo.thumb}}"" alt="">\n            </div>\n            <div ng-if="!item.photo.thumb" class="foodlog-image">\n              <img src="images/gray_nix_apple_small.png" alt="">\n            </div>\n            <div class="foodname_measure_container">\n              <div class="foodlog-food-name">{{item.food_name | cut:true:cut:\'...\' | ucfirst}}</div>\n              <div class=\'foodlog-qty-measure\'>\n                <span> <span ng-if="item.brand_name">{{item.brand_name}}, </span>{{item.serving_qty || 1 }} {{item.serving_unit | cut:true:32:\'...\' || item.food_name}}</span>\n              </div>\n            </div>\n            <div class="foodlog-calories with-label">\n              <span> {{item.nf_calories | caloriesFilter | number: 0}} </span>\n              <span class="calories-label"> cal </span>\n            </div>\n          </div>\n        </ion-item>\n        <ion-item class="item-divider" ng-if="data.search.length && boostFreeform && (!selectedFilter || selectedFilter == \'Freeform\')">\n          Freeform\n        </ion-item>\n        <ion-item ng-if="data.search.length && boostFreeform && (!selectedFilter || selectedFilter == \'Freeform\')" ng-click="addCommonFood(data.search, true)">\n          <div class="foodlog-item-container" style="display: flex;">\n            <div style="line-height: 35px"> {{data.search}} </div>\n            <div style="display: inline-block; position:absolute; top:50%; transform:translateY(-50%); -webkit-transform:translateY(-50%); right: 6px;color: #d5d5d2; font-weight: 100!important; text-transform: uppercase;margin-top: -1px;">\n              <i class="icon ion-chevron-right" style="font-size:20px; vertical-align: middle;"></i>\n            </div>\n          </div>\n        </ion-item>\n        <ion-item class="item-divider" ng-if="data.instant.self.length && (!selectedFilter || selectedFilter == \'users_foods\')">\n          History\n        </ion-item>\n        <ion-item ng-if="data.instant.self.length && (!selectedFilter || selectedFilter == \'users_foods\')" ng-repeat="item in data.instant.self" ng-click="addMyFood(item)">\n          <div class="foodlog-item-container">\n            <div ng-if="item.photo.thumb" class="foodlog-image">\n              <img ng-src="{{item.photo.thumb}}" alt="">\n            </div>\n            <div ng-if="!item.photo.thumb" class="foodlog-image">\n              <img src="images/gray_nix_apple_small.png" alt="">\n            </div>\n            <div class="foodname_measure_container">\n              <div class="foodlog-food-name" ng-bind-html="item.food_name | highlight:data.search">{{item.food_name | cut:true:cut:\'...\' | ucfirst}}</div>\n              <div class=\'foodlog-qty-measure\'>\n                <span> <span ng-if="item.brand_name ">{{item.brand_name}}, </span>{{item.serving_qty || 1 }} {{item.serving_unit | cut:true:32:\'...\' || item.food_name}}</span>\n              </div>\n            </div>\n            <div class="foodlog-calories with-label">\n              <span> {{item.nf_calories | caloriesFilter | number: 0}} </span>\n              <span class="calories-label"> cal </span>\n            </div>\n          </div>\n        </ion-item>\n\n        <ion-item class="item-divider" ng-if="(filteredCustomFoods.length || filteredRecipes.length) && data.search.length && (!selectedFilter || selectedFilter == \'users_foods\')">\n          Your foods\n        </ion-item>\n        <ion-item ng-if="data.customFoods.length && data.search.length && (!selectedFilter || selectedFilter == \'users_foods\')" ng-repeat="item in filteredCustomFoods = (data.customFoods | filter:{food_name: data.search}) | limitTo:3+(autocompleteView.additionToLimit/2) " ng-click="addCustomFood(item)">\n          <div class="foodlog-item-container">\n            <div ng-if="item.photo.thumb" class="foodlog-image">\n              <img ng-src="{{item.photo.thumb}}" alt="">\n            </div>\n            <div ng-if="!item.photo.thumb" class="foodlog-image">\n              <img src="images/gray_nix_apple_small.png" alt="">\n            </div>\n            <div class="foodname_measure_container">\n              <div class="foodlog-food-name" ng-bind-html="item.food_name | highlight:data.search">{{item.food_name | cut:true:cut:\'...\' | ucfirst}}</div>\n              <div class=\'foodlog-qty-measure\'>\n                <span> <span ng-if="item.brand_name ">{{item.brand_name}}, </span>1 {{item.serving_unit | cut:true:32:\'...\' || item.food_name}}</span>\n              </div>\n            </div>\n            <div class="foodlog-calories with-label">\n              <span> {{item.nf_calories/item.serving_qty | caloriesFilter | number: 0}} </span>\n              <span class="calories-label"> cal </span>\n            </div>\n          </div>\n        </ion-item>\n        <ion-item ng-if="data.recipes.length && data.search.length && (!selectedFilter || selectedFilter == \'users_foods\')" ng-repeat="item in filteredRecipes = (data.recipes | filter:{name: data.search}) | limitTo:3+(autocompleteView.additionToLimit/2)" ng-click="addRecipe(item)">\n          <div class="foodlog-item-container">\n            <div ng-if="item.photo.thumb" class="foodlog-image">\n              <img ng-src="{{item.photo.thumb}}" alt="">\n            </div>\n            <div ng-if="!item.photo.thumb" class="foodlog-image">\n              <img src="images/gray_nix_apple_small.png" alt="">\n            </div>\n            <div class="foodname_measure_container">\n              <div class="foodlog-food-name" ng-bind-html="item.name | highlight:data.search">{{item.name | cut:true:cut:\'...\' | ucfirst}}</div>\n              <div class=\'foodlog-qty-measure\'>\n                <span> <span ng-if="item.brand_name ">{{item.brand_name}}, </span>1 {{item.serving_unit | cut:true:32:\'...\' || item.name}}</span>\n              </div>\n            </div>\n            <div class="foodlog-calories with-label">\n              <span> {{(item.full_nutrients | nutrient: 208: \'value\')/item.serving_qty | number: 0}} </span>\n              <span class="calories-label"> cal </span>\n            </div>\n          </div>\n        </ion-item>\n        <ion-item class="item-divider" ng-if="data.instant.common.length && (!selectedFilter || selectedFilter == \'Common\')">\n          Common Foods\n        </ion-item>\n        <ion-item ng-if="data.instant.common.length && (!selectedFilter || selectedFilter == \'Common\')" ng-repeat="item in data.instant.common | limitTo:autocompleteView.commonLimit+autocompleteView.additionToLimit" ng-click="addCommonFood(item.food_name, false)">\n          <div class="foodlog-item-container" style="display:flex;">\n            <div ng-if="item.photo.thumb" class="foodlog-image">\n              <img ng-src="{{item.photo.thumb}}" alt="">\n            </div>\n            <div ng-if="!item.photo.thumb" class="foodlog-image">\n              <img src="images/gray_nix_apple_small.png" alt="">\n            </div>\n            <div style="padding-top:4px;white-space: normal;padding-right:60px;" ng-bind-html="item.food_name | ucfirst | highlight:data.search">{{item.food_name}}</div>\n            <div style="display: inline-block; position:absolute; top:50%; transform:translateY(-50%); -webkit-transform:translateY(-50%); right: 6px;color: #d5d5d2; font-weight: 100!important; text-transform: uppercase;margin-top: -1px;">\n              <i class="icon ion-chevron-right" style="font-size:20px; vertical-align: middle;"></i>\n            </div>\n          </div>\n        </ion-item>\n        <ion-item class="item-divider" ng-if="data.instant.branded.length && (!selectedFilter || selectedFilter == \'Branded\')">\n          Branded Foods\n        </ion-item>\n        <ion-item ng-if="data.instant.branded.length && (!selectedFilter || selectedFilter == \'Branded\')" ng-repeat="item in data.instant.branded | limitTo:autocompleteView.brandedLimit+autocompleteView.additionToLimit" ng-click="addBrandedFood(item)">\n          <div class="foodlog-item-container">\n            <div ng-if="item.photo.thumb" class="foodlog-image">\n              <img ng-src="{{item.photo.thumb}}" alt="">\n            </div>\n            <div ng-if="!item.photo.thumb" class="foodlog-image">\n              <img src="images/gray_nix_apple_small.png" alt="">\n            </div>\n            <div class="foodname_measure_container">\n              <div class="foodlog-food-name" ng-bind-html="item.food_name | highlight:data.search">{{item.food_name | cut:true:cut:\'...\' | ucfirst}}</div>\n              <div class=\'foodlog-qty-measure\'>\n                <span> <span ng-if="item.brand_name">{{item.brand_name}}, </span>{{item.serving_qty || 1 }} {{item.serving_unit | cut:true:32:\'...\' || item.food_name}}</span>\n              </div>\n            </div>\n            <div class="foodlog-calories with-label">\n              <span> {{item.nf_calories | caloriesFilter | number: 0}} </span>\n              <span class="calories-label"> cal </span>\n            </div>\n          </div>\n        </ion-item>\n        <ion-item ng-if="data.instant.branded.length && showFullBranded && (!selectedFilter || selectedFilter == \'Branded\')" ng-repeat="item in data.instant.branded | limitTo: autocompleteView.brandedLimit-20" ng-click="addBrandedFood(item)">\n          <div class="foodlog-item-container">\n            <div ng-if="item.photo.thumb" class="foodlog-image">\n              <img ng-src="{{item.photo.thumb}}" alt="">\n            </div>\n            <div ng-if="!item.photo.thumb" class="foodlog-image">\n              <img src="images/gray_nix_apple_small.png" alt="">\n            </div>\n            <div class="foodname_measure_container">\n              <div class="foodlog-food-name" ng-bind-html="item.food_name | highlight:data.search">{{item.food_name | cut:true:cut:\'...\' | ucfirst}}</div>\n              <div class=\'foodlog-qty-measure\'>\n                <span> <span ng-if="item.brand_name">{{item.brand_name}}, </span>{{item.serving_qty || 1 }} {{item.serving_unit | cut:true:32:\'...\' || item.food_name}}</span>\n              </div>\n            </div>\n            <div class="foodlog-calories with-label">\n              <span> {{item.nf_calories | caloriesFilter | number: 0}} </span>\n              <span class="calories-label"> cal </span>\n            </div>\n          </div>\n        </ion-item>\n        <div\n          class="show-more"\n          ng-if="!autocompleteView.additionToLimit && !!selectedFilter &&\n          ((selectedFilter==\'users_foods\' && filteredCustomFoods.length + filteredRecipes.length > 6) ||\n          (selectedFilter==\'Common\' && data.instant.common.length > autocompleteView.commonLimit) ||\n          (selectedFilter==\'Branded\' && data.instant.branded.length > autocompleteView.commonLimit))"\n          ng-click="autocompleteView.additionToLimit = 10">\n          Show More Results &nbsp; <i class="fa fa-angle-down" aria-hidden="true"></i>\n        </div>\n        <div class="show-more" ng-if="data.instant.branded.length && !showFullBranded && !selectedFilter" ng-click="showMoreBranded()">\n          Show More Results &nbsp; <i class="fa fa-angle-down" aria-hidden="true"></i>\n        </div>\n        <ion-item ng-if="!!selectedFilter && data.search.length &&\n          ((selectedFilter==\'users_foods\' && (filteredCustomFoods.length + filteredRecipes.length == 0) && !data.instant.self.length) ||\n          (selectedFilter==\'Common\' && !data.instant.common.length) ||\n          (selectedFilter==\'Branded\' && !data.instant.branded.length))\n          ">\n          <div class="foodlog-item-container">\n            <div style="line-height: 35px;font-style:italic;text-align: center;">No matching foods found</div>\n          </div>\n        </ion-item>\n        <ion-item class="item-divider" style="border:none;" ng-if="data.search.length && !boostFreeform && (!selectedFilter || selectedFilter == \'Freeform\')">\n          Freeform\n        </ion-item>\n        <ion-item ng-if="data.search.length && !boostFreeform && (!selectedFilter || selectedFilter == \'Freeform\')" ng-click="addCommonFood(data.search, true)">\n          <div class="foodlog-item-container">\n            <div style="line-height: 35px"> {{data.search}} </div>\n          </div>\n        </ion-item>\n      </ion-list>\n    </div>\n    <div ng-if="showAutocomplete && !loading" class="padding ">\n      <button class="button button-block button-balanced " ng-click="goToSmart() ">\n        Browse All Foods\n      </button>\n      <button class="button button-block button-balanced " ng-click="goToCustomFood() ">\n        Create custom food\n      </button>\n    </div>\n  </div>\n</ion-content>\n');
  $templateCache.put('templates/views/directives/mealBuilder.html', '<ion-footer-bar on-touch="goToReviewFoods()" class="bar-dark meal-builder-footer" ng-class="flashActive">\n  <div class="meal-builder-title " ng-click="goToReviewFoods()"> Review <span class="green"> {{$root.itemsInBuilder.length}} </span> Foods </div>\n  <div class="meal-builder-calories" ng-click="goToReviewFoods()" >\n    <span class="green total-mealbuilder-calories" count-up="{{itemsInBuilderCalories | caloriesFilter}}" value="0" duration="0.2"></span>\n    <span class="calories-label"> cal </span>\n  </div>\n  <div class="meal-builder-icon">\n  <i class="ion-chevron-right" > </i>\n  </div>\n</ion-footer-bar>\n');
  $templateCache.put('templates/views/directives/weightGraph.html', '<div class="weight-graph">\n  <div class="panel panel-default panel-chart">\n    <div class="panel-heading">\n      <div><strong>Weight Graph</strong></div>\n    </div>\n    <div class="panel-body">\n      <form class="form" ng-if="!$root.noInternet">\n        <div class="list">\n          <label class="item item-select">\n            <span class="select-label">Interval</span>\n            <select ng-model="vm.interval"\n                    ng-options="+index as label for (index, label) in intervals"\n                    ng-change="setInterval()">\n              <option value="">-- Set Interval --</option>\n            </select>\n          </label>\n          <label ng-click="showDatePicker(\'begin\')" class="item item-input item-icon-right" >\n            <span class="input-label">From</span>\n            <span>{{begin.value | amDateFormat: \'MM/DD/YYYY\'}}</span>\n            <i class="icon ion-calendar"></i>\n          </label>\n          <label ng-click="showDatePicker(\'end\')" class="item item-input item-icon-right" >\n            <span class="input-label">To</span>\n            <span>{{end.value | amDateFormat: \'MM/DD/YYYY\'}}</span>\n            <i class="icon ion-calendar"></i>\n          </label>\n        </div>\n      </form>\n      <div class="item text-center" ng-if="!chartLineLabels.length && !$root.noInternet">No data has been tracked for this period</div>\n      <div class="item text-center" ng-if="$root.noInternet">Weight graph is not available in offline mode.</div>\n    </div>\n    <div class="panel-body" ng-if="chartLineLabels.length && !$root.noInternet">\n      <div class="item">\n        <div class="status">\n          <div class="row">\n            <div class="col-33">\n              <strong>{{stats.startValue}} {{weightUnit}}</strong>\n              Start\n            </div>\n            <div class="col-33">\n              <strong>{{stats.endValue}} {{weightUnit}}</strong>\n              {{stats.endText}}\n            </div>\n            <div class="col-33">\n              <strong class="weight-change">\n                <span class="fa"\n                      ng-class="{\n                        \'fa-arrow-down\': stats.change < 0,\n                        \'fa-arrow-up\': stats.change > 0,\n                        \'fa-minus\': stats.change == 0\n                      }"\n                      aria-hidden="true"></span>\n                {{stats.change}} {{weightUnit}}\n              </strong>\n            Change ({{stats.changePercentage > 0 ? \'+\' : \'\'}}{{stats.changePercentage | abs}}%)\n            </div>\n          </div>\n        </div>\n        <canvas class="chart chart-line"\n                chart-options="chartLineOptions"\n                chart-data="chartLineCharts"\n                chart-labels="chartLineLabels"\n                chart-legend="false"\n                chart-series="chartLineSeries"\n                chart-colours="chartLineColours"\n                chart-click="clickHandler"\n                chart-dataset-override="datasetOverride"\n                >\n        </canvas>\n      </div>\n    </div>\n  </div>\n</div>\n');
  $templateCache.put('templates/views/directives/whenModule.html', '<div class="row" ng-click=\'whenSection.toggleWhenSection()\'>\n  <div class="col col-75" style="padding-left: 7px; white-space: normal;">\n    <strong>When:</strong> {{displayDay}}, <span style="display:inline-block">{{whenSection.convertMealTimeString(displayMeal)}}</span>\n  </div>\n  <div class="col col-25 text-right"  style="padding-right: 7px">\n    <i class="icon ion-edit" style="font-size:15px"></i>\n  </div>\n</div>\n<div ng-show=\'whenSection.show\' class="ng-hide">\n  <div class="padding when-buttons">\n    <div class="button-bar bar-stable">\n      <a class=\'button button-small\' ng-repeat="(key, mealTimeTemplate) in whenSection.mealTimeTemplates" ng-if="key === \'breakfast\' || key === \'lunch\' || key === \'dinner\'" ng-class=\'{active: mealTimeTemplate.selected}\' ng-click=\'whenSection.changeActiveMealTimeTemplate(key)\'>{{mealTimeTemplate.title}}</a>\n    </div>\n    <div class="button-bar bar-stable">\n      <a class=\'button button-small\' ng-repeat=\'(key, mealTimeTemplate) in whenSection.mealTimeTemplates\' ng-if="key === \'morningsnack\' || key === \'afternoonsnack\' || key === \'eveningsnack\'" ng-class=\'{active: mealTimeTemplate.selected}\' ng-click=\'whenSection.changeActiveMealTimeTemplate(key)\'>{{mealTimeTemplate.title}}</a>\n    </div>\n  </div>\n  <div class="padding">\n    <div class="button-bar bar-stable">\n      <a class=\'button button-small icon-small\' ng-repeat=\'(key, mealDateTemplate) in whenSection.mealDateTemplates\' ng-class=\'{active: mealDateTemplate.selected, "ion-calendar": key === "customday"}\' ng-click=\'whenSection.changeActiveMealDateTemplate(key)\'>\n            {{mealDateTemplate.title}}\n      </a>\n    </div>\n  </div>\n</div>\n');
}]);